|     |     |
| --- | --- |
| ![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image001.png) |  |

|     |
| --- |
| Volume A: <br>Definition of the **CIDOC Conceptual**<br>**Reference Model** |

Produced by the CIDOC
CRM

Special Interest Group

Version 7.1.3

February 2024

Editors: Chryssoula Bekiari, George
Bruseker, Erin Canning, Martin Doerr,

Philippe Michon, Christian-Emil Ore, Stephen Stead, Athanasios Velios

CC BY 4.0 ![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image002.jpg) 2022 Individual Contributors
to CIDOC CRM 7.1.3

This page is
left blank on purpose

**Table of Contents**

[Introduction............................................................................................................................................................................................. 9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012062)

[Objectives of the\\
CIDOC CRM.................................................................................................................................................... 9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012063)

[Scope of the CIDOC\\
CRM.......................................................................................................................................................... 10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012064)

[Compatibility with\\
the CIDOC CRM........................................................................................................................................ 11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012065)

[Terminology.................................................................................................................................................................................... 11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012066)

[Applied Form................................................................................................................................................................................. 19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012067)

[Naming Conventions................................................................................................................................................... 20](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012068)

[Inheritance and\\
Transitivity........................................................................................................................................ 21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012069)

[Shortcuts......................................................................................................................................................................... 21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012070)

[About the logical\\
expressions used in the CIDOC CRM...................................................................................... 21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012071)

[Property Quantifiers..................................................................................................................................................... 23](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012072)

[Modelling principles........................................................................................................................................................................... 25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012073)

[Reality, Knowledge\\
Bases and CIDOC CRM.......................................................................................................................... 25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012074)

[Authorship of\\
Knowledge Base Contents................................................................................................................................. 26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012075)

[Extensions of CIDOC\\
CRM........................................................................................................................................................ 27](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012076)

[Minimality...................................................................................................................................................................................... 29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012077)

[Monotonicity.................................................................................................................................................................................. 29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012078)

[Disjointness.................................................................................................................................................................................... 31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012079)

[Introduction to the\\
basic concepts..................................................................................................................................................... 33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012080)

[Relations with\\
Events................................................................................................................................................................... 34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012081)

[Spatial Relations........................................................................................................................................................... 37](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012082)

[Temporal Relations...................................................................................................................................................... 39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012083)

[Spatiotemporal\\
Relations............................................................................................................................................ 40](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012084)

[Specific Modelling\\
Constructs.................................................................................................................................................... 42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012085)

[About Types................................................................................................................................................................... 42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012086)

[Temporal Relation\\
Primitives based on fuzzy boundaries.................................................................................... 43](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012087)

[Class & Property\\
Hierarchies............................................................................................................................................................ 47](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012088)

[CIDOC CRM Class\\
Hierarchy.................................................................................................................................................... 48](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012089)

[CIDOC CRM Property\\
Hierarchy.............................................................................................................................................. 51](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012090)

[CIDOC CRM Properties\\
of Properties (.1 Properties)........................................................................................... 54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012091)

[CIDOC CRM Class\\
Declarations...................................................................................................................................................... 56](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012092)

[E1 CRM Entity.............................................................................................................................................................................. 57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012093)

[E2 Temporal Entity....................................................................................................................................................................... 57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012094)

[E3 Condition State........................................................................................................................................................................ 58](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012095)

[E4 Period......................................................................................................................................................................................... 59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012096)

[E5 Event.......................................................................................................................................................................................... 60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012097)

[E6 Destruction................................................................................................................................................................................ 62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012098)

[E7 Activity...................................................................................................................................................................................... 62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012099)

[E8 Acquisition................................................................................................................................................................................ 63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012100)

[E9 Move.......................................................................................................................................................................................... 65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012101)

[E10 Transfer of\\
Custody.............................................................................................................................................................. 65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012102)

[E11 Modification........................................................................................................................................................................... 66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012103)

[E12 Production............................................................................................................................................................................... 67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012104)

[E13 Attribute\\
Assignment............................................................................................................................................................ 68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012105)

[E14 Condition\\
Assessment.......................................................................................................................................................... 69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012106)

[E15 Identifier\\
Assignment........................................................................................................................................................... 69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012107)

[E16 Measurement.......................................................................................................................................................................... 70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012108)

[E17 Type Assignment................................................................................................................................................................... 71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012109)

[E18 Physical Thing....................................................................................................................................................................... 71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012110)

[E19 Physical Object...................................................................................................................................................................... 72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012111)

[E20 Biological\\
Object................................................................................................................................................................... 73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012112)

[E21 Person...................................................................................................................................................................................... 73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012113)

[E22 Human-Made\\
Object............................................................................................................................................................ 74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012114)

[E24 Physical\\
Human-Made Thing.............................................................................................................................................. 74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012115)

[E25 Human-Made\\
Feature........................................................................................................................................................... 75](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012116)

[E26 Physical\\
Feature..................................................................................................................................................................... 76](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012117)

[E27 Site........................................................................................................................................................................................... 76](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012118)

[E28 Conceptual\\
Object................................................................................................................................................................. 77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012119)

[E29 Design or\\
Procedure............................................................................................................................................................. 78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012120)

[E30 Right........................................................................................................................................................................................ 79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012121)

[E31 Document................................................................................................................................................................................ 79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012122)

[E32 Authority\\
Document............................................................................................................................................................. 79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012123)

[E33 Linguistic\\
Object................................................................................................................................................................... 80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012124)

[E34 Inscription............................................................................................................................................................................... 81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012125)

[E35 Title.......................................................................................................................................................................................... 81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012126)

[E36\\
Visual Item.............................................................................................................................................................................. 82](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012127)

[E37 Mark........................................................................................................................................................................................ 82](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012128)

[E39 Actor........................................................................................................................................................................................ 83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012129)

[E41 Appellation............................................................................................................................................................................. 83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012130)

[E42 Identifier................................................................................................................................................................................. 85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012131)

[E52 Time-Span............................................................................................................................................................................... 85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012132)

[E53 Place........................................................................................................................................................................................ 87](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012133)

[E54 Dimension............................................................................................................................................................................... 88](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012134)

[E55 Type......................................................................................................................................................................................... 89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012135)

[E56 Language................................................................................................................................................................................. 89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012136)

[E57 Material................................................................................................................................................................................... 90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012137)

[E58 Measurement Unit................................................................................................................................................................. 90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012138)

[E59 Primitive Value...................................................................................................................................................................... 91](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012139)

[E60 Number................................................................................................................................................................................... 92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012140)

[E61 Time Primitive....................................................................................................................................................................... 92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012141)

[E62 String....................................................................................................................................................................................... 93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012142)

[E63 Beginning of\\
Existence........................................................................................................................................................ 93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012143)

[E64 End of Existence.................................................................................................................................................................... 94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012144)

[E65 Creation................................................................................................................................................................................... 94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012145)

[E66 Formation................................................................................................................................................................................ 95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012146)

[E67 Birth......................................................................................................................................................................................... 95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012147)

[E68 Dissolution.............................................................................................................................................................................. 96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012148)

[E69 Death....................................................................................................................................................................................... 96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012149)

[E70 Thing........................................................................................................................................................................................ 97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012150)

[E71 Human-Made Thing.............................................................................................................................................................. 97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012151)

[E72 Legal Object........................................................................................................................................................................... 98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012152)

[E73 Information\\
Object................................................................................................................................................................ 98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012153)

[E74 Group....................................................................................................................................................................................... 99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012154)

[E77 Persistent Item..................................................................................................................................................................... 100](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012155)

[E78 Curated Holding.................................................................................................................................................................. 101](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012156)

[E79 Part Addition........................................................................................................................................................................ 102](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012157)

[E80 Part Removal....................................................................................................................................................................... 103](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012158)

[E81 Transformation.................................................................................................................................................................... 103](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012159)

[E83 Type Creation....................................................................................................................................................................... 104](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012160)

[E85 Joining................................................................................................................................................................................... 105](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012161)

[E86 Leaving................................................................................................................................................................................. 105](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012162)

[E87 Curation\\
Activity................................................................................................................................................................. 106](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012163)

[E89 Propositional\\
Object........................................................................................................................................................... 106](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012164)

[E90 Symbolic Object.................................................................................................................................................................. 107](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012165)

[E92 Spacetime Volume.............................................................................................................................................................. 108](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012166)

[E93 Presence................................................................................................................................................................................ 109](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012167)

[E94 Space Primitive................................................................................................................................................................... 109](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012168)

[E95\\
Spacetime Primitive............................................................................................................................................................ 110](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012169)

[E96 Purchase................................................................................................................................................................................ 111](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012170)

[E97 Monetary Amount............................................................................................................................................................... 112](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012171)

[E98 Currency................................................................................................................................................................................ 112](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012172)

[E99 Product Type........................................................................................................................................................................ 113](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012173)

[CIDOC CRM Property\\
Declarations.............................................................................................................................................. 114](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012174)

[P1 is identified by\\
(identifies)................................................................................................................................................... 115](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012175)

[P2 has type (is type\\
of)............................................................................................................................................................... 116](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012176)

[P3 has\\
note.................................................................................................................................................................................... 116](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012177)

[P4 has time-span (is\\
time-span of)........................................................................................................................................... 117](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012178)

[P5 consists of\\
(forms part of).................................................................................................................................................... 118](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012179)

[P7 took place at\\
(witnessed)...................................................................................................................................................... 118](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012180)

[P8 took place on or\\
within (witnessed).................................................................................................................................... 119](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012181)

[P9 consists of\\
(forms part of).................................................................................................................................................... 120](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012182)

[P10 falls within\\
(contains)......................................................................................................................................................... 120](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012183)

[P11 had participant\\
(participated in)........................................................................................................................................ 121](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012184)

[P12 occurred in the\\
presence of (was present at).................................................................................................................. 122](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012185)

[P13 destroyed (was\\
destroyed by)............................................................................................................................................ 122](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012186)

[P14 carried out by\\
(performed)................................................................................................................................................. 123](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012187)

[P15 was influenced\\
by (influenced)......................................................................................................................................... 124](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012188)

[P16 used specific\\
object (was used for).................................................................................................................................. 124](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012189)

[P17 was motivated by\\
(motivated)........................................................................................................................................... 125](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012190)

[P19 was intended use\\
of (was made for):............................................................................................................................... 126](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012191)

[P20 had specific\\
purpose (was purpose of)............................................................................................................................ 126](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012192)

[P21 had general\\
purpose (was purpose of)............................................................................................................................. 127](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012193)

[P22 transferred\\
title to (acquired title through)...................................................................................................................... 128](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012194)

[P23 transferred\\
title from (surrendered title through)........................................................................................................... 128](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012195)

[P24 transferred\\
title of (changed ownership through).......................................................................................................... 129](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012196)

[P25 moved (moved by).............................................................................................................................................................. 129](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012197)

[P26 moved to (was\\
destination of)........................................................................................................................................... 130](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012198)

[P27 moved from (was\\
origin of)............................................................................................................................................... 130](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012199)

[P28 custody\\
surrendered by (surrendered custody through)............................................................................................... 131](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012200)

[P29 custody received\\
by (received custody through)........................................................................................................... 131](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012201)

[P30 transferred\\
custody of (custody transferred through).................................................................................................... 132](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012202)

[P31 has modified\\
(was modified by)....................................................................................................................................... 132](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012203)

[P32 used general\\
technique (was technique of)..................................................................................................................... 133](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012204)

[P33 used specific\\
technique (was used by)............................................................................................................................. 134](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012205)

[P34 concerned (was\\
assessed by)............................................................................................................................................. 134](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012206)

[P35 has identified\\
(was identified by)..................................................................................................................................... 135](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012207)

[P37 assigned (was\\
assigned by)................................................................................................................................................ 135](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012208)

[P38 deassigned (was\\
deassigned by)....................................................................................................................................... 136](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012209)

[P39 measured (was\\
measured by)............................................................................................................................................ 137](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012210)

[P40 observed\\
dimension (was observed in)........................................................................................................................... 137](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012211)

[P41 classified (was\\
classified by)............................................................................................................................................. 138](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012212)

[P42 assigned (was\\
assigned by)................................................................................................................................................ 139](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012213)

[P43 has dimension\\
(is dimension of)....................................................................................................................................... 139](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012214)

[P44 has condition\\
(is condition of).......................................................................................................................................... 140](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012215)

[P45 consists of (is\\
incorporated in).......................................................................................................................................... 140](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012216)

[P46 is composed of\\
(forms part of).......................................................................................................................................... 141](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012217)

[P48 has preferred\\
identifier (is preferred identifier of)........................................................................................................ 142](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012218)

[P49 has former or\\
current keeper (is former or current keeper of)..................................................................................... 142](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012219)

[P50 has current\\
keeper (is current keeper of)......................................................................................................................... 143](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012220)

[P51 has former or\\
current owner (is former or current owner of)...................................................................................... 144](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012221)

[P52 has current\\
owner (is current owner of).......................................................................................................................... 144](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012222)

[P53 has former or\\
current location (is former or current location of)................................................................................ 145](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012223)

[P54\\
has current permanent location (is current permanent location of)............................................................................ 146](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012224)

[P55 has current\\
location (currently holds).............................................................................................................................. 146](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012225)

[P56 bears feature\\
(is found on)................................................................................................................................................. 147](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012226)

[P57 has number of\\
parts............................................................................................................................................................. 148](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012227)

[P59 has section (is\\
located on or within)................................................................................................................................ 148](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012228)

[P62 depicts (is\\
depicted by)....................................................................................................................................................... 149](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012229)

[P65 shows visual\\
item (is shown by)....................................................................................................................................... 150](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012230)

[P67 refers to (is\\
referred to by)................................................................................................................................................. 150](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012231)

[P68 foresees use of\\
(use foreseen by)...................................................................................................................................... 151](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012232)

[P69 has association\\
with (is associated with)......................................................................................................................... 152](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012233)

[P70\\
documents (is documented in).......................................................................................................................................... 153](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012234)

[P71 lists (is listed\\
in).................................................................................................................................................................. 153](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012235)

[P72 has language (is\\
language of)............................................................................................................................................ 154](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012236)

[P73 has translation\\
(is translation of)...................................................................................................................................... 154](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012237)

[P74 has current or\\
former residence (is current or former residence of)........................................................................... 155](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012238)

[P75 possesses (is\\
possessed by)................................................................................................................................................ 155](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012239)

[P76 has contact\\
point (provides access to)............................................................................................................................. 155](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012240)

[P79 beginning is\\
qualified by.................................................................................................................................................... 156](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012241)

[P80 end is qualified\\
by............................................................................................................................................................... 156](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012242)

[P81 ongoing\\
throughout............................................................................................................................................................. 157](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012243)

[P82 at some time\\
within............................................................................................................................................................. 158](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012244)

[P86 falls within\\
(contains)......................................................................................................................................................... 158](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012245)

[P89\\
falls within (contains)......................................................................................................................................................... 159](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012246)

[P90 has value............................................................................................................................................................................... 159](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012247)

[P91 has unit (is\\
unit of).............................................................................................................................................................. 160](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012248)

[P92 brought into\\
existence (was brought into existence by)............................................................................................... 160](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012249)

[P93 took out of\\
existence (was taken out of existence by).................................................................................................. 161](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012250)

[P94 has created (was\\
created by).............................................................................................................................................. 162](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012251)

[P95 has formed (was\\
formed by).............................................................................................................................................. 162](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012252)

[P96 by mother (gave\\
birth)........................................................................................................................................................ 163](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012253)

[P97 from father (was\\
father for)............................................................................................................................................... 163](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012254)

[P98 brought into\\
life (was born)............................................................................................................................................... 164](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012255)

[P99 dissolved (was\\
dissolved by)............................................................................................................................................. 164](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012256)

[P100 was death of\\
(died in)....................................................................................................................................................... 165](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012257)

[P101 had as general\\
use (was use of)...................................................................................................................................... 165](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012258)

[P102 has title (is\\
title of)............................................................................................................................................................ 166](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012259)

[P103 was intended\\
for (was intention of)............................................................................................................................... 167](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012260)

[P104 is subject to\\
(applies to)................................................................................................................................................... 167](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012261)

[P105 right held by\\
(has right on).............................................................................................................................................. 168](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012262)

[P106 is composed of\\
(forms part of)....................................................................................................................................... 168](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012263)

[P107 has current or\\
former member (is current or former member of)............................................................................. 169](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012264)

[P108 has produced (was\\
produced by).................................................................................................................................... 171](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012265)

[P109 has current or\\
former curator (is current or former curator of)................................................................................. 171](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012266)

[P110 augmented (was\\
augmented by)..................................................................................................................................... 172](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012267)

[P111 added (was\\
added by)....................................................................................................................................................... 172](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012268)

[P112 diminished (was\\
diminished by)..................................................................................................................................... 173](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012269)

[P113 removed (was\\
removed by)............................................................................................................................................. 173](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012270)

[P121 overlaps with...................................................................................................................................................................... 174](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012271)

[P122\\
borders with....................................................................................................................................................................... 175](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012272)

[P123 resulted in\\
(resulted from)............................................................................................................................................... 175](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012273)

[P124 transformed\\
(was transformed by)................................................................................................................................. 176](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012274)

[P125 used object of\\
type (was type of object used in).......................................................................................................... 177](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012275)

[P126 employed (was\\
employed in).......................................................................................................................................... 177](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012276)

[P127 has broader\\
term (has narrower term)........................................................................................................................... 178](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012277)

[P128 carries (is\\
carried by)........................................................................................................................................................ 178](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012278)

[P129 is about (is\\
subject of)...................................................................................................................................................... 179](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012279)

[P130 shows features\\
of (features are also found on)............................................................................................................. 179](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012280)

[P132\\
spatiotemporally overlaps with....................................................................................................................................... 180](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012281)

[P133 is\\
spatiotemporally separated from................................................................................................................................ 181](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012282)

[P134 continued (was\\
continued by)......................................................................................................................................... 182](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012283)

[P135 created type\\
(was created by).......................................................................................................................................... 183](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012284)

[P136 was based on\\
(supported type creation)........................................................................................................................ 183](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012285)

[P137 exemplifies (is\\
exemplified by)...................................................................................................................................... 184](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012286)

[P138 represents (has\\
representation)....................................................................................................................................... 184](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012287)

[P139 has alternative\\
form (is alternative form of)................................................................................................................. 185](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012288)

[P140 assigned\\
attribute to (was attributed by)....................................................................................................................... 186](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012289)

[P141 assigned (was\\
assigned by)............................................................................................................................................. 187](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012290)

[P142 used\\
constituent (was used in)........................................................................................................................................ 187](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012291)

[P143 joined (was\\
joined by)...................................................................................................................................................... 188](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012292)

[P144 joined with\\
(gained member by).................................................................................................................................... 189](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012293)

[P145 separated (left\\
by)............................................................................................................................................................. 190](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012294)

[P146 separated from\\
(lost member by)................................................................................................................................... 190](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012295)

[P147 curated (was\\
curated by).................................................................................................................................................. 191](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012296)

[P148 has component\\
(is component of).................................................................................................................................. 192](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012297)

[P150 defines typical\\
parts of (defines typical wholes for)................................................................................................... 192](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012298)

[P151 was formed from\\
(participated in)................................................................................................................................. 193](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012299)

[P152 has parent (is\\
parent of)................................................................................................................................................... 193](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012300)

[P156 occupies (is\\
occupied by)................................................................................................................................................ 194](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012301)

[P157 is at rest\\
relative to (provides reference space for)..................................................................................................... 195](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012302)

[P160 has temporal\\
projection (is temporal projection of).................................................................................................... 196](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012303)

[P161 has spatial\\
projection (is spatial projection of)............................................................................................................ 196](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012304)

[P164 is temporally\\
specified by (temporally specifies)....................................................................................................... 197](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012305)

[P165 incorporates\\
(is incorporated in).................................................................................................................................... 198](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012306)

[P166 was a presence\\
of (had presence)................................................................................................................................... 199](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012307)

[P167 was within\\
(includes)....................................................................................................................................................... 199](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012308)

[P168 place is\\
defined by (defines place)................................................................................................................................. 200](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012309)

[P169 defines\\
spacetime volume (spacetime volume is defined by)................................................................................... 201](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012310)

[P170 defines time\\
(time is defined by).................................................................................................................................... 201](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012311)

[P171 at some place\\
within......................................................................................................................................................... 202](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012312)

[P172\\
contains............................................................................................................................................................................... 202](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012313)

[P173 starts before\\
or with the end of (ends after or with the start of)................................................................................ 203](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012314)

[P174 starts before\\
the end of (ends after the start of)........................................................................................................... 204](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012315)

[P175 starts before\\
or with the start of (starts after or with the start of)............................................................................. 205](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012316)

[P176 starts before\\
the start of (starts after the start of)......................................................................................................... 206](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012317)

[P177 assigned\\
property of type (is type of property assigned)........................................................................................... 207](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012318)

[P179 had sales price\\
(was sales price of)................................................................................................................................ 208](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012319)

[P180 has currency\\
(was currency of)....................................................................................................................................... 209](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012320)

[P182 ends before or\\
with the start of (starts after or with the end of)................................................................................ 209](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012321)

[P183 ends before the\\
start of (starts after the end of)........................................................................................................... 210](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012322)

[P184 ends before or\\
with the end of (ends with or after the end of).................................................................................. 211](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012323)

[P185 ends before the\\
end of (ends after the end of).............................................................................................................. 212](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012324)

[P186 produced thing\\
of product type (is produced by)........................................................................................................ 213](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012325)

[P187 has production\\
plan (is production plan for)................................................................................................................ 214](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012326)

[P188 requires\\
production tool (is production tool for)......................................................................................................... 214](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012327)

[P189 approximates\\
(is approximated by)................................................................................................................................ 215](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012328)

[P190 has symbolic\\
content........................................................................................................................................................ 216](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012329)

[P191 had duration\\
(was duration of)........................................................................................................................................ 217](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012330)

[P195 was a presence\\
of (had presence)................................................................................................................................... 217](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012331)

[P196 defines (is\\
defined by)...................................................................................................................................................... 218](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012332)

[P197 covered parts\\
of (was partially covered by)................................................................................................................. 218](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012333)

[P198 holds or\\
supports (is held or supported by).................................................................................................................. 219](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012334)

[Works Cited........................................................................................................................................................................................ 221](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012335)

[Appendix............................................................................................................................................................................................. 231](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012336)

[Deprecated classes and\\
properties............................................................................................................................................ 231](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012337)

[Deprecated Class\\
Migration Instructions............................................................................................................... 231](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012338)

[Deprecated Property\\
Migration Instructions......................................................................................................... 232](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012339)

[Amendments................................................................................................................................................................................ 234](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_Toc106012340)

**Table of Tables**

Table 1: Symbolic Operators in First-Order
Logic Representation............................................................................... 22

Table 2: Temporal Relation Primitives................................................................................................................................ 46

Table 3: CIDOC CRM Class Hierarchy.............................................................................................................................. 48

Table 4: CIDOC CRM Property Hierarchy........................................................................................................................ 51

Table 5: CIDOC CRM Properties of Properties
(.1 Properties) Hierarchy................................................................... 54

Table 6: Deprecated Class Migration
Instructions.......................................................................................................... 231

Table 7: Deprecated Property Migration
Instructions.................................................................................................... 232

**Table**
**of Figures**

Figure 1: High Level Properties and Classes of
CIDOC CRM...................................................................................... 35

Figure 2: CIDOC CRM Encoding Example
(Winkelmann seeing Laocoön).............................................................. 36

Figure 3: Symbolic Representation of
"Winkelmann seeing Laocoön" as an Evolution in Space and Time......... 37

Figure 4: Basic CIDOC CRM Properties and
Classes for Reasoning about Spatial Information............................ 38

Figure 5: Basic CIDOC CRM Properties and
Classes for Reasoning about Temporal Information........................ 39

Figure 6: Basic CIDOC CRM Properties and
Classes for Reasoning with Spacetime Volumes.............................. 41

Figure 7: Explanation of Interior and Boundary
and an Example of Use from P174 starts before the end of (ends after the start
of)..................................................................................................................................................................................................... 45

Figure 8: Temporal entity A starts before or
with the end of temporal entity B. Here A is longer than B............ 203

Figure 9: Temporal entity A starts before or
with the end of temporal entity B. Here A is shorter than B........... 204

Figure 10: Temporal entity A starts before the
end of temporal entity B. Here A is longer than B....................... 205

Figure 11: Temporal entity A starts before the
end of temporal entity B. Here A is shorter than B....................... 205

Figure 12: Temporal entity A starts before or
with the start of temporal entity B. Here A is longer than B........ 206

Figure 13: Temporal entity A starts before or
with the start of temporal entity B. Here A is shorter than B....... 206

Figure 14: Temporal entity A starts before the
start of temporal entity B. Here A is longer than B...................... 207

Figure 15: Temporal entity A starts before the
start of temporal entity B. Here A is shorter than B..................... 207

Figure 16: Temporal entity A ends before or
with the start of temporal entity B. Here A is longer than B.......... 210

Figure 17: Temporal entity A ends before or
with the start of temporal entity B. Here A is shorter than B......... 210

Figure 18: Temporal entity A ends before the
start of temporal entity B. Here A is longer than B........................ 211

Figure 19: Temporal entity A ends before the
start of temporal entity B. Here A is shorter than B....................... 211

Figure 20: Temporal entity A ends before or
with the end of temporal entity B. Here A is longer than B........... 212

Figure 21: Temporal entity A ends before or
with the end of temporal entity B. Here A is shorter than B.......... 212

Figure 22: Temporal entity A ends before the
end of temporal entity B. Here A is longer than B......................... 213

Figure 23: Temporal entity A ends before the
end of temporal entity B. Here A is shorter than B........................ 213

# Introduction

This document is the formal definition of
the CIDOC Conceptual Reference Model (“CIDOC CRM”), a formal ontology intended
to facilitate the integration, mediation and interchange of heterogeneous
cultural heritage information and similar information from other domains, as
further detailed below. The CRM is the culmination of more than two decades of
standards development work by the International Committee for Documentation
(CIDOC) of the International Council of Museums (ICOM). Work on the CRM itself
began in 1996 under the auspices of the ICOM-CIDOC Documentation Standards
Working Group. Since 2000, development of the CRM has been officially delegated
by ICOM-CIDOC to the CIDOC CRM Special Interest Group (SIG). The SIG, in turn,
collaborates with the ISO working group ISO/TC46/SC4/WG9 to bring the CRM to
the form and status of an International Standard. This set of collaborations
has resulted in the production of ISO 21127:2004, ISO 21127:2014, and ISO
21127:2023, the ISO standard editions of the CIDOC CRM. This collaboration will
be continued in order to support the next update of the ISO standard edition.
The present document belongs to the series of evolving versions of the formal
definition of the CRM, which serve the ISO working group as community draft for
the standard. Eventual minor differences, in semantics and notation, of the ISO
standard text from the present, community CIDOC CRM version, which the ISO
working group requires and implements, will be harmonized in the subsequent
versions of the present, community CIDOC CRM formal definition document.

## Objectives of the CIDOC CRM

The primary role of the CIDOC CRM is to
enable the exchange and integration of information from heterogeneous sources
for the reconstruction and interpretation of the past at a human scale, based
on all kinds of material evidence, including texts, audio-visual material and
oral tradition. It starts from, but is not limited to, the needs of museum
documentation and research based on museum holdings. It aims at providing the
semantic definitions and clarifications needed to transform disparate,
localised information sources into a coherent global resource, be it within a
larger institution, in intranets or on the Internet, and to make it available
for scholarly interpretation and scientific evaluation. These goals determine
the constructs and level of detail of the CIDOC CRM.

More specifically, it defines, in terms
of a formal ontology, the **underlying** **semantics** of database **schemata**
and **structured** documents used in the documentation of cultural heritage
and scientific activities. In particular, it defines the semantics related to
the study of the past and current state of our world, as it is characteristic
for museums, but also or other cultural heritage institutions and disciplines.
It does **not** define any of the **terminology** appearing typically as
data in the respective data structures; it foresees, however, the
characteristic relationships for its use. It does **not** aim at proposing
what cultural heritage institutions should document. Rather, it explains the
logic of what they actually currently document, and thereby enables **semantic**
**interoperability.**

The CIDOC CRM intends, moreover, to
provide a model of the intellectual structure of the respective kinds of
mentioned documentation in logical terms. As such, it has not been optimised
for implementation specific storage and processing factors. Actual system
implementations may lead to solutions where elements and links between relevant
elements of our conceptualizations are no longer explicit in a database or
other structured storage system. For instance, the birth event that connects
elements such as father, mother, birth date, birth place may not appear in the
database, in order to save storage space or response time of the system. The
CIDOC CRM provides a conceptual and technical means to explain how such
apparently disparate entities are semantically and logically interconnected,
and how the ability of the database to answer certain intellectual questions is
affected by the omission of such elements and links.

The CIDOC CRM aims to support the
following specific functionalities:

·Inform developers of information systems as a
guide to good practice in conceptual modelling, in order to effectively
structure and relate information assets of cultural documentation.

·Serve as a common language for domain experts
and IT developers to formulate requirements and to agree on system
functionalities with respect to the correct handling of cultural contents.

·To serve as a formal language for the
identification of common information contents in different data formats; in
particular, to support the implementation of automatic data transformation
algorithms from local to global data structures without loss of meaning. The
latter being useful for data exchange, data migration from legacy systems, data
information integration and mediation of heterogeneous sources.

·To support associative queries against
integrated resources by providing a global model of the basic classes and their
associations to formulate such queries.

·It is further believed that advanced natural
language algorithms and case-specific heuristics can take significant advantage
of the CIDOC CRM to resolve free text information into a formal logical form,
if that is regarded beneficial. The CIDOC CRM is not thought, however, to be a
means to replace scholarly text, rich in meaning, by logical forms, but only a
means to identify related data.

Users of the CIDOC CRM should be aware
that the definition of data entry systems requires support of
community-specific terminology, guidance to what should be documented and in
which sequence, and application-specific consistency controls. The CIDOC CRM
does not provide such notions.

By its very structure and formalism, the
CIDOC CRM is extensible and users are encouraged to create extensions for the
needs of more specialized communities and applications.

## Scope of the CIDOC CRM

The overall scope of the CIDOC CRM can be
summarised in simple terms as the curated, **factual knowledge** about the
past at a human scale.

However, a more detailed and useful
definition can be articulated by defining both the **intended scope**,
a broad and maximally-inclusive definition of general application principles,
and the **practical scope**, which is expressed by the overall scope of a
growing reference set of specific, identifiable documentation standards and practices
that the CIDOC CRM aims to semantically describe, restricted, always, in its
details to the limitations of the Intended Scope.

The reasons for these distinctions
between intended and practical scope are twofold. Firstly, the CIDOC CRM is
developed in a “bottom-up” manner, starting from well-understood, actual, and
widely used concepts of domain experts, which are disambiguated and gradually
generalized as more forms of encoding are encountered. This aims to avoid the
misadaptations and vagueness that can sometimes be found in
introspection-driven attempts to find overarching concepts for such a wide
scope, and provides stability to the generalizations found. Secondly, it is a
means to identify and keep a focus on the concepts most needed by the communities
working in the scope of the CIDOC CRM and to maintain a well-defined agenda for
its evolution.

The intended scope of the CIDOC CRM may,
therefore, be defined as all information required for the exchange and
integration of heterogeneous scientific and scholarly documentation about the
past at a human scale and the available documented and empirical evidence for
this. This definition requires further elaboration:

·The term “scientific and scholarly
documentation” is intended to convey the requirement that the depth and quality
of descriptive information that can be handled by the CIDOC CRM should be
sufficient for serious academic research. This does not mean that information
intended for presentation to members of the general public is excluded, but
rather that the CRM is intended to provide the level of detail and precision
expected and required by museum professionals and researchers in the field.

·As “available documented and material evidence”
are regarded all types of material collected and displayed by museums and
related institutions, as defined by ICOM [\[1\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftn1 ""), and other collections, in-situ objects, sites, monuments and
intangible heritage relating to fields such as social history, ethnography,
archaeology, fine and applied arts, natural history, history of sciences and
technology.

·The concept “documentation” includes the
detailed description of individual items, in situ or within collections, groups
of items, and collections as a whole, as well as practices of intangible
heritage. It pertains to their current state as well as to information about
their past. The CIDOC CRM is specifically intended to cover contextual
information: the historical, geographical and theoretical background that gives
cultural heritage collections much of their cultural significance and value.

·The exchange of relevant information with
libraries and archives, and the harmonisation of the CIDOC CRM with their
models, falls within the intended scope of the CIDOC CRM.

·Information required solely for the administration
and management of cultural institutions, such as information relating to
personnel, accounting, and visitor statistics, falls outside the intended scope
of the CIDOC CRM.

The practical scope [\[2\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftn2 "") of the CIDOC CRM is expressed in terms of the set of reference
standards and de facto standards for documenting factual knowledge that have
been used to guide and validate the CIDOC CRM’s development and its further
evolution. The CRM covers the same domain of discourse as the union of these
reference standards; this means that for data correctly encoded according to
these documentation formats there can be a CIDOC CRM-compatible expression that
conveys the same meaning.

## Compatibility with the CIDOC CRM

Users intending to take advantage of the
semantic interoperability offered by the CIDOC CRM should ensure conformance
with the relevant data structures. Conformance pertains either to data to be
made accessible in an integrated environment or intended for transport to other
environments. Any encoding of data in a formal language that preserves the
relations of the classes, properties, and inheritance rules defined by this
International Standard, is regarded as conformant.

Conformance with the CIDOC CRM does not
require complete matching of all local documentation structures, nor that all
concepts and structures present in this International Standard be implemented.
This International Standard is intended to allow room both for extensions,
needed to capture the full richness of cultural documentation, and for simplification,
in the interests of economy. A system will be deemed partially conformant if it
supports a subset of subclasses and subproperties defined by this International
Standard. Designers of the system should publish details of the constructs that
are supported.

The focus of the CIDOC CRM is the
exchange and mediation of structured information. It does not require the
interpretation of unstructured (free text) information into a structured,
logical form. Unstructured information is supported, but falls outside the
scope of conformance considerations.

Any documentation system will be deemed
conformant with this International Standard, regardless of the internal data
structures it uses; if a deterministic logical algorithm can be constructed,
that transforms data contained in the system into a directly compatible form
without loss of meaning.

No assumptions are made as to the nature
of this algorithm. “Without loss of meaning” signifies that designers and users
of the system are satisfied that the data representation corresponds to the
semantic definitions provided by this International Standard.

## Terminology

The following definitions of key
terminology used in this document are provided both as an aid to readers
unfamiliar with object-oriented modelling terminology, and to specify the
precise usage of terms that are sometimes applied inconsistently across the
object-oriented modelling community for the purpose of this document. Where
applicable, the editors have tried to consistently use terminology that is
compatible with that of the Resource Description Framework (RDF), [\[3\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftn3 "") a recommendation of the World Wide Web Consortium. The editors have
tried to find a language, which is comprehensible to the non-computer expert
and precise enough for the computer expert so that both understand the intended
meaning.

|     |     |
| --- | --- |
| class | A class is a category of items that<br>share one or more common traitsserving as criteria to identify the<br>items belonging to the class. These **properties** need not be explicitly<br>formulated in logical terms, but may be described in a text (here called a **scope**<br>**note**) that refers to a common conceptualisation of domain experts. The<br>sum of these traits is called the **intension** of the class. A class may<br>be the **domain** or **range** of none, one or more properties formally<br>defined in a model. The formally defined properties need not be part of the<br>intension of their domains or ranges: such properties are optional. An item<br>that belongs to a class is called an **instance** of this class. A class<br>is associated with an open set of real-life instances, known as the **extension**<br>of the class. Here “open” is used in the sense that it is generally beyond<br>our capabilities to know all instances of a class in the world and indeed<br>that the future may bring new instances about at any time ( **Open World**).<br>Therefore, a class cannot be defined by enumerating its instances. A class<br>plays a role analogous to a grammatical noun, and can be completely defined<br>without reference to any other construct (unlike properties **,** which<br>must have an unambiguously defined domain and range). In some contexts, the<br>terms individual class, entity or node are used synonymously with class. <br>For example: <br>Person is a class. To be a Person may actually<br>be determined by DNA characteristics, but everyone knows what a Person is. A<br>Person may have the property of being a member of a Group, but it is not<br>necessary to be member of a Group in order to be a Person. It is impossible<br>to know all the "Persons" of the past. There will be more Persons in the future. |
| subclass | A subclass is a **class** that is a<br>specialization of another class (its **superclass**). Specialization or<br>the IsA relationship means that: <br>1all **instances** of the subclass are also<br>instances of its superclass, <br>2the **intension** of the subclass extends<br>the intension of its superclass, i.e., its traits are more restrictive than<br>that of its superclass and <br>3the subclass inherits the definition of all of<br>the **properties** declared for its superclass without exceptions ( **strict**<br>**inheritance**), in addition to having none, one or more properties of its<br>own. <br>A subclass can have more than one<br>immediate superclass and consequently inherits the properties of all of its<br>superclasses ( **multiple inheritance**). The IsA relationship or<br>specialization between two or more classes gives rise to a structure known as<br>a class hierarchy. The IsA relationship is transitive and may not be cyclic.<br>In some contexts (e.g., the programming language C++) the term derived class<br>is used synonymously with subclass. <br>For example:<br>Every Person IsA Biological Object, or<br>Person is a subclass of Biological Object. <br>Also, every Person IsA Actor. A Person<br>may die. However, other kinds of Actors, such as companies, don’t die (c.f.<br>2). <br>Every Biological Object IsA Physical<br>Object. A Physical Object can be moved. Hence, a Person can be moved also<br>(c.f. 3). |
| superclass | A superclass is a **class** that is<br>a generalization of one or more other classes (its **subclasses**), which<br>means that it subsumes all **instances** of its subclasses, and that it<br>can also have additional instances that do not belong to any of its<br>subclasses. The **intension** of the superclass is less restrictive than<br>any of its subclasses. This subsumption relationship or generalization is the<br>inverse of the IsA relationship or specialization.<br>For example:<br>“Biological Object subsumes Person” is<br>synonymous with “Biological Object is a superclass of Person”. It needs fewer<br>traits to identify an item as a Biological Object than to identify it as a<br>Person. |
| intension | The intension of a **class** or **property**<br>is its intended meaning. It consists of one or more common traitsshared<br>by all **instances** of the class or property. These traits need not be<br>explicitly formulated in logical terms, but may just be described in a text<br>(here called a **scope note**) that refers to a conceptualisation common<br>to domain experts. In particular, the so-called **primitive** concepts,<br>which make up most of the CIDOC CRM, cannot be further reduced to other<br>concepts by logical terms. |
| extension | The extension of a **class** is the<br>set of all real-life **instances** belonging to the class that fulfil the<br>criteria of its **intension**. This set is “open” in the sense that it is<br>generally beyond our capabilities to know all instances of a class in the<br>world and indeed that the future may bring new instances about at any time ( **Open**<br>**World**). An information system may at any point in time refer to some<br>instances of a class, which form a subset of its extension. |
| scope note | A scope note is a textual description<br>of the **intension** of a **class** or **property.**<br>Scope notes are not formal modelling<br>constructs, but are provided to help explain the intended meaning and<br>application of the CIDOC CRM’s classes and properties. Basically, they refer<br>to a conceptualisation common to domain experts and disambiguate between<br>different possible interpretations. Illustrative example **instances** of<br>classes and properties are also regularly provided in the scope notes for<br>explanatory purposes. |
| instance | An<br>instance of a **class** is a real-world item that fulfils the criteria of<br>the **intension** of the class. Note, that the number of **instances**<br>declared for a class in an information system is typically less than the<br>total in the real world. For example, you are an instance of Person, but you<br>are not mentioned in all information systems describing Persons.<br>For example:<br>The painting known as the “The Mona<br>Lisa” is an instance of the class E22 Human-Made Object.<br>An instance of a **property** is a<br>factual relation between an instance of the **domain** and an instance of<br>the **range** of the property that matches the criteria of the **intension**<br>of the property.<br>For example:<br>The Mona Lisa _has former or current_<br>_owner._ The Louvre is an instance of the property _P51 has former or_<br>_current owner (is former or current owner of)._ |
| property | A property serves to define a<br>relationship of a specific kind between two **classes.** The property is<br>characterized by an **intension**, which is conveyed by a **scope note.**<br>A property plays a role analogous to a grammatical verb, in that it must be<br>defined with reference to both its **domain** and **range**, which are<br>analogous to the subject and object in grammar (unlike classes, which can be<br>defined independently). It is arbitrary, which class is selected as the<br>domain, just as the choice between active and passive voice in grammar is<br>arbitrary. In other words, a property can be interpreted in both directions,<br>with two distinct, but related interpretations. Properties may themselves<br>have properties that relate to other classes (This feature is used in this<br>model only in order to describe dynamic subtyping of properties). Properties<br>can also be specialized in the same manner as classes, resulting in IsA<br>relationships between **subproperties** and their **superproperties**.<br>In some contexts, the terms attribute,<br>reference, link, role or slot are used synonymously with property.<br>For example:<br>“Physical Human-Made Thing _depicts_ CRM Entity” is equivalent to “CRM Entity _is depicted by_ Physical<br>Human-Made Thing”. |
| inverse of | The inverse of a property is the<br>reinterpretation of a **property** from **range** to **domain**<br>without more general or more specific meaning, similar to the choice between<br>active and passive voice in some languages. In contrast to some knowledge<br>representation languages, such as RDF and OWL, this document regards that the<br>inverse of a property is not a property in its own right that needs an<br>explicit declaration of being inverse of another, but an interpretation<br>implicitly existing for any property. The inverse of the inverse of a<br>property is identical to the property itself, i.e., its primary sense of<br>direction.<br>For example:<br>“CRM Entity _is depicted by_<br>Physical Human-Made Thing” is the inverse of “Physical Human-Made Thing _depicts_ CRM Entity” |
| subproperty | A subproperty is a **property** that<br>is a specialization of another property (its **superproperty**).<br>Specialization or IsA relationship means that: <br>1all **instances** of the subproperty are<br>also instances of its superproperty, <br>2the **intension** of the subproperty<br>extends the intension of the superproperty, i.e., its traits are more<br>restrictive than that of its superproperty, <br>3the **domain** of the subproperty is the<br>same as the domain of its superproperty or a **subclass** of that domain,<br>4the **range** of the subproperty is the<br>same as the range of its superproperty or a subclass of that range,<br>5the subproperty inherits the definition of all<br>of the properties declared for its superproperty without exceptions ( **strict**<br>**inheritance**), in addition to having none, one or more properties of its<br>own.<br>A subproperty can have more than one<br>immediate superproperty and consequently inherits the properties of all of<br>its superproperties ( **multiple inheritance**). The IsA relationship or<br>specialization between two or more properties gives rise to the structure<br>called a property hierarchy. The IsA relationship is transitive and may not<br>be cyclic. <br>Some object-oriented programming<br>languages, such as C++, do not contain constructs that allow for the<br>expression of the specialization of properties as sub-properties.<br>Alternatively, a property may be<br>subproperty of the **inverse of** another property, i.e., reading the<br>property from range to domain. In that case:<br>1all instances of the subproperty are also<br>instances of the inverse of the other property, <br>2the intension of the subproperty extends the<br>intension of the inverse of the other property, i.e., its traits are more<br>restrictive than that of the inverse of the other property, <br>3the domainof the subproperty is the<br>same as the range of the other property or a subclass of that range,<br>4the range of the subproperty is the same as<br>the domain of the other property or a subclass of that domain,<br>5the subproperty inherits the definition of all<br>of the properties declared for the other property without exceptions (strict<br>inheritance), in addition to having none, one or more properties of its own.<br>The definitions of inherited properties have to be interpreted in the inverse<br>sense of direction of the subproperty, i.e., from range to domain. |
| superproperty | A superproperty is a **property**<br>that is a generalization of one or more other properties (its **subproperties**),<br>which means that it subsumes all **instances** of its subproperties, and<br>that it can also have additional instances that do not belong to any of its<br>subproperties. The **intension** of the superproperty is less restrictive<br>than any of its subproperties. The subsumption relationship or generalization<br>is the inverse of the IsA relationship or specialization. A superproperty may<br>be a generalization of the **inverse of** another property. |
| domain | The domain is the **class** for<br>which a **property** is formally defined. This means that **instances**<br>of the property are applicable to instances of its domain class. A property<br>must have exactly one domain, although the domain class may always contain<br>instances for which the property is not instantiated. The domain class is<br>analogous to the grammatical subject of the phrase for which the property is<br>analogous to the verb. It is arbitrary which class is selected as the domain<br>and which as the **range**, just as the choice between active and passive<br>voice in grammar is arbitrary. Property names in the CIDOC CRM are designed<br>to be semantically meaningful and grammatically correct when read from domain<br>to range **.** In addition, the inverse property name, normally given in<br>parentheses, is also designed to be semantically meaningful and grammatically<br>correct when read from range to domain. |
| range | The range is the **class** that<br>comprises all potential values of a **property.** That means that **instances**<br>of the property can link only to instances of its range class. A property<br>must have exactly one range, although the range class may always contain<br>instances that are not the value of the property. The range class is<br>analogous to the grammatical object of a phrase for which the property is analogous<br>to the verb. It is arbitrary which class is selected as **domain** and<br>which as range, just as the choice between active and passive voice in<br>grammar is arbitrary. Property names in the CIDOC CRM are designed to be<br>semantically meaningful and grammatically correct when read from domain to<br>range **.** In addition, the inverse property name, normally given in<br>parentheses, is also designed to be semantically meaningful and grammatically<br>correct when read from range to domain. |
| inheritance | Inheritance of **properties** from **superclasses**<br>to **subclasses** means that if an item x is an **instance** of a **class**<br>A, then:<br>1all properties that must hold for the<br>instances of any of the superclasses of A must also hold for item x, and<br>2all optional properties that may hold for the instances<br>of any of the superclasses of A may also hold for item x. |
| strict <br>inheritance | Strict **inheritance** means that<br>there are no exceptions to the inheritance of **properties** from **superclasses**<br>to **subclasses**. For instance, some systems may declare that elephants<br>are grey, and regard a white elephant as an exception. Under strict<br>inheritance it would hold that: if all elephants were grey, then a white<br>elephant could not be an elephant. Obviously not all elephants are grey. To<br>be grey is not part of the **intension** of the concept elephant but an<br>optional property. The CIDOC CRM applies strict inheritance as a<br>normalization principle. |
| multiple<br>inheritance | Multiple<br>**inheritance** means that a **class** A may have more than one<br>immediate **superclass**. The **extension** of a class with multiple<br>immediate superclasses is a subset of the intersection of all extensions of<br>its superclasses. The **intension** of a class with multiple immediate<br>superclasses extends the intensions of all its superclasses, i.e., its traits<br>are more restrictive than any of its superclasses. If multiple inheritance is<br>used, the resulting “class hierarchy” is a directed graph and not a tree<br>structure. If it is represented as an indented list, there are necessarily<br>repetitions of the same class at different positions in the list.<br>For example:<br>Person is both an Actor and a<br>Biological Object. |
| multiple Instantiation | Multiple<br>**Instantiation** is the term that describes the case that an instance of<br>class A is also regarded as an instance of one or more other classes B1...n<br>at the same time. When multiple instantiation is used, it has the effect that<br>the properties of all these classes become available to describe this<br>instance. For instance, some particular cases of destruction may also be<br>activities (e.g., Herostratos’ deed), but not all destructions are activities<br>(e.g., destruction of Herculaneum). In comparison, multiple inheritance<br>describes the case that all instances of a class A are implicitly instances<br>of all superclasses of A, by virtue of the definition of the class A, whereas<br>the combination of classes used for multiple instantiation is a<br>characteristic of particular instances only. It is important to note that<br>multiple instantiation is not allowed using combinations of disjoint classes. |
| endurant, perdurant | “The<br>difference between enduring and perduring entities (which we shall also call _endurants_ and _perdurants_) is related to their behaviour in time. Endurants<br>are wholly present (i.e., all their proper parts are present) at any time<br>they are present. Perdurants, on the other hand, just extend in time by<br>accumulating different temporal parts, so that, at any time they are present,<br>they are only partially present, in the sense that some of their proper<br>temporal parts (e.g., their previous or future phases) may be not present.<br>E.g., the piece of paper you are reading now is wholly present, while some<br>temporal parts of your reading are not present any more. Philosophers say<br>that endurants are entities that are in time, while lacking however temporal<br>parts (so to speak, all their parts flow with them in time). Perdurants, on<br>the other hand, are entities that happen in time, and can have temporal parts<br>(all their parts are fixed in time).” (Gangemi et al. 2002, pp. 166-181). |
| shortcut | A shortcut is a formally defined single<br>**property** that represents a deduction or join of a data path in the<br>CIDOC CRM. The **scope notes** of all properties characterized as<br>shortcuts describe in words the equivalent deduction. Shortcuts are<br>introduced for the cases where common documentation practice refers only to<br>the deduction rather than to the fully developed path. For example, museums<br>often only record the dimension of an object without documenting the<br>Measurement that observed it. The CIDOC CRM declares shortcuts explicitly as<br>single properties in order to allow the user to describe cases in which he<br>has less detailed knowledge than the full data path would need to be<br>described. For each shortcut, the CIDOC CRM contains in its schema the<br>properties of the full data path explaining the shortcut. |
| monotonic<br>reasoning | Monotonic reasoning is a term from<br>knowledge representation. A reasoning form is monotonic if an addition to the<br>set of propositions making up the knowledge base never determines a decrement<br>in the set of conclusions that may be derived from the knowledge base via<br>inference rules. In practical terms, if experts enter subsequently correct<br>statements to an information system, the system should not regard any results<br>from those statements as invalid, when a new one is entered. The CIDOC CRM is<br>designed for monotonic reasoning and so enables conflict-free merging of huge<br>stores of knowledge. |
| disjoint | **Classes**<br>are disjoint if the intersection of their **extensions** is an empty set.<br>In other words, they have no common **instances** in any possible world. |
| primitive | The term primitive as used in knowledge<br>representation characterizes a concept that is declared and its meaning is<br>agreed upon, but that is not defined by a logical deduction from other<br>concepts. For example, mother may be described as a female human with child.<br>Then mother is not a primitive concept. Event however is a primitive concept.<br> <br>Most of the CIDOC CRM is made up of<br>primitive concepts. |
| Open World | The “Open World Assumption” is a term<br>from knowledge base systems. It characterizes knowledge base systems that<br>assume the information stored is incomplete relative to the universe of<br>discourse they intend to describe. This incompleteness may be due to the<br>inability of the maintainer to provide sufficient information or due to more<br>fundamental problems of cognition in the system’s domain. Such problems are<br>characteristic of cultural information systems. Our records about the past<br>are necessarily incomplete. In addition, there may be items that cannot be<br>clearly assigned to a given **class**. <br>In particular, absence of a certain **property**<br>for an item described in the system does not mean that this item does not<br>have this property. For example, if one item is described as Biological<br>Object and another as Physical Object, this does not imply that the latter<br>may not be a Biological Object as well. Therefore, **complements** of a<br>class with respect to a **superclass** cannot be concluded in general from<br>an information system using the Open World Assumption. For example, one<br>cannot list “all Physical Objects known to the system that are not Biological<br>Objects in the real world”, but one may of course list “all items known to<br>the system as Physical Objects but that are not known to the system as<br>Biological Objects”. |
| complement | Thecomplement of a class A with<br>respect to one of its **superclasses** B is the set of all **instances**<br>of B that are not instances of A. Formally, it is the set-theoretic<br>difference of the **extension** of B minus the extension of A. Compatible<br>extensions of the CIDOC CRM should not declare any **class** with the **intension** of them being the complement of one or more other classes. To do so will<br>normally violate the desire to describe an **Open World**. For example,<br>for all possible cases of human gender, male should not be declared as the<br>complement of female or vice versa. What if someone is both or even of<br>another kind? |
| query containment | Query<br>containment is a problem from database theory: A query X contains another<br>query Y, if for each possible population of a database the answer set to<br>query X contains also the answer set to query Y. If query X and Y were<br>classes, then X would be **superclass** of Y. |
| interoperability | Interoperability means the capability<br>of different information systems to communicate some of their contents. In<br>particular, it may mean that<br>1 two systems can exchange information, and/or <br>2 multiple systems can be accessed with a<br>single method. <br>Generally, syntacticinteroperability<br>is distinguished from **semantic** **interoperability**. Syntactic<br>interoperability means that the information encoding of the involved systems<br>and the access protocols are compatible, so that information can be processed<br>as described above without error. However, this does not mean that each<br>system processes the data in a manner consistent with the intended meaning.<br>For example, one system may use a table called “Actor” and another one called<br>“Agent”. With syntactic interoperability, data from both tables may only be<br>retrieved as distinct, even though they may have exactly the same meaning. To<br>overcome this situation, semantic interoperability has to be added. The CIDOC<br>CRM relies on existing syntactic interoperability and is concerned only with<br>adding _semantic_ _interoperability_. |
| semantic interoperability | Semantic **interoperability** means<br>the capability of different information systems to communicate information<br>consistent with the intended meaning. In more detail, the intended meaning<br>encompasses <br>1the data structure elements involved, <br>2the terminology appearing as data and <br>3the identifiers used in the data for factual<br>items such as places, people, objects etc.<br>Obviously, communication about data<br>structure must be resolved first. In this case consistent communication means<br>that data can be transferred between data structure elements with the same<br>intended meaning or that data from elements with the same intended meaning<br>can be merged. In practice, the different levels of generalization in<br>different systems do not allow the achievement of this ideal. Therefore,<br>semantic interoperability is regarded as achieved if elements can be found<br>that provide a reasonably close generalization for the transfer or merge.<br>This problem is being studied theoretically as the **query containment** problem.<br>The CIDOC CRM is only concerned with semantic interoperability on the level<br>of data structure elements. |
| property quantifier | We<br>use the term "property quantifier" for the declaration of the<br>allowed number of **instances** of a certain **property** that can<br>refer to a particular instance of the **range** class or the **domain**<br>class of that property. These declarations are ontological, i.e., they refer<br>to the nature of the real world described and not to our current knowledge.<br>For example, each person has exactly one father, but collected knowledge may<br>refer to none, one or many. |
| universal | The fundamental ontological distinction<br>between universals and particulars can be informally understood by<br>considering their relationship with instantiation: particulars are entities<br>that have no **instances** in any possible world; universals are entities<br>that do have instances. **Classes** and **properties** (corresponding<br>to predicates in a logical language) are usually considered to be universals.<br>(after Gangemi et al. 2002, pp. 166-181). |
| knowledge creation process | All knowledge contained in an<br>information system must have been introduced into that system by some human<br>agent, either directly or indirectly. Despite this fact, many, if not most,<br>statements within such a system will lack specific attribution of authority.<br>That being said, in the domain of cultural heritage, it is common practice<br>that, for the processes of collection documentation and management, there are<br>clearly and explicitly elaborated systems of responsibility outlining by whom<br>and how knowledge can be added and or modified in the system. Ideally these<br>systems are specified in institutional policy and protocol documents. Thus,<br>it is reasonable to hold that all such statements that lack explicit<br>authority attribution within the information system can, in fact, be read as<br>the official view of the administrating institution of that system. <br>Such a position does not mean to imply<br>that an information system represents at any particular moment a completed<br>phase of knowledge that the institution promotes. Rather, it means to<br>underline that, in a CH context, a managed set of data, at any state of<br>elaboration, will in fact embody an adherence to some explicit code of<br>standards which guarantees the validity of that data within the scope of said<br>standards and all practical limitations. So long as the information is under<br>active management it remains continuously open to revision and improvement as<br>further research reveals further understanding surrounding the objects of<br>concern.<br>A distinct exception to this rule is<br>represented by information in the data set that carries with it an explicit<br>statement of responsibility.<br>In CIDOC CRM such statements of<br>responsibility are expressed through knowledge creation events such as E13<br>Attribute Assignment and its relevant subclasses. Any information in a CIDOC<br>CRM model that is based on an explicit creation event for that piece of<br>information, where the creator’s identity has been given, is attributed to<br>the authority and assigned to the responsibility of the actor identified as<br>causal in that event. For any information in the system connected to<br>knowledge creation events that do not explicitly reference their creator, as<br>well as any information not connected to creation events, the responsibility<br>falls back to the institution responsible for the database/knowledge graph.<br>That means that for information only expressed through shortcuts such as _P2_<br>_has type_, where no knowledge creation event has been explicitly<br>specified, the originating creation event cannot be deduced and the<br>responsibility for the information can never be any other body than the<br>institution responsible for the whole information system.<br>In the case of an institution taking<br>over stewardship of a database transferred into their custody, two relations<br>of responsibility for the knowledge therein can be envisioned. If the<br>institution accepts the dataset and undertakes to maintain and update it,<br>then they take on responsibility for that information and become the default<br>authority behind its statements as described above. If, on the other hand,<br>the institution accepts the data set and stores it without change as a closed<br>resource, then it can be considered that the default authority remains the<br>original steward. |
| transitivity | Transitivity is defined in the standard<br>way found in mathematics or logic: A property P is transitive if the domain<br>and range is the same class and for all instances x, y, z of this class the<br>following is the case: If x is related by P to y and y is related by P to z,<br>then x is related by P to z. The intention of a property as described in the<br>scope note will decide whether a property is transitive or not. For example,<br>the property _P121 overlaps with_ between instances of E53 Place is not<br>transitive, while the property _P89 falls within (contains)_ between<br>instances of E53 Place and the property _P46 is composed of (forms part of)_<br>between instances of E18 Physical Thing are both transitive. Transitivity is<br>especially useful when CIDOC CRM is implemented in a system with deduction. |
| symmetry | Symmetry is defined in the standard way<br>found in mathematics or logic: A property P is symmetric if the domain and<br>range are the same class and for all instances x, y of this class the<br>following is the case: If x is related by P to y, then y is related by P to<br>x. The intention of a property as described in the scope note will decide<br>whether a property is symmetric or not. An example of a symmetric property is<br>E53 Place _. P122 borders with:_ E53 Place. The names of symmetric<br>properties have no parenthetical form, because reading in the range-to-domain<br>direction is the same as the domain-to-range reading. |
| reflexivity | Reflexivity is defined in the standard<br>way found in mathematics or logic: A property P is reflexive if the domain<br>and range are the same class and for all instances x, of this class the<br>following is the case: x is related by P to itself. The intention of a<br>property as described in the scope note will decide whether a property is<br>reflexive or not. An example of a reflexive property is E53 Place _. P89_<br>_falls within (contains):_ E53 Place. |

## Applied Form

The CIDOC CRM is an ontology in the sense
used in computer science. It has been expressed as an object-oriented semantic
model, in the hope that this formulation will be comprehensible to both
documentation experts and information scientists alike, while at the same time
being readily converted to machine-readable formats such as RDF Schema or OWL.
A CRM conformant documentation system can be implemented using RDF Schema or
OWL, but also in Relational or Object-Oriented schema. CIDOC CRM instances can
be encoded in RDF, JSON LD, XML, OWL and others.

More specifically, the CIDOC CRM is
expressed in terms of the primitives of semantic data modelling. As such, it
consists of:

·_classes_, which
represent general notions in the domain of discourse, such as the CIDOC CRM
class E21 Person which represents the notion of person;

·_properties_, which
represent the binary relations that link the individuals in the domain of
discourse, such as the CIDOC CRM property P152 has parent linking a person to
one of the person’s parent.

·_properties of properties_, such as the property _P14.1 in the role of_, of the CIDOC CRM
property P14 carried out by (see also section “About Types”).

They do not appear in the property hierarchy list, but are included as part of
their base property declaration and are referred to in the class declarations.
They all have the implicit quantification “many to many” (see also section
“Property Quantifiers”).

Although the definition of the CIDOC CRM
provided here is complete, it is an intentionally compact and concise
presentation of the CIDOC CRM’s 81 classes and 160 unique properties. It does
not attempt to articulate the inheritance of properties by subclasses
throughout the class hierarchy (this would require the declaration of several
thousand properties, as opposed to 160). However, this definition does contain
all of the information necessary to infer and automatically generate a full
declaration of all properties, including inherited properties.

### Naming Conventions

The following naming conventions have
been applied hereafter:

·Classes are identified by numbers preceded by
the letter “E” (historically, classes were sometimes referred to as
“Entities”), and are named using noun phrases (nominal groups) in title case
(initial capitals). For example, E63 Beginning of Existence.

·Properties
are identified by numbers preceded by the letter “P,” and are named in both
directions, using verbal phrases in lower case. Properties with the character
of states are named in the present tense, such as “has type”, whereas
properties relating to events are named in past tense, such as “carried out”.
For example, _P126 employed (was employed in)_.

·Property names should
be read in their non-parenthetical form for the domain-to-range direction, and
in parenthetical form for the range-to-domain direction. Reading a property in
range-to-domain direction is equivalent to the inverse of that property.
Following a current notational practice in OWL knowledge representation
language, we represent inverse properties in this text by adding a letter “i”
following the identification number and the parenthetical form of the full
property name, such as _P59i is located on or within_, which is the
inverse of _P59 has section (is located on or within)._

·Properties with a range
that is a subclass of E59 Primitive Value (such as E1 CRM Entity _. P3 has_
_note:_ E62 String) have no parenthetical name form because reading the
property name in the range-to-domain direction is not regarded as meaningful.

·Properties that have
identical domain and range are either symmetric or transitive. Instantiating a
symmetric property implies that the relation holds for both the domain-to-range
and the range-to-domain directions. An example of this is E53 Place _. P122_
_borders with:_ E53 Place. The names of symmetric properties have no
parenthetical form, because reading in the range-to-domain direction is the
same as the domain-to-range reading. Transitive asymmetric properties, such as
E4 Period _. P9 consists of (forms part of):_ E4 Period, do have a parenthetical form that relates
to the meaning of the inverse direction.

·The choice of property domains, and hence the
order of their names, is established in accordance with the following priority
list:

-Temporal Entity and its subclasses

-Thing and its subclasses

-Actor and its subclasses

-Other

·Properties of properties are identified by “P”,
followed by the number of the base property extended with “.1” and are
named in one direction using a verbal phrase in lower case in the present
tense. For example: the property _P62.1 mode of depiction_ of the property
_P62 depicts (is depicted by)._

### Inheritance and Transitivity

CIDOC CRM is formulated as a class system
with inheritance. A property P with domain A and range B will also be a
property between any possible subclasses of A and of B. In many cases there
will be a common subclass C of both A and B. In these cases, when the property
is restricted to C, that is, with C as domain and range, the restricted
property could be transitive. For instance, an E73 Information Object can be
incorporated into an E90 Symbolic Object and thus an information object can be
incorporated in another information object.

In the definition of CIDOC CRM the
transitive properties are explicitly marked as such in the scope notes. All
unmarked properties should be considered as not transitive.

### Shortcuts

Some properties are declared as shortcuts
of longer, more comprehensively articulated paths that connect the same domain
and range classes as the shortcut property through one or more intermediate
classes. For example, the property E18 Physical Thing _. P52 has current owner_
_(is current owner of)_:E39 Actor, is a shortcut for a fully
articulated path from E18 Physical Thing through E8 Acquisition to E39 Actor.
An instance of the fully-articulated path always implies an instance of the shortcut
property. However, the inverse may not be true; an instance of the
fully-articulated path cannot always be inferred from an instance of the
shortcut property inside the frame of the actual knowledge base.

The class E13 Attribute Assignment allows
for the documentation of how the assignment of any property came about, and
whose opinion it was, even in cases of properties not explicitly characterized
as “shortcuts”.

### About the logical expressions used in the CIDOC CRM

The present CIDOC CRM specifications are
annotated with logical axioms, providing an additional formal expression of the
CIDOC CRM ontology. This section briefly introduces the assumptions that are at
the basis of the logical expression of the CIDOC CRM (for a fully detailed
account of the logical expression of semantic data modelling, see (Reiter,1984)).

In terms of semantic data modelling, classes and properties are used to express ontological knowledge by
means of various kinds of constraints, such as sub-class/sub-property links,
e.g., E21 Personis a sub-class ofE20 Biological Object, or
domain/range constraints, e.g., the domain of _P152 has parent_ is class
E21 Person _._

In contrast, first-order logic-based
knowledge representation relies on a language for formally encoding an ontology.
This language can be directly put in correspondence with semantic data
modelling in a straightforward way:

·classes are named by _unary predicate symbols_;
conventionally, we use E21as the unary predicate symbol corresponding to class E21 Person;

·properties are named by _binary predicate_
_symbols_; conventionally, we use P152as the binary predicate symbol
corresponding to property _P152 has parent._

·properties of properties, “.1 properties” are
named by _ternary predicate symbols_; conventionally, we use P14.1as the ternary
predicate symbol corresponding to property _P14.1 in_
_the role of._

Ontology is expressed in logic by means
of _logical axioms_, which correspond to the constraints of semantic
modelling. In the definition of classes and properties of the CIDOC CRM, the
axioms are placed under the heading ‘In first-order logic’. There are several
options for writing statements in first-order logic. In this document, a
standard compact notation widely used in text books and scientific papers is
used. The definition is given in table 1 below.

Table 1: Symbolic
Operators In First-Order Logic Representation

|     |     |     |     |
| --- | --- | --- | --- |
| Symbol | Name | Reads | Truth value |
| Operators |  |  |  |
| ∧ | conjunction | and | (φ ∧ ψ) is true<br>if and only<br>if both _φ_ and _ψ_ are true |
| ∨ | disjunction | or | (φ ∨ ψ) is true<br>if and only if at<br>least one of either φ or ψ is true |
| ¬ | negation | not | ¬φ is true if<br>and only if _φ_ is false |
| ⇒ | implication | implies,<br>if … then ... | (φ ⇒ ψ) is true <br>if and only if it<br>is not the case that _φ_ is true and _ψ_ is false |
| ⇔ | equivalence | is equivalent to, <br>if … and only if … | φ ⇔ ψ is true<br>if and only if<br>both _φ_ and _ψ_ are true or<br>both φ and ψ are false |
| Quantifiers |  |  |  |
| ∃ | existential quantifier | exists, <br>there exists at least one |  |
| ∀ | Universal quantifier | forall, <br>for all |  |

For instance, the above sub-class link
between E21 PersonandE20 Biological Object can be formulated in
first-order logic as the axiom:

(∀x) \[E21(x) ⇒E20(x)\]

(reading: for
all individuals x, if x is an E21 then x is an E20).

In the definitions of classes and
properties in this document the universal quantifier(s) are omitted for
simplicity, so the above axiom is simply written:

E21(x) ⇒E20(x)

Likewise, the above domain constraint on
property _P152 has parent_ can be formulated in first-order logic as the
axiom:

P152(x,y) ⇒E21(x)

(reading: for
all individuals x and y, if x is a P152 of y, then x is an E21).

Properties of properties, indicated by a '.1' after the property
number are described as ternary predicate symbols. For example, the
property P14.1 _in the role of_ is described as the ternary predicate
symbol corresponding to property P14 carried out by (performed):

P14(x,y) ⇒
E7(x)

P14(x,y)⇒
E39(y)

P14(x,y,z) ⇒ \[P14(x,y) ∧ E55(z)\]

These basic considerations should be used
by the reader to understand the logical axioms that are used into the
definition of the classes and properties. Further information about the first
order formulation of CIDOC CRM can be found in (Meghini & Doerr, 2018).

### Property Quantifiers

Quantifiers for properties are provided
for the purpose of semantic clarification only, and should **not** be
treated as implementation recommendations. The CIDOC CRM has been designed to
accommodate alternative opinions and incomplete information; all properties
should therefore be implemented as optional and repeatable for their domain and
range (“many to many (0,n:0,n)”). The term “cardinality constraints” is avoided
here as it typically pertains to implementations.

The
following table lists all possible property quantifiers occurring in this
document according to their notation, together with a textual explanation. In
order to provide optimal clarity, two widely accepted notations are used
redundantly in this document, a verbal and a numeric one. The verbal notation
uses phrases such as “one to many”, and the numerical one, expressions such as
“(0,n:0,1)”. While the terms “one”, “many”, and “necessary” are fairly intuitive,
the term “dependent” denotes a situation where a range instance cannot exist
without an instance of the respective property. In other words, the property is
“necessary” for its range (Meghini, C. & Doerr, M.,
2018).

|     |     |
| --- | --- |
| **many to many (0,n:0,n)** | Unconstrained: an individual domain<br>instance and range instance of this property can have zero, one, or more<br>instances of the property. In other words, the property is optional and<br>repeatable for its domain and range. |
| **one to many**<br>**(0,n:0,1)** | An individual domain instance of this<br>property can have zero, one, or more instances of the property, but an<br>individual range instance cannot be referenced by more than one instance of<br>this property. In other words, the property is optional for its domain and<br>range, but repeatable for its domain only. This situation is sometimes called<br>a “fan-out”. |
| **many to one**<br>**(0,1:0,n)** | An individual domain instance of this<br>property can have zero or one instance of the property, but an individual<br>range instance can be referenced by zero, one, or more instances of the property.<br>In other words, the property is optional for its domain and range, but<br>repeatable for its range only. This situation is sometimes called a “fan-in”. |
| **many to many, necessary (1,n:0,n)** | An individual domain instance of this<br>property can have one or more instances of this property, but an individual<br>range instance can have zero, one, or more instances of the property. In<br>other words, the property is necessary and repeatable for its domain, and<br>optional and repeatable for its range. |
| **one to many, necessary**<br>**(1,n:0,1)** | An individual domain instance of this<br>property can have one or more instances of the property, but an individual<br>range instance cannot be referenced by more than one instance of the property.<br>In other words, the property is necessary and repeatable for its domain, and<br>optional but not repeatable for its range. This situation is sometimes called<br>a “fan-out”. |
| **many to one, necessary**<br>**(1,1:0,n)** | An individual domain instance of this<br>property must have exactly one instance of the property, but an individual<br>range instance can be referenced by zero, one, or more instances of the property.<br>In other words, the property is necessary and not repeatable for its domain,<br>and optional and repeatable for its range. This situation is sometimes called<br>a “fan-in”. |
| **one to many, dependent**<br>**(0,n:1,1)** | An individual domain instance of this<br>property can have zero, one, or more instances of the property, but an<br>individual range instance must be referenced by exactly one instance of the property.<br>In other words, this property is optional and repeatable for its domain, but<br>necessary and not repeatable for its range. This situation is sometimes called<br>a “fan-out”. |
| **many to many, necessary, dependent**<br>**(1,n:1,n)** | An individual domain instance and range<br>instance of this property must have at least one instance of this property.<br>In other words, this property is necessary and repeatable for its domain and<br>range. |
| **one to many, necessary, dependent**<br>**(1,n:1,1)** | An individual domain instance of this<br>property can have one or more instances of the property, but an individual<br>range instance must be referenced by exactly one instance of the property. In<br>other words, the property is necessary and repeatable for its domain, and<br>necessary but not repeatable for its range. This situation is sometimes called<br>a “fan-out”. |
| **many to one, necessary, dependent**<br>**(1,1:1,n)** | An individual domain instance of this<br>property must have exactly one instance of the property, but an individual<br>range instance can be referenced by one or more instances of the property. In<br>other words, the property is necessary and not repeatable for its domain, and<br>necessary and repeatable for its range. This situation is sometimes called a<br>“fan-in”. |
| **one to one**<br>**(1,1:1,1)** | An individual domain instance and range<br>instance of this property must have exactly one instance of the property. In<br>other words, the property is necessary and not repeatable for its domain and<br>for its range. |
| **one to one, necessary**<br>**(1,1:0,1)** | An individual domain instance of this<br>property must have exactly one instance of this property, but an individual<br>range instance cannot be referenced by more than one instance of this<br>property. In other words, this property is necessary and not repeatable for<br>its domain, and optional but not repeatable for its range. |

The CIDOC CRM
defines some dependencies between properties and the classes that are their
domains or ranges. These can be one or both of the following:

·the property is necessary for the domain

·the property is necessary for the range, or, in
other words, the range is dependent on the property.

The possible kinds of dependencies are
defined in the table above. Note that if a dependent property is not specified
for an instance of the respective domain or range, it means that the property
exists, but the value on one side of the property is unknown. In the case of
optional properties, the methodology proposed by the CIDOC CRM does not
distinguish between a value being unknown or the property not being applicable
at all. For example, one may know that an object has an owner, but the owner is
unknown. In a CIDOC CRM instance this case cannot be distinguished from the
fact that the object has no owner at all. Of course, such details can always be
specified by a textual note.

Note that the quantification of all
properties of properties, “.1” properties, is “many-to-many” and, therefore,
does not appear explicitly in their definitions.

# Modelling principles

The following modelling principles have
guided and informed the development of the CIDOC CRM.

## Reality, Knowledge Bases and CIDOC CRM

The CIDOC CRM is
a formal ontology in the sense introduced by (Guarino, 1998). [\[4\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftn4 "") The present document is intended to
embrace an audience not specialized in computer science and logic; therefore,
it focuses on the informal semantics and on the pragmatics of the CIDOC CRM
concepts, offering a detailed discussion of the main traits of the
conceptualization underlying the CIDOC CRM through basic usage patterns. [\[5\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftn5 "") The CIDOC CRM aims to assist sharing,
connecting and integrating information from research about the past. In order
to understand the function of a formal ontology of this kind, one needs to make
the following distinctions:

·The _material_
_reality_. For the purpose of the CIDOC CRM, material reality is regarded as
whatever has substance that can be perceived with senses or instruments.
Examples are people, a forest or a settlement environment, sea, atmosphere,
distant celestial or cellular micro structures, including what we assume could
be potentially or theoretically perceived if we could be there, such as the
centre of the Earth or the sun, and all that is past. It is constrained to space
and time. What goes on in _our minds_ or is produced by our minds is also
regarded as part of the material reality, as it becomes materially evident to
other people at least by our utterances, behaviour and products.

·The units
of description or _particulars_, i.e. the things and relations which we
refer to in order to distinguish parts of reality. Examples are Mount Ida, the
Taj Mahal, the formation of China by emperor Qin Shi Huang (秦始皇) in 221BC, Tut-Ankh Amun and his embalming, Prince Shotoku
of Japan sending a mission to China in 607AD, the participation of Socrates in
the Battle of Potidaea or the radiocarbon dating of the Iceman Ötzi
(Kutschera, 2002).

A formal
ontology, such as the CIDOC CRM, constitutes a controlled language for talking
about particulars. I.e., it provides classes and properties for categorizing
particulars as so-called “instances” in a way that their individuation, unity
and relevant properties are as unambiguous as possible. For instance, Tut-Ankh
Amun as instance of E21 Person _is_ the real pharaoh from his birth to
death, and not extending to his mummy, according to the specification of the
class E21 Person and its properties in the CIDOC CRM.

For clarification, the CIDOC CRM does not
take a position against or in favour of the existence of spiritual substance
nor of substance not accessible by either senses or instruments, nor does it
suggest a materialistic philosophy. However, for practical reasons, it relies
on the priority of integrating information based on material evidence available
for whatever human experience. The CIDOC CRM only commits to a unique material
reality independent from the observer.

When _descriptions_ of particulars
are provided, reference to them shall be made by unique names, titles or
constructed identifiers, all of which are instances of E41 Appellation in the
CIDOC CRM, in order the reference to be independent of the context. (In
contrast, reference to particulars by pronouns or enumerations of
characteristic properties, such as name and birth date, are context dependent).
The appellation, and the relation between the appellation and the referred item
or relationship, must not be confused with the referred item and its identity.
For example, Tut-Ankh Amun the name (instance of E41 Appellation) is different
from Tut-Ankh Amun the person (instance of E21 Person) and also different from
the relationship between name and person ( _P1 is identified by_).
Instances of CIDOC CRM classes are the _real_ particulars, not their
names, but in descriptions, names must be used as surrogates for the real
things meant. Particulars are approximate individuations, like sections, of
parts of reality. In other words, the uniqueness of reality does not depend on
where one draws the line between the mountain and the valley.

A CIDOC CRM-compatible _knowledge base_
(KB) (Meghini & Doerr 2018) is an instance of E73 Information Object in the
CIDOC CRM. It contains (data structures that encode) formal statements
representing propositions believed to be true in a reality by an observer.
These statements use appellations (e.g., https://id.loc.gov/authorities/names/n79066005 [\[6\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftn6 "")) of ontological particulars and of CRM concepts (e.g. _P100i died_
_in_). Thereby users, in their capacity of having real-world knowledge and
cognition, may be able to relate these statements to the propositions they are
meant to characterize, and be able to reason and research about their validity.
In other words, the formal instances in a knowledge base are the _identifiers_,
not the real things or phenomena. A special case is digital content: a KB in a
computer system may contain statements about instances of E90 Symbolic Object
and the real thing may be text residing within the same KB. The instance of E90
Symbolic Object and its textual representation are separate entities and they
can be connected with the property _P190 has symbolic content._

Therefore, a knowledge base does not
contain knowledge, but _statements that represent_ knowledge, as long as
there exist people that can resolve the identifiers used to their referents.
(Appellations described in a knowledge base, and not used as primary
substitutes of other items, are of course explicitly declared as instances of
E41 Appellation in the knowledge base.)

## Authorship of Knowledge Base Contents

This section describes a recommended good
practice how to relate authority to knowledge base contents.

Statements in a KB must have been
inserted by some human agent, either directly or indirectly. However, these
statements often make no reference to that agent, lacking attribution of
authority. An example of such statements in the CIDOC CRM is information
expressed through shortcuts such as _P2 has type_. In the domain of
cultural heritage, it is common practice that the responsibility for
maintaining knowledge in the KB is elaborated in institutional policy or
protocol documents. Thus, it is reasonable to hold that statements which lack
explicit authority attribution can be read as the official view of the
administrating institution of that system, i.e., the maintainers of the KB.
This does not imply that the knowledge described in the KB is complete. So long
as the information is under active management, it remains continuously open to revision
and improvement as further research reveals further understandings. [\[7\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftn7 "") A KB does not represent a slice of reality, but the justified
beliefs of its maintainers about that reality. For simplicity, we speak about a
KB as representing some reality.

Statements in a KB may also carry
explicit references to agents that produced them, i.e., further statements of
responsibility. In CIDOC CRM such statements of responsibility are expressed
though knowledge creation events such as E13 Attribute Assignment and its
relevant subclasses. Any knowledge that is about an explicit knowledge creation
event, where the creator’s identity has been given, is implicitly attributed to
be correctly referred to in the KB by the maintaining authority, whereas the
responsibility for the content created by that event is assigned to the agent
identified as causal to that event.

In the special case of an institution
taking over stewardship of a database transferred into their custody, two
relations of responsibility for the knowledge therein can be envisioned. If the
institution accepts the dataset and undertakes to maintain and update it, then
they take on responsibility for that information and become the default
authority behind its statements as described above. If, on the other hand, the
institution accepts the data set and stores it without change as a closed
resource, then it can be considered that the default authority remains the
original steward like for any other scholarly document kept by the institution.

## Extensions of CIDOC CRM

Since the intended scope of the CIDOC CRM
is a subset of the “real” world and is therefore potentially infinite, the
model has been designed to be extensible through the linkage of compatible
external type hierarchies.

Of necessity, some concepts covered by
the CIDOC CRM are defined in less details than others: E39 Actor and E30 Right,
for example. This is a natural consequence of staying within the model’s
clearly articulated practical scope in an intrinsically unlimited domain of
discourse. These ‘underdeveloped’ concepts can be considered as candidate
superclasses for compatible extensions, in particular for disciplines with a
respective focus. Additions to the model are known as extensions while the main
model is known as CRMbase.

Compatibility of extensions with the CRM
means that data structured according to an extension must also remain valid as
instances of CIDOC CRM base classes. In practical terms, this implies query
containment: any queries based on CIDOC CRM concepts to a KB should retrieve a
result set that is correct according to the model’s semantics, regardless of
whether the KR is structured according to the CIDOC CRM’s semantics alone, or
according to the CIDOC CRM plus compatible extensions. For example, a query
such as “list all events” should recall 100% of the instances deemed to be
events by the CIDOC CRM, regardless of how they are classified by the
extension.

A sufficient condition for the
compatibility of an extension with the CIDOC CRM is that its classes, other
than E1 CRM Entity, subsume all classes of the extension, and all properties of
the extension are either subsumed by CRM properties, or are part of a path for
which a CIDOC CRM property is a shortcut, and that classes and properties of
the extension can be well distinguished from those in the CIDOC CRM. For
instance, a class “tangible object” may be in conflict with existing classes of
the CIDOC CRM. Obviously, such a condition can only be tested intellectually.

The CRM provides a number of mechanisms
to ensure that coverage of the intended scope can be increased on demand
without losing compatibility:

1Existing classes can be extended, either
structurally as subclasses or dynamically using the type hierarchy (see section
About Types below).

2Existing properties can be extended, either
structurally as subproperties, or in some cases, dynamically, using properties
of properties which allow subtyping (see section About Types below).

3Additional
information that falls outside the semantics formally defined by the CIDOC CRM
can be recorded as unstructured data using E1 CRM Entity. _P3 has note_:
E62 String.

4Extending the CIDOC CRM by superclasses and
properties that pertain to a wider scope. They are called conservative
extensions, if they preserve backwards compatibility with instances described
with the CIDOC CRM.

Following strategies 1, 2 and 3 will have
the result that the CIDOC CRM concepts subsume and thereby cover the
extensions. This means that querying an extended knowledge base only with
concepts of the CIDOC CRM will nevertheless retrieve all facts described via
the extensions.

**In mechanism 3**, the information in the notes is accessible in the respective
knowledge base by retrieving the instances of E1 CRM Entity that are domain of _P3_
_has note_. Keyword search will also work for the content of the note. Rules
should be applied to attach a note to the item most specific for the content.
For instance, details about the role of an actor in an activity should be
associated with the instance of E7 Activity, and not with the instance of E39
Actor. This approach is preferable when queries relating elements from the
content of such notes across the knowledge base are not expected.

In general, only concepts to be used for
selecting multiple instances from the knowledge base by formal querying need to
be explicitly modelled. This criterion depends on the expected scope and use of
the particular knowledge base.The CIDOC CRM prioritizes modelling
the kinds of facts one would like to retrieve and relate from heterogeneous content
sources, potentially from different institutions. It does not, by way of
contrast, focus on the modelling of facts with a more local scope such as the
administrative practices internal to an institution.

**Mechanism 4**, conservative extension, is more complex:

With increasing use of the CIDOC CRM,
there is also a need for extensions that model phenomena from a scope wider
than the original one of the CIDOC CRM, but which are also applicable to the
concepts that do fall within the CIDOC CRM’s scope. When this occurs,
properties of the CIDOC CRM may be found to be applicable more generally to
superclasses of the extension than to those of their current domain or range in
the CIDOC CRM. This is a consequence of the key principle of the CIDOC CRM to
model “bottom up”, i.e. selecting the domains and ranges for properties to be
as narrow as they would apply in a well understood fashion in the current
scope, thus avoiding making poorly understood generalizations at risk of
requiring non-monotonic correction.

The fourth mechanism for extending the
CIDOC CRM by conservation extension can be seen to be split into two cases:

1A new class or property is added to an extension
of the CIDOC CRM, which is not covered by superclasses other than E1 CRM Entity
or a superproperty in the CIDOC CRM respectively. In this case, all facts
described only by such concepts are not accessible by queries with CIDOC CRM
concepts. Therefore, the extension should publish in a compatibility statement
the additional relevant high-level classes and properties needed to retrieve
all facts documented with the extended model. This case is a monotonic
extension.

2The domain or range of an existing property in
the CIDOC CRM is changed to a superclass of the one or the other or both,
because the property is understood to be applicable beyond its originally
anticipated scope. In this case, all facts described by the extension are still
accessible by querying with the concepts of the CIDOC CRM, but the extension
can describe additional facts that the CIDOC CRM could not. This case is a
monotonic extension and generally recommended, because it enables bottom-up
evolution of the model. If this change is part of a new release of the CIDOC
CRM itself, it is simply backwards compatible, and this has been done frequently
in the evolution of this model.

If this second case should be documented
and implemented in an extension module **separate from** the CIDOC CRM, it
may come in conflict with the current way knowledge representation languages,
such as RDF/OWL, treat it, because in formal logic changing the range or domain
of a property is regarded **as** changing the ontological meaning **completely;**
there is no distinction betwe **en the meaning of the property independent of**
**domain and range and the specification of the domain and range**. It is,
however, similar to what in logic is called a conservative extension of a
theory, and necessary for an effective modular management of ontologies.

Therefore, for the interested reader, we
describe here a definition of this case in terms of first-order logic, which
shows how modularity can formally be achieved:

Let us assume a property P defined with
domain class A and range class C also holds for a domain class B, superclass of
A, and a range class D, superclass of C, in the sense of its ontological
meaning in the real world. We describe this situation by introducing an
auxiliary formal property P’, defined with domain class B and range class D,
and apply the following logic:

A(x) ⇒ B(x)


     C(x) ⇒ D(x)


P(x,y) ⇒ A(x)


P(x,y) ⇒ C(y)


P’(x,y) ⇒ B(x)

                               P’(x,y) ⇒
D(y)

Then, P’ is a conservative extension of P
if: A(x)∧
C(y) ∧ P’(x,y) ⇔ P(x,y)

In other words, a separate extension
module may re-declare the respective property with another identifier,
preferably using the same label, and implement the above rule.

## Minimality

Although the scope of the CIDOC CRM is
very broad, the model itself is constructed as economically as possible:

·CIDOC CRM classes and properties are either
primitive, or they are key concepts in the practical scope.

·Complements of CIDOC CRM classes are not
declared, because, considering the Open World principle, there are no
properties for complements of a class (see Terminology and first consequence of
Monotonicity).

A CIDOC CRM class is declared when:

·It is required as the domain or range of a
property not appropriate to its superclass.

·It serves as a merging point of two CIDOC CRM
class branches via multiple IsA (e.g., E25 Human-Made Feature). When the branch
superclasses are used for multiple instantiation of an item, this item is in
the intersection of the scopes. The class resulting from multiple IsA should be
narrower in scope than the intersection of the scopes of the branch
superclasses.

·It is useful as a leaf class (i.e., at the end
of a CIDOC CRM branch) to domain communities building CIDOC CRM extensions or
matching key domain classes from other models to the CIDOC CRM (e.g., E34
Inscription).

## Monotonicity

The CIDOC CRM’s primary role is to
support the meaningful integration of information in an Open World. The
adoption of the Open World principle means that the CIDOC CRM itself must
remain fundamentally open and knowledge bases implemented using it should be
flexible enough to receive new insights. At the model level, new classes and
properties within the CIDOC CRM’s scope may be found in the course of
integrating more documentation records or when new kinds of relevant facts come
to the attention of its maintainers. At the level of the KBs, the need to add
or revise information may arise due to numerous external factors. Research may
open new questions; documentation may be directed to new or different
phenomena; natural or social evolution may reveal new objects of study.

It is the aim of the maintainers of the
CIDOC CRM to respect the Open World principle and to follow the principle of
monotonicity. Monotonicity requires that adding new classes and properties to
the model or adding new statements to a knowledge base does not invalidate
already modelled structures and existing statements.

A first consequence of this commitment,
at the level of the model, is that the CIDOC CRM aims to be monotonic in the
sense of Domain Theory. That is to say, the existing CIDOC CRM constructs and
the deductions made from them should remain valid and well-formed, even as new
constructs are added by extensions to the CIDOC CRM. Any extensions should be,
under this method, backwards compatible with previous models. The only
exception to this rule arises when a previous construct is considered
objectively incorrect by the domain experts and thus subjected to corrective
revision. Adopting the principle of monotonicity has active consequences for
the basic manner in which classes and properties are designed and declared in
the CIDOC CRM. In particular, it forbids the declaration of complement classes,
i.e. classes solely defined by excluding instances of some other classes.

For example:

FRBRoo (Bekiari et al (eds). 2015)
extends the CIDOC CRM. In version 2.4 of FRBRoo, F51 Name Use Activity was
declared as a subclass to the CIDOC CRM class E7 Activity. This class was added
in order to describe a phenomenon specific to library practice and not
considered within CRM base. F51 Name Use Activity describes the practice of an
instance of E74 Group adopting and deploying a name within a context for a
time-span. The creation of this extension is monotonic because no existing IsA
relationship or inheritance of properties in CRM base are compromised and no
future extension is ruled out. By way of contrast, if, to handle this
situation, a subclass “Other Activity” had been declared, a non-monotonic
change would have been introduced. This would be the case because the scope
note of a complement class like “Other Activities” would forbid any future
declaration of specializations of E7 Activity such as F51 Name Use Activity. In
the case the need arose to declare a particular specialized subclass, a
non-monotonic revision would have to be made, since there would be no
principled way to decide which instances of “Other Activity” were instances of
the new, specialized class and which were not. Such non-monotonic changes are
extremely costly to end users, compromising backwards compatibility and
long-term integration.

As a second consequence, maintaining
monotonicity is also required during revising or augmenting data within a CIDOC
CRM compatible system. That is, existing CIDOC CRM instances, their properties
and the deductions made from them, should always remain valid and well-formed,
even as new instances, regarded as consistent by the domain expert, are added
to the system.

For example:

If someone describes correctly that an
item is an instance of E19 Physical Object, and later it is correctly
characterized as an instance of E20 Biological Object, the system should not
stop treating it as an instance of E19 Physical Object. This is achieved by
declaring E20 Biological Object as subclass of E19 Physical Object.

This example further demonstrates that
the IsA hierarchy of classes and properties can represent characteristic stages
of increasing knowledge about some item during the processes of investigation
and collection of evidence. Higher level classes can be used to safely classify
objects whose precise characteristics are not known in the first instance. An
ambiguous biological object may, for example, be classified as only a physical
object. Subsequent investigation can reveal its nature as a biological object.
A knowledge base constructed with CIDOC CRM classes designed to support
monotonic revision allows for seeking physical objects that were not yet
recognized as biological ones. This ability to integrate information with
different specificity of description in a well-defined way is particularly
important for large-scale information integration. Such a system supports
scholars being able to integrate all information about potentially relevant
phenomena into the information system without forcing an over or under
commitment to knowledge about the object. Since large scale information
integration always deals with different levels of knowledge of its relevant
objects, this feature enables a consistent approach to data integration.

A third consequence, applied at the level
of the knowledge base, is that in order to formally preserve monotonicity, when
it is required to record and store alternative opinions regarding phenomena all
formally defined properties should be implemented as unconstrained (many: many)
so that conflicting instances of properties are merely accumulated. Thus,
integrated knowledge can serve as a research tool for accumulating relevant
alternative opinions around well-defined entities, whereas conclusions about
the truth are the task of open-ended scientific or scholarly hypothesis
building.

For example:

King Arthur’s basic life events are
highly contested. Once entered in a knowledge base, he should be defined as an
instance of E21 Person and treated as having existed as such within the sense
of our historical discourse. The instance of E21 Person is used as the
collection point for describing possible properties and existence of this
individual. Alternative opinions about properties, such as the birthplace and
his living places, should be accumulated without validity decisions being made
during data compilation. King Arthur may be entered as a different instance, of
E28 Conceptual Object, for describing him as mythological character and
accumulating possibly mythological facts.

The fourth consequence of monotonicity
relates to the use of time dependent properties in a knowledge base. Certain
properties declared in the CIDOC CRM, such as having a part, an owner or a
location, may change many times for a single item during the course of its
existence. Asserting that such a property holds for some item means that that
property held for some particular, undetermined time-span within the course of
its existence. Consequently, one item may be the subject of multiple statements
asserting the instantiation of that property without conflict or need for
revision. The collection of such statements would reflect an aggregation of
these instances of this property holding over the time-span of the item’s
existence. If a more specific temporal knowledge is required/available, it is
recommended to explicitly describe the events leading to the assertion of that
property for that item. For example, in the case of acquiring or losing an
item, it would be appropriate to declare the related event class such as E9
Move. By virtue of this principle, the CRM achieves monotonicity with respect
to an increase of knowledge about the states of an item at different times,
regardless of their temporal order.

Time-neutral properties may be
specialized in a future monotonic extension by time-specific properties, but
not vice-versa. Also, many properties registered do not change over time or are
relative to events in the model already. Therefore, the CIDOC CRM always gives
priority to modelling properties as time-neutral, and rather representing
changes by events.

However, for some of these properties
many databases may describe a “current” state relative to some property, such
as “current location” or “current owner”. Using such a “current” state means
that the database manager is able to verify the respective reality at the
latest date of validity of the database. Obviously, this information is
non-monotonic, i.e., it requires deletion when the state changes. In order to
preserve a reduced monotonicity, these properties have time-neutral
superproperties by which respective instances can be reclassified if the
validity becomes unknown or no longer holds. Therefore, the use of such
properties in the CRM is only recommended if they can be maintained consistently.
Otherwise, they should be reclassified by their time-neutral superproperties.
This holds in particular if data is exported to another repository (see also
the paragraph “Authorship of Knowledge Base Contents” above).

## Disjointness

Classes are disjoint if they cannot share
any common instances at any time, past, present or future. That implies that it
is not possible to instantiate an item using a combination of classes that are
mutually disjoint or with subclasses of them (see “multiple instantiation” in section
“Terminology”). There are many examples of disjoint classes in the CIDOC CRM.

A comprehensive declaration of all
possible disjoint class combinations afforded by the CIDOC CRM has not been
provided here; it would be of questionable practical utility and may easily
become inconsistent with the goal of providing a concise definition. However,
there are two key examples of disjoint class pairs that are fundamental to an effective
comprehension of the CIDOC CRM:

·E2 Temporal Entity is disjoint from E77 Persistent
Item. Instances of the class E2 Temporal Entity are perdurants, whereas
instances of the class E77 Persistent Item are endurants. Even though instances
of E77 Persistent Item have a limited existence in time, they are fundamentally
different in nature from instances of E2 Temporal Entity, because they preserve
their identity between events. Declaring endurants and perdurants as disjoint
classes is consistent with the distinctions made in data structures that fall
within the CIDOC CRM’s practical scope.

·E18 Physical Thing is disjoint from E28
Conceptual Object. The distinction is between material and immaterial items,
the latter being exclusively human-made. Instances of E18 Physical Thing and
E28 Conceptual Object differ in many fundamental ways; for example, the
production of instances of E18 Physical Thing implies the incorporation of
physical material, whereas the production of instances of E28 Conceptual Object
does not. Similarly, instances of E18 Physical Thing cease to exist when
destroyed, whereas an instance of E28 Conceptual Object perishes only when it
is forgotten and its last physical carrier is destroyed.

This page is
left blank on purpose

# Introduction to the basic concepts

The following paragraphs explain the most
general logic of the CIDOC CRM. The CIDOC CRM is a formalized representation of
historical discourse, a formal ontology. In this capacity, it is meant to
support the (re)presentation of fact based, analytic discourse about what has
happened in the past in a human understandable and machine-processable manner.
It achieves this function by proposing a series of formalized properties
(relations) and classes. The formalized properties support the making of
semantically explicit statements relating classes of things. Their formal
definition logically explicates the classes of things to which they may
pertain. The CIDOC CRM properties thus enable a formal, logically explicit
description of relations between individual, real world items, classified under
distinct ontological classes. Encoding analytic data pertaining to the past
under such a system of statements provides a standard representation for data
and allows the uniform application of reasoning to large sets of data.

Grounding this high-level logic is a
hierarchical system of classes and relations, that provide basic ontological
distinctions by which to represent historical discourse. Familiarity with the
basic ontological distinctions made in the top level of the class hierarchy
provides the basic entry point to understanding how to apply the CIDOC CRM for
knowledge representation.

The highest-level distinction in the
CIDOC CRM is represented by the top-level concepts of E77 Persistent Item,
equivalent to the philosophical notion of endurant; E2 Temporal Entity,
equivalent to the philosophical notion of perdurant and, further, the concept
of E92 Spacetime Volume.

As an event-centric model, supporting
historical discourse, the CIDOC CRM firstly enables the description of entities
that are themselves time-limited processes or evolutions within the passing of
time using E2 Temporal Entity and its subclasses. Their basic function is to
capture the fact of something having happened over time. In addition to
allowing the description of a temporal duration, the subclasses of E2 Temporal
Entity are used to document the historical relations between objects, similar
to the role of action verbs in a natural language phrase. The more specific
subclasses of E2 Temporal Entity enable the documentation of events pertaining
to individually related/affected material, social or mental objects that have
been described using subclasses of E77 Persistent Item. This precise
documentation is enabled through the use of specialized properties formalizing
the manner of the relation or affect. Examples of specific subclasses of E2
Temporal Entity include E12 Production, which allows the representation of
events of making things by humans, and E5 Event which allows the documentation,
among other things, of geological events and large-scale social events such as
a war. Each of these subclasses have specific properties associated to them
which allow them to function to represent the specific, real-world connection
between instances of E77 Persistent Item, such as the relation of an object to
its time of production through _P108i was produced by_(E12) or the
relation of a place to a geological phenomenon through _P7i witnessed_
(E5). The entities that E2 Temporal Entity documents, being time limited
processes/occurrences, are such that their existence can be declared only on
the basis of direct observation or recording of the event, or indirect
observation of its material outcomes. Evidence of such entities may be
preserved on material objects that are permanently changed because of them.
Likewise, events may have been recorded in text or remembered through oral
history. E2 Temporal Entity and its subclasses are central to the CRM and
essential for almost all modelling tasks (e.g., in a museum catalogue one cannot
consider an object outside its production event).

The real-world entities, which the event
centric modelling of the CIDOC CRM aims to enable the accurate historical
description of, are captured through E77 Persistent Item and its subclasses.
E77 Persistent Item is used to describe entities that are relatively stable in
form through the passage of time, maintaining a recognizable identity because
their significant properties do not change. Specific subclasses of E77
Persistent Item can illustrate this point. E22 Human-Made Object is used for
the description of discrete, physical objects having been produced by human
action, such as an artwork or monument. An artwork or monument is persistent
with regards to its physical constitution. So long as it retains its general
physical form, it is said to exist and to participate in the flow of historical
events. E28 Conceptual Object is also used to describe persistent items, but of
a mental character. It is used to describe identifiable ideas that are named and
form an object of historical discourse. Its identity conditions rely in having
a carrier by which it can be recalled. The entities described by E77 Persistent
Item are prone to change through human activity, biological, geological or
environmental processes, but are regarded to continue to exist and be the same
just as long as such changes do not alter their basic identity (essence) as
defined in the scope note of the relevant class.

The notion of identity is key in the
application of CIDOC CRM. The properties and relations it provides are designed
to allow the accurate historical description of the evolution of real-world
items through time. This being the case, classes and properties are created in
order to provide a definition, which will allow the accurate application of the
classes or properties to the same real-world items by diverse users. Identity,
in the sense of the CIDOC CRM, therefore, means that informed people are able
to agree that they refer to the same, single thing in its distinction from others,
both in its extent and over its time of existence. The criteria for such a
determination should come from understanding the scope note of the respective
CIDOC CRM class this thing is regarded to be an instance of, because
communication via information systems may not leave space for respective
clarifying dialogues between users. For example, the Great Sphinx of Giza may
have lost part of its nose, but there is no question that we are still
referring to the same monument as that before the damage occurred, since it
continues to represent significant characteristics and distinctness from an
overall shaping in the past, which is of archaeological relevance. Things
lacking sufficient stability or differentiation, such as atmosphere, soil,
clouds, waves, are not instances of E77 Persistent Item, and not suited for
information integration. Discourse about such items may be documented with
concepts of the CIDOC CRM as observations in relation to things of persistent
identity, such as places.

Learning to distinguish and then
interrelate instances of E77 Persistent Item (endurants) and instances of E2
Temporal Entity (perdurants) using the appropriate properties is key to the
proper understanding and application of CIDOC CRM in order to formally
represent analytic historical data. In the large majority of cases, the
distinction this provides, and the subsequent elaboration of subclasses and
properties is adequate to describe the content of database records in the
cultural and scientific heritage domain. In exceptional cases, where there is a
need to consider complex combinations of changes of spatial extent over time,
the concept of spacetime (E92 Spacetime Volume) also needs to be considered.
E92 Spacetime Volume describes the entities whose substance has or is an
identifiable, confined geometrical extent in the material world that may vary
over time, fuzzy boundaries notwithstanding. For example, the built settlement
structure of the city of Athens is confined both from the point of view of
time-span (from its founding until now) and from its changing geographical
extent over the centuries, which may become more or less evident from current
observation, historical documents and excavations. Even though E92 Spacetime
Volume is an important theoretical part of the model, it can be ignored for
most practical documentation and modelling tasks.

The key to the proper understanding of
CIDOC CRM comes through the appropriation of its basic divisions and the logic
these represent. It is important to underline that the CIDOC CRM is not
intended to function as a classification system or vocabulary tool. The basic
class divisions in CIDOC CRM are declared in order to be able to apply distinct
properties to these classes and, in so doing, formulate precise, analytic
propositions that represent historical realities. The expressive power of CIDOC
CRM comes not from the application of classes to classify entities but in the
documenting the interrelation of individual historical items through
well-defined properties. These properties characteristically cover subjects
such as relations of _identifying_ items by names and identifiers; _participation_
of persistent items in temporal entities; _locations_ of temporal entities
and physical things in space and time; relations of _observation_ and assessment;
part-decomposition and _structural_ properties of anything; _influence_
of things and experiences on the activities of people and their products; and _reference_
of information objects to anything.

We explain these concepts with the help
of graphical representations in the next sections.

## Relations with Events

Figure 1 illustrates the minimal
properties in the CIDOC CRM for documenting “what has happened”, the central
pattern of the model. First, consider the class E1 CRM Entity, the formal top
class of the model. It primarily serves a technical purpose to aggregate the
ontologically meaningful concepts of the model. It declares however two
important properties of general validity and distinct features of the model: _P1_
_is identified by_, with range E41 Appellation _,_ makes the fundamental
ontological distinction between the identity of a particular and an identifier
(see section “Reality, Knowledge Bases and CIDOC CRM” above), and in practice
allows for describing a discourse about resolving historical ambiguities of
names and reconciliation of multiple identifiers. The property _P2 has type_,
with range E55 Type, constitutes a practical interface for refining classes by
terminologies, being often volatile, as detailed in the section “About Types”
below.

![Diagram  Description automatically generated](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image003.png)

Figure 1: High Level Properties and Classes of
CIDOC CRM

All classes in Figure 1 are direct or
indirect subclasses of E1 CRM Entity _,_ but for better readability, only
the “subclass of” -link from E2 Temporal Entity is shown. The latter comprises
phenomena that continuously occur over some time-span (E52 Time-Span) in the
natural time dimension, but some of them may not be confined to specific area,
such as a marriage status. Further specializing, E4 Period comprises phenomena
occurring in addition within a specific area in the physical space, which can
be specified by _P7 took place at_, with range E53 Place. Instances of E4
Period can be of any size, such as the Warring States Period, the Roman Period,
a siege or just the process of making a signature. Further specializing, E5
Eventcomprises phenomena involving and affecting certain instances of
E77 Persistent Item in a way characteristic of the kind of process, which can
be specified by the property _P12 occurred in the presence of_. This
concept of presence is very powerful: it constrains the existence of the
involved things to the respective places within the specified time and implies
the potential of passive or active involvement and mutual impact. Via presence,
events represent nodes in a network of things meeting in various combinations
in the course of time at different places.

The most important specializations of E77
Persistent Item in this context are: E39 Actor, those capable of intentional
actions, E18 Physical Thing, having an identity bound to a relative stability
of material form, and E28 Conceptual Object, the idealized things that can be
recognized but have an identity independent from the materialization on a
specific carrier. The property _P12 occurred in the presence of_ has 36
direct and indirect subproperties, relating these and many more subclasses of
E5 Event and E77 Persistent Item _._ Regardless whether a CRM-compatible
knowledge base is created with these properties only or with their much more
expressive specializations, querying for the five high-level properties in
figure 1 will provide answer to all “Who-When-Where-What-How” questions, and
allow for retrieving potentially richly elaborated stories of people, places,
times and things.

This
pattern of “meeting” is complemented by two more subclasses of E5 Event: E63
Beginning of Existence and E64 End of Existence, which imply not only presence,
but constitute the **endpoints of existence** of things and people in space
and time, often in explicit presence and interaction with others, be they
causal by producing or consuming or just witnessing. Note that the model
supports multiple instantiation. As a consequence, particular events can be
instances of combinations of these and other classes, describing tightly
integrated processes of multiple nature. The representation of things connected
in events by presence, beginning and end of existence is sufficient to describe
the logic of _termini postquos and antequos_, a major form of reasoning
about chronology in historical studies.

As a simple, real example of applying the
above concepts we present a historical event, relevant for the history of art:
Johann-Joachim Winckelmann (a German Scholar) has seen the so-called Laocoön
Group in 1755 in the Vatican in Rome (at display in the Cortile del Belvedere).
He described his impressions in 1764 in his “History of the Art of Antiquity”,
(being the first to articulate the difference between Greek, Greco-Roman and
Roman art, characterizing Greek art with the famous words “…noble simplicity,
silent grandeur”). The sculpture, in Hellenistic "Pergamene baroque"
style (Bieber 1961, Brilliant 2000) is widely assumed to be a copy, made
between 27 BC and 68 AD (following a Roman commission) from a Greek (no more
extent) original. Johann-Joachim Winckelmann was born 1717 as child of Martin
Winckelmann and Anna-Maria Meyer and died in 1768 in Trieste.

Figure 2 presents a semantic graph of
this event, as described above, using CIDOC CRM concepts. The facts in
parentheses above are omitted for better clarity. Instances of classes are
represented by informative labels instead of identifiers, in boxes showing the
class label above the instance label. Properties are represented as arrows with
the property label attached. After class labels and property labels, the
identifiers of the respective superclasses and superproperties from Figure 1
are shown in parenthesis, in order to demonstrate that the story can be
represented and queried with these concepts only. It also shows how concept
specialization increases expressiveness without losing genericity. It is
noteworthy that the transfer of information from the Greek original, to the
copy, to the mind of Winckelmann and into his writings can be solely understood
by this chain of things _being present_ in different meetings. Note also
that the degree to which a fact is believed to be real does not affect the
choice of CIDOC CRM concepts for description of the fact, nor the reality
concept underlying the model.

![A diagram of a flowchart    Description automatically generated](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image004.jpg)

Figure 2: CIDOC CRM Encoding Example (Winckelmann
seeing Laocoön)

Figure 2 represents in addition one more
top-level property of the CIDOC CRM: _P67 refers to_, which describe an
evidence-based fact that an information object makes reference to an
identifiable item.

As mentioned above, the central concept
of the CIDOC CRM is the representation of a part of reality that can be
approximated as a network of things meeting in various combinations in
spacetime. Using the same example from above, Figure 3 illustrates this concept
via an alternative symbolic representation. It aims at rendering the idea that
people and things in the past have performed mostly unknown trajectories in
spacetime, and the historical facts known to us constrain their possible
whereabouts for some limited time-spans to having been together at some known or
unknown place.

We use a one-dimensional representation
of space, as used in archaeology to describe the spatial evolution of periods
or cultures over time, and a vertical time axis. We symbolize the trajectories
of things and people as fuzzy lines between events in order to render their
relative indeterminacy between known events. Non-animate things use to be
stationary if not transferred, whereas people may move around on their own. We
symbolize events as fuzzy ovals to render the fuzzy boundaries of events in
space and time. Note that in this representation, as a general pattern, things
may “survive” events, emerge from events or end in events. Beginning and ending
of existence impose an additional temporal order on events of causal nature,
which can be stronger than explicit dates. We symbolize the unreported ends of
existence of people and things, which are also events, by a dot at the end of
the trajectory.

![A diagram of a person and person  Description automatically generated](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image005.png)

Figure 3: Symbolic Representation of
"Winkelmann seeing Laocoön" as an Evolution in Space and Time

In the following, we give an overview of
the system of spatial and temporal relations in the CIDOC CRM, because it
constitutes an important tool for precise documentation of the past and has a
certain complexity that needs to be understood in a synopsis.

### Spatial Relations

A major area of documentation and
historical research centres around positioning in space of what has happened
and the things involved, as well as reasoning about respective spatial
relations. The key class CIDOC CRM provides for modelling this information is
E53 Place. E53 Place is used to document geometric extents in the physical
space containing actual or possible positions of things or happenings. The
higher-level properties and classes of CIDOC CRM that centre around E53 Place
allow for the documentation of: relations between places; recording the
geometric expressions defining or approximating a place and their semantic
function; tracing the history of locations of a physical object; identifying the
places where an individual or group have been located; identifying places on a
physical object and the spatial extent of certain temporal entities.

_Geometric Expressions of Place_: Contemporary documentation of spatial information has access to
advanced equipment for accurately recording location and libraries of
georeferenced place information. For this reason, documentation of place now
often includes the recording of precise coordinates for a referenced place. Of
great importance semantically, is to understand the manner in which such a
geometric place expression actually relates to a referenced place. The cluster
or relations _P168 place is defined by_, _P171 at some place within_,
and _P172 contains_ allows the user to link to geometric place expressions
while also accurately indicating how this expression relates to the documented
place. Geometric place expressions are instances of E94 Space Primitive, a
primitive class for expressing values in data systems not further analysed in
the CIDOC CRM. These properties provide a valid interface to the OGC standards,
as elaborated in CRMgeo (Doerr & Hiebel 2013).

![Diagram, schematic  Description automatically generated](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image006.png)

Figure 4: Basic CIDOC CRM Properties and Classes
for Reasoning about Spatial Information

_Relations between Places:_ The cluster of relations _P89 falls within (contains)_, _P122_
_borders with_, _P121 overlaps with_ and _P189 approximates_ can
express relative relationships held between places. These properties hold
between instances of E53 Place and allow interordering places using common mereotopological
concepts.

_History of Object Locations_: Instances of place are often referenced in order to record the
location of some object. When the movement of the object to different locations
through time is of interest, it is also important to be able to analytically
record the different locations at which an object was and at what point. The
CIDOC CRM offers two top level mechanisms for tracing the relation of objects
to places. If the aspect of time is unknown or not of interest, then an object
can be related to a place through the properties _P53 has former or current_
_location_ and _P55 has current location_. The former property is the
conservatively appropriate choice for documenting the object-to-place relation
when time elements are not known. If one is actively tracking current location,
the latter property is also of use. When an accurate history of the temporal
aspect of location should be provided, the user should take advantage of the
class E9 Move, a temporal entity class. Instantiating E9 Move allows the user
to document the origin, destination and concerned object of a move event using
the collection of properties _P27 moved from_, _P26 moved to_, _P25_
_moved_. Being a temporal class E9 Move further allows the tracing of time,
agency etc. Note that things may be moved indirectly as parts of or within
other things.

_Actor Locations_: Tracking the history of the location of actors is related to the
history of object location with a significant difference: in the CIDOC CRM an
actor is defined as an entity featuring agency which is not the case in objects
and physical entities in general. Not being physical, an actor cannot be the
subject of an instance of E9 Move which documents physical relocations. The
CIDOC CRM thus offers the notion of _P74 has current or former residence_
in order to document the relation of a person or group to a location as
residing there at some time.

_Places on a Physical Object_: In the recording of cultural heritage and other scientific data,
particularly about mobile objects, including ships, it is often necessary to
identify where on an object or a certain feature is located and where a certain
phenomenon is observed. For this, the CIDOC CRM offers the relation _P59 has_
_section_ relating the object to the places which are defined upon it. Note
that Earth is the physical object we relate places to per default. In
geological times, a narrower relation to a tectonic plate may be necessary.

_Spatial Extent of Temporal Entities_: In order to spatially define the extent of temporal phenomena, the
CIDOC CRM offers two properties that apply to all instances of temporal entity
under the class E4 Period: _P7 took place at_ and _P8 took place on or_
_within_. The former is used to relate a temporal phenomenon directly to an
instance of E53 Place which provides the geometric context in which that
phenomenon took place. The latter property allows the documentation of a
temporal phenomenon taking place in relation to a physical object. This is
useful for recording information such as the occurrence of an event on a moving
ship or within a particular storage container, where the geometric location is
not known or indirectly relevant.

### Temporal Relations

Historical and scientific discourse about
the past deals with different levels of knowledge regarding events and their
temporal ordering that feed into chronology. Chronology is fundamental to
understanding social and natural history, and reasoning about temporal
relations and causality is directly related. An immense wealth of physical
observations allows for inferring temporal relations and vice-versa. It is
important to be able to document temporality both with regards to known dates
but also according to relative positioning within a historical timeline. The
top-level properties of the CIDOC CRM relating to temporal entities support the
documentation of: dates as time-spans or dimensions, mereological relations
between temporal entities as well as a complete suite of topological relations.

_Dates and Durations_: When some absolute dates limiting a temporal entity are known,
this can be documented by instantiating the _P4 has time-span_ property
and creating an instance of E52 Time-span. Dates should then be recorded as
instances of E61 Time Primitiveand related to the time-span through
properties _P81 ongoing throughout_ or _P82 at some time within_.
Time is recorded as a span and not an instant in the CIDOC CRM. The choice of
property _P81 ongoing throughout_ allows the documentation of knowledge
that a temporal phenomenon was occurring at least at all points of a known time-span.
The property _P82 at some time within_ allows the weaker claim that the
phenomenon must have occurred within the limits of a particular time-span
without further specifying as to when precisely. It is the default for
historical dates, given, for instance, in years for events of much smaller
duration. The actual mode of encoding the documented date is outside the scope
of the CIDOC CRM, which defines this with a primitive class, E61 Time
Primitive. Finally, the property _P191 had duration_ can be deployed in
order to document a temporal phenomenon with known duration but with less
precisely temporal positioning. For instance, a birth may be known with the
precision of a year, but with a duration of 3 hours. For documenting exact
time-spans that are result of a declaration rather than observation, for
instance in order to describe a time-span multiple events may fall into, the
property _P170 defines time_ allows for specifying the time-span uniquely
by a temporal primitive, rather than by _P81 ongoing throughout_ or _P82_
_at some time within_ using an identical time primitive.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image007.jpg)

Figure 5: Basic CIDOC CRM Properties and Classes
for Reasoning about Temporal Information

_Mereological relations_: The documentation of the part-whole relationship of temporal
phenomena is crucial for historical reasoning. The CIDOC CRM distinguishes
under temporal entities two immediate specializations: E4 Period is a
high-level concept for the documentation of temporal phenomena of change and
interactions in space and time, comprising but not limited to historical
periods such as Ming or Roman, and is further specialized in rich hierarchy of
more specific processes and activities. The second specialization is E3
Condition State _,_ a rather specific class for the documentation of static
phases of physical things. The CIDOC CRM so far does not describe a
higher-level class of static phases, because they are normally deductions from
multiple observations, problematic in information integration and vulnerable to
non-monotonic revision. For both classes, two different mereological relations
are articulated: The property _P9 consists of_ is used to document proper
parthood between instances of E4 Period, i.e. to describe how the phenomena
that make up an instance of E4 Period can causally be subdivided into more
delimited phenomena. In contrast, the property _P10 falls within_,
explained further in the section about spatiotemporal relations, describes only
a non-causal co-occurrence in the same spatiotemporal extent. The property _P5_
_consists of_ indicates, in analogy, proper parthood between instances of E3
Condition State.

_Topological Relations_: A lot of semantic relations have implications on the temporal
ordering of temporal entities. For instance, meeting someone must occur after
birth and before death of the involved parties. Information can only be
transferred after it has been learned. On the other side, direct information
about temporal order has implications on possible or impossible semantic
relations. This form of reasoning is of paramount importance for research about
the past. It turned out that the popular temporal relations defined by (Allen,
1983), which the CIDOC CRM had adopted in previous versions, are not well
suited to describe inferences from semantic relations, as detailed in the
section “Temporal Relation Primitives based on fuzzy boundaries” below.
Instead, the CIDOC CRM introduces a theory of fuzzy boundaries in time that
enables the accurate interpositioning of temporal entities between themselves taking
into account the inherent fuzziness of temporal boundaries. This model subsumes
the earlier introduced Allen temporal relations which may continue to be used
in extensions of the CIDOC CRM.

### Spatiotemporal Relations

Treating space and time as separate
entities is normally adequate for describing events and where things are. When
more precise documentation and reasoning is required about phenomena spreading
out over time, such as Bronze Age, a settlement, a nation, moving reference
frames such as ships, things being stored in containers and moved around, built
structures being partially destroyed, rebuilt and altered etc., space and time
must be understood as a coherent continuum, the so-called spacetime. This is
not a familiar concept for many users, and those not interested in such details
may therefore skip this section.

However, the respective model the CIDOC
CRM adopts constitutes a valid interface to the OGC standards, as elaborated in
CRMgeo (Doerr & Hiebel 2013) and important for connecting to GIS
applications. The key class CIDOC CRM provides for modelling this information
is E92 Spacetime Volume. E92 Spacetime Volume is used to document geometric
extents in the physical spacetime containing actual or possible positions of
things or happenings, in particular in those cases when the changes of place to
be documented cannot be reduced to distinct events, because the spatial extent
changes continuously. The higher-level properties and classes of CIDOC CRM that
centre around E92 Spacetime Volume allow for the documentation of: relations
between spacetime volumes, relations to space and time as separate entities,
and treating the exact extent of physical things and periods in space at any
time of their existence as spacetime volumes. Its use is particularly elegant
for the description of temporal gazetteers.

_Defining a Spacetime Volume:_ There are three ways to define a spacetime volume:

1The property _P169 defines spacetime volume_ should
be used to declare a spatiotemporal container for some things or happenings in
terms of spatial coordinates that may vary over time, be it in discrete steps
or continuously with the help of spacetime expressions. The latter are
instances of E95 Spacetime Primitive, a primitive class for expressing values
in data systems not further analysed in the CIDOC CRM.

2Instances of E4 Period are regarded to be
specialized instances of E92 Spacetime Volume that are formed by the spreading
out of the phenomena that make up an instance of E4 Period. As such they are
fuzzy but in general observable.

3The continuous sequence of spatial extent that
the matter of an instance of E18 Physical Thing occupies in the course of time,
defines a spacetime volume unique to it from the beginning of its existence to
its end, which can also be understood as its trajectory through the universe
The property _P169 defines_ allows for referring to this spacetime volume,
in order to document its additional properties. As such this spacetime volume
is fuzzy but in general observable. It is not easy to make a mental picture of
the spacetime volume of a physical thing, but the construct simplifies all
reasoning about where things have been.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image008.jpg)

Figure 6: Basic CIDOC CRM Properties and Classes
for Reasoning with Spacetime Volumes

_Relations with Places and Physical_
_Things:_ The property _P161 has spatial projection_
associates a spacetime volume with the complete spatial extent it has occupied
during its time-span of definition. Due to relativity of space, the definition
of an instance of E53 Place must be relative to some physical thing as
geometric reference. This can explicitly be documented with the property _P157_
_is at rest relative to_. If the place where something is at a certain point
in time is given in multiple reference spaces in relative movement, such as
with respect to a ship versus to the seafloor, these differently defined places
may later move apart. Therefore, a spacetime volume, even though uniquely
defined, can have any number of spatial projections, depending on the reference
space. Currently, the GPS system defines a default reference space on the
surface of Earth. In art conservation and other descriptions of mobile object
of fixed shape, it is useful to refer to the precise place a physical thing
occupies with respect to itself as reference space via _P156 occupies_,
for further analysis. _P156 occupies_ constitutes a particular projection
of the spacetime volume of this thing. In contrast, the property _P53 has_
_former or current location_ only describes that a thing was within a
specific place given in some reference space for an undefined time.

_Relations with Time-Spans and Periods:_ The property _P160 has temporal projection_ associates a
spacetime volume with the complete temporal extent it has covered comprising
all places of its definition. In contrast to places, the reference system of
time is unique [\[8\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftn8 "") except for the choice of origin. For instances of E4 Period and its
subclasses, which inherit _P160 has temporal projection,_ the property is
actually identical with the property _P4 has time-span_ inherited from E2
Temporal Entity _,_ because is describes the temporal extent of the
phenomena that make up an instance of E4 Period. Therefore, it is recommended
to use _P4 has time-span_ for instances of E4 Period and its subclasses,
rather than _P160 has temporal projection_.

_Relations of Presence:_ Instances of E93 Presence are specialized instances of E92
Spacetime Volume that are identical with the spatial evolution of a larger
spacetime volume specified by _P166 was presence of_, but delimited to a,
normally short, time-span declared by _P164 is temporally specified by_.
In other words, they constitute “snapshots” or “time-slices” of another
spacetime volume, such as the extent of the Roman Empire during 30AD. They are
the basic construct to describe exactly where something was or happened at a
particular time(-span), in connection with the property _P161 has spatial_
_projection._ In particular, it allows for describing the whereabouts of
mobile objects, be it in the storage of a museum, a palace, deposited in the
ground, or transported in a container, such as the bone of a saint. For ease of
use, a shortcut _P195 was presence of_ is defined directly to E18 Physical
Thing, bypassing the definition of its spacetime volume.

_Topological Relations:_ Finally,the model defines truly spatiotemporal topological
relations. _P10 falls within (contains)_ is the complete inclusion of one
spacetime volume in another. It should not be confused with inclusion in the
spatial and temporal projection, which may be larger. For example, in 14 AD,
Mesopotamia was not within the Roman Empire. Further, the properties _P132_
_spatiotemporally overlaps with_ and its negation _P133 is spatiotemporally_
_separated from_ are fundamental to argue about temporary parthood, possible
continuity etc.

## Specific Modelling Constructs

### About Types

Virtually all structured descriptions of
museum objects begin with a unique object identifier and information about the “type”
of the object, often in a set of fields with names like “classification”, “category”,
“object type”, “object name”, etc. All these fields are used for terms that
declare that the object belongs to a particular category of items. In the CIDOC
CRM the class E55 Type comprises concepts denoted by terms. Instances of E55
Type represent concepts (universals) in contrast to instances of E41
Appellation, which are used to name instances of CIDOC CRM classes.

For this purpose, the CIDOC CRM provides
two basic properties that describe classification with terminology,
corresponding to what is the current practice in the majority of information
systems. The class E1 CRM Entity is the domain of the property _P2 has type_
_(is type of)_, which has the range E55 Type. Consequently, every class in
the CIDOC CRM, with the exception of E59 Primitive Value, inherits the property
_P2 has type (is type of)._ This provides a general alternative mechanism
to specialize the classification of CIDOC CRM instances to any level of detail,
by linking to external vocabulary sources, thesauri, classification schemas or
ontologies.

Analogous to the function of the _P2_
_has type (is type of)_ property, some properties in the CIDOC CRM are
associated with an additional property. These are numbered in the CIDOC CRM
documentation with a ‘.1’ extension. The range of these properties of
properties always falls under E55 Type. The purpose of a property of a property
is to provide an alternative mechanism to specialize its domain property
through the use of property subtypes declared as instances of E55 Type. They do
not appear in the property hierarchy list but are included as part of the
property declarations and referred to in the class declarations. For example, _P62.1_
_mode of depiction_: E55 Type is associated with E24 Physical Human-Made
Thing. _P62 depicts (is depicted by):_ E1 CRM Entity.

The class E55 Type also serves as the
range of properties that relate to categorical knowledge commonly found in
cultural documentation. For example, the property _P125 used object of type_
_(was type of object used in)_ enables the CIDOC CRM to express statements
such as “this casting was produced using a mould”, meaning that there has been
an unknown or unmentioned object, a mould, that was actually used. This enables
the specific instance of the casting to be associated with the entire type of
manufacturing devices known as moulds. Further, the objects of type “mould”
would be related via _P2 has type (is type of)_ to this term. This
indirect relationship may actually help in detecting the unknown object in an
integrated environment. On the other side, some casting may refer directly to a
known mould via _P16 used specific object (was used for)._ So, a
statistical question to how many objects in a certain collection are made with
moulds could be answered correctly following both paths through _P16 used_
_specific object (was used for)_ \- _P2 has type (is type of)_ and _P125_
_used object of type (was type of object used in)_. This consistent treatment
of categorical knowledge enhances the CIDOC CRM’s ability to integrate cultural
knowledge.

Types, that is, instances of E55 Type and
its subclasses, can be used to characterize the instances of a CIDOC CRM class
and hence refine the meaning of the class. A type ‘artist’ can be used to
characterize persons through _P2 has type (is type of)_. On the other
hand, in an art history application of the CIDOC CRM it can be adequate to extend
the CIDOC CRM class E21 Person with a subclass E21.xx Artist. What is the
difference of the type ‘artist’ and the class Artist? From an everyday
conceptual point of view there is no difference. Both denote the concept
‘artist’ and identify the same set of persons. Thus, in this setting a type
could be seen as a class and the class of types may be seen as a metaclass.
Since current systems do not provide an adequate control of user defined
metaclasses, the CIDOC CRM prefers to model instances of E55 Type as if they
were particulars, with the relationships described in the previous paragraphs.

Users may decide to implement a concept
either as a subclass extending the CIDOC CRM class system or as an instance of
E55 Type. A new subclass should only be created in case the concept is
sufficiently stable and associated with additional explicitly modelled
properties specific to it. Otherwise, an instance of E55 Type provides more
flexibility of use. Users that may want to describe a discourse not only using
a concept extending the CIDOC CRM but also describing the history of this
concept itself, may choose to model the same concept both as subclass and as an
instance of E55 Type with the same name. Similarly, it should be regarded as
good practice to foresee for each term hierarchy refining a CIDOC CRM class a
term equivalent of this class as top term. For instance, a term hierarchy for
instances of E21 Person may begin with “Person”.

One role of E55 Type is to be the CIDOC
CRM’s interface to domain specific ontologies and thesauri or less formal
terminological systems. Such sets of concepts can be represented in the CIDOC
CRM as subclasses of E55 Type, forming hierarchies of terms, i.e., instances of
E55 Type linked via _P127 has broader term (has narrower term)._ Such
hierarchies may be extended with additional properties. Other standard models,
in particular richer ones, used to describe terminological systems can also be
interfaced with the CIDOC CRM by declaring their respective concept class as
being equivalent to E55 Type, and their respective broader/narrower relation as
being identical with _P127 has broader term (has narrower term)_, as long
as they are semantically compatible.

In addition to being an interface to
external thesauri and classification systems, E55 Type is an ordinary class in
the CIDOC CRM and a subclass of E28 Conceptual Object. E55 Type and its
subclasses inherit all properties from this superclass. Thus, together with the
CIDOC CRM class E83 Type Creation the rigorous scholarly or scientific process
that ensures a type is exhaustively described and appropriately named can be
modelled inside the CIDOC CRM. In some cases, particularly in archaeology and
the life sciences, E83 Type Creation requires the identification of an
exemplary specimen and the publication of the type definition in an appropriate
scholarly forum. This is very central to research in the life sciences, where a
type would be referred to as a “taxon,” the type description as a “protologue,”
and the exemplary specimens as “original element” or “holotype”.

Finally, instances of E55 Type or
suitable subclasses can describe universals from type systems not organized in
thesauri or ontologies, such as industrial product names and types, defined and
published by the producers themselves for each new product or product variant.

### Temporal Relation Primitives based on fuzzy boundaries

It is characteristic for sciences dealing
with the past, such as history, archaeology or geology, to derive temporal
topological relations from stratigraphic and other observations and from
considerations of causality between events. For this reason, the CIDOC CRM
introduced, in version 3.3, the whole set of temporal relationships of Allen’s
temporal logic (the now deprecated properties P114 to P120). It was regarded at
that time as a well-justified, exhaustive and sufficient theory to deal with
temporal topological relationships of spatiotemporal phenomena relevant to
cultural historical discourse. Allen’s temporal logic is based on the assumption
of known, exact endpoints of time intervals (time-spans), described by an
exhaustive set of mutually exclusive relationships.

Since many temporal relations can be
inferred from facts causal to them, e.g. a birth necessarily occurring before
any intentional interaction of a person with other individuals, or from
observations of material evidence without knowing the absolute time, the
temporal relationships pertain in the CIDOC CRM to E2 Temporal Entities, and
not their Time-Spans, which require knowledge of absolute time. If absolute
times are known, deduction of Allen’s relation is a simple question of
automated calculus and not the kind of primary scientific insight the CIDOC
CRM, as a core model, is interested in. However, their application turned out to
be problematic in practice for two reasons:

**Firstly,**
facts causal to temporal relationships result in expressions that often require
a disjunction (logical OR condition) of Allen’s relationships. For instance, a
child may be stillborn. Ignoring states at pregnancy as it is usual in older
historical sources, birth may be _equal to_ death, _meet_ with death
or be _before_ death. The knowledge representation formalism chosen for
the CIDOC CRM however does **not allow** for specifying **disjunctions**,
except within queries. Consequently, simple properties of the CIDOC CRM that
imply a temporal order, such as _P134 continued_, cannot be declared as
subproperties of the temporal relationship they do imply, which would be, in
this case: “before, meets, overlaps, starts, started-by, contains, finishes,
finished-by, equals, during or overlapped by” (see _P174 starts before the_
_end of_).

**Secondly,** nature
does not allow us to observe equality of points in time. There are three
possible interpretations to this fact. Common to all three interpretations is
that they can be described in terms of fuzzy boundaries. The model proposed
here is consistent with **all** three of these interpretations.

1Any
observable phenomenon that can be dated has a **natural temporal extent**
with **fuzzy boundaries** of **gradual transition** from not existing to
definitely existing and then to no longer existing.

2These fuzzy boundaries can also be interpreted
as the time intervals about which experts, even with a complete knowledge of
the described phenomenon, may not agree as to whether this phenomenon is
already ongoing or not, or still ongoing or not.

3Under a
third interpretation, the fact that an instance of E2 Temporal Entity is
ongoing is **not observable** within the fuzzy boundaries.

Consider, for instance, a birth. Extending
over a limited and non-negligible duration in the scale of hours it begins and
ends gradually (1), but can be given alternative scientific definitions of
start and end points (2), and neither of these can be determined with a
precision much smaller than on a scale of minutes (3). The fuzzy boundaries **do**
**not** describe the relation of incomplete or imprecise knowledge to reality.
Assuming a lowest granularity in time is an approach which does not help,
because the relevant extent of fuzziness varies at a huge scale even in
cultural reasoning, depending on the type of phenomena considered. The only
exact match is between arbitrarily declared time intervals, such as the end of
a year being equal to the beginning of the next year, or that “Early Minoan” ends
exactly when “Middle Minoan” starts, whenever that might have been.
Consequently, we introduce here a new set of “temporal relation primitives”
with the following characteristics:

·It is a minimal set of properties that allows
for specifying all possible relations between two time intervals given by their
start and end points, either directly, or by conjunction (logical AND
condition) of the latter.

·Start and end points are interpreted as “thick”
fuzzy boundaries as described above.

·Conditions
of equality of end points are relaxed to the condition that the fuzzy
boundaries **overlap**. Therefore, knowledge of the shape of the fuzzy
function is **not** needed.

·All of Allen’s relationships can be expressed
either directly or by conjunctions of these properties.

·In case of time intervals without or with
negligibly short fuzzy boundaries, all of Allen’s relationships can exactly be
described by adequate conjunctions of these properties.

·No relationship is equal to the inverse of
another. Inverses are specified by exchanging the roles of domain and range.

#### Notation

We use the following notation:

Comparing two instances of E2 Temporal
Entity, we denote one with capital letter A, its (fuzzy) starting time with Astart
and its (fuzzy) ending time with Aend, such that A = \[Astart,Aend\];
we denote the other with capital letter B, its (fuzzy) starting time with Bstart and its (fuzzy) ending time with
Bend, such that B = \[Bstart,Bend\].

We identify a temporal relation with a
predicate name (label) and define it by one or more (in)equality expressions
between its end points, such as:

A _starts before_
_the end of_ B if and only if (⇔) **A** **start** **<**
**Bend**

We visualize a temporal relation
symbolizing the temporal extents of two instances A and B of E2 Temporal Entity
as horizontal bars, considered to be on a horizontal time-line proceeding from
left to right. The fuzzy boundary areas are symbolized by an
increasing/decreasing colour gradient. The different choices of relative
arrangement the relationship allows for are symbolized by two extreme allowed
positions of instance A with respect to instance B connected by arrows. The
reader may imagine it as the relative positions of a train A approaching a
station B. If the relative length of A compared to B matters, two diagrams are
provided.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image009.png)

Key

|     |     |
| --- | --- |
| 1 | **Interior**<br>time points for which the described Temporal Entity is definitely on-going |
| 2 | **Boundary**<br>fuzzy transitions zones in which the described Termporal Entity is developing<br>or vanishing |
| 3 | A starts before the end of B |

Figure 7: Explanation of Interior and Boundary and
an Example of Use from P174 starts before the end of (ends after the start of).

#### Overview of Temporal Relation Primitives

The final set of temporal relation
primitives can be separated into two groups:

1Those based on improper inequalities, such as Astart ≤ Bend (odd number items in Table 2).

2Those based on proper inequalities, such as Astart
< Bend (even number items in Table
2).

Improper inequalities with fuzzy
boundaries are understood as extending into situations in which the fuzzy
boundaries of the respective endpoints may overlap. In other words, they include
situations in which it cannot be decided when one interval has ended and when
the other started, but there is no knowledge of a definite gap between these
endpoints. In a proper inequality with fuzzy boundaries, the fuzzy boundaries
of the respective endpoints must not overlap, i.e. there is knowledge of a
definite gap between these endpoints, for instance, a discontinuity between
settlement phases based on the observation of archaeological layers.

Table 2: Temporal
Relation Primitives

|     |     |     |
| --- | --- | --- |
|  | **Property** | **Interpretation** |
| 1 | P173 starts<br>before or with the end of | Astart<br>≤ Bend |
| 2 | P174 starts<br>before the end of | Astart<br>< Bend |
| 3 | P175 starts<br>before or with the start of | Astart<br>≤ Bstart |
| 4 | P176 starts<br>before the start of | Astart<br>< Bstart |
| 5 | P182 ends<br>before or with the start of | Aend<br>≤ Bstart |
| 6 | P183 ends<br>before the start of | Aend<br>< Bstart |
| 7 | P184 ends<br>before or with the end of | Aend<br>≤ Bend |
| 8 | P185 ends<br>before the end of | Aend<br>< Bend |

# Class & Property Hierarchies

Although they do not provide
comprehensive definitions, compact mono-hierarchical presentations of the class
and property IsA hierarchies have been found to significantly aid comprehension
and navigation of the CIDOC CRM. Since the CRM is poly-hierarchical, a
mono-hierarchical presentation form is achieved by a top-down expansion of all
inverse IsA relations regardless whether a concept has already be presented at
another place in the same hierarchy. This form is provided below.

The class hierarchy presented below has
the following format:

·Each line begins with a unique class identifier,
consisting of a number preceded by the letter “E” (originally denoting
“entity,” although now replaced by convention with the term “class”).

·A series of hyphens (“-”) follows the unique
class identifier, indicating the hierarchical position of the class in the IsA
hierarchy.

·The English name of the class appears to the
right of the hyphens.

·The index is ordered by hierarchical level, in a
“depth first” manner, from the smaller to the larger subhierarchies.

·Classes that appear in more than one position in
the class hierarchy as a result of multiple inheritance are shown in an italic
typeface.

The property hierarchy presented below
has the following format:

·Each line begins with a unique property
identifier, consisting of a number preceded by the letter “P” (for “property”).

·A series of hyphens (“-”) follows the unique
property identifier, indicating the hierarchical position of the property in
the IsA hierarchy.

·The English name of the property appears to the
right of the hyphens, followed by its inverse name in parentheses for reading
in the range to domain direction.

·The domain class for which the property is
declared.

·The range class that the property references.

·The index is ordered by hierarchical level, in a
“depth first” manner, from the smaller to the larger subhierarchies, and by
property number between equal siblings.

·Properties that appear in more than one position
in the property hierarchy as a result of multiple inheritance are shown in an
italic typeface.

## CIDOC CRM Class Hierarchy

Table 3: CIDOC
CRM Class Hierarchy

|     |     |     |     |     |     |     |     |     |     |     |     |     |     |
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- |
| [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7306) | CRM Entity |
| [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) | - | Temporal Entity |
| [E3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7360) | - | - | Condition State |
| [E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7376) | - | - | Period |
| [E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7409) | - | - | - | Event |
| [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7454) | - | - | - | - | Activity |
| [E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7498) | - | - | - | - | - | Acquisition |
| [E96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8829) | - | - | - | - | - | - | Purchase |
| [E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7522) | - | - | - | - | - | Move |
| [E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7537) | - | - | - | - | - | Transfer of Custody |
| [E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) | - | - | - | - | - | Modification |
| [E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7584) | - | - | - | - | - | - | Production |
| [E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) | - | - | - | - | - | - | Part Addition |
| [E80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8606) | - | - | - | - | - | - | Part Removal |
| [E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7603) | - | - | - | - | - | Attribute Assignment |
| [E14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7628) | - | - | - | - | - | - | Condition Assessment |
| [E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7643) | - | - | - | - | - | - | Identifier Assignment |
| [E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7660) | - | - | - | - | - | - | Measurement |
| [E17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7678) | - | - | - | - | - | - | Type Assignment |
| [E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8372) | - | - | - | - | - | Creation |
| [E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8639) | - | - | - | - | - | - | Type Creation |
| [E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8388) | - | - | - | - | - | Formation |
| [E85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8654) | - | - | - | - | - | Joining |
| [E86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) | - | - | - | - | - | Leaving |
| [E87](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8685) | - | - | - | - | - | Curation Activity |
| [E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8332) | - | - | - | - | Beginning of<br>Existence |
| [E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8406) | - | - | - | - | - | Birth |
| [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8620) | - | - | - | - | - | Transformation |
| [E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7584) | - | - | - | - | - | _Production_ |
| [E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8372) | - | - | - | - | - | _Creation_ |
| [E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8639) | - | - | - | - | - | - | _Type Creation_ |
| [E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8388) | - | - | - | - | - | _Formation_ |
| [E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8353) | - | - | - | - | End of Existence |
| [E6](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7436) | - | - | - | - | - | Destruction |
| [E68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8421) | - | - | - | - | - | Dissolution |
| [E69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8434) | - | - | - | - | - | Death |
| [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8620) | _-_ | _-_ | _-_ | _-_ | _-_ | _Transformation_ |
| [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8556) | - | Persistent Item |
| [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8447) | - | - | Thing |
| [E72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8490) | - | - | - | Legal Object |
| [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7692) | - | - | - | - | Physical Thing |
| [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7723) | - | - | - | - | - | Physical Object |
| [E20](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7746) | - | - | - | - | - | - | Biological Object |
| [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7761) | - | - | - | - | - | - | - | Person |
| [E22](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7777) | - | - | - | - | - | - | Human-Made Object |
| [E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7791) | - | - | - | - | - | Physical Human-Made<br>Thing |
| [E22](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7777) | - | - | - | - | - | - | _Human-Made Object_ |
| [E25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7818) | - | - | - | - | - | - | Human-Made Feature |
| [E78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8576) | - | - | - | - | - | - | Curated Holding |
| [E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7833) | - | - | - | - | - | Physical Feature |
| [E27](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7851) | - | - | - | - | - | - | Site |
| [E25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7818) | - | - | - | - | - | - | _Human-Made Feature_ |
| [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) | - | - | - | - | Symbolic Object |
| [E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8507) | - | - | - | - | - | Information Object |
| [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7896) | - | - | - | - | - |  | Design or Procedure |
| [E31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7931) | - | - | - | - | - |  | Document |
| [E32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7947) | - | - | - | - | - | - | - | Authority Document |
| [E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7960) | - | - | - | - | - | - | Linguistic Object |
| [E34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7982) | - | - | - | - | - | - | - | Inscription |
| [E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7997) | - | - | - | - | - | - | - | Title |
| [E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8013) | - | - | - | - | - |  | Visual Item |
| [E37](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8033) | - | - | - | - | - | - | - | Mark |
| [E34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7982) | - | - | - | - | - | - | - | _-_ | _Inscription_ |
| [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8065) | - | - | - | - | - | Appellation |
| [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8102) | - | - | - | - | - | - | Identifier |
| [E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7997) | - | - | - | - | - | - | Title |
| [E95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8800) | - | - | - | - | - | - | Spacetime Primitive |
| [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8784) | - | - | - | - | - | - | Space Primitive |
| [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8304) | - | - | - | - | - | - | Time Primitive |
| [E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431) | - | - | - | Human-Made Thing |
| [E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7791) | - | - | - | - | _Physical_<br>_Human-Made Thing_ |
| [E22](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7777) | - | - | - | - | - | _Human-Made Object_ |
| [E25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7818) | - | - | - | - | - | _Human-Made Feature_ |
| [E78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8576) | - | - | - | - | - | _Curated Holding_ |
| [E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7867) | - | - | - | - | Conceptual Object |
| [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) | _-_ | _-_ | _-_ | _-_ | _-_ | _Symbolic Object_ |
| [E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8507) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Information Object_ |
| [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Design or_<br>_Procedure_ |
| [E31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7931) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Document_ |
| [E32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7947) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Authority Document_ |
| [E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7960) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ |  | _Linguistic Object_ |
| [E34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7982) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Inscription_ |
| [E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7997) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ |  | _-_ | _Title_ |
| [E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8013) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _\- Visual Item_ |
| [E37](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8033) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Mark_ |
| [E34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7982) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Inscription_ |
| [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8065) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Appellation_ |
| [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8102) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Identifier_ |
| [E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7997) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Title_ |
| [E95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8800) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Spacetime_<br>_Primitive_ |
| [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8784) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Space Primitive_ |
| [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8304) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Time Primitive_ |
| [E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8698) | _-_ | _-_ | _-_ | _-_ | _-_ | Propositional Object |
| [E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8507) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Information Object_ |
| [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7896) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Design or_<br>_Procedure_ |
| [E31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7931) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Document_ |
| [E32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7947) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Authority Document_ |
| [E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7960) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Linguistic Object_ |
| [E34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7982) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Inscription_ |
| [E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7997) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Title_ |
| [E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8013) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Visual Item_ |
| [E37](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8033) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Mark_ |
| [E34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7982) | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _-_ | _Inscription_ |
| [E30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7919) | - | - | - | - | - | - | Right |
| [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8193) | - | - | - | - | - | Type |
| [E56](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8219) | - | - | - | - | - | - | Language |
| [E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) | - | - | - | - | - | - | Material |
| [E58](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8251) | - | - | - | - | - | - | Measurement Unit |
| [E98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8852) | - | - | - | - | - | - | - | Currency |
| [E99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8865) | - | - | - | - | - | - | Product Type |
| [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8047) | - | - | Actor |
| [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8531) | - | - | - | Group |
| [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7761) | - | - | - | _Person_ |
| [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8122) | - | Time-Span |
| [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8145) | - | Place |
| [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8168) | - | Dimension |
| [E97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8841) | - | - | Monetary Amount |
| [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) | - | Spacetime Volume |
| [E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7350) | - | - | _Period_ |
| [E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) | - | - | - | _Event_ |
| [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) | - | - | - | _-_ | _Activity_ |
| [E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7472) | - | - | - | _-_ | _-_ | _Acquisition_ |
| [E96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8829) | - | - | - | _-_ | _-_ | _-_ | _Purchase_ |
| [E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7496) | - | - | - | _-_ | _-_ | _Move_ |
| [E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7537) | - | - | - | _-_ | _-_ | _Transfer of_<br>_Custody_ |
| [E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) | - | - | - | _-_ | _-_ | _Modification_ |
| [E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7584) | - | - | - | _-_ | _-_ | _-_ | _Production_ |
| [E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) | - | - | - | _-_ | _-_ | _-_ | _Part Addition_ |
| [E80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8606) | - | - | - | _-_ | _-_ | _-_ | _Part Removal_ |
| [E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7603) | - | - | - | _-_ | _-_ | _Attribute_<br>_Assignment_ |
| [E14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7628) | - | - | - | _-_ | _-_ | _-_ | _Condition_<br>_Assessment_ |
| [E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7643) | - | - | - | _-_ | _-_ | _-_ | _Identifier_<br>_Assignment_ |
| [E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7660) | - | - | - | _-_ | _-_ | _-_ | _Measurement_ |
| [E17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7678) | - | - | - | _-_ | _-_ | _-_ | _Type Assignment_ |
| [E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8372) | - | - | - | _-_ | _-_ | _Creation_ |
| [E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8639) | - | - | - | _-_ | _-_ | _-_ | _Type Creation_ |
| [E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8388) | - | - | - | _-_ | _-_ | _Formation_ |
| [E85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8654) | - | - | - | _-_ | _-_ | _Joining_ |
| [E86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) | - | - | - | _-_ | _-_ | _Leaving_ |
| [E87](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8685) | - | - | - | _-_ | _-_ | _Curation Activity_ |
| [E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8332) | - | - | - | _-_ | _Beginning of_<br>_Existence_ |
| [E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8406) | - | - | - | _-_ | _-_ | _Birth_ |
| [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8620) | - | - | - | _-_ | _-_ | _Transformation_ |
| [E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7584) | - | - | - | _-_ | _-_ | _Production_ |
| [E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8372) | - | - | - | _-_ | _-_ | _Creation_ |
| [E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8639) | - | - | - | _-_ | _-_ | _-_ | _Type Creation_ |
| [E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8388) | - | - | - | _-_ | _-_ | _Formation_ |
| [E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8353) | - | - | - | _-_ | _End of Existence_ |
| [E6](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7436) | - | - | - | _-_ | _-_ | _Destruction_ |
| [E68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8421) | - | - | - | _-_ | _-_ | _Dissolution_ |
| [E69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8434) | - | - | - | _-_ | _-_ | _Death_ |
| [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8620) | _-_ | _-_ | _-_ | _-_ | _-_ | _Transformation_ |
| [E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8767) | - | - | Presence |
| [E59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8270) | - | Primitive Value |
| [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8291) | - | - | Number |
| [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8304) | - | - | _Time Primitive_ |
| [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) | - | - | String |
| [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8762) | - | - | _Space Primitive_ |
| [E95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8778) | - | - | _Spacetime_<br>_Primitive_ |
|  |  |  |  |  |  |  |  |  |  |  |  |  |  |

## CIDOC CRM Property Hierarchy

Table 4: CIDOC
CRM Property Hierarchy

|     |     |     |     |
| --- | --- | --- | --- |
| **Property id** | **Property Name** | **Entity –**<br>**Domain** | **Entity - Range** |
| [P1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8872) | is identified by<br>(identifies) | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity | [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation |
| [P48](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9718) | -   has preferred identifier (is<br>preferred identifier of) | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity | [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier |
| [P102](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10481) | -   has title<br>(is title of) | [E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431) Human-Made Thing | [E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971) Title |
| [P168](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11810)i | -   place is<br>defined by (defines place) | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place | [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8762) Space primitive |
| [P169](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11479)i | -   spacetime volume is defined by<br>(defines spacetime volume) | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume | [E95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8778)<br>Spacetime Primitive |
| [P170](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11495)i | -  time is<br>defined by (defines time) | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span | [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8279) Time Primitive |
| [P2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8894) | has type (is type<br>of) | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P137](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10996) | -  <br>exemplifies (is exemplified by) | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P177](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11651) | -   assigned<br>property type | [E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7577)<br>Attribute Assignment | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8915) | has note | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity | [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) String |
| [P79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10152) | -   beginning<br>is qualified by | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span | [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) String |
| [P80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10169) | -   end is<br>qualified by | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span | [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) String |
| [P190](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11875) | -   has<br>symbolic content | [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object | [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) String |
| [P4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8939) | has time-span (is<br>time-span of) | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span |
| [P5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8953) | consists of<br>(forms part of) | [Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State | [Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State |
| [P7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8970) | took place at (witnessed) | [E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8987) | took place on or<br>within (witnessed) | [E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9081) | occurred in the<br>presence of (was present at) | [E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event | [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533) Persistent Item |
| [P111](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10655) | -   added (was<br>added by) | [E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8569) Part Addition | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P113](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10690) | -   removed<br>(was removed by) | [E80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8583) Part Removal | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9052) | -   had<br>participant (participated in) | [E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9126) | -   -  <br>carried out by (performed) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P22](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9273) | -   -   -  <br>transferred title to (acquired title through) | [E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7472) Acquisition | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P23](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9293) | -   -   -   transferred<br>title from (surrendered title through) | [E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7472) Acquisition | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9378) | -   -   -   custody surrendered by<br>(surrendered custody through) | [E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7511) Transfer of Custody | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9397) | -   -   -   custody received by<br>(received custody through) | [E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7511) Transfer of Custody | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10372) | -   -   by<br>mother (gave birth) | [E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8383) Birth | [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7735) Person |
| [P99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10425) | -   -  <br>dissolved (was dissolved by) | [E68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8398) Dissolution | [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group |
| [P143](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11131) | -   -   joined<br>(was joined by) | [E85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8631) Joining | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P144](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11151) | -   -   joined<br>with (gained member by) | [E85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8631) Joining | [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group |
| [P145](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11176) | -   -  <br>separated (left by) | [E86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8647) Leaving | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P146](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11196) | -   -  <br>separated from (lost member by) | [E86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8647) Leaving | [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group |
| [P151](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11264) | -   -   was<br>formed from (participated  in) | [E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8365) Formation | [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group |
| [P16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9172) | -   used<br>specific object (was used for) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing |
| [P33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9470) | -   -   used<br>specific technique (was used by) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870)<br>Design or Procedure |
| [P111](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10655) | -   -   added<br>(was added by) | [E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8569) Part Addition | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P142](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11110) | -   -   used<br>constituent (was used in) | [E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7617) Identifier Assignment | [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object |
| [P25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9326) | -   moved<br>(moved by) | [E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7496) Move | [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object |
| [P31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9431) | -   has<br>modified (was modified by) | [E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7535) Modification | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P108](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10598) | -  -    has<br>produced (was produced by) | [E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7558) Production | [E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765)<br>Physical Human-Made Thing |
| [P110](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10637) | -   -  <br>augmented (was augmented by) | [E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8569) Part Addition | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666)<br>Physical Thing |
| [P112](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10672) | -   -  <br>diminished (was diminished by) | [E80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8583) Part Removal | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666)<br>Physical Thing |
| [P92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10287) | -   brought into existence (was brought<br>into existence by) | [E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8309) Beginning of Existence | [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533) Persistent Item |
| [P94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10335) | -   -   has<br>created (was created by) | [E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8349) Creation | [E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7841) Conceptual Object |
| [P135](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10958) | -   -   -  <br>created type (was created by) | [E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8616) Type Creation | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10355) | -   -   has<br>formed (was formed by) | [E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8365) Formation | [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group |
| [P98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10407) | -   -  <br>brought into life (was born) | [E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8383) Birth | [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7735) Person |
| [P108](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10598) | _-  -    has_<br>_produced (was produced by)_ | [_E12_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7558) _Production_ | [_E24_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765) _Physical Human-Made Thing_ |
| [P123](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10743) | -   -  <br>resulted in (resulted from) | [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8597) Transformation | [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533) Persistent Item |
| [P93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10311) | -   took out of existence (was taken<br>out of existence by) | [E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8330) End of Existence | [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533) Persistent Item |
| [P13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9108) | -   -  <br>destroyed (was destroyed by) | [E6](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7410) Destruction | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10425) | _-   -_<br>_dissolved (was dissolved by)_ | [_E68_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8398) _Dissolution_ | [_E74_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) _Group_ |
| [P100](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10444) | -   -   was<br>death of (died in) | [E69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8411) Death | [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7735) Person |
| [P124](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10762) | -   -  <br>transformed (was transformed by) | [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8597) Transformation | [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533) Persistent Item |
| [P15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9152) | was influenced by<br>(influenced) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9172) | _-   used_<br>_specific object (was used for)_ | [_E7_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) _Activity_ | [_E70_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) _Thing_ |
| [P33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9470) | -   -   used<br>specific technique (was used by) | [E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7535) Modification | [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870)<br>Design or Procedure |
| [P111](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10655) | -   -   added<br>(was added by) | [E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8569) Part Addition | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P142](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11110) | -   -   used<br>constituent (was used in) | [E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7617)<br>Identifier Assignment | [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object |
| [P17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9201) | -   was<br>motivated by (motivated) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P134](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10938) | -   continued<br>(was continued by) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity |
| [P136](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10975) | -   was based<br>on (supported type creation) | [E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8616) Type Creation | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9220) | was intended use<br>of (was made for) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431)<br>Human-Made Thing |
| [P20](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9238) | had specific<br>purpose (was purpose of) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event |
| [P21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9254) | had general<br>purpose (was purpose of) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9311) | transferred title<br>of (changed ownership through) | [E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7472) Acquisition | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9344) | moved to (was<br>destination of) | [E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7496) Move | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P27](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9361) | moved from (was<br>origin of) | [E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7496) Move | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9416) | transferred<br>custody of (custody transferred through) | [E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7511) Transfer of Custody | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P43](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9643) | has dimension<br>(is dimension of) | [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing | [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144) Dimension |
| [P44](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9660) | has condition (is<br>condition of) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State |
| [P45](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9677) | consists of (is<br>incorporated in) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) Material |
| [P49](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9738) | has former or<br>current keeper (is former or current keeper of) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P50](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9758) | -   has<br>current keeper (is current keeper of) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P109](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10618) | -   has current or former curator (is<br>current or former curator of) | [E78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) Curated Holding | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P51](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9777) | has former or<br>current owner (is former or current owner of) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9797) | -   has<br>current owner (is current owner of) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9818) | has former or<br>current location (is former or current location of) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9854) | -   has<br>current location (currently holds) | [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P156](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11302) | -   occupies<br>(is occupied by) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9839) | has current<br>permanent location (is current permanent location of) | [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9895) | has number of<br>parts | [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object | [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8266) Number |
| [P59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9911) | has section (is<br>located on or within) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9927) | depicts<br>(is depicted by) | [E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765)<br>Physical Human-Made Thing | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9968) | refers to (is<br>referred to by) | [E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8675) Propositional Object | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9991) | -   foresees<br>use of (use foreseen by) | [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870) Design or Procedure | [E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) Material |
| [P70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10034) | -   documents<br>(is documented in) | [E31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7905) Document | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10053) | -   lists (is<br>listed in) | [E32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7921) Authority Document | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P129](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10852) | -   is about<br>(is subject of) | [E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8675) Propositional Object | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P138](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11017) | -   represents<br>(has representation) | [E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7987) Visual Item | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10010) | has association<br>with (is associated with) | [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870) Design or Procedure | [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870) Design or Procedure |
| [P72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10070) | has language (is<br>language of) | [E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7934) Linguistic Object | [E56](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8194) Language |
| [P74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10107) | has current or<br>former residence (is current or former residence of) | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P75](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10122) | possesses (is<br>possessed by) | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor | [E30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7893) Right |
| [P76](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10137) | has contact point<br>(provides access to) | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor | [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation |
| [P81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10186) | ongoing<br>throughout | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span | [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8279) Time Primitive |
| [P82](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10202) | at some time<br>within | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span | [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8279) Time Primitive |
| [P86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10219) | falls within<br>(contains) | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span |
| [P89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10237) | falls within<br>(contains) | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_heading=h.319y80a) Place | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10256) | has value | [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144) Dimension | [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8266) Number |
| [P91](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10271) | has unit (is unit<br>of) | [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144) Dimension | [E58](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8226) Measurement Unit |
| [P180](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11687) | -   has<br>currency | [E97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) Monetary Amount | [E98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8830) Currency |
| [P97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10390) | from father (was<br>father for) | [E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8383) Birth | [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7735) Person |
| [P101](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10463) | had as general<br>use (was use of) | [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P103](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10505) | was intended for<br>(was intention of) | [E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431) Human-Made Thing | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P104](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10520) | is subject to<br>(applies to) | [E72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8467) Legal Object | [E30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7893) Right |
| [P105](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10535) | right held by<br>(has right on) | [E72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8467) Legal Object | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9797) | _-   has_<br>_current owner (is current owner of)_ | [_E18_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) _Physical Thing_ | [_E39_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) _Actor_ |
| [P106](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10554) | is composed of<br>(forms part of) | [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object | [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object |
| [P165](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11401) | -  <br>incorporates (is incorporated in) | [E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8484) Information Object | [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object |
| [P107](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10575) | has current or<br>former member (is current or former member of) | [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group | [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor |
| [P121](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10707) | overlaps with | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P122](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10725) | borders with | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P125](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10782) | used object of<br>type (was type of object used in) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9452) | -   used<br>general technique (was technique of) | [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P126](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10799) | employed (was<br>employed in) | [E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7535) Modification | [E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) Material |
| [P127](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10815) | has broader term<br>(has narrower term) | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P130](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10870) | shows features of<br>(features are also found on) | [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing | [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing |
| [P73i](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10085) | -   is<br>translation of | [E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7934) Linguistic Object | [E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7934) Linguistic Object |
| [P128](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10833) | -   carries<br>(is carried by) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object |
| [P65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9947) | -   -   shows<br>visual item (is shown by) | [E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765)<br>Physical Human-Made Thing | [E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7987) Visual Item |
| [P132](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10895) | spatiotemporally<br>overlaps with | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670)<br>Spacetime Volume | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume |
| [P10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9027) | -   falls<br>within (contains) | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723)<br>Spacetime Volume | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume |
| [P166](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11425) | -   -   was a<br>presence of (had presence) | [E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8744)<br>Presence | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume |
| [P46](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9693) | is composed of<br>(forms part of) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666)<br>Physical Thing | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P56](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9874) | -   bears<br>feature (is found on) | [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697)<br>Physical Object | [E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7807) Physical Feature |
| [P133](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10917) | is separated from | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723)<br>Spacetime Volume | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume |
| [P139](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11041) | has alternative<br>form (is alternative form of) | [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039)<br>Appellation | [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation |
| [P140](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11066) | assigned<br>attribute to (was attributed by) | [E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7577)<br>Attribute Assignment | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9490) | -   concerned<br>(was assessed by) | [E14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7602)<br>Condition Assessment | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9568) | -   measured<br>(was measured by) | [E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7634)<br>Measurement | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9605) | -   classified<br>(was classified by) | [E17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7652)<br>Type Assignment | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P141](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11087) | assigned (was<br>assigned by) | [E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7577)<br>Attribute Assignment | [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity |
| [P35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9511) | -   has<br>identified (identified by) | [E14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7602)<br>Condition Assessment | [Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State |
| [P37](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9530) | -   assigned<br>(was assigned by) | [E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7617)<br>Identifier Assignment | [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier |
| [P38](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9549) | -   deassigned<br>(was deassigned by) | [E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7617)<br>Identifier Assignment | [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier |
| [P40](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9585) | -   observed<br>dimension (was observed in) | [E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7634) Measurement | [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144) Dimension |
| [P42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9623) | -   assigned<br>(was assigned by) | [E17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7652) Type Assignment | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P147](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11216) | curated (was<br>curated by) | [E87](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8662) Curation Activity | [E78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) Curated Holding |
| [P148](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11232) | has component (is<br>component of) | [E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8675) Propositional Object | [E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8675) Propositional Object |
| [P150](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11249) | defines typical<br>parts of (defines typical wholes for) | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type | [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type |
| [P152](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11281) | has parent (is<br>parent of) | [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7735) Person | [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7735) Person |
| [P157](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11327) | is at rest<br>relative to (provides reference space for) | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P59i](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9911) | -    is<br>located on or within | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P156i](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11302) | _-    is_<br>_occupied by_ | [_E53_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) _Place_ | [_E18_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) _Physical Thing_ |
| [P160](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11345) | has temporal<br>projection | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span |
| [P164](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11381) | -    is temporally specified by<br>(temporally specifies) | [E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8744) Presence | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span |
| [P161](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11362) | has spatial<br>projection | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P167](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11442) | was within<br>(includes) | [E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_heading=h.3z7bk57) Presence | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P171](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11514) | at some place<br>within | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place | [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8762) Space Primitive |
| [P172](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11530) | contains | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place | [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8762) Space Primitive |
| [P173](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11546) | starts before or<br>with the end of (ends after or with the start of) | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity |
| [P174](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11569) | -   starts<br>before the end of (ends after the start of) | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity |
| [P184](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11759) | -    -   ends before or with the end of<br>(ends with or after the end of) | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity |
| [P185](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11784) | -    -   -   ends before the end of<br>(ends after the end of) | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity |
| [P182](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11704) | -    -   -   -   ends before or with the<br>start of (starts after or with the end of) | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity |
| [P175](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11599) | -    -   starts before or with the<br>start of (starts after or with the start of) | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity |
| [P176](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11624) | -    -   -   starts before the start of<br>(starts after the start of) | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity |
| [P134](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10938)i | _-    -   -_<br>_-   was continued by_ | [_E7_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) _Activity_ | [_E7_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) _Activity_ |
| [P182](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11704) | _-    -   -   -   ends before or with the_<br>_start of (starts after or with the end of)_ | [_E2_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310) _Temporal Entity_ | [_E2_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310) _Temporal Entity_ |
| [P183](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11392) | -    -   -   -   -   ends before the<br>start of (starts after the end of) | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity | [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity |
| [P179](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11672) | had sales price<br>(was sales price of) | [E96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8807) Purchase | [E97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) Monetary Amount |
| [P186](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11810) | produced thing of<br>product type (is produced by) | [E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7558) Production | [E99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8841) Product Type |
| [P187](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11825) | has production<br>plan (is production plan for) | [E99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8841) Product Type | [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870) Design or Procedure |
| [P188](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11839) | requires<br>production tool (is production tool for) | [E99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8841) Product Type | [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object |
| [P189](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11853) | approximates | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P191](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11896) | had duration (was<br>duration of) | [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span | [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144) Dimension |
| [P195](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11910) | was a presence of<br>(had presence) | [E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8744) Presence | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |
| [P196](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11927) | defines (is<br>defined by) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume |
| [P197](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11945) | covered parts of<br>(was partially covered by) | [E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8744) Presence | [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place |
| [P198](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11961) | holds or supports<br>(is held or supported by) | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing | [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing |

### CIDOC CRM Properties of Properties (.1 Properties)

Table 5: CIDOC
CRM Properties of Properties (.1 Properties) Hierarchy

|     |     |     |     |
| --- | --- | --- | --- |
| **Property**<br>**id** | **Property**<br>**Name** | **Property –**<br>**Domain** | **Entity -**<br>**Range** |
| P3.1 | has type | E1 CRM<br>Entity. **P3 has note:** E62 String | E55 Type |
| P14.1 | in the role<br>of | E7 Activity. **P14**<br>**carried out by (performed)**:E39 Actor | E55 Type |
| P16.1 | mode of use | E7 Activity. **P16**<br>**used specific object (was used for)**: E70 Thing | E55 Type |
| P19.1 | mode of use | E7 Activity. **P19**<br>**was intended use of (was made for):** E71 Human-Made Thing | E55 Type |
| P62.1 | mode of depiction | E24 Physical<br>Human-Made Thing. **P62 depicts (is depicted by)**: E1 CRM Entity | E55 Type |
| P67.1 | has type | E89<br>Propositional Object. **P67 refers to (is referred to by)**: E1 CRM Entity | E55 Type |
| P138.1 | -   mode of representation | E36 Visual<br>Item. **P138 represents (has representation)**: E1 CRM Entity | E55 Type |
| P69.1 | has type | E29 Design or<br>Procedure. **P69 has association with (is associated with)**: E29 Design<br>or Procedure | E55 Type |
| P102.1 | has type | E71<br>Human-Made Thing. **P102 has title (is title of)**: E35 Title | E55 Type |
| P107.1 | kind of<br>member | E74 Group. **P107**<br>**has current or former member (is current or former member of)**: E39 Actor | E55 Type |
| P136.1 | in the<br>taxonomic role | E83 Type<br>Creation. P136 was based on (supported type creation): E1 CRM Entity | E55 Type |
| P130.1 | kind of<br>similarity | E70 Thing. **P130**<br>**shows features of (features are also found on):** E70 Thing. | E55 Type |
| P137.1 | in the<br>taxonomic role | E1 CRM<br>Entity. **P137 exemplifies (is exemplified by)**: E55 Type | E55 Type |
| P139.1 | has type | **E41**<br>**Appellation**. **P139 has**<br>**alternative form (is alternative form of)**: E41 Appellation | E55 Type |
| P144.1 | kind of<br>member | E85 Joining. **P144**<br>**joined with (gained member by)**: E74 Group | E55 Type |
| P189.1 | has type | E53 Place. **P189**<br>**approximates (is approximated by)**. E53 Place | E55 Type |

This page is
left blank on purpose

# CIDOC CRM Class Declarations

The classes of the CIDOC CRM are
comprehensively declared in this section using the following format:

·Class names are presented as headings in bold
face, preceded by the class’ unique identifier;

·The line “Subclass of:” declares the superclass
of the class from which it inherits properties;

·The line “Superclass of:” is a cross-reference
to the subclasses of this class;

·The line “Scope note:” contains the textual
definition of the concept the class represents;

·The line “Examples:” contains a bulleted list of
examples of instances of this class. If the example is also instance of a
subclass of this class, the unique identifier of the subclass is added in
parenthesis. If the example instantiates two classes, the unique identifiers of
both classes is added in parenthesis. Non-fictitious examples may be followed
by an explanation in brackets.

·The line “In first-order logic:” expresses the
formal constraints of the class in terms of logical axioms in a first-order logic
notation;

·The line “Properties:” declares the list of the
class’ properties;

·Each property is represented by its unique
identifier, its forward and reverse names, and the range class that it links
to, separated by colons;

·Inherited properties are not represented;

·Properties of properties are shown indented and
in parentheses beneath their respective domain property.

E1 CRM Entity

Superclass of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096)
Time-Span

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144)
Dimension

[E59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8245)
Primitive Value

[E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533) Persistent Item

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume

Scope note:

This class comprises all things in
the universe of discourse of the CIDOC Conceptual Reference Model.

It is an abstract concept providing
for three general properties:

·Identification by name or appellation, and in
particular by a preferred identifier

·Classification by type, allowing further
refinement of the specific subclass to which an instance belongs

·Attachment of free text and other unstructured
data for the expression of anything not captured by formal properties

All
other classes within the CIDOC CRM are directly or indirectly specialisations
of E1 CRM Entity.

Examples:

the earthquake in Lisbon 1755 (E5)
(Chester, 2001)

In first-order logic:

E1(x)

Properties:

[P1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8872) is identified by (identifies): [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

[P2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8894) has type (is type of): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

[P3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8915) has note: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) String

(P3.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

[P48](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9718) has preferred identifier (is preferred
identifier of): [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076)
Identifier

[P137](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10996) exemplifies (is exemplified by): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

(P137.1 in the taxonomic role: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

E2 Temporal Entity

Subclass of:

[Ε1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7280) CRM Entity

Superclass of:

[Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State

[E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period

Scope note:

This class comprises all phenomena,
such as the instances of E4 Periods and E5 Events, which happen over a limited
extent in time. This extent in time must be contiguous, i.e., without gaps. In
case the defining kinds of phenomena for an instance of E2 Temporal Entity
cease to happen, and occur later again at another time, we regard that the
former instance of E2 Temporal Entity has ended and a new instance has come
into existence. In more intuitive terms, the same event cannot happen twice.

In some contexts, such phenomena are
also called perdurants. This class is disjoint from E77 Persistent Item and is
an abstract class that typically has no direct instances. E2 Temporal Entity is
specialized into E4 Period, which applies to a particular geographic area (defined
with a greater or lesser degree of precision), and E3 Condition State, which
applies to instances of E18 Physical Thing.

Examples:

Bronze
Age (E4) (Childe, 1963)

the
earthquake in Lisbon 1755 (E5) (Chester, 2001)

the
Peterhof Palace near Saint Petersburg being in ruins from 1944 to 1946 (E3)
(Maddox, 2015)

In first-order logic:

E2(x) ⇒ E1(x)

Properties:

[P4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8939) has time-span (is time-span of): [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span

[P173](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11546) starts before or
with the end of (ends after or with the start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[P174](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11569) starts before the end of (ends after the start
of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[P175](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11599) starts before or with the start of (starts after
or with the start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[P176](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11624) starts before the start of (starts after the
start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[P182](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11704) ends before or with the start of (starts after
or with the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[P183](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11731) ends before the start of (starts after the end
of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[P184](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11759) ends before or with the end of (ends with or
after the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[P185](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11784) ends before the end of (ends after the end
of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

E3 Condition
State

Subclass of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Scope note:

This class comprises the states of
objects characterised by a certain condition over a time-span.

An instance of this class describes
the prevailing physical condition of any material object or feature during a
specific instance of E52 Time-Span. In general, the time-span for which a
certain condition can be asserted may be shorter than the real time-span, for
which this condition held.

The nature of that condition can be
described using _P2 has type_. For example, the instance of E3 Condition
State “condition of the SS Great Britain between 22nd September 1846
and 27th August 1847” can be characterized as an instance “wrecked”
of E55 Type.

Examples:

the
"reconstructed" state of the “Amber Room” in Tsarskoje Selo from
summer 2003 until now (Owen, 2009)

the
"ruined" state of Peterhof Palace near Saint Petersburg from 1944 to
1946 (Maddox, 2015)

the
state of my turkey in the oven at 14:30 on 25th December 2002 \[ _P2_\
_has type:_ E55 Type “still not cooked”\] (fictitious)

the
topography of the leaves of Sinai Printed Book 3234.2361 on the 10th
July 2007 \[described as: of type "cockled"\] (fictitious)

In first-order logic:

E3(x) ⇒ E2(x)

Properties:

[P5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8953) consists of (forms part of): [Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State

E4 Period

Subclass of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume

Superclass of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event

Scope note:

This class comprises sets of
coherent phenomena or cultural manifestations occurring in time and space.

It is the social or physical
coherence of these phenomena that identify an instance of E4 Period and not the
associated spatiotemporal extent. This extent is only the “ground” or space in
an abstract physical sense that the actual process of growth, spread and
retreat has covered. Consequently, different periods can overlap and coexist in
time and space, such as when a nomadic culture exists in the same area and time
as a sedentary culture. This also means that overlapping land use rights,
common among first nations, amounts to overlapping periods.

Often, this class is used to
describe prehistoric or historic periods such as the “Neolithic Period”, the
“Ming Dynasty” or the “McCarthy Era”, but also geopolitical units and
activities of settlements are regarded as special cases of E4 Period. However,
there are no assumptions about the scale of the associated phenomena. In
particular all events are seen as synthetic processes consisting of coherent
phenomena. Therefore, E4 Period is a superclass of E5 Event. For example, a
modern clinical birth, an instance of E67 Birth, can be seen as both a single
event, i.e. an instance of E5 Event, and as an extended period, i.e. an
instance of E4 Period, that consists of multiple physical processes and
complementary activities performed by multiple instances of E39 Actor.

E4 Period is a subclass of E2
Temporal Entity and of E92 Spacetime Volume. The latter is intended as a
phenomenal spacetime volume as defined in CIDOC CRMgeo (Doerr & Hiebel,
2013). By virtue of this multiple inheritance, it is possible to discuss the
physical extent of an instance of E4 Period without representing each instance
of it together with an instance of its associated spacetime volume. This model
combines two quite different kinds of substance: an instance of E4 Period is a
phenomenon while an instance of E92 Spacetime Volume is an aggregation of
points in spacetime. However, the real spatiotemporal extent of an instance of
E4 Period is regarded to be unique to it due to all its details and fuzziness;
its identity and existence depends uniquely on the identity of the instance of
E4 Period. Therefore, this multiple inheritance is unambiguous and effective
and furthermore corresponds to the intuitions of natural language.

Typical use of this class in
cultural heritage documentation is for documenting cultural and artistic
periods. There are two different conceptualisations of ‘artistic style’,
defined either by physical features or by historical context. For example,
“Impressionism” can be viewed as a period in the European sphere of influence
lasting from approximately 1870 to 1905 during which paintings with particular
characteristics were produced by a group of artists that included (among
others) Monet, Renoir, Pissarro, Sisley and Degas. Alternatively, it can be
regarded as a style applicable to all paintings sharing the characteristics of
the works produced by the Impressionist painters, regardless of historical
context. The first interpretation is an instance of E4 Period, and the second
defines morphological object types that fall under E55 Type.

A geopolitical unit as a specific
case of an instance of E4 Period is the set of activities and phenomena related
to the claim of power, the consequences of belonging to a jurisdictional area
and an administrative system that establishes a geopolitical unit. Examples
from the modern period are countries or administrative areas of countries such
as districts whose actions and structures define activities and phenomena in
the area that they intend to govern. The borders of geopolitical units are
often defined in contracts or treaties although they may deviate from the
actual practice. The spatiotemporal properties of Geopolitical units can be
modelled through the properties inherited from E92 Spacetime Volume.

Another specific case of an instance
of E4 Period is the actual extent of the set of activities and phenomena as
evidenced by their physical traces that define a settlement, such as the
populated period of Nineveh.

Examples:

Jurassic
(Hallam, 1975)

Populated
Period of Nineveh

Imperial
Rome under Marcus Aurelius

European
Bronze Age (Harrison, 2004)

Italian
Renaissance (Macdonald, 1992)

Thirty
Years War (Lee, 1991)

Sturm
und Drang (Berkoff, 2013)

Cubism
(Cox, 2000)

The
Capital of Russia (E4) \[the capital of Russia in the sense of an administrative\
unit moved in historical times from Moscow to St Petersburg and then back to\
Moscow. This exemplifies an administrative unit changing place over time\
without temporal discontinuity\]

The
settling activity of the community of Helsinki (a.k.a. Helsingfors) (E7) \[the\
original settlement called Helsinki was located in the area of the modern\
airport. The community moved later to settle on the coast. This exemplifies a\
continued activity changing place over time without temporal discontinuity\]

Bronze
Age (E4) \[Bronze Age, in the sense of technological adoption, spread over\
disjoint areas including islands such as the British Isles without temporal\
discontinuity\]

Japan,
the state (E4) \[In 2021, the Japanese state as a political unit comprised in\
6852 islands extending along the Pacific coast of Asia\]

In first-order logic:

E4(x) ⇒ E2(x)

E4(x) ⇒ E92(x)

Properties **:**

[P7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8970) took place at (witnessed): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[P8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8987) took place on or within (witnessed): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

[P9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9005) consists of (forms part of): [E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period

E5 Event

Subclass of:

[E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period

Superclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8309) Beginning of Existence

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8330) End of Existence

Scope note:

This class comprises distinct,
delimited and coherent processes and interactions of a material nature, in
cultural, social or physical systems, involving and affecting instances of E77
Persistent Item in a way characteristic of the kind of process. Typical
examples are meetings, births, deaths, actions of decision taking, making or
inventing things, but also more complex and extended ones such as conferences,
elections, building of a castle, or battles.

While the continuous growth of a
tree lacks the limits characteristic of an event, its germination from a seed
does qualify as an event. Similarly, the blowing of the wind lacks the distinctness
and limits of an event, but a hurricane, flood or earthquake would qualify as
an event. Mental processes are considered as events, in cases where they are
connected with the material externalization of their results; for example, the
creation of a poem, a performance or a change of intention that becomes obvious
from subsequent actions or declarations.

The effects of an instance of E5
Event may not lead to relevant permanent changes of properties or relations of
the items involved in it, for example an unrecorded performance. Of course, in
order to be documented, some kind of evidence for an event must exist, be it
witnesses, traces or products of the event.

While instances of E4 Period always
require some form of coherence between its constituent phenomena, in addition,
the essential constituents of instances of E5 Event should contribute to an
overall effect; for example, the statements made during a meeting and the
listening of the audience.

Viewed at a coarse level of detail,
an instance of E5 Event may appear as if it had an ‘instantaneous’ overall
effect, but any process or interaction of material nature in reality have an
extent in time and space. At a fine level, instances of E5 Event may be analysed
into component phenomena and phases within a space and timeframe, and as such
can be seen as a period, regardless of the size of the phenomena. The reverse
is not necessarily the case: not all instances of E4 Period give rise to a
noteworthy overall effect and are thus not instances of E5 Event.

Examples:

the
birth of Cleopatra (E67) (Pomeroy, 1984)

the
destruction of Herculaneum by volcanic eruption in 79 AD (E6) (Camardo, 2013)

World War
II (E7) (Barber, 1994)

the
Battle of Stalingrad (E7) (Hoyt, 1993)

the
Yalta Conference (E7) (Harbutt, 2010)

my
birthday celebration 28-6-1995 (E7)

the
falling of a tile from my roof last Sunday (fictitious)

the
CIDOC conference 2003 (E7)

In first-order logic:

E5(x) ⇒ E4(x)

Properties:

[P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9052) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[P12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9081) occurred in the presence of (was present at): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533) Persistent Item

E6 Destruction

Subclass of:

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8330) End of Existence

Scope note:

This class comprises events that
destroy one or more instances of E18 Physical Thing, such that they lose their
identity as the subjects of documentation.

Some destruction events are
intentional, while others are independent of human activity. Intentional destruction
can be documented by classifying the event as both an instance of E6
Destruction and of E7 Activity.

The decision to document an object
as destroyed, transformed, or modified is context-sensitive:

1\. If the matter remaining from the
destruction is not documented, the event is modelled solely as an instance of
E6 Destruction.

2\. An event should also be
documented using E81 Transformation if it results in the destruction of one or
more objects and the simultaneous production of others using parts or material
from the original. In this case, the new items have separate identities. Matter
is preserved, but identity is not.

3\. When the initial identity of the
changed instance of E18 Physical Thing is preserved, the event should be
documented as an instance of E11 Modification.

Examples:

the
destruction of Herculaneum by volcanic eruption in 79 AD (Camardo, 2013)

the
destruction of Nineveh (E6, E7) (River, 2016)

the
breaking of a champagne glass yesterday by my dog (fictitious)

In first-order logic:

E6(x) ⇒ E64(x)

Properties:

[P13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9108) destroyed (was destroyed by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

E7 Activity

Subclass of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event

Superclass of:

[E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7472) Acquisition

[E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7496) Move

[E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7511) Transfer of Custody

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7535) Modification

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7577) Attribute Assignment

[E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8349) Creation

[E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8365) Formation

[E85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8631) Joining

[E86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8647) Leaving

[E87](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8662) Curation Activity

Scope note:

This class comprises actions
intentionally carried out by instances of E39 Actor that result in changes of
state in the cultural, social, or physical systems documented.

This notion includes complex,
composite, and long-lasting actions such as the building of a settlement or a
war, as well as simple, short-lived actions such as the opening of a door.

Examples:

the
Battle of Stalingrad (Hoyt, 1993)

the
Yalta Conference (Harbutt, 2010)

my
birthday celebration 28-6-1995

the writing of
“Faust” by Goethe (E65) (Williams, 2020)

the formation of
the Bauhaus 1919 (E66) (Droste, 2006)

the people of Iraq
giving the name ‘Quyunjig’ to the place identified by the TGN as ‘7017998’

Kira Weber working
in glass art from 1984 to 1993

Kira Weber working
in oil and pastel painting from 1993

In first-order logic:

E7(x) ⇒ E5(x)

Properties:

[P14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9126) carried out by (performed): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

(P14.1 in the role of: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

[P15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9152) was influenced by (influenced): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[P16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9172) used specific object (was used for): [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing

(P16.1 mode of use: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

[P17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9201) was motivated by (motivated): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[P19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9220) was intended use of (was made for): [E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431) Human-Made Thing

(P19.1 mode of use: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

[P20](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8962) had specific purpose (was purpose of): [E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event

[P21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9254) had general purpose (was purpose of): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

[P32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9452) used general technique (was technique of): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

[P33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9470) used specific technique (was used by): [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870) Design or Procedure

[P125](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10782) used object of type (was type of object used
in): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

[P134](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10938) continued (was continued by): [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

E8 Acquisition

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

Superclass of:

[E96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8807) Purchase

Scope note:

This class comprises transfers of
legal ownership from one or more instances of E39 Actor to one or more other
instances of E39 Actor.

The class also applies to the
establishment or loss of ownership of instances of E18 Physical Thing. It does
not, however, imply changes of any other kinds of rights. The recording of the
donor and/or recipient is optional. It is possible that in an instance of E8
Acquisition there is either no donor or no recipient. Depending on the
circumstances, it may describe:

1the beginning
of ownership

2the end of
ownership

3the
transfer of ownership

4the
acquisition from an unknown source

5the loss of
title due to destruction of the item

It may also describe events where a
collector appropriates legal title, for example, by annexation or field
collection. The interpretation of the museum notion of “accession” differs
between institutions. The CIDOC CRM therefore models legal ownership (E8
Acquisition) and physical custody (E10 Transfer of Custody) separately.
Institutions will then model their specific notions of accession and
deaccession as combinations of these.

Examples

the
collection of a hammerhead shark, _genus_ _Sphyrna_
(Carchariniformes), by John Steinbeck and Edward Ricketts at Puerto Escondido
in the Gulf of Mexico on 25th March 1940. (Steinbeck, 2000)

the
acquisition of El Greco’s “The Apostles Peter and Paul” by the State Hermitage
in Saint Petersburg.
(https://hermitagemuseum.org/wps/portal/hermitage/digital-collection/01.+Paintings/32730)

the
loss of my stuffed _Fringilla coelebs_ due to insect damage last year
(fictitious)

In first-order logic:

E8(x) ⇒ E7(x)

Properties:

[P22](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9273) transferred title to (acquired title through): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[P23](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9293) transferred title from (surrendered title
through): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[P24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9311) transferred title of (changed ownership
through): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

E9 Move

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

Scope note:

This class comprises changes of the
physical location of the instances of E19 Physical Object.

Note,
that the class E9 Move inherits the property _P7 took place at (witnessed):_ E53
Place. This property should be used to describe the trajectory or a larger area
within which a move takes place, whereas the properties _P26 moved to (was_
_destination of)_, _P27 moved from (was origin of)_ describe the start
and end points only. Moves may also be documented to consist of other moves
(via _P9 consists of (forms part of)_), in order to describe intermediate
stages on a trajectory. In that case, start and end points of the partial moves
should match appropriately between each other and with the overall event.

Examples:

the
relocation of London Bridge from the UK to the USA (Wildfang, 2005)

the movement of
the exhibition “Tutankhamun: Treasures of the Golden Pharaoh” between 15th September and 2nd
November 2019

In first-order logic:

E9(x) ⇒ E7(x)

Properties:

[P25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9326) moved (moved by): [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object

[P26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9344) moved to (was destination of): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[P27](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9361) moved from (was origin of): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

E10 Transfer of Custody

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

Scope note:

This class comprises transfers of
the physical custody or the legal responsibility for the physical custody of
objects. The recording of the donor or recipient is optional. It is possible
that in an instance of E10 Transfer of Custody there is either no donor or no
recipient.

Depending on the circumstances, it
may describe:

1the beginning of custody (there is no previous
custodian)

2the end of custody (there is no subsequent
custodian)

3the transfer of custody (transfer from one
custodian to the next)

4the receipt of custody from an unknown source
(the previous custodian is unknown)

5the declared loss of an object (the current or
subsequent custodian is unknown)

In the event that only a single kind
of transfer of custody occurs, either the legal responsibility for the custody
or the actual physical possession of the object but not both, this difference
should be expressed using the property _P2 has type (is type of)_.

The sense of physical possession
requires that the object of custody be in the hands of the keeper at least with
a part representative for the whole. The way, in which a representative part is
defined, should ensure that it is unambiguous who keeps a part and who the
whole and should be consistent with the identity criteria of the kept instance
of E18 Physical Thing.

The interpretation of the museum
notion of "accession" differs between institutions. The CIDOC CRM
therefore models legal ownership and physical custody separately. Institutions
will then model their specific notions of accession and deaccession as
combinations of these.

Theft is a specific case of illegal
transfer of custody.

Examples:

the
delivery of the paintings by Secure Deliveries Inc. to the National Gallery

the
return of Picasso’s “Guernica” to Madrid’s Prado in 1981 (Chipp, 1988)

the
transfer of custody of the work described as “Von der Velden ein Ufer an der
See” from Johann Matthäus von Merian to the Auction House Heldevier
(Jacob) for the purpose of sale, ca. 1716

the
transfer of custody of the painting ‘Mrs. Fitzherbert’ to the art dealer
Knoedler from Parke-Bernet Galleries (New York, NY, USA) ca. March 1941

In first-order logic:

E10(x) ⇒ E7(x)

Properties:

[P28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9378) custody surrendered by (surrendered custody
through): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[P29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9397) custody received by (received custody through):
[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[P30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9416) transferred custody of (custody transferred
through): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical
Thing

E11 Modification

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

Superclass of:

[E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7558) Production

[E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8569) Part Addition

[E80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8583) Part Removal

Scope note:

This class comprises instances of E7
Activity that are undertaken to create, alter or change instances of E24
Physical Human-Made Thing.

This class includes the production
of an item from raw materials and other so far undocumented objects. It also
includes the conservation treatment of an object.

Since the distinction between
modification and production is not always clear, modification is regarded as
the more generally applicable concept. This implies that some items may be
consumed or destroyed in an instance of E11 Modification, and that others may
be produced as a result of it. An event should also be documented using an
instance of E81 Transformation if it results in the destruction of one or more
objects and the simultaneous production of others using parts or material from
the originals. In this case, the new items have separate identities.

An activity undertaken on an object
which was designed to alter it, but which, in fact, it did not in any seemingly
significant way (such as the application of a solvent during conservation which
failed to dissolve any part of the object), is still considered as an instance
of E11 Modification. Typically, any such activity will leave at least forensic
traces of evidence on the object.

If the instance of E29 Design or
Procedure utilized for the modification prescribes the use of specific
materials, they should be documented using property _P68 foresees use of (use_
_foreseen by)_: E57 Material of E29 Design or Procedure, rather than via _P126_
_employed (was employed in)_: E57 Material.

Examples:

the
construction of the SS Great Britain (E12) (Gregor, 1971)

the
impregnation of the Vasa warship in Stockholm for preservation after 1956
(Håfors, 2010)

the
transformation of the Enola Gay into a museum exhibit by the National Air and
Space Museum in Washington DC between 1993 and 1995 (E12, E81) (Yakel, 2000)

the
last renewal of the gold coating of the Toshogu shrine in Nikko, Japan (Cali
and Dougil, 2012)

In first-order logic:

E11(x) ⇒ E7(x)

Properties:

[P31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9431) has modified (was modified by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

[P126](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10799) employed (was employed in): [E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) Material

E12 Production

Subclass of:

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7535) Modification

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8309) Beginning of Existence

Scope note:

This class comprises activities that
are designed to, and succeed in, creating one or more new items.

It specializes the notion of
modification into production. The decision as to whether or not an object is
regarded as new is context sensitive. Normally, items are considered “new” if
there is no obvious overall similarity between them and the consumed items and
material used in their production. In other cases, an item is considered “new”
because it becomes relevant to documentation by a modification. For example,
the scribbling of a name on a potsherd may make it a voting token. The original
potsherd may not be worth documenting, in contrast to the inscribed one.

This entity can be collective: the
printing of a thousand books, for example, would normally be considered a
single event.

An event should also be documented using
an instance of E81 Transformation if it results in the destruction of one or
more objects and the simultaneous production of others using parts or material
from the originals. In this case, the new items have separate identities and
matter is preserved, but identity is not.

Examples:

the
construction of the SS Great Britain (Gregor, 1971)

the
first casting of the Little Mermaid from the harbour of Copenhagen (Dewey,
2003)

Rembrandt’s
creating of the seventh state of his etching “Woman sitting half dressed beside
a stove”, 1658, identified by Bartsch Number 197 (E12, E65, E81) (Hind, 1923)

In first-order logic:

E12(x) ⇒ E11(x)

E12(x) ⇒ E63(x)

Properties:

[P108](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10598) has produced (was produced by): [E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765) Physical Human-Made
Thing

[P186](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11810) produced thing of product type (is produced
by): [E99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8841) Product Type

E13 Attribute
Assignment

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

Superclass of:

[E14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7602) Condition Assessment

[E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7617) Identifier Assignment

[E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7634) Measurement

[E17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7652) Type Assignment

Scope note:

This class comprises the actions of
making assertions about one property of an object or any single relation
between two items or concepts. The type of the property asserted to hold
between two items or concepts can be described by the property _P177 assigned_
_property of type (is type of property assigned)_: E55 Type.

For example, the class describes the
actions of people making propositions and statements during certain
scientific/scholarly procedures, e.g. the person and date when a condition
statement was made, an identifier was assigned, the museum object was measured,
etc. Which kinds of such assignments and statements need to be documented
explicitly in structures of a schema rather than free text, depends on whether
this information should be accessible by structured queries.

This class allows for the
documentation of how the respective assignment came about, and whose opinion it
was. Note that all instances of properties described in a knowledge base are
the opinion of someone. Per default, they are the opinion of the team
maintaining the knowledge base. This fact must not individually be registered
for all instances of properties provided by the maintaining team, because it
would result in an endless recursion of whose opinion was the description of an
opinion. Therefore, the use of instances of E13 Attribute Assignment marks the
fact that the maintaining team is in general neutral to the validity of the
respective assertion, but registers someone else’s opinion and how it came about.

All properties assigned in such an
action can also be seen as directly relating the respective pair of items or
concepts. Multiple use of instances of E13 Attribute Assignment may possibly
lead to a collection of contradictory values.

Examples:

the
examination of MS Sinai Greek 418 by Nicholas Pickwoad in November 2003 (Honey
& Pickwoad, 2010)

the assessment of the current ownership of Martin
Doerr’s silver cup in February 1997(fictitious)

In first-order logic:

E13(x) ⇒ E7(x)

Properties:

[P140](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11066) assigned attribute to (was attributed by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[P141](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11087) assigned (was assigned by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[P177](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11651) assigned property type (is type of property
assigned): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

E14 Condition Assessment

Subclass of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7577) Attribute Assignment

Scope note:

This class describes the act of
assessing the state of preservation of an object during a particular period.

The condition assessment may be
carried out by inspection, measurement, or through historical research. This
class is used to document circumstances of the respective assessment that is relevant
to interpret its quality at a later stage, or to continue research on related
documents.

Examples:

last
year’s inspection of humidity damage to the frescos in the St. George chapel in
our village (fictitious)

the
condition assessment of the endband cores of MS Sinai Greek 418 by Nicholas
Pickwoad in November 2003 (Honey & Pickwoad, 2010)

the
condition assessment of the cover of MS Sinai Greek 418 by Nicholas Pickwoad in
November 2003 (Honey & Pickwoad, 2010)

In first-order logic:

E14(x) ⇒ E13(x)

Properties:

[P34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9490) concerned (was assessed by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

[P35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9511) has identified (was identified by): [Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State

E15 Identifier Assignment

Subclass of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7577) Attribute Assignment

Scope note:

This class comprises activities that
result in the allocation of an identifier to an instance of E1 CRM Entity. An
instance of E15 Identifier Assignment may include the creation of the
identifier from multiple constituents, which themselves may be instances of E41
Appellation. The syntax and kinds of constituents to be used may be declared in
a rule constituting an instance of E29 Design or Procedure.

Examples of such identifiers include
Find Numbers, Inventory Numbers, uniform titles in the sense of librarianship
and Digital Object Identifiers (DOI). Documenting the act of identifier
assignment and deassignment is especially useful when objects change custody or
the identification system of an organization is changed. In order to keep track
of the identity of things in such cases, it is important to document by whom,
when, and for what purpose an identifier is assigned to an item.

The fact that an identifier is a
preferred one for an organisation can be expressed by using the property E1 CRM
Entity _. P48 has preferred identifier (is preferred identifier of):_ E42
Identifier. It can better be expressed in a context independent form by assigning
a suitable E55 Type, such as “preferred identifier assignment”, to the
respective instance of E15 Identifier Assignment through the _P2 has type (is_
_type of)_ property.

Examples:

replacement
of the inventory number TA959a by GE34604 for a 17th century lamentation
cloth at the Museum Benaki, Athens

assigning
the author and uniform title heading “Goethe, Johann Wolfgang von, 1749-1832.
Faust. 1. Theil.” to a work

on
1st June 2001, assigning the personal name heading “Guillaume, de
Machaut, ca. 1300-1377” to Guillaume de Machaut (Kelly, 2014)

In first-order logic:

E15(x) ⇒ E13(x)

Properties:

[P37](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9530) assigned (was assigned by): [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier

[P38](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9549) deassigned (was deassigned by): [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier

[P142](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11110) used constituent (was used in): [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

E16 Measurement

Subclass of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7577) Attribute Assignment

Scope note:

This class comprises actions
measuring physical properties and other values that can be determined by a
systematic, objective procedure of direct observation of particular states of
physical reality.

An instance of E16 Measurement may
use simple counting or tools, such as yardsticks or radiation detection
devices. The interest is in the method and care applied, so that the
reliability of the result may be judged at a later stage, or research continued
on the associated documents. The date of the event is important for dimensions,
which may change value over time, such as the length of an object subject to
shrinkage. Methods and devices employed should be associated with instances of
E16 Measurement by properties such as _P33 used specific technique_: E29
Design or Procedure, _P125 used object of type_: E55 Type, _P16 used_
_specific object (was used for)_: E70 Thing, whereas basic techniques such as
"carbon-14 dating" should be encoded using _P2 has type (is type_
_of)_: E55 Type. Details of methods and devices reused or reusable in other
instances of E16 Measurement should be documented for these entities rather
than the measurements themselves, whereas details of particular execution may
be documented by free text or by instantiating adequate sub-activities, if the
detail may be of interest for an overarching query.

Regardless whether a measurement is
made by an instrument or by human senses, it represents the initial transition
from physical reality to information without any other documented information
object in between within the reasoning chain that would represent the result of
the interaction of the observer or device with reality. Therefore, determining
properties of an instance of E90 Symbolic Object is regarded as an instance of
E13 Attribute Assignment, which may be inferred from observing and measuring
representative carriers. In the case that the carrier can be named, the
property _P16 used specific object (was used for)_ should be used to indicate
the instance(s) of E18 Physical Thing that was used as the empirical basis for
the attribute assignment. For instance, inferring properties of depicted items
using image material, such as satellite images, is not regarded as an instance
of E16 Measurement, but as a subsequent instance of E13 Attribute Assignment.
Rather, only the production of the images, understood as arrays of radiation
intensities, is regarded as an instance of E16 Measurement. The same reasoning
holds for other sensor data.

Examples:

measurement
of the height of silver cup 232 on 31st August 1997 (fictitious)

the
carbon 14 dating of the “Schoeninger Speer II” in 1996 \[The carbon 14 dating of\
an approximately 400.000 year old complete Old Palaeolithic wooden spear found\
in Schoeningen, Niedersachsen, Germany, in 1995.\] (Kouwenhoven, 1997)

In first-order logic:

E16(x) ⇒ E13(x)

Properties:

[P39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9568) measured (was measured by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

[P40](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9585) observed dimension (was observed in): [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144) Dimension

E17 Type Assignment

Subclass of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7577) Attribute Assignment

Scope note:

This class comprises the actions of classifying
items of whatever kind. Such items include objects, specimens, people, actions,
and concepts.

This class allows for the
documentation of the context of classification acts in cases where the value of
the classification depends on the personal opinion of the classifier, and the
date that the classification was made. This class also encompasses the notion
of “determination,” i.e. the systematic and molecular identification of a
specimen in biology.

Examples:

the
first classification of object GE34604 as Lamentation cloth at the Museum
Benaki, Athens

the
determination of a cactus in Martin Doerr’s garden as _Cereus hildmannianus_ K.Schum.,
July 2003

In first-order logic:

E17(x) ⇒ E13(x)

Properties:

[P41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9605) classified (was classified by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[P42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9623) assigned (was assigned by): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

E18 Physical Thing

Subclass of:

[E72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8467) Legal Object

Superclass of:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765) Physical Human-Made Thing

[E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7807) Physical Feature

Scope note:

This class comprises all persistent
physical items with a relatively stable form, human-made or natural.

Depending on the existence of
natural boundaries of such things, the CIDOC CRM distinguishes the instances of
E19 Physical Object from instances of E26 Physical Feature, such as holes,
rivers, pieces of land, etc. Most instances of E19 Physical Object can be moved
(if not too heavy), whereas features are integral to the surrounding matter.

An instance of E18 Physical Thing
occupies not only a particular geometric space at any instant of its existence,
but in the course of its existence it also forms a trajectory through
spacetime, which occupies a real, that is phenomenal, volume in spacetime. We
include in the occupied space the space filled by the matter of the physical
thing and all its inner spaces, such as the interior of a box. For the purpose
of more detailed descriptions of the presence of an instance of E18 Physical
Thing in space and time it can be associated with its specific instance of E92
Spacetime Volume by the property _P196 defines (is defined by)._

The CIDOC CRM is generally not
concerned with amounts of matter in fluid or gaseous states, as long as they
are not confined in an identifiable way for an identifiable minimal time-span.

Examples:

the
Cullinan Diamond (E19) (Scarratt and Shor, 2006)

the
cave “Ideon Andron” in Crete (E26) (Smith, 1844-49)

the Mona
Lisa (E22) (Mohen, 2006)

In first-order logic:

E18(x) ⇒ E72(x)

Properties:

[P44](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9660) has condition (is condition of): [Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State

[P45](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9677) consists of (is incorporated in): [E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) Material

[P46](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9693) is composed of (forms part of): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

[P49](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9738) has former or current keeper (is former or
current keeper of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021)
Actor

[P50](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9758) has current keeper (is current keeper of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[P51](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9524) has former or current owner (is former or
current owner of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021)
Actor

[P52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9797) has current owner (is current owner of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[P53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9818) has former or current location (is former or
current location of): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120)
Place

[P59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9911) has section (is located on or within): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[P128](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10833) carries (is carried by): [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

[P156](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11302) occupies (is occupied by): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[P196](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11927) defines (is defined by): [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume

E19 Physical Object

Subclass of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

Superclass of:

[E20](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7720) Biological Object

[E22](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7751) Human-Made Object

Scope note:

This class comprises items of a
material nature that are units for documentation and have physical boundaries
that separate them completely in an objective way from other objects.

The class also includes all
aggregates of objects made for functional purposes of whatever kind,
independent of physical coherence, such as a set of chessmen. Typically,
instances of E19 Physical Object can be moved (if not too heavy).

In some contexts, such objects,
except for aggregates, are also called “bona fide objects”, i.e. naturally
defined objects (Smith & Varzi, 2000).

The decision as to what is
documented as a complete item, rather than by its parts or components, may be
purely administrative or may be a result of the order in which the item was
acquired.

Examples:

Aphrodite
of Milos (E22) (Kousser, 2005)

the
Cullinan Diamond (Scarratt and Shor, 2006)

Apollo
13 at the time of launch (E22) (Lovell and Kluger, 1994)

In first-order logic:

E19(x) ⇒ E18(x)

Properties:

[P54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9839) has current permanent location (is current
permanent location of): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120)
Place

[P55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9854) has current location (currently holds): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[P56](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9874) bears feature (is found on): [E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7807) Physical Feature

[P57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9895) has number of parts: [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8266) Number

E20 Biological Object

Subclass of:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object

Superclass of:

[E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7735) Person

Scope note:

This class comprises individual
items of a material nature, which live, have lived, or are natural products of
or from living organisms.

Artificial
objects that incorporate biological elements, such as Victorian butterfly
frames, can be documented as both instances of E20 Biological Object and E22
Human-Made Object.

Examples:

me
(fictitious)

Tut-Ankh-Amun
(Edwards and Boltin, 1979)

Boukephalus
\[Horse of Alexander the Great\] (Lamb,
2005)

petrified dinosaur excrement PA1906-344

In first-order logic:

E20(x) ⇒ E19(x)

E21 Person

Subclass of:

[E20](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7720) Biological Object

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

Scope note:

This class comprises real persons
who live or are assumed to have lived.

Legendary figures that may have
existed, such as Ulysses and King Arthur, fall into this class if the
documentation refers to them as historical figures. In cases where doubt exists
as to whether several persons are in fact identical, multiple instances can be
created and linked to indicate their relationship. The CIDOC CRM does not
propose a specific form to support reasoning about possible identity.

In a bibliographic context, a name
presented following the conventions usually employed for personal names will be
assumed to correspond to an actual real person (an instance of E21 Person),
unless evidence is available to indicate that this is not the case. The fact
that a persona may erroneously be classified as an instance of E21 Person does
not imply that the concept comprises personae.

Examples:

Tut-Ankh-Amun
(Edwards and Boltin, 1979)

Nelson
Mandela (Brown and Hort, 2006)

In first-order logic:

E21(x) ⇒ E20(x)

E21(x) ⇒ E39(x)

Properties:

[P152](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11281) has parent (is parent of): [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7735) Person

E22 Human-Made Object

Subclass of:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765) Physical Human-Made Thing

Scope note:

This class comprises all persistent
physical objects of any size that are purposely created by human activity and
have physical boundaries that separate them completely in an objective way from
other objects.

The class also includes all
aggregates of objects made for functional purposes of whatever kind,
independent of physical coherence, such as a set of chessmen.

Examples:

the Rosetta Stone (E22)

LNER
Class A4 4468 Mallard \[the World’s fastest steam locomotive, preserved at the\
National Railway Museum of York, UK\] (Solomon, 2003)

the
Portland Vase (Walker, 2004)

In first-order logic:

E22(x) ⇒ E19(x)

E22(x) ⇒ E24(x)

E24 Physical Human-Made Thing

Subclass of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

[E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431)
Human-Made Thing

Superclass of:

[E22](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7751) Human-Made Object

[E25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7792) Human-Made Feature

[E78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) Curated Holding

Scope note:

This class comprises all persistent
physical items of any size that are purposely created by human activity. This
class comprises, besides others, human-made objects, such as a sword, and human-made
features, such as rock art. For example, a “cup and ring” carving on bedrock is
regarded as instance of E24 Physical Human-Made Thing.

Instances
of E24 Physical Human-Made Thing may be the result of modifying pre-existing
physical things, preserving larger parts or most of the original matter and
structure, which poses the question if they are new or even human-made, the
respective interventions of production made on such original material should be
obvious and sufficient to regard that the product has a new, distinct identity
and intended function and is human-made. Substantial continuity of the previous
matter and structure in the new product can be documented by describing the
production process also as an instance of E81 Transformation.

Whereas
interventions of conservation and repair are not regarded to produce a new
instance of E24 Physical Human-Made Thing, the results of preparation of
natural history specimens that substantially change their natural or original
state should be regarded as instances of E24 Physical Human-Made Things,
including the uncovering of petrified biological features from a solid piece of
stone. On the other side, scribbling a museum number on a natural object should
not be regarded to make it human-made. This notwithstanding, parts, sections,
segments, or features of an instance of E24 Physical Human-Made Thing may
continue to be non-human-made and preserved during the production process, for
example natural pearls used as a part of an eardrop.

Examples:

the
Forth Railway Bridge (Shipway, Bouch, Baker and Fowler, 1990).

the
Channel Tunnel (E25) (Holliday, Marcou and Vickerman, 1991)

the Palace of Knossos (Evans, 1921)

the Colosseum in Rome, Italy (Hopkins and Beard, 2011)

the
Historical Collection of the Museum Benaki in Athens (E78) (Georgoula, 2005)

the Rosetta Stone (E22)

my
paperback copy of Crime & Punishment (E22) (fictitious)

the
computer disk at ICS-FORTH that stores the canonical Definition of the CIDOC
CRM v.3.2 (E22)

my
empty DVD disk (E22) (fictitious)

In first-order logic:

E24(x) ⇒ E18(x)

E24(x) ⇒ E71(x)

Properties:

[P62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9927) depicts (is depicted by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

(P62.1 mode of depiction: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

[P65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9947) shows visual item (is shown by): [E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7987) Visual Item

E25 Human-Made Feature

Subclass of:

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765) Physical Human-Made Thing

[E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7807) Physical Feature

Scope note:

This class comprises physical
features that are purposely created by human activity, such as scratches,
artificial caves, artificial water channels, etc. In particular, it includes
the information encoding features on mechanical or digital carriers.

Examples:

the
Manchester Ship Canal (Farnie, 1980)

Michael
Jackson’s nose following plastic surgery

the
laser-readable “pits” engraved June 2014 on Martin Doerr’s CD-R, copying songs
of Edith Piaf

the
carved letters on the Rosetta Stone

In first-order logic:

E25(x) ⇒ E24(x)

E25(x) ⇒ E26(x)

E26 Physical Feature

Subclass of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

Superclass of:

[E25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7792) Human-Made Feature

[E27](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7825) Site

Scope note:

This class comprises identifiable
features that are physically attached in an integral way to particular physical
objects.

Instances of E26 Physical Feature
share many of the attributes of instances of E19 Physical Object. They may have
a one-dimensional, two-dimensional, or three-dimensional geometric extent, but
there are no natural borders that separate them completely in an objective way
from the carrier objects. For example, a doorway is a feature but the door
itself, being attached by hinges, is not.

Instances of E26 Physical Feature
can be features in a narrower sense, such as scratches, holes, reliefs, surface
colours, reflection zones in an opal crystal or a density change in a piece of
wood. In the wider sense, they are portions of particular objects with
partially imaginary borders, such as the core of the Earth, an area of property
on the surface of the Earth, a landscape or the head of a contiguous marble
statue. They can be measured and dated, and it is sometimes possible to state
who or what is or was responsible for them. They cannot be separated from the
carrier object, but a segment of the carrier object may be identified (or
sometimes removed) carrying the complete feature.

This definition coincides with the
definition of “fiat objects”, with the exception of aggregates of “bona fide
objects” (Smith & Varzi, 2000).

Examples:

the cave of Dirou, Mani, Greece (Psimenos. 2005)

the
temple in Abu Simbel before its removal, which was carved out of solid rock
(E25) (Hawass, 2000)

Albrecht
Duerer's signature on his painting of Charles the Great (E25) (Strauss, 1974)

the
damage to the nose of the Great Sphinx in Giza (Temple, 2009)

Michael
Jackson’s nose prior to plastic surgery

In first-order logic:

E26(x) ⇒ E18(x)

E27 Site

Subclass of:

[E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7807) Physical Feature

Scope note:

This class comprises pieces of land
or sea floor.

In contrast to the purely geometric
notion of E53 Place, this class describes constellations of matter on the
surface of the Earth or other celestial body, which can be represented by
photographs, paintings, and maps.

Instances of E27 Site are composed
of relatively immobile material items and features in a particular
configuration at a particular location.

Examples:

the
Amazon river basin (Hegen, 1966)

Knossos
(Evans, 1921)

the
Apollo 11 landing site (Siegler and Smrekar, 2014)

Heathrow
Airport (Wicks, 2014)

the
submerged harbour of the Minoan settlement of Gournia, Crete (Watrous, 2012)

the
island of Crete

In first-order logic:

E27(x) ⇒ E26(x)

E28 Conceptual Object

Subclass of:

[E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431)
Human-Made Thing

Superclass of:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8675) Propositional Object

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Scope note:

This class comprises non-material
products of our minds and other human produced data that have become objects of
a discourse about their identity, circumstances of creation, or historical
implication. The production of such information might have been supported by
the use of technical devices such as cameras or computers.

Characteristically, instances of
this class are created, invented or thought by someone, and then may be documented
or communicated between persons. Instances of E28 Conceptual Object have the
ability to exist on more than one particular carrier at the same time, such as
paper, electronic signals, marks, audio media, paintings, photos, human
memories, etc.

They cannot be destroyed. They exist
as long as they can be found on at least one carrier or in at least one human
memory. Their existence ends when the last carrier and the last memory are
lost.

Examples:

Beethoven’s
“Ode an die Freude” (Ode to Joy) (E73) (Kershaw, 1999)

the
definition of “ontology” in the Oxford English Dictionary (E73) (Oxford
University Press, 1989)

the
knowledge about the victory at Marathon carried by the famous runner (E89)
(Lagos & Karyanos, 2020)

\[Explanation note: The following examples illustrate the distinction\
between a propositional object, its names and its encoded forms. The Maxwell\
equations (Ball, 1962) are a good example, because they belong to the\
fundamental laws of physics and their mathematical content yields identical,\
unambiguous results regardless formulation and encoding.\]

“Maxwell
equations” (E41) \[preferred subject access point from LCSH, [http://lccn.loc.gov/sh85082387](http://lccn.loc.gov/sh85082387), accessed 18th April\
2021\. This is only the name for the Maxwell equations as standardized by the\
Library of Congress and not the equations themselves.\]

“Equations,
Maxwell” (E41) \[variant subject access point from LCSH, [http://lccn.loc.gov/sh85082387](http://lccn.loc.gov/sh85082387), accessed 18th April\
2021\. This is another name for the equation standardized by the Library of\
Congress and not the equations themselves.\]

Maxwell's
equations (E89) \[This is the propositional content of the equations proper,\
independent of any particular notation or mathematical formalism.\] (Ball, 1962)

The
encoding of Maxwells equations as in
https://upload.wikimedia.org/wikipedia/commons/c/c4/Maxwell%27sEquations.svg
(E73) \[accessed 18th April 2021. This is one possible symbolic\
encoding of the propositional content of the equations.\]

In first-order logic:

E28(x) ⇒ E71(x)

E29 Design or Procedure

Subclass of:

[E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8484) Information Object

Scope note:

This class comprises documented
plans for the execution of actions in order to achieve a result of a specific
quality, form, or contents. In particular, it comprises plans for deliberate
human activities that may result in new instances of E71 Human-Made Thing or
for shaping or guiding the execution of an instance of E7 Activity.

Instances of E29 Design or Procedure
can be structured in parts and sequences or depend on others.

This is modelled using _P69 has_
_association with (is associated with)_: E29 Design or Procedure.

Designs or procedures can be seen as
one of the following:

1A schema for the activities it describes

2A schema of the products that result from their
application

3An independent intellectual product that may
have never been applied, such as Leonardo da Vinci’s famous plans for flying
machines

Because designs or procedures may
never be applied or only partially executed, the CIDOC CRM models a loose
relationship between the plan and the respective product.

Examples:

the
ISO standardisation procedure

the
musical notation for Beethoven’s “Ode to Joy” (Kershaw, 1999)

the
architectural drawings for the Kölner Dom (Cologne Cathedral) in Cologne,
Germany (Wolff, 1999)

the
drawing found on Folio 860 of the Codex Atlanticus from Leonardo da Vinci, 1486
to 1490, kept in the Biblioteca Ambrosiana in Milan

In
first-order logic:

E29(x) ⇒ E73(x)

Properties:

[P68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9991) foresees use of (use foreseen by): [E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) Material

[P69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10010) has association with (is associated with): [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870) Design or Procedure

(P69.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

E30 Right

Subclass of:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8675) Propositional Object

Scope note:

This class comprises legal
privileges concerning material and immaterial things or their derivatives.

These include reproduction and
property rights.

Examples:

copyright
held by ISO on ISO/CD 21127

ownership
of the “Mona Lisa” by the museum of the Louvre, Paris, France

In first-order logic:

E30(x) ⇒ E89(x)

E31 Document

Subclass of:

[E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8484) Information Object

Superclass of:

[E32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7921) Authority Document

Scope note:

This class comprises identifiable
immaterial items that make propositions about reality.

These propositions may be expressed
in text, graphics, images, audiograms, videograms, or by other similar means.
Documentation databases are regarded as instances of E31 Document. This class
should not be confused with the concept “document” in Information Technology,
which is compatible with E73 Information Object.

Examples:

the
Encyclopaedia Britannica (E32) (Kogan, 1958)

the
image content of the photo of the Allied Leaders at Yalta published by UPI,
1945 (E36)

Domesday
Book \[a manuscript record of the "Great Survey" of much of England\
and parts of Wales completed in 1086 by order of King William the Conqueror\]
(Hallam 1986)

In first-order logic:

E31(x) ⇒ E73(x)

Properties:

[P70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10034) documents (is documented in): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

E32 Authority Document

Subclass of:

[E31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7905) Document

Scope note:

This class comprises encyclopaedia,
thesauri, authority lists and other documents that define terminology or
conceptual systems for consistent use.

Examples:

Webster's
Dictionary (Herbert, 1994)

Getty
Art and Architecture Thesaurus (Getty Trust, 1990)

the
CIDOC Conceptual Reference Model (Gergatsoulis et al., 2010)

In first-order logic:

E32(x) ⇒ E31(x)

Properties:

[P71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10053) lists (is listed in): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

E33 Linguistic Object

Subclass of:

[E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8484) Information Object

Superclass of:

[E34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7956) Inscription

[E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971) Title

Scope note:

This class comprises identifiable
expressions in natural language or languages.

Instances of E33 Linguistic Object
can be expressed in many ways: e.g. as written texts, recorded speech, or sign
language. However, the CIDOC CRM treats instances of E33 Linguistic Object
independently from the medium or method by which they are expressed. Expressions
in formal languages, such as computer code or mathematical formulae, are not
treated as instances of E33 Linguistic Object by the CIDOC CRM. These should be
modelled as instances of E73 Information Object.

In general, an instance of E33
Linguistic Object may also contain non-linguistic information, often of
artistic or aesthetic value. Only in cases in which the content of an instance
of E33 Linguistic Object can completely be expressed by a series of
binary-encoded symbols, its content may be documented within a respective
knowledge base by the property _P190 has symbolic content_: E62 String.
Otherwise, it should be understood as an identifiable digital resource only
available independently from the respective knowledge base.

In other cases, such as pages of an
illuminated manuscript or recordings containing speech in a language supported
by a writing system, the linguistic part of the content of an instance of E33
Linguistic Object may be documented within a respective knowledge base in a
note by _P3 has note_: E62 String. Otherwise, it may be described using
the property _P165 incorporates (is incorporated in)_: E73 Information
Object as a different object with its own identity.

Examples:

the
text of the Ellesmere Chaucer manuscript (Hilmo, 2019)

the
lyrics of the song “Blue Suede Shoes” (Cooper, 2008)

the
text of the “Jabberwocky” by Lewis Carroll (Carroll, 1981)

the
text of “Doktoro Jekyll kaj Sinjoro Hyde” \[an Esperanto translation of Dr.\
Jekyll and Mr. Hyde\]. (Stevenson, Morrison and Mann, 1909)

the
free dialog in the local dialect recorded in 1958, Telemark, Norway stored on
tape or.7-89.s1 (00.15:46-00:34), The Language Collection at the University
Library in Bergen, Norway (verified on 2020)

In
first-order logic:

E33(x) ⇒ E73(x)

Properties:

[P72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10070) has language (is language of): [E56](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8194) Language

[P73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10085) has translation (is translation of): [E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7934) Linguistic Object

E34 Inscription

Subclass of:

[E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7934) Linguistic Object

[E37](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8007) Mark

Scope note:

This class comprises recognisable
texts that can be attached to instances of E24 Physical Human-Made Thing.

The transcription of the text can be
documented in a note by _P3 has note:_ E62 String. The alphabet used can
be documented by _P2 has type:_ E55 Type. This class is not intended to
describe the idiosyncratic characteristics of an individual physical embodiment
of an inscription, but the underlying prototype. The physical embodiment is
modelled in the CIDOC CRM as instances of E24 Physical Human-Made Thing.

The relationship of a physical copy
of a book to the text it contains is modelled using E18 Physical Thing. _P128_
_carries (is carried by)_: E33 Linguistic Object _._

Examples:

“keep
off the grass” \[on a sign stuck in the lawn of the quad of Balliol College,\
Oxford, UK\]

the
text published in Corpus Inscriptionum LatinarumV 895 (Mommsen, 1872)

**“** Kilroy was here”

In first-order logic:

E34(x) ⇒ E33(x)

E34(x) ⇒ E37(x)

E35 Title

Subclass of:

[E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7934) Linguistic Object

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

Scope note:

This class comprises the textual
strings that within a cultural context can be clearly identified as titles due
to their form. Being a subclass of E41 Appellation, E35 Title can only be used
when such a string is actually used as a title of a work, such as a text, an
artwork, or a piece of music.

Titles are proper noun phrases or
verbal phrases, and should not be confused with generic object names such as
“chair”, “painting”, or “book” (the latter are common nouns that stand for
instances of E55 Type). Titles may be assigned by the creator of the work
itself, or by a social group.

This class also comprises the
translations of titles that are used as surrogates for the original titles in
different social contexts.

Examples:

“The
Merchant of Venice” (McCullough, 2005)

“Mona
Lisa” (Mohen, Menu and Mottin, 2006)

“La
Pie” (Bortolatto, 1981)

“Lucy
in the Sky with Diamonds” (Lennon, 1967)

In first-order logic:

E35(x) ⇒ E33(x)

E35(x) ⇒ E41(x)

E36 Visual Item

Subclass of:

[E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8484) Information Object

Superclass of:

[E37](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8007) Mark

Scope note:

This
class comprises the intellectual or conceptual aspects of recognisable marks
and images.

This
class does not intend to describe the idiosyncratic characteristics of an
individual physical embodiment of a visual item, but the underlying prototype.
For example, a mark such as the ICOM logo is generally considered to be the
same logo when used on any number of publications. The size, orientation, and
colour may change, but the logo remains uniquely identifiable. The same is true
of images that are reproduced many times. This means that visual items are
independent of their physical support.

The E36
Visual Item class provides a means of identifying and linking together
instances of E24 Physical Human-Made Thing that carry the same visual symbols,
marks, or images, etc. The property _P62 depicts (is depicted by)_ between
E24 Physical Human-Made Thing and the depicted subjects (E1 CRM Entity) can be
regarded as a shortcut of the more fully developed path from E24 Physical
Human-Made Thing through _P65 shows visual item (is shown by)_, E36 Visual
Item, _P138 represents (has representation)_ to E1 CRM Entity, which in
addition captures the optical features of the depiction.

Examples:

the
visual appearance of Monet’s “La Pie” (Bortolatto, 1981)

the
Coca-Cola logo (E34)

the
Chi-Rho (E37)

the
communist red star (E37)

the surface shape of Auguste Rodin's statue
"Le Penseur" \[There exist more than 20 copies, even of different\
size. Therefore, this is a good example that it is only the common surface\
shape, an immaterial visual item, which justifies displaying these copies as\
works of Auguste Rodin. As usual practice, Rodin himself did not produce the\
bronze statue, but only the prototype model.\]

In first-order logic:

E36(x) ⇒ E73(x)

Properties:

[P138](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11017) represents (has representation): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

(P138.1 mode of representation: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

E37 Mark

Subclass of:

[E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7987) Visual Item

Superclass of:

[E34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7956) Inscription

Scope note:

This class comprises symbols, signs,
signatures, or short texts applied to instances of E24 Physical Human-Made
Thing by arbitrary techniques, often in order to indicate such things as
creator, owner, dedications, purpose, or to communicate information generally.
Instances of E37 Mark do not represent the actual image of a mark, but the
abstract ideal (or archetype) as used for codification in reference documents
forming cultural documentation.

This class
specifically excludes features that have no semantic significance, such as
scratches or tool marks. These should be documented as instances of E25
Human-Made Feature.

Examples:

Minoan
double axe mark (Lowe Fri, 2011)

©

☺

In first-order logic:

E37(x)
⇒ E36(x)

E39 Actor

Subclass of:

[E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533) Persistent Item

Superclass of:

[E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7735) Person

[E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group

Scope note:

This class comprises people, either
individually or in groups, who have the potential to perform intentional
actions of kinds for which they can be held responsible.

Examples:

London
and Continental Railways (E74)

the
Governor of the Bank of England in 1975 (E21)

Sir Ian McKellen
(E21) (Gibson, 1986)

In first-order logic:

E39(x) ⇒ E77(x)

Properties:

[P74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10107) has current or former residence (is current or
former residence of): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120)
Place

[P75](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10122) possesses (is possessed by): [E30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7893) Right

[P76](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10137) has contact point (provides access to): [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

E41 Appellation

Subclass of:

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Superclass of:

[E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971) Title

[E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076)
Identifier

[E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8279) Time
Primitive

[E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8762) Space Primitive

[E95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8778) Spacetime Primitive

Scope
note:

This class comprises all signs,
either meaningful or not, or arrangements of signs following a specific syntax,
that are used or can be used to refer to and identify a specific instance of
some class within a certain context.

Instances of E41 Appellation do not
identify things by their meaning, even if they happen to have one, but by
convention, tradition, or agreement. Instances of E41 Appellation are cultural
constructs; as such, they have a context, a history, and a use in time and
space by some group of users. A given instance of E41 Appellation can have
alternative forms, i.e. other instances of E41 Appellation that are regarded as
equivalent, regardless of the thing it denotes.

Different languages may use
different appellations for the same thing, such as the names of major cities.
Some appellations may be formulated using a valid noun phrase of a particular
language. In these cases, the respective instances of E41 Appellation should
also be declared as instances of E33 Linguistic Object. Then the language using
the appellation can be declared with the property _P72 has language_: E56
Language.

Instances of E41 Appellation may be
used to identify any instance of E1 CRM Entity and sometimes are characteristic
for instances of more specific subclasses of E1 CRM Entity, such as for
instances of E52 Time-Span (for instance “dates”), E39 Actor, E53 Place or E28
Conceptual Object. Postal addresses and E-mail addresses are characteristic
examples of identifiers used by services transporting things between clients.

Even numerically expressed
identifiers for extents in space or time are also regarded as instances of E41
Appellation, such as Gregorian dates or spatial coordinates, even though
they allow for determining some time or location by a known procedure starting
from a reference point and by virtue of that fact play a double role as
instances of E59 Primitive Value.

E41 Appellation should not be confused
with the act of naming something. Cf. E15 Identifier Assignment.

Examples:

“Martin”

“Aquae
Sulis Minerva”

“the
Merchant of Venice” (E35) (McCullough, 2005)

“Spigelia
marilandica (L.) L.” \[not the species, just the name\] (Hershberger, Robacker
and Jenkins, 2015)

“information
science” \[not the science itself, but the name used to refer to the subject\
matter in an English-speaking context\]

“安”
\[Chinese “an”, meaning “peace”\]

“6°5’29”N
45°12’13”W” \[example of a spatial coordinate\]

“Black
queen’s bishop 4” \[chess coordinate, example of an identifier in a conceptual\
space (E89)\]

“19-MAR-1922”
\[example of date\]

“+41
22 418 5571” \[example of contact point\]

“weasel@paveprime.com”
\[example of contact point\]

“CH-1211,
Genève” \[example of place appellation\]

“1-29-3
Otsuka, Bunkyo-ku, Tokyo, 121, Japan” \[example of a postal address\]

“the
poop deck of H.M.S Victory” \[example of a section definition on a human-made\
object (E22)\]

“the
Venus de Milo’s left buttock” \[example of a section definition on a human-made\
object (E22)\]

In first-order logic:

E41(x) ⇒ E90(x)

Properties:

[P139](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11041) has alternative form (is alternative form of):
[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

(P139.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

E42 Identifier

Subclass of:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

Scope note:

This class comprises strings or
codes assigned to instances of E1 CRM Entity in order to identify them uniquely
and permanently within the context of one or more organisations. Such codes are
often known as inventory numbers, registration codes, etc. and are typically
composed of alphanumeric sequences. Postal addresses, telephone numbers, URLs and
e-mail addresses are characteristic examples of identifiers used by services
transporting things between clients.

The class E42 Identifier is not
normally used for machine-generated identifiers used for automated processing
unless these are also used by human agents.

Examples:

“MM.GE.195”

“13.45.1976”

“OXCMS:
1997.4.1” (fictitious)

“ISSN
0041-5278” \[Identifier for “The UNESCO Courier (Print)”\]

ISRC
“FIFIN8900186” \[Identifier for : Kraft (29 min 14 s) / Magnus Lindberg, comp. ;\
Toimii Ensemble ; Swedish Radio symphony orchestra ; Esa-Pekka Salonen, dir.\]

Shelf
mark “Res 8 P 10”

“Guillaume
de Machaut (1300?-1377)” \[a controlled personal name heading that follows the\
French rules\] (Reaney, 1974)

“+41
22 418 5571”

“ [weasel@paveprime.com](mailto:weasel@paveprime.com)”

“Rue
David Dufour 5, CH-1211, Genève”

“1-29-3
Otsuka, Bunkyo-ku, Tokyo, 121, Japan”

In first-order logic:

E42(x) ⇒ E41(x)

E52 Time-Span

Subclass of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Scope note:

This class comprises abstract
temporal extents, in the sense of Galilean physics, having a beginning, an end,
and a duration.

Instances of E52 Time-Span have no
semantic connotations about phenomena happening within the temporal extent they
represent. They do not convey any meaning other than a positioning on the
“time-line” of chronology. The actual extent of an instance of E52 Time-Span
can be approximated by properties of E52 Time-Span giving inner and outer
bounds in the form of dates (instances of E61 Time Primitive). Comparing
knowledge about time-spans is fundamental for chronological reasoning.

Some instances of E52 Time-Span may
be defined as the actual, in principle observable, temporal extent of instances
of E2 Temporal Entity via the property _P4 has time-span (is time-span of):_ E52
Time-Span. They constitute phenomenal time-spans as defined in CRMgeo (Doerr
& Hiebel 2013). Since our knowledge of history is imperfect and physical
phenomena are fuzzy in nature, the extent of phenomenal time-spans can only be
described in approximation. An extreme case of approximation, might, for
example, define an instance of E52 Time-Span having unknown beginning, end and
duration. It may, nevertheless, be associated with other descriptions by which people
can infer knowledge about it, such as in relative chronologies.

Some instances of E52 may be defined
precisely as representing a declaration of a temporal extent, as, for instance,
done in a business contract. They constitute declarative time-spans as defined
in CRMgeo (Doerr & Hiebel 2013) and can be described via the property E61
Time Primitive _P170 defines time (time is defined by)_: E52 Time-Span.

When used as a common E52 Time-Span
for two events, it will nevertheless describe them as being simultaneous, even
if nothing else is known.

Examples:

1961

From
12-17-1993 to 12-8-1996

14h30
to 16h22 4th July 1945

9.30
am 1.1.1999 to 2.00 pm 1.1.1999

the
time-span of the Ming Dynasty (Chan, 2011)

In
first-order logic:

E52(x) ⇒ E1(x)

Properties:

[P79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10152) beginning is qualified by: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) String

[P80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10169) end is qualified by: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) String

[P81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10186) ongoing throughout: [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8279) Time Primitive

[P82](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10202) at some time within: [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8279) Time Primitive

[P86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10219) falls within (contains): [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span

[P191](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11896) had duration (was duration of): [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144) Dimension

E53 Place

Subclass of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Scope note:

This class comprises extents in the natural space where
people live, in particular on the surface of the Earth, in the pure sense of
physics: independent from temporal phenomena and matter. They may serve
describing the physical location of things or phenomena or other areas of
interest. Geometrically, instances of E53 Place constitute single contiguous
areas or a finite aggregation of disjoint areas in space which are each
individually contiguous. They may have fuzzy boundaries.

The instances of E53 Place are
usually determined by reference to the position of “immobile” objects such as
buildings, cities, mountains, rivers, or dedicated geodetic marks, but may also
be determined by reference to mobile objects. A Place can be determined by
combining a frame of reference and a location with respect to this frame.

It is sometimes argued that
instances of E53 Place are best identified by global coordinates or absolute
reference systems. However, relative references are often more relevant in the
context of cultural documentation and tend to be more precise. In particular, people
are often interested in position in relation to large, mobile objects, such as
ships. For example, the Place at which Nelson died is known with reference to a
large mobile object, i.e. H.M.S Victory. A resolution of this Place in terms of
absolute coordinates would require knowledge of the movements of the vessel and
the precise time of death, either of which may be revised, and the result would
lack historical and cultural relevance.

Any instance of E18 Physical Thing
can serve as a frame of reference for an instance of E53 Place. This may be
documented using the property _P157 is at rest relative to (provides_
_reference space for)_.

Examples:

the
extent of the UK in the year 2003

the
position of the hallmark on the inside of my wedding ring (fictitious)

the
place referred to in the phrase: “Fish collected at three miles north of the
confluence of the Arve and the Rhone”

here
\-\> <\- \[the place between these two arrows in one of the reader's paper\
copy of this document. Each copy constitutes a different place of this spot.\]

In first-order logic:

E53(x) ⇒ E1(x)

Properties:

[P89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10237) falls within (contains): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[P121](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10707) overlaps with: [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[P122](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10725) borders with: [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[P157](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11327) is at rest relative to (provides reference
space for): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical
Thing

[P168](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11459) place is defined by (defines place): [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8762) Space Primitive

[P171](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11514) at some place within: [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8762) Space Primitive

[P172](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11530) contains: [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8762) Space Primitive

[P189](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11853) approximates (is approximated by): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

E54 Dimension

Subclass of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Superclass of:

[E97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) Monetary Amount

Scope note:

This class comprises quantifiable
properties that can be measured by some calibrated means and can be
approximated by values, i.e. points or regions in a mathematical or conceptual
space, such as natural or real numbers, RGB values, etc.

An instance of E54 Dimension
represents the empirical or theoretically derived quantity, including the
precision tolerances resulting from the particular method or calculation. The
identity of an instance of E54 Dimension depends on the method of its determination
because each method may produce different values even when determining
comparable qualities. For instance, the wingspan of a bird alive or dead is a
different dimension. Thermoluminescence dating and Rehydroxylation \[RHX\] dating
are different dimensions of temporal distance from now, even if they aim at
dating the same object. The method of determination should be expressed using
the property _P2 has type (is type of)_. Note that simple terms such as
“diameter” or “length” are normally insufficient to unambiguously describe a
respective dimension. In contrast, “maximum linear extent” may be sufficient.

The properties of the class E54
Dimension allow for expressing the numerical approximation of the values of
instances of E54 Dimension adequate to the precision of the applied method of
determination. If the respective quantity belongs to a non-discrete space
according to the laws of physics, such as spatial distances, it is recommended
to record them as approximations by intervals or regions of indeterminacy
enclosing the assumed true values. For instance, a length of 5 cm may be
recorded as 4.5-5.5 cm, according to the precision of the respective
observation. Note, that comparability of values described in different units
depends critically on the representation as value regions.

Numerical approximations in archaic
instances of E58 Measurement Unit used in historical records should be
preserved. Equivalents corresponding to current knowledge should be recorded as
additional instances of E54 Dimension, as appropriate.

Examples:

the weight of the Luxor Obelisk \[250 metric tons\]

the
vertical height of the statue of David by Michelangelo \[5.17 metres\]

the
weight of the Great Star of Africa diamond \[530.2 carats\]

the
calibrated C14 date for the Shroud of Turin \[AD1262-1312, 1303-1384\]

the
horizontal diameter of the Stonehenge Sarsen Circle \[33 metres\] (Pryor, 2016)

the
length of the sides of the Great Pyramid at Giza \[230.34 metres\] (Lehner and
Hawass, 2017)

the
duration of the time-span of the Battle of Issos/Issus on 15th
November 333 B.C.E. \[less than 12 hours\] (Howard, 2012)

Christie’s
hammer price, in British Pounds, for Vincent van Gogh's "Still Life: Vase
with Fifteen Sunflowers" in London on 30th March 1987 (E97)
\[24.75 million GBP (British Pounds)\]

In first-order logic:

E54(x) ⇒ E1(x)

Properties:

[P90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10256) has value: [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8266) Number

[P91](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10271) has unit (is unit of): [E58](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8121) Measurement Unit

E55 Type

Subclass of:

[E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7841) Conceptual Object

Superclass of:

[E56](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8194) Language

[E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) Material

[E58](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8226) Measurement Unit

[E99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8841) Product Type

Scope note:

This class comprises concepts
denoted by terms from thesauri and controlled vocabularies used to characterize
and classify instances of CIDOC CRM classes. Instances of E55 Type represent
concepts, in contrast to instances of E41 Appellation which are used to name
instances of CIDOC CRM classes.

E55 Type provides an interface to
domain specific ontologies and thesauri. These can be represented in the CIDOC
CRM as subclasses of E55 Type, forming hierarchies of terms, i.e. instances of
E55 Type linked via _P127 has broader term (has narrower term_): E55 Type.
Such hierarchies may be extended with additional properties.

Examples:

weight,
length, depth \[types for instances of E54 Dimension\]

portrait,
sketch, animation \[types for instances of E36 Visual Item\]

French,
English, German \[types for instances of E56 Language\]

excellent,
good, poor \[types for instances of E3 Condition State\]

Ford
Model T, chop stick \[types for instances of E22 Human-Made Object\]

cave,
doline, scratch \[types for instances of E26 Physical Feature\]

poem,
short story \[types for instances of E33 Linguistic Object\]

wedding,
earthquake, skirmish \[types for instances of E5 Event\]

In
first-order logic:

E55(x) ⇒
E28(x)

Properties:

[P127](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10815) has broader term (has narrower term): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

[P150](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11249) defines typical parts of (define typical
wholes for): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

E56 Language

Subclass of:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

Scope note:

This class is a specialization of
E55 Type and comprises the natural languages in the sense of concepts.

This
type is used categorically in the model without reference to instances of it,
i.e. the Model does not foresee the description of instances of instances of
E56 Language, e.g. “instances of Mandarin Chinese”.

It is recommended that
internationally or nationally agreed codes and terminology should be used to
denote instances of E56 Language, such as those defined in ISO 639-3:2007 and
later versions.

Examples:

ell
\[Greek\]

eng
\[English\]

epo
\[Esperanto\]

spa
\[Spanish\]

fra
\[French\]

In first-order logic:

E56(x) ⇒ E55(x)

E57 Material

Subclass of:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

Scope note:

This class is a specialization of
E55 Type and comprises the concepts of materials.

Instances of E57 Material may denote
properties of matter before its use, during its use, and as incorporated in an
object, such as ultramarine powder, tempera paste, reinforced concrete.
Discrete pieces of raw-materials kept in museums, such as bricks, sheets of
fabric, pieces of metal, should be modelled individually in the same way as
other objects. Discrete used or processed pieces, such as the stones from Nefer
Titi's temple, should be modelled as parts (cf. _P46 is composed of (forms_
_part of)_:E18 Physical Thing).

This type is used categorically in
the model without reference to instances of it, i.e. the Model does not foresee
the description of instances of instances of E57 Material, e.g. “instances of
gold”.

It is recommended that
internationally or nationally agreed codes and terminology should be used.

Examples:

brick
(Gurcke, 1987)

gold
(Watson, 1990)

aluminium
(Norman, 1986)

polycarbonate
(Mhaske, 2011)

resin
(Barton, 1992)

In first-order logic:

E57(x) ⇒ E55(x)

E58 Measurement Unit

Subclass of:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

Superclass of:

[E98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8830) Currency

Scope note:

This class is a specialization of
E55 Type and comprises the types of measurement units: feet, inches,
centimetres, litres, lumens, etc.

This type is used categorically in
the model without reference to instances of it, i.e. the model does not foresee
the description of instances of instances of E58 Measurement Unit, e.g.
“instances of cm”.

Système International (SI)
units or internationally recognized non-SI terms should be used whenever
possible, such as those defined by ISO80000:2009. Archaic Measurement Units
used in historical records should be preserved.

Examples:

cm
\[centimetre\]

km
\[kilometre\]

m
\[metre\]

m/s \[metres\
per second\] (Hau et al., 1999)

A \[ampere\]

GRD
\[Greek Drachma\] (E98) (Daniel, 2014)

°C \[degrees centigrade\]
(Beckman, 1998)

In first-order logic:

E58(x) ⇒ E55(x)

E59 Primitive Value

Subclass of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Superclass of:

[E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8266) Number

[E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8279) Time Primitive

[E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) String

[E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8762) Space Primitive

[E95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8778) Spacetime Primitive

Scope note:

This class comprises values of
primitive data types of programming languages or database management systems
and data types composed of such values used as documentation elements, as well
as their mathematical abstractions.

The instances of E59 Primitive Value
and its subclasses are not considered elements of the universe of discourse the
CIDOC CRM aims to define and analyse. Rather, they play the role of a symbolic
interface between the scope of the model and the world of mathematical and
computational manipulations and the symbolic objects they define and handle.

In particular, they comprise lexical
forms encoded as “strings” or series of characters and symbols based on
encoding schemes (characterised by being a limited subset of the respective
mathematical abstractions) such as UNICODE and values of datatypes that can be
encoded in a lexical form, including quantitative specifications of time-spans
and geometry. They have in common that instances of E59 Primitive Value define
themselves by virtue of their encoded value, regardless of the nature of their
mathematical abstractions.

Therefore, in an implementation,
instances of E59 Primitive should be represented directly in the encoded
symbolic form supported by the respective platform, such as a character string
or a formatted date. They must not be represented in an implementation
indirectly via, another a universal resource identifier, which in turn is
linked to the actual encoded symbolic form. In a concrete application, it is
recommended that the primitive value system from a chosen implementation
platform and/or data definition language be used to substitute for this class
and its subclasses.

Examples:

“ABCDEFG”
(E62)

3.14
(E60)

0
(E60)

1921-01-01
(E61)

In first-order logic:

E59(x) ⇒ E1(x)

E60 Number

Subclass of:

[E59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8245) Primitive Value

Scope note:

This class comprises any encoding of
computable (algebraic) values such as integers, real numbers, complex numbers,
vectors, tensors, etc., including intervals of these values to express limited
precision.

Numbers are fundamentally distinct
from identifiers in continua, which are instances of E41 Appellation, such as
Gregorian dates or spatial coordinates, even though their encoding may be
similar. Instances of E60 Number can be combined with each other in algebraic
operations to yield other instances of E60 Number, e.g. 1 + 1 = 2. Identifiers
in continua may be combined with numbers expressing distances to yield new
identifiers, e.g., 1924-01-31 + 2 days = 1924-02-02. Cf. E54 Dimension.

Examples:

5

3+2i

1.5e-04

(0.5,
\- 0.7,88)

In first-order logic:

E60(x) ⇒ E59(x)

E61 Time Primitive

Subclass of:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

[E59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8245) Primitive Value

Scope note:

This class comprises instances of
E59 Primitive Value for time that should be implemented with appropriate
validation, precision, and references to temporal coordinate systems to express
time in some context relevant to cultural and scientific documentation.

Instantiating different instances of
E61 Time Primitive relative to the same instance of E52 Time-Span allows for
the expression of multiple opinions/approximations of the same phenomenon. When
representing different opinions/approximations of the E52 Time-Span of some E2
Temporal Entity, multiple instances of E61 Time Primitive should be
instantiated relative to one E52 Time-Span. Only one E52 Time-Span should be
instantiated since there is only one real phenomenal time extent of any given
temporal entity.

The instances of E61 Time Primitive
are not considered as elements of the universe of discourse that the CIDOC CRM
aims at defining and analysing. Rather, they play the role of a symbolic
interface between the scope of this model and the world of mathematical and
computational manipulations and the symbolic objects they define and handle.

Therefore, they must not be
represented in an implementation by a universal identifier associated with a
content model of different identity. In a concrete application, it is recommended
that the primitive value system from a chosen implementation platform and/or
data definition language be used to substitute for this class.

Examples:

“1994
to 1997”

“13th
May 1768”

“2000/01/01
00:00:59.7”

“85th
century BCE”

In first-order logic:

E61(x) ⇒ E41(x)

E61(x) ⇒ E59(x)

Properties:

[P170](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11495) defines time (time is defined by): [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span

E62 String

Subclass of:

[E59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8245) Primitive Value

Scope note:

This class comprises coherent
sequences of binary-encoded symbols. They correspond to the content of an
instance of E90 Symbolic object. Instances of E62 String represent only the
symbol sequence itself. They may or may not contain a language code.

In contrast, instances of other
subclasses of E59 Primitive value represent entities in mathematical spaces
other than that of symbol sequences, by using binary-encoded symbols, such as
date expressions or numbers in decimal encoding. For instance, different syntactic
forms of a date expression may represent the same date but consist of different
strings.

Examples:

“the
quick brown fox jumps over the lazy dog”

“6F
6E 54 79 70 31 0D 9E”

In first-order logic:

E62(x) ⇒ E59(x)

E63 Beginning of Existence

Subclass of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event

Superclass of:

[E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7558) Production

[E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8349) Creation

[E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8365) Formation

[E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8383) Birth

[E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8597) Transformation

Scope note:

This class comprises events that
bring into existence any instance of E77 Persistent Item.

It may be used for temporal
reasoning about things (intellectual products, physical items, groups of
people, living beings) beginning to exist; it serves as a hook for both a _terminus_
_post quem_ and a _terminus ante quem_.

Examples:

the
birth of my child (E67) (fictitious)

the
birth of Snoopy, my dog (fictitious)

the
calving of the iceberg that sank the Titanic

the
construction of the Eiffel Tower (E12) (Tissandier, 1889)

In first-order logic:

E63(x) ⇒ E5(x)

Properties:

[P92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10287) brought into existence (was brought into
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533)
Persistent Item

E64 End of Existence

Subclass of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event

Superclass of:

[E6](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7410) Destruction

[E68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8398)
Dissolution

[E69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8411) Death

[E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8597)
Transformation

Scope note:

This class comprises events that end
the existence of any instance of E77 Persistent Item.

It may be used for temporal
reasoning about things (physical items, groups of people, living beings)
ceasing to exist; it serves as a hook both a _terminus post quem_ and a _terminus_
_ante quem_. In cases where substance from an instance of E77 Persistent Item
continues to exist in a new form, the process would be documented as instances
of E81 Transformation.

Examples:

the
death of Snoopy, my dog (fictitious)

the
melting of the snowman (E6)

the
burning of the Temple of Artemis in Ephesos by Herostratos in 356 BC (E7, E6)
(Trell, 1945)

In first-order logic:

E64(x) ⇒ E5(x)

Properties:

[P93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10038) took out of existence (was taken out of
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533)
Persistent Item

E65 Creation

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8309) Beginning of Existence

Superclass of:

[E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8616) Type Creation

Scope note:

This class comprises events that
result in the creation of conceptual items or immaterial products, such as
legends, poems, texts, music, images, movies, laws, types, etc.

Examples:

the
framing of the U.S. Constitution (Farrand, 1913)

the
drafting of U.N. Resolution 1441 (United Nations Security Council, 2002)

In first-order logic:

E65(x) ⇒ E7(x)

E65(x) ⇒ E63(x)

Properties:

[P94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10062) has created (was created by): [E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7841) Conceptual Object

E66 Formation

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8309) Beginning of Existence

Scope note:

This class comprises events that
result in the formation of a formal or informal E74 Group of people, such as a
club, society, association, corporation, or nation.

E66 Formation does not include the
arbitrary aggregation of people who do not act as a collective.

The formation of an instance of E74
Group does not require that the group is populated with members at the time of
formation. In order to express the joining of members at the time of formation,
the respective activity should be simultaneously an instance of both E66
Formation and E85 Joining.

Examples:

the
formation of the CIDOC CRM Special Interest Group in 2000

the
formation of the Soviet Union (Pipes, 1964)

the
conspiring of the murderers of Caesar (Irwin, 1935)

In
first-order logic:

E66(x) ⇒ E7(x)

E66(x) ⇒ E63(x)

Properties:

[P95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10355) has formed (was formed by): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group

[P151](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11264) was formed from (participated in): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group

E67 Birth

Subclass of:

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8309) Beginning of Existence

Scope note:

This class comprises the births of
human beings. E67 Birth is a biological event focussing on the context of
people coming into life. (E63 Beginning of Existence comprises the coming into
life of any living being.)

Twins, triplets, etc. are brought
into life by the same instance of E67 Birth. The introduction of the E67 Birth event
as a documentation element allows the description of a range of family
relationships in a simple model. Suitable extensions may describe more details
and the complexity of motherhood since the advent of modern medicine. In this
model, the biological father is not seen as a necessary participant in the E67
Birth.

Examples:

the
birth of Alexander the Great (Stoneman, 2004)

In first-order logic:

E67(x) ⇒ E63(x)

Properties:

[P96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10372) by mother (gave birth): [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_heading=h.1egqt2p)
Person

[P97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10390) from father (was father for): [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_heading=h.1egqt2p)
Person

[P98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10407) brought into life (was born): [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_heading=h.1egqt2p)
Person

E68 Dissolution

Subclass of:

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8330) End of Existence

Scope note:

This class comprises the events that
result in the formal or informal termination of an instance of E74 Group.

If the dissolution was deliberate,
the Dissolution event should also be instantiated as an instance of E7
Activity.

Examples:

the
fall of the Roman Empire (Whittington, 1964)

the
liquidation of Enron Corporation (Atlas, 2001)

In first-order logic:

E68(x) ⇒ E64(x)

Properties:

[P99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10425) dissolved (was dissolved by): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group

E69 Death

Subclass of:

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8330) End of Existence

Scope note:

This class comprises the deaths of
human beings.

If a person is _killed_, their
death should be instantiated as E69 Death and as E7 Activity. The death or
perishing of other living beings should be documented as instances of E64 End
of Existence.

Examples:

the
murder of Julius Caesar (E69, E7) (Irwin, 1935)

the
death of Senator Paul Wellstone (Monast and Tao, 2002)

In first-order logic:

E69(x) ⇒ E64(x)

Properties:

[P100](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10444) was death of (died in): [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_heading=h.1egqt2p)
Person

E70 Thing

Subclass of:

[E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8533) Persistent Item

Superclass of:

[E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431) Human-Made Thing

[E72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8467) Legal Object

Scope note:

This general class comprises
discrete, identifiable, instances of E77 Persistent Item that are documented as
single units, that either consist of matter or depend on being carried by
matter and are characterized by relative stability.

They may be intellectual products or
physical things. They may, for instance, have a solid physical form, an
electronic encoding, or they may be a logical concept or structure.

Examples:

my
photograph collection (E78) (fictitious)

the
bottle of milk in my refrigerator (E22) (fictitious)

the
Riss A1 plan of the Straßburger Münster (French: _Cathédrale_
_Notre-Dame de Strasbourg_) (E29) (Liess, R., 1985)

the
thing on the top of Otto Hahn’s desk (E19)

the
form of the no-smoking sign (E36)

the cave
of Dirou, Mani, Greece (E26) (Psimenos, 2005)

In first-order logic:

E70(x) ⇒ E77(x)

Properties:

[P43](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9545) has dimension (is dimension of): [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144) Dimension

[P101](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10463) had as general use (was use of): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

[P130](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10870) shows features of (features are also found
on): [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing

(P130.1 kind of similarity: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

E71 Human-Made Thing

Subclass of:

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing

Superclass of:

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765) Physical Human-Made Thing

[E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7841) Conceptual Object

Scope note:

This class comprises discrete,
identifiable human-made items that are documented as single units.

These items are either intellectual
products or human-made physical things, and are characterized by relative
stability. They may, for instance, have a solid physical form, an electronic
encoding, or they may be logical concepts or structures.

Examples:

Beethoven’s
5th Symphony (E73) (Lockwood, 2015)

Michelangelo’s
David (E22) (Paoletti and Bagemihl, 2015)

Einstein’s
Theory of General Relativity (E89) (Hartle, 2003)

the
taxon _‘Fringilla coelebs_ Linnaeus,1758’ (E55) (Sinkevicius and
Narusevicius, 2002)

In first-order logic:

E71(x) ⇒ E70(x)

Properties:

[P102](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10481) has title (is title of): [E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971) Title

(P102.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

[P103](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10505) was intended for (was intention of): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

E72 Legal Object

Subclass of:

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing

Superclass of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Scope note:

This class comprises those material
or immaterial items to which instances of E30 Right, such as the right of
ownership or use, can be applied.

This is generally true for all
instances of E18 Physical Thing. In the case of instances of E28 Conceptual
Object, however, the identity of an instance of E28 Conceptual Object or the
method of its use may be too ambiguous to reliably establish instances of E30
Right, as in the case of taxa and inspirations. Ownership of corporations is
currently regarded as out of scope of the CIDOC CRM.

Examples:

the
Cullinan diamond (E19) (Scarratt and Shor, 2006)

definition
of the CIDOC Conceptual Reference Model Version 5.0.4 (E73) (ISO 21127: 2014)

In first-order logic:

E72(x) ⇒ E70(x)

Properties:

[P104](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10520) is subject to (applies to): [E30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7893) Right

[P105](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10535) right held by (has right on): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

E73 Information Object

Subclass of:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8675) Propositional Object

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Superclass of:

[E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870)
Design or Procedure

[E31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7905)
Document

[E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7934)
Linguistic Object

[E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7987)
Visual Item

Scope note:

This class comprises identifiable
immaterial items, such as poems, jokes, data sets, images, texts, multimedia
objects, procedural prescriptions, computer program code, algorithm or
mathematical formulae, that have an objectively recognizable structure and are
documented as single units. The encoding structure known as a “named graph”
also falls under this class, so that each “named graph” is an instance of E73
Information Object.

An instance of E73 Information
Object does not depend on a specific physical carrier, which can include human
memory, and it can exist on one or more carriers simultaneously.

Instances of E73 Information Object
of a linguistic nature should be declared as instances of the E33 Linguistic
Object subclass. Instances of E73 Information Object of a documentary nature
should be declared as instances of the E31 Document subclass. Conceptual items
such as types and classes are not instances of E73 Information Object, nor are
ideas without a reproducible expression.

Examples:

image
BM000038850.JPG from the Clayton Herbarium in London (E31) (Natural History Museum, 2021)

E.
A. Poe's “The Raven” (Poe, 1869)

the
movie “The Seven Samurai” by Akira Kurosawa (Mellen, 2002)

the text of Huray
describing the Maxwell Equations (Huray, 2010)

the Getty AAT as
published as Linked Open Data, accessed 1/10/2014

In first-order logic:

E73(x) ⇒ E89(x)

E73(x) ⇒ E90(x)

Properties:

[P165](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11401) incorporates (is incorporated in): [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

E74 Group

Subclass of:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

Scope note:

This class comprises any gatherings
or organizations of human individuals or groups that act collectively or in a
similar way due to any form of unifying relationship. In the wider sense this
class also comprises official positions which used to be regarded in certain
contexts as one actor, independent of the current holder of the office, such as
the president of a country. In such cases, it may happen that the group never
had more than one member. A joint pseudonym (i.e. a name that seems indicative
of an individual but that is actually used as a persona by two or more people)
is a particular case of E74 Group.

A gathering of people becomes an
instance of E74 Group when it exhibits organizational characteristics usually
typified by a set of ideas or beliefs held in common, or actions performed
together. These might be communication, creating some common artifact, a common
purpose such as study, worship, business, sports, etc. Nationality can be
modelled as membership in an instance of E74 Group. Married couples and other
concepts of family are regarded as particular examples of E74 Group.

Examples:

the
Impressionists (Wilson, 1994)

the
Navajo (Correll, 1972)

the
Greeks (Williams, 1993)

the
peace protestors in New York City on 15th February 2003

Exxon-Mobil
(Raymond, 2006)

King
Solomon and his wives (Thieberger, 1947)

the
President of the Swiss Confederation

Nicolas
Bourbaki \[the collective pseudonym of a group of mathematicians, predominantly\
French alumni of the École normale supérieure\] (Aczel, 2007)

Betty
Crocker (Crocker, 2012)

Ellery Queen \[Ellery Queen is a pseudonym created in\
1929 by American crime fiction writers Frederic Dannay and Manfred Bennington\
Lee.\] (Wheat, 2005)

Greenpeace

Paveprime
Ltd

the
National Museum of Denmark

In first-order logic:

E74(x) ⇒ E39(x)

Properties:

[P107](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10575) has current or former member (is current or
former member of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021)
Actor

(P107.1 kind of member: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

E77
Persistent Item

Subclass of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Superclass of:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8424) Thing

Scope note:

This class comprises items that have
persistent characteristics of structural nature substantially related to their
identity and their integrity, sometimes known as “endurants” in philosophy.
Persistent Items may be physical entities, such as people, animals or things,
conceptual entities such as ideas, concepts, products of the imagination or
even names.

Instances of E77 Persistent Item may
be present or be part of interactions in different periods or events. They can
repeatedly be recognized at disparate occasions during their existence by
characteristics of structural nature. The respective characteristics need not
be exactly the same during all the existence of an instance of E77 Persistent
Item. Often, they undergo gradual change, still bearing some similarities with
that of previous times, or disappear completely and new emerge. For instance, a
person, from the time of being born on, will gradually change all its features
and acquire new ones, such as a scar. Even the DNA in different body cells will
develop defects and mutations. Nevertheless, relevant characteristics used should
be sufficiently similar to recognize the instance for some substantial period
of time.

The more specific criteria that
determine the identity of instances of subclasses of E77 Persistent Item may
vary considerably and are described or referred to in the respective scope
notes. The decision about which exact criteria to use depends on whether the
observable behaviour of the respective part of reality such confined conforms
to the reasoning the user is interested in. For example, a building can be
regarded as no longer existing if it is dismantled and the materials reused in
a different configuration. On the other hand, human beings go through radical
and profound changes during their life-span, affecting both material
composition and form, yet preserve their identity by other criteria, such as
being bodily separated from other persons. Similarly, inanimate objects may be
subject to exchange of parts and matter. On the opposite, the identity of a
(version of a) text of a scientific publication is given by the exact
arrangement of its relevant symbols.

The main classes of objects that
fall outside the scope of the E77 Persistent Item class are temporal objects
such as periods, events and acts, and descriptive properties.

An instance of E77 Persistent Item
does not require actual knowledge of the identifying features of the instance
being currently known. There may be cases, where the actual identifying
features of an instance of E77 Persistent Item are not decidable at a
particular state of knowledge.

Examples:

Leonardo
da Vinci (E21) (Strano, 1953)

Stonehenge
(E24) (Pryor, 2016)

the
hole in the ozone layer (E4) (Hufford and Horwitz, 2005)

the
First Law of Thermodynamics (E89) (Craig and Gislason, 2002)

the
Bermuda Triangle (E53) (Dolan, 2005)

In first-order logic:

E77(x) ⇒ E1(x)

E78 Curated Holding

Subclass of:

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7765) Physical Human-Made Thing

Scope note:

This class comprises aggregations of
instances of E18 Physical Thing that are assembled and maintained (“curated”
and “preserved,” in museological terminology) by one or more instances of E39
Actor over time for a specific purpose and audience, and according to a
particular collection development plan. Typical instances of curated holdings
are museum collections, archives, library holdings and digital libraries. A
digital library is regarded as an instance of E18 Physical Thing because it
requires keeping physical carriers of the electronic content.

Items may be added or removed from
an E78 Curated Holding in pursuit of this plan. This class should not be
confused with the E39 Actor maintaining the E78 Curated Holding who is often
referred to using the name of the E78 Curated Holding (e.g. “The Wallace
Collection decided…”).

Collective objects in the general
sense, like a tomb full of gifts, a folder with stamps, or a set of chessmen,
should be documented as instances of E19 Physical Object, and not as instances
of E78 Curated Holding. This is because they form wholes, either because they
are physically bound together or because they are kept together for their
functionality.

Examples:

the
John Clayton Herbarium (Blake, 1918), (Natural History Museum, 2021)

the
Wallace Collection (Ingamells, 1990)

Mikael Heggelund Foslie’s coralline red algae Herbarium
at the Museum of Natural History and Archaeology, Trondheim, Norway
(Woelkerling et al., 2005)

the Digital Collections of the Munich
DigitiZation Center (MDZ) accessible via [https://www.digitale-sammlungen.de/](https://www.digitale-sammlungen.de/) at least in January 2018.

In first-order logic:

E78(x) ⇒ E24(x)

Properties:

[P109](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10618) has current or former curator (is current or
former curator of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021)
Actor

E79 Part Addition

Subclass of:

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7535) Modification

Scope note:

This class comprises
activities that result in an instance of E18 Physical Thing being increased,
enlarged, or augmented by the addition of a part.

Typical scenarios
include the attachment of an accessory, the integration of a component, the
addition of an element to an aggregate object, or the accessioning of an object
into a curated instance of E78 Curated Holding. Both the E18 Physical Thing
being augmented and the E18 Physical Thing that is being added are treated as
separate identifiable wholes prior to the instance of E79 Part Addition.
Following the addition of parts, the resulting assemblages are treated
objectively as single identifiable wholes, made up of constituent or component
parts bound together either physically (for example the engine becoming a part
of the car), or by sharing a common purpose (such as the 32 chess pieces that
make up a chess set). This class of activities forms a basis for reasoning
about the history and continuity of identity of objects that are integrated
into other objects over time, such as precious gemstones being repeatedly
incorporated into different items of jewellery, or
cultural artefacts being added to different museum
instances of E78 Curated Holding over their lifespan.

Examples:

the
setting of the Koh-I-Noor diamond into the crown of Queen Elizabeth the Queen
Mother (Dalrymple, 2017)

the
addition of the painting “Room in Brooklyn” by Edward Hopper to the collection
of the Museum of Fine Arts, Boston

the attachment of
the bronze hand on the tree forming the Alpi Marittime \[[https://giuseppepenone.com/en/words/maritime-alps](https://giuseppepenone.com/en/words/maritime-alps)\]
(Mangini, 2010)

In first-order logic:

E79(x) ⇒ E11(x)

Properties:

[P110](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10637) augmented (was augmented by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7280)
Physical Thing

[P111](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10655) added (was added by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

E80 Part Removal

Subclass of:

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7535) Modification

Scope note:

This class comprises the activities
that result in an instance of E18 Physical Thing being decreased by the removal
of a part.

Typical scenarios include the
detachment of an accessory, the removal of a component or part of a composite
object, or the deaccessioning of an object from a curated collection, an
instance of E78 Curated Holding. If the instance of E80 Part Removal results in
the total decomposition of the original object into pieces, such that the whole
ceases to exist, the activity should instead be modelled as an instance of E81
Transformation, i.e. a simultaneous destruction and production. In cases where
the part removed has no discernible identity prior to its removal but does have
an identity subsequent to its removal, the activity should be modelled as both
an instance of E80 Part Removal and E12 Production. This class of activities
forms a basis for reasoning about the history, and continuity of identity over
time, of objects that are removed from other objects, such as precious
gemstones being extracted from different items of jewellery, or cultural
artifacts being deaccessioned from different museum collections over their
lifespan.

Examples:

the
removal of the Porite coral specimen from the Cocos Islands by Charles Darwin
in April 1836 (Natural History Museum, 2021, b)

the
removal of the engine from my car (fictitious)

the
disposal of object number 1976:234 from the collection (fictitious)

In first-order logic:

E80(x) ⇒ E11(x)

Properties:

[P112](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10672) diminished (was diminished by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7280)
Physical Thing

[P113](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10690) removed (was removed by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

E81 Transformation

Subclass of:

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8309) Beginning of Existence

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8330) End of Existence

Scope note:

This class comprises the events that
result in the simultaneous destruction of one or more than one E18 Physical
Thing and the creation of one or more than one E18 Physical Thing that
preserves recognizable substance and structure from the first one(s) but has
fundamentally different nature or identity.

Although the old and the new
instances of E18 Physical Thing are treated as discrete entities having
separate, unique identities, they are causally connected through the E81
Transformation; the destruction of the old E18 Physical Thing(s) directly
causes the creation of the new one(s) using or preserving some relevant
substance and structure. Instances of E81 Transformation are therefore distinct
from re-classifications (documented using E17 Type Assignment) or modifications
(documented using E11 Modification) of objects that do not fundamentally change
their nature or identity. Characteristic cases are reconstructions and
repurposing of historical buildings or ruins, fires leaving buildings in ruins,
taxidermy of specimen in natural history.

Even though such instances of E81
Transformation are often motivated by a change of intended use, substantial
material changes should justify the documentation of the result as a new
instance of E18 Physical Thing and not just the change of function. The latter
may be documented as an extended activity (instance of E7 Activity) of using
it.

Examples:

the mummification of Tut-Ankh-Amun (E81, E12) \[the\
mummification of the body of the deceased is a human production process and\
simultaneously preserves structures of the body at and before death\] (Carter
and Mace 1977)

the
death, carbonization and petrification of some people of Pompeii in 79AD by the
intense heat of a pyroclastic cloud and ashes from the Eruption of Mount
Vesuvius (E69, E81)

the
transformation of the _Hephaisteion_ temple in Athens, better known as “Theseion” _,_
into a Christian church, dedicated to [Saint George](https://en.wikipedia.org/wiki/Saint_George) around AD 700 (E81,E12) \[which\
actually helped preserving part of the antique temple structure from 449BC\]

In first-order logic:

E81(x) ⇒ E63(x)

E81(x) ⇒ E64(x)

Properties:

[P123](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10743) resulted in (resulted from): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

[P124](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10762) transformed (was transformed by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

E83 Type Creation

Subclass of:

[E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8349) Creation

Scope note:

This class comprises activities
formally defining new types of items.

It is typically a rigorous scholarly
or scientific process that ensures a type is exhaustively described and
appropriately named. In some cases, particularly in archaeology and the life
sciences, E83 Type Creation requires the identification of an exemplary
specimen and the publication of the type definition in an appropriate scholarly
forum. The activity modelled as an instance of E83 Type Creation is central to
research in the life sciences, where a type would be referred to as a “taxon,”
the type description as a “protologue,” and the exemplary specimens as
“original element” or “holotype”.

Examples:

creation
of the taxon _Penicillium brefeldianum_ (Dodge, 1933)

addition
of class E85 Joining to the CIDOC CRM

In first-order logic:

E83(x) ⇒ E65(x)

Properties:

[P135](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10958) created type (was created by): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

[P136](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10975) was based on (supported type creation): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

(P136.1 in the taxonomic role: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

E85 Joining

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

Scope note:

This class comprises the activities
that result in an instance of E39 Actor becoming a member of an instance of E74
Group. This class does not imply initiative by either party. It may be the
initiative of a third party.

Typical scenarios include becoming a
member of a social organisation, becoming an employee of a company, marriage,
the adoption of a child by a family, and the inauguration of somebody into an
official position.

Examples:

the
election of Sir Isaac Newton as Member of Parliament for the University of
Cambridge to the Convention Parliament of 1689 (Gleick, 2003)

the
inauguration of Mikhail Sergeyevich Gorbachev as leader of the Union of Soviet
Socialist Republics (USSR) in 1985 (Butson, 1986)

the
implementation of the membership treaty between EU and Denmark, 1st
January 1993

In first-order logic:

E85(x) ⇒ E7(x)

Properties:

[P143](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11131) joined (was joined by): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[P144](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11151) joined with (gained member by): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group

(P144.1 kind of member: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

E86 Leaving

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

Scope note:

This class comprises the activities
that result in an instance of E39 Actor to be disassociated from an instance of
E74 Group. This class does not imply initiative by either party. It may be the
initiative of a third party.

Typical scenarios include the
termination of membership in a social organisation, ending the employment at a
company, divorce, and the end of tenure of somebody in an official position.

Examples:

the
end of Sir Isaac Newton’s duty as Member of Parliament for the University of
Cambridge to the Convention Parliament in 1702 (Gleick, 2003)

George
Washington’s leaving office in 1797 (Jones, 1979)

the
implementation of the treaty regulating the termination of Greenland’s
membership in EU between EU, Denmark and Greenland 1st February 1985

In first-order logic:

E86(x) ⇒ E7(x)

Properties:

[P145](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11176) separated (left by): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8021) Actor

[P146](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11196) separated from (lost member by): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8508) Group

E87 Curation Activity

Subclass of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7428) Activity

Scope note:

This class comprises the activities
that contribute to the management and the preservation and evolution of
instances of E78 Curated Holding, following an implicit or explicit curation
plan.

It specializes the notion of
activity into the curation of a collection and allows the history of curation
to be recorded.

Items are accumulated and organized
following criteria such as subject, chronological period, material type, style
of art, etc., and can be added or removed from an instance of E78 Curated
Holding for a specific purpose and/or audience. The initial aggregation of
items to form a collection is regarded as an instance of E12 Production Event,
while the activities of evolving, preserving, and promoting a collection are
regarded as instances of E87 Curation Activity _._

Examples:

the
curation of Mikael Heggelund Foslie’s coralline red algae Herbarium 1876 to
1909 (when Foslie died), now at the Museum of Natural History and Archaeology,
Norway (Woelkerling et al., 2005)

In first-order logic:

E87(x) ⇒ E7(x)

Properties:

[P147](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11216) curated (was curated by): [E78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) Curated Holding

E89 Propositional Object

Subclass of:

[E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7841) Conceptual Object

Superclass of:

[E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8484) Information Object

[E30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7893) Right

Scope note:

This class comprises immaterial
items, including but not limited to stories, plots, procedural prescriptions,
algorithms, laws of physics or images that are, or represent in some sense,
sets of propositions about real or imaginary things and that are documented as
single units or serve as topic of discourse.

This class also comprises items that
are “about” something in the sense of a subject. In the wider sense, this class
includes expressions of psychological value such as non-figural art and musical
themes. However, conceptual items such as types and classes are not instances
of E89 Propositional Object. This should not be confused with the definition of
a type, which is indeed an instance of E89 Propositional Object.

Examples:

Maxwell’s
Equations (Ball, 1962)

the
ideational contents of Aristotle’s book entitled ‘Metaphysics’ as rendered in
the Greek texts translated in Oxford edition

the
underlying prototype of any “no-smoking” sign (E36)

the
common ideas of the plots of the movie “The Seven Samurai” by Akira Kurosawa
and the movie “The Magnificent Seven” by John Sturges (Mellen, 2002)

the
image content of the photo of the Allied Leaders at Yalta published by UPI,
1945 (E36)

the
character “Little Red Riding Hood”, variants of which appear amongst others in
Grimm brothers’ “Rotkäppchen”, other oral fairy tales and the film “Hoodwinked”

the
place “Havnor” as invented by Ursula K. Le Guin for her “Earthsea” book series,
the related maps and appearing in derivative works based on these novels

In first-order logic:

E89(x) ⇒ E28(x)

Properties:

[P67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9968) refers to (is referred to by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

(P67.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type)

[P129](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10852) is about (is subject of): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[P148](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11232) has component (is component of): [E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8675) Propositional Object

E90 Symbolic Object

Subclass of:

[E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7841)
Conceptual Object

[E72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8467) Legal
Object

Superclass of:

[E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8484) Information Object

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

Scope note:

This class comprises identifiable
symbols and any aggregation of symbols, such as characters, identifiers,
traffic signs, emblems, texts, data sets, images, musical scores, multimedia
objects, computer program code, or mathematical formulae that have an
objectively recognizable structure and that are documented as single units.

It includes sets of signs of any
nature, which may serve to designate something, or to communicate some
propositional content. An instance of E90 Symbolic Object may or may not have a
specific meaning, for example an arbitrary character string.

In some cases, the content of an
instance of E90 Symbolic Object may completely be represented by a serialized
digital content model, such as a sequence of ASCII-encoded characters, an XML
or HTML document, or a TIFF image. The property _P3 has note_ and its
subproperty _P190 has symbolic content_ allow for the description of this
content model. In order to disambiguate which symbolic level is the carrier of
the meaning, the property _P3.1 has type_ can be used to specify the
encoding (e.g. “bit”, “Latin character”, RGB pixel).

Examples:

‘ecognizabl’

the
“no-smoking” sign (E36)

“BM000038850.JPG”
(E41) \[identifies a digital image\] (Natural History Museum, 2021)

image
BM000038850.JPG from the Clayton Herbarium in London (E36) \[depicts specimen of\
Verbesina virginica\] (Natural History Museum, 2021)

the
distribution of form, tone and colour found on Leonardo da Vinci’s painting
named “Mona Lisa” in daylight (E36)

the
Italian text of Dante’s “Divina Commedia” as found in the authoritative
critical edition “La Commedia secondo l’antica vulgata a cura di Giorgio
Petrocchi” (E33) (Petrocchi, 1967)

In first-order logic:

E90(x) ⇒ E28(x)

E90(x) ⇒ E72(x)

Properties:

[P106](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10554) is composed of (forms part of): [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

[P190](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11875) has symbolic content: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8298) String

E92 Spacetime Volume

Subclass of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Superclass of:

[E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period

[E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8744)
Presence

Scope note:

This class comprises 4-dimensional
point sets (volumes) in physical spacetime (in contrast to mathematical models
of it) regardless of their true geometric forms. They may derive their identity
from being the extent of a material phenomenon or from being the interpretation
of an expression defining an extent in spacetime. Intersections of instances of
E92 Spacetime Volume, E53 Place, and E52 Time-Span are also regarded as
instances of E92 Spacetime Volume. An instance of E92 Spacetime Volume is
either contiguous or composed of a finite number of contiguous subsets. Its
boundaries may be fuzzy due to the properties of the phenomena it derives from
or due to the limited precision up to which defining expression can be
identified with a real extent in spacetime. The duration of existence of an
instance of E92 Spacetime Volume is its projection on time.

Examples:

the
extent in space and time of the Event of Caesar’s murder (Irwin, 1935)

where
and when the carbon 14 dating of the “Schoeninger Speer II” in 1996 took place
(Kouwenhoven, 1997)

the
spatio-temporal trajectory of the H.M.S. Victory from its building to its
actual location (Goodwin, 2015)

the
extent in space and time defined by a polygon approximating the Danube river
flood in Austria between 6th and 9th August 2002

In first-order logic:

E92(x) ⇒ E1(x)

Properties:

[P10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9027) falls within (contains): [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume

[P132](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10895) spatiotemporally overlaps with: [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume

[P133](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10917) spatiotemporally separated from: [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume

[P160](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11345) has temporal projection (is temporal
projection of): [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096)
Time-Span

[P161](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11362) has spatial projection (is spatial projection
of): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

E93 Presence

Subclass of:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume

Scope note:

This class comprises instances of
E92 Spacetime Volume, whose temporal extent has been chosen in order to
determine the spatial extent of a phenomenon over the chosen time-span.
Respective phenomena may, for instance, be historical events or periods, but
can also be the diachronic extent and existence of physical things. In other
words, instances of this class fix a slice of another instance of E92 Spacetime
Volume in time.

The temporal extent of an instance
of E93 Presence typically is predetermined by the researcher so as to focus the
investigation particularly on finding the spatial extent of the phenomenon by
testing for its characteristic features. There are at least two basic
directions such investigations might take. The investigation may wish to
determine where something was during some time or it may wish to reconstruct
the total passage of a phenomenon’s spacetime volume through an examination of
discrete presences. Observation and measurement of features indicating the
presence or absence of a phenomenon in some space allows for the progressive
approximation of spatial extents through argumentation typically based on
inclusion, exclusion and various overlaps.

Examples:

the
Roman Empire on 19th August AD 14 (Clare and Edwards, 1992)

Johann
Joachim Winckelmann’s whereabouts in December 1775 (Leppmann, 1970)

Johann
Joachim Winckelmann’s whereabouts from 19th November 1755 until 9th
April 1768 (Leppmann, 1970)

In first-order logic:

E93(x) ⇒ E92(x)

Properties:

[P164](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11381) is temporally specified by (temporally
specifies): [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8096) Time-Span

[P166](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11425) was a presence of (had presence): [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723) Spacetime Volume

[P167](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11442) was within (includes): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

[P195](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11910) was a presence of (had presence): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

[P197](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11945) covered parts of (was partially covered by): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8120) Place

E94 Space Primitive

Subclass of:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039)
Appellation

[E59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8245)
Primitive Value

Scope note:

This class comprises instances of
E59 Primitive Value for space that should be implemented with appropriate
validation, precision and references to spatial coordinate systems to express
geometries on or relative to Earth, or on any other stable constellations of
matter, relevant to cultural and scientific documentation.

An instance of E94 Space Primitive
defines an instance of E53 Place in the sense of a declarative place as
elaborated in CRMgeo (Doerr & Hiebel 2013), which means that the identity
of the place is derived from its geometric definition. Such a declarative place
may allow for the approximation of instances of E53 Place defined by the actual
extent of some phenomenon, such as a settlement or a riverbed, or other forms
of identification rather than by an instance of E94 Space Primitive. Note that using
an instance of E94 Space Primitive for approximating the actual extent of some
place always defines a (declarative) instance of E53 Place in its own right.

Definitions of instances of E53
Place using different spatial reference systems are always definitions of
different instances of E53 Place.

Instances of E94 Space Primitive
provide the ability to link CIDOC CRM encoded data to the kinds of geometries
used in maps or Geoinformation systems. They may be used for visualization of
the instances of E53 Place they define, in their geographic context and for
computing topological relations between places based on these geometries. E94
Space Primitive is not further elaborated upon within this model. It is
considered good practice to maintain compatibility with OGC standards.

Examples:

<gml:Point
gml:id="p21"
srsName="http://www.opengis.net/def/crs/EPSG/0/4326">
<gml:coordinates>45.67, 88.56</gml:coordinates> </gml:Point>
\[Coordinate Information in GML\]

“40°31'17.9"N
21°15'48.3"E” \[A single point for approximating the centre of the city of\
Kastoria, Greece\]

POLYGON ((30 10, 40 40, 20 40, 10 20, 30
10)) \[Well-Known Text (WKT)\]

In first-order logic:

E94(x) ⇒ E41(x)

E94(x) ⇒ E59(x)

E95 Spacetime Primitive

Subclass of:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039)
Appellation

[E59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8245)
Primitive Value

Scope note:

This class comprises instances of
E59 Primitive Value for spacetime volumes that should be implemented with
appropriate validation, precision and reference systems to express geometries
being limited and varying over time on or relative to Earth, or any other
stable constellations of matter, relevant to cultural and scientific
documentation. An instance of E95 Spacetime Primitive may consist of one
expression including temporal and spatial information such as in GML or a
different form of expressing spacetime in an integrated way such as a formula
containing all 4 dimensions.

An instance of E95 Spacetime
Primitive defines an instance of E92 Spacetime Volume in the sense of a
declarative spacetime volume as defined in CRMgeo (Doerr & Hiebel 2013),
which means that the identity of the instance of E92 Spacetime Volume is
derived from its geometric and temporal definition. This declarative spacetime
volume allows for the application of all E92 Spacetime Volume properties to
relate phenomenal spacetime volumes of periods and physical things to
propositions about their spatial and temporal extents.

Instances of E92 Spacetime Volume
defined by _P169 defines spacetime volume (spacetime volume is defined by)_
that use different spatiotemporal referring systems are always regarded as
different instances of the E92 Spacetime Volume.

It is possible for a spacetime
volume to be defined by phenomena causal to it, such as an expanding and
declining realm, a settlement structure or a battle, or other forms of
identification rather than by an instance of E95 Spacetime Primitive. Any
spatiotemporal approximation of such a phenomenon by an instance of E95 Spacetime
Primitive constitutes an instance of E92 Spacetime Volume in its own right.

E95 Spacetime Primitive is not
further elaborated upon within this model. Compatibility with OGC standards is
recommended.

Examples:

<Placemark>

                      <name>
Byzantine Empire </name>styleUrl>#style\_1</styleUrl>

                      <TimeSpan>

                                      <begin>330</begin><end>1453</end>

                      </TimeSpan>

                      <Polygon>

                                      <altitudeMode>clampToGround</altitudeMode>

                                      <outerBoundaryIs>

                                                      <LinearRing>

<coordinates>18.452787460,40.85553626,0
17.2223187,40.589098,....0 17.2223,39.783

</coordinates>

                                                      </LinearRing>

                                      </outerBoundaryIs>

                      </Polygon>


</Placemark>

    \[spatial and\
temporal information in KML for the maximum extent of the Byzantine Empire\]

In first-order logic:

E95(x) ⇒
E41(x)

E95(x) ⇒ E59(x)

Properties:

[P169](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11479) defines spacetime volume (spacetime volume is
defined by): [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8723)
Spacetime Volume

E96 Purchase

Subclass of:

[E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7472) Acquisition

Scope note:

This class comprises transfers of
legal ownership from one or more instances of E39 Actor to one or more
different instances of E39 Actor, where the transferring party is completely
compensated by the payment of a monetary amount. In more detail, a purchase
agreement establishes a fixed monetary obligation at its initialization on the
receiving party, to the giving party. An instance of E96 Purchase begins with
the contract or equivalent agreement and ends with the fulfilment of all
contractual obligations. In the case that the activity is abandoned before both
parties have fulfilled these obligations, the activity is not regarded as an
instance of E96 Purchase.

This class is a very specific case
of the much more complex social business practices of exchange of goods and the
creation and satisfaction of related social obligations. Purchase activities
which define individual sales prices per object can be modelled by
instantiating E96 Purchase for each object individually and as part of an
overall instance of E96 Purchase transaction.

Examples:

the
purchase of 10 okka of nails by the captain A. Syrmas on 18th
September 1895 in Thessaloniki (Syrmas, 1896)

In first-order logic:

E96(x) ⇒ E8(x)

Properties:

[P179](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11672) had sales price (was sales price of): [E97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) Monetary Amount

E97 Monetary Amount

Subclass of:

[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8144) Dimension

Scope note:

This class comprises quantities of
monetary possessions or obligations in terms of their nominal value with
respect to a particular currency. These quantities may be abstract accounting
units, the nominal value of a heap of coins or bank notes at the time of
validity of the respective currency, the nominal value of a bill of exchange or
other documents expressing monetary claims or obligations. It specifically
excludes amounts expressed in terms of weights of valuable items, like gold and
diamonds, and quantities of other non-currency items, like goats or stocks and
bonds.

Example:

Christie’s
hammer price for Vincent van Gogh’s “Still Life: Vase with Fifteen Sunflowers” in London on 30th
March 1987

In first-order logic:

E97(x) ⇒ E54(x)

Properties:

[P180](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11687) has currency (was currency of): [E98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10407) Currency

E98 Currency

Subclass of:

[E58](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8226) Measurement Unit

Scope note:

This class comprises the units in
which a monetary system, supported by an administrative authority or other
community, quantifies and arithmetically compares all monetary amounts declared
in the unit. The unit of a monetary system must describe a nominal value which
is kept constant by its administrative authority and an associated banking
system if it exists, and not by market value. For instance, one may pay with
grams of gold, but the respective monetary amount would have been agreed as the
gold price in US dollars on the day of the payment. Under this definition,
British Pounds, U.S. Dollars, and European Euros are examples of currency, but
“grams of gold” is not. One monetary system has one and only one currency.
Instances of this class must not be confused with coin denominations, such as
“Dime” or “Sestertius”. Non-monetary exchange of value in terms of quantities
of a particular type of goods, such as cows, do not constitute a currency.

Examples:

“As”
\[Roman mid republic\]

“Euro”
(Temperton, 1997)

“US
Dollar” (Rose, 1978)

In
first-order logic:

E98(x) ⇒ E58(x)

E99 Product Type

Subclass of:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8169) Type

Scope note:

This class comprises types that
stand as the models for instances of E22 Human-Made Object that are produced as
the result of production activities using plans exact enough to result in one
or more series of uniform, functionally and aesthetically identical and
interchangeable items. The product type is the intended ideal form of the
manufacture process. It is typical of instances of E22 Human-Made Object that
conform to an instance of E99 Product Type that its component parts are
interchangeable with component parts of other instances of E22 Human-Made
Object made after the model of the same instance of E99 Product Type.
Frequently, the uniform production according to a given instance of E99 Product
Type is achieved by creating individual tools, such as moulds or print plates
that are themselves carriers of the design of the product type. Modern tools
may use the flexibility of electronically controlled devices to achieve such
uniformity. The product type itself, i.e. the potentially unlimited series of
aesthetically equivalent items, may be the target of artistic design, rather
than the individual object. In extreme cases, only one instance of a product
type may have been produced, such as in a “print on demand” process which was
only triggered once. However, this should not be confused with industrial
prototypes, such as car prototypes, which are produced prior to the production
line being set up, or test the production line itself.

Examples:

Volkswagen
Type 11 \[Beetle\] (Rieger, 2013)

Dragendorff
54 samian vessel

1937
Edward VIII brass threepenny bit

Qin
Crossbow trigger un-notched Part B (Bg2u) (Li, 2012)

Nokia
Cityman 1320 \[The first Nokia mobile phone\]

In first-order logic:

E99(x) ⇒ E55(x)

Properties:

[P187](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11825) has production plan (is production plan for): [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7870) Design or Procedure

[P188](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11839) requires production tool (is production tool
for): [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7697) Physical Object

# CIDOC CRM Property Declarations

The properties of the CIDOC CRM are
comprehensively declared in this section using the following format:

•Property names are presented as headings in bold
face, preceded by unique property identifiers;

•The line “Domain:” declares the class for which the
property is defined;

•The line “Range:” declares the class to which
the property points, or that provides the values for the property;

•The line “Subproperty of:” is a cross-reference
to any superproperties the property may have;

•The line “Superproperty of:” is a
cross-reference to any subproperties the property may have;

•The line “Quantification:” declares the possible
number of occurrences for domain and range class instances for the property.
Possible values are: one:many, many:one, many:many;

•The line “Scope note:” contains the textual
definition of the concept the property represents;

•The line “Examples:” contains a bulleted list of
examples of instances of this property. If the example is also instance of a
subproperty of this property, the unique identifier of the subclass is added in
parenthesis. If the example instantiates two properties, the unique identifiers
of both properties is added in parenthesis. This line provides illustrative
examples showing how the property should be used;

•The line “In first-order logic:” expresses the
formal constraints of the property in terms of logical axioms in a first-order logic
notation.

P1 is identified by (identifies)

Domain:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM
Entity

Range:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039)
Appellation

Superproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P48](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9718) has preferred identifier (is preferred
identifier of): [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076)
Identifier

[E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431) Human-Made Thing. [P102](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10481) has title (is title of): [E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971) Title

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place. [P168](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11405) place is defined by (defines place): [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8709) Space Primitive

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume. [P169](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11428) i spacetime volume is defined by: [E95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8725) Spacetime Primitive

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span. [P170](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11444) i time is defined by: [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_heading=h.meukdy)
Time Primitive

Quantification:

many to many (0,n:0,n)

Scope note:

This property describes the naming
or identification of any real-world item by a name or any other identifier.

This property is intended for
identifiers in general use, which form part of the world the model intends to
describe, and not merely for internal database identifiers which are specific
to a technical system, unless these latter also have a more general use outside
the technical context. This property includes in particular identification by
mathematical expressions such as coordinate systems used for the identification
of instances of E53 Place. The property does not reveal anything about when,
where and by whom this identifier was used. A more detailed representation can
be made using the fully developed (i.e. indirect) path through E15 Identifier
Assignment.

This property is a shortcut for the
path from E1 CRM Entity through _P140i was attributed by_, E15 Identifier
Assignment, _P37 assigned_ toE42 Identifier.

It is also a shortcut for the path
from E1 CRM Entity through _P1 is identified by_, E41 Appellation, _P139_
_has alternative form_ to E41 Appellation.

Examples:

The
capital of Italy (E53) _is identified by_ “Rome” (E41). (Leach, 2017)

Text
25014–32 (E33) _is identified by_ “The Decline and Fall of the Roman
Empire” (E35). (Gibbon, 2013)

In first-order logic:

P1(x,y) ⇒ E1(x)

P1(x,y) ⇒ E41(y)

P1(x,y) ⇐ (∃z)
\[E15(z)˄ P140i(x,z) ˄ P37(z,y)\]

P1(x,y) ⇐ (∃z)
\[E41(z)˄ P1(x,z) ˄ P139(z,y)\]

P2 has type (is type of)

Domain:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Superproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P137](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10945) exemplifies (is exemplified by): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561)Attribute
Assignment. [P177](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11599)
assigned property of type (is type of property assigned): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many to many (0,n:0,n)

Scope note:

This property allows sub-typing of
CIDOC CRM entities –a form of specialisation – through the use of a
terminological hierarchy, or thesaurus.

The CIDOC CRM is intended to focus
on the high-level entities and relationships needed to describe data
structures. Consequently, it does not specialise entities any further than is
required for this immediate purpose. However, entities in the isA hierarchy of
the CIDOC CRM may by specialised into any number of sub-entities, which can be
defined in the E55 Type hierarchy. E41 Appellation, for example, may be
specialised into “e-mail address”, “telephone number”, “post office box”, “URL”,
etc., none of which figures explicitly in the CIDOC CRM class hierarchy. A
comprehensive explanation about refining CIDOC CRM concepts by E55 Type is
given in the section “About Types” in the section on “Specific Modelling
Constructs” of this document.

This property is a shortcut for the
path from E1 CRM Entity through _P41i was classified by,_ E17 Type
Assignment, _P42 assigned_ toE55 Type.

Examples:

“enquiries@cidoc-crm.org”
(E41) _has type_ e-mail address (E55). (fictitious)

In first-order logic:

P2(x,y) ⇒
E1(x)

P2(x,y) ⇒ E55(y)

P2(x,y) ⇐ (∃z)
\[E17(z)\] ˄ P41i(x,z) ˄ P42(z,y)\]

P3 has note

Domain:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM
Entity

Range:

[E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282) String

Superproperty of:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span. [P79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10103) beginning is qualified by: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282)String

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span. [P80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10120) end is qualified by: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282)String

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object. [P190](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11822) has symbolic content: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282)String

Quantification:

one to many (0,n:0,1)

Scope note:

This property is a container for all
informal descriptions about an object that have not been expressed in terms of
CIDOC CRM constructs.

In particular, it captures the
characterisation of the item itself, its internal structures, appearance, etc.

Like property _P2 has type (is_
_type of)_, this property is a consequence of the restricted focus of the
CIDOC CRM. The aim is not to capture, in a structured form, everything that can
be said about an item; indeed, the CIDOC CRM formalism is not regarded as
sufficient to express everything that can be said. Good practice requires use
of distinct note fields for different aspects of a characterisation. The _P3.1_
_has type_ property of _P3 has note_ allows differentiation of specific
notes, e.g. “construction”, “decoration”, etc.

An item may have many notes, but a
note is attached to a specific item.

Examples:

Coffee
mug – OXCMS:1983.1.1 (E19) _has note_ “chipped at edge of handle” (E62) _has_
_type_ Condition (E55). (fictitious)

In first-order logic:

P3(x,y) ⇒ E1(x)

P3(x,y) ⇒ E62(y)

P3(x,y,z) ⇒ \[P3(x,y) ∧\
E55(z)\]

Properties:

P3.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P4 has time-span (is time-span of)

Domain:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310) Temporal Entity

Range:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property associates an instance
of E2 Temporal Entity with the instance of E52 Time-Span during which it was
on-going. The associated instance of E52 Time-Span is understood as the real
time-span during which the phenomena making up the temporal entity instance
were active. More than one instance of E2
Temporal Entity may share a common instance of E52 Time-Span only if they come
into being and end being due to identical declarations or events.

Examples:

The
Yalta Conference (E7) _has time-span_ Yalta Conference time-span (E52).
(Harbutt, 2010)

In first-order logic:

P4(x,y) ⇒ E2(x)

P4(x,y) ⇒ E52(y)

P5 consists of (forms part of)

Domain:

[Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State

Range:

[Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State

Quantification:

many to many (0,n:0,n)

Scope note:

This property describes the
decomposition of an instance of E3 Condition State into discrete, subsidiary
states.

It is assumed that the sub-states
into which the condition state is analysed form a logical whole, although the
entire story may not be completely known, and that the sub-states are in fact
constitutive of the general condition state. For example, a general condition
state of “in ruins” may be decomposed into the individual stages of decay.

This property is transitive and asymmetric.

Examples:

The Condition State of the ruined Parthenon (E3) _consists_
_of_ the bombarded state after the explosion of a Venetian shell in 1687
(E3). (Mommsen, 1941)

In first-order logic:

P5(x,y) ⇒ E3(x)

P5(x,y) ⇒ E3(y)

\[P5(x,y) ∧ P5(y,z)\] ⇒
P5(x,z)

P5(x,y) ⇒ ¬P5(y,x)

P7 took place at (witnessed)

Domain:

[E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property describes the spatial
location of an instance of E4 Period.

The related instance of E53 Place
should be seen as a wider approximation of the geometric area within which the
phenomena that characterise the period in question occurred, see below. _P7_
_took place at (witnessed)_ does not convey any meaning other than spatial
positioning (frequently on the surface of the earth). For example, the period
“Révolution française” can be said to have taken place in “France
in 1789”; the “Victorian” period may be said to have taken place in “Britain
from 1837-1901” and its colonies, as well as other parts of Europe and North
America. An instance of E4 Period can take place at multiple non-contiguous,
non-overlapping locations.

Any place
where something happened includes the spatial projection of the happening given
in the same geometric reference system. For instance, HMS Victory, as place of
Lord Nelson's dying, includes the location of his body relative to the hull of
HMS Victory at his time of death as the most precise location of his death. By
the definition of _P161 has spatial projection_, an instance of E4
Period takes place on all its spatial projections to respective reference
systems, that is, instances of E53 Place. Therefore, this property implies the
more fully developed path from E4 Period through _P161 has spatial_
_projection_, E53 Place, _P89 falls within_ to E53 Place,
where both places are defined in the same geometric reference system. The
relation between an instance of E53 Place and its reference system can
conveniently be documented via the property _P157 is at rest relative to_
_(provides reference space for)_.

Something
that has happened at a given place can also be considered to have happened at a
smaller place within it: for example, it is reasonable to say Caesar’s murder
took place in Rome, but also on the Forum Romanum, and more precisely in the
Curia. It is characteristic for different historical sources to use varying
precision in such statements, without being in contradiction with each other.
This may be due to lack of knowledge or to the relevance of the precision for
the purpose of the statement. In information integration, the more precise
statement improves the overall knowledge.

Examples:

The
period “Révolution française” (E4) _took place at_ the area
covered by France in 1789 (E53). (Bertaud, 2004)

In first-order logic:

P7(x,y) ⇒ E4(x)

P7(x,y) ⇒ E53(y)

P7(x,y) ⇒ (∃z,u) \[P157(y,u) ˄ P157(z,u) ˄ P161(x,z)\
˄ P89(z,y)\]

\[E4(x)\
˄ P157(y,u) ˄ P157(v,u) ˄ P7(x,y) ˄ P161(x,z) ˄\
P89(z,v) ˄ P89(v,y)\] ⇒ P7(x,v)

P8 took place
on or within (witnessed)

Domain:

[E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650) Physical Thing

Quantification:

many to many (0,n:0,n)

Scope note:

This property describes the location
of an instance of E4 Period with respect to an instance of E18 Physical Thing.

This property is a shortcut of the
more fully developed path from E4 Period through _P7 took place at_, E53
Place, _P156i is occupied by_ to E18 Physical Thing.

It describes a period that can be
located with respect to the space defined by an E19 Physical Object such as a
ship or a building. The precise geographical location of the object during the
period in question may be unknown or unimportant.

For example, the French and German
armistice of 22nd June 1940 was signed in the same railway carriage
as the armistice of 11th November 1918.

Examples:

The
coronation of Queen Elizabeth II (E7) _took place on or within_
Westminster Abbey (E18). (Strong, 2005)

In first-order logic:

P8(x,y) ⇒ E4(x)

P8(x,y) ⇒ E18(y)

P8(x,y) ⇐ (∃z)
\[E53(z) ˄ P7(x,z) ˄ P156i(z,y)\]

P9 consists of (forms part of)

Domain:

[E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period

Range:

[E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period

Subproperty of:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume. [P10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8978) i contains: [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E4 Period with another instance of E4 Period that is defined by a subset of
the phenomena that define the former. Therefore, the spacetime volume of the
latter must fall within the spacetime volume of the former.

This property is transitive and asymmetric.

Examples:

Cretan
Bronze Age (E4) _consists of_ Middle Minoan (E4). (Hood, 1971)

In first-order logic:

P9(x,y) ⇒ E4(x)

P9(x,y) ⇒ E4(y)

P9(x,y) ⇒ P10(y,x)

\[P9(x,y) ∧ P9(y,z)\] ⇒ P9(x,z)

P9(x,y) ⇒ ¬P9(y,x)

P10 falls within
(contains)

Domain:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Range:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Subproperty of:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume. [P132](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10846) spatiotemporally overlaps with: [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Superproperty of:

[E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8691)Presence. [P166](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11374)
was a presence of (had presence):[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

[E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period. [P9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8956) i forms part of: [E4](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7351) Period

Quantification:

many to many, necessary, dependent
(1,n:1,n)

Scope note:

This property associates an instance
of E92 Spacetime Volume with another instance of E92 Spacetime Volume that
falls within the latter. In other words, all points in the former are also
points in the latter.

This property is transitive and
reflexive.

Examples:

The
Great Plague (E4) _falls within_ The Gothic period (E4). (Porter, 2009)

In first-order logic:

P10(x,y) ⇒ E92(x)

P10(x,y) ⇒ E92(y)

P10(x,y) ⇒ P132(x,y)

P10(x,y) ∧ P10(y,z)\]
⇒ P10(x,z)

P10(x,x)

P11 had participant (participated in)

Domain:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9032) occurred in the presence of (was present at): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Superproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9076) carried out by (performed): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

[E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8367) Birth. [P96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10323) by mother (gave birth): [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7719) Person

[E68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8382) Dissolution. [P99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10376) dissolved (was dissolved by): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

[E85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8615) Joining. [P143](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11080) joined (was joined by): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

[E85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8615) Joining. [P144](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11100) joined with (gained member by): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

[E86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8631) Leaving. [P145](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11125) separated (left by): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

[E86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8631) Leaving. [P146](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11145) separated from (lost member by): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

[E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8349) Formation. [P151](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11213) was formed from (participated in): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

Quantification:

many to many (0,n:0,n)

Scope note:

This property describes the active
or passive participation of instances of E39 Actors in an instance of E5 Event.

It documents known events in which
an instance of E39 Actor has participated during the course of that actor’s
life or history. The instances of E53 Place and E52 Time-Span where and when
these events happened provide constraints about the presence of the related instances
of E39 Actor in the past. Collective actors, i.e. instances of E74 Group, may
physically participate in events via their representing instances of E21
Persons only. The participation of multiple actors in an event is most likely
an indication of their acquaintance and interaction.

The property implies that the actor
was involved in the event but does not imply any causal relationship. For
instance, someone having been portrayed can be said to have participated in the
creation of the portrait.

Examples:

Napoleon
(E21) _participated in_ The Battle of Waterloo (E7). (Dawson, 2018)

Maria
(E21) _participated in_ Photographing of Maria (E7). (fictitious)

In first-order logic:

P11(x,y) ⇒ E5(x)

P11(x,y) ⇒ E39(y)

P11(x,y) ⇒
P12(x,y)

P12 occurred in the presence of (was present at)

Domain:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event

Range:

[E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Superproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9003) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9122) used specific object (was used for): [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

[E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7480) Move. [P25](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9276) moved (moved by): [E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7681) Physical Object

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7519) Modification. [P31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9381) has modified (was modified by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8293) Beginning of Existence. [P92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10238) brought into existence (was brought into
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8314) End of Existence. [P93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10262) took out of existence (was taken out of
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

[E80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8567) Part Removal. [P113](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10641) removed (was removed by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property describes the active
or passive presence of an E77 Persistent Item in an instance of E5 Event
without implying any specific role.

It documents known events in which
an instance of E77 Persistent Item was present during the course of its life or
history. For example, an object may be the desk, now in a museum, on which a
treaty was signed. The instance of E53 Place and the instance of E52 Time-Span
where and when these events happened provide constraints about the presence of
the related instance E77 Persistent Item in the past. Instances of E90 Symbolic
Object, in particular information objects, are physically present in events via
at least one of the instances of E18 Physical Thing carrying them. Note, that
the human mind can be such a carrier. A precondition for a transfer of
information to a person or another new physical carrier is the presence of the
respective information object and this person or physical thing in one event.

Examples:

Deckchair
42 (E19) _was present at_ the sinking of the Titanic (E5). (Aldridge,
2008)

In first-order logic:

P12(x,y) ⇒ E5(x)

P12(x,y) ⇒ E77(y)

P13 destroyed (was destroyed by)

Domain:

[E6](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7410) Destruction

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650) Physical Thing

Subproperty of:

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8314) End of Existence. [P93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10262) took out of existence (was taken out of
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Quantification:

one to many, necessary (1,n:0,1)

Scope note:

This property links an instance of
E6 Destruction to an instance of E18 Physical Thing that has been destroyed by
it.

Destruction implies the end of an
item’s life as a subject of cultural documentation – the physical matter of
which the item was composed may in fact continue to exist. An instance of E6
Destruction may be contiguous with an instance of E12 Production that brings
into existence a derived object composed partly of matter from the destroyed
object.

Examples:

The
Tay Bridge Disaster (E6) _destroyed_ the Tay Bridge (E22). (Thomas, 1972)

In first-order logic:

P13(x,y) ⇒ E6 (x)

P13(x,y) ⇒ E18(y)

P13(x,y) ⇒
P93(x,y)

P14 carried out by (performed)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9003) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Superproperty of:

[E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7456) Acquisition. [P22](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9223) transferred title to (acquired title through): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

[E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7456) Acquisition. [P23](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9243) transferred title from (surrendered title
through): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

[E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7495) Transfer of Custody. [P28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9328) custody surrendered by (surrendered custody through): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

[E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7495)Transfer
of Custody. [P29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9347) custody
received by (received custody through): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property describes the active
participation of an instance of E39 Actor in an instance of E7 Activity.

It implies causal or legal
responsibility. The _P14.1 in the role of_ property of the property
specifies the nature of an Actor’s participation.

Examples:

The
painting of the Sistine Chapel (E7) _carried out by_ Michelangelo
Buonaroti (E21) _in the role of_ master craftsman (E55). (Goldscheider,
1953)

In first-order logic:

P14(x,y) ⇒ E7(x)

P14(x,y)⇒ E39(y)

P14(x,y) ⇒ P11(x,y)

P14(x,y,z) ⇒ \[P14(x,y)\
∧ E55(z)\]

Properties:

P14.1 in the role of: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P15 was influenced by (influenced)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Superproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9122) used specific object (was used for): [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9151) was motivated by (motivated): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P134](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10887) continued (was continued by): [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

[E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8600) Type Creation. [P136](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10924) was based on (supported type creation): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This is a high-level property, which
captures the relationship between an instance of E7 Activity and anything, that
is, an instance of E1 CRM Entity, that may have had some bearing upon it.

The property has more specific
subproperties.

Examples:

The
designing of the Sydney Harbour Bridge (E7) _was influenced by_ the Tyne Bridge
(E22). (Dorman Long, 1932)

In first-order logic:

P15(x,y) ⇒ E7(x)

P15(x,y) ⇒ E1(y)

P16 used specific object (was used for)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9032) occurred
in the presence of (was present at): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517)
Persistent Item

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9102) was influenced by (influenced): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Superproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9420) used specific technique (was used by): [E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7854) Design or Procedure

[E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) Part Addition. [P111](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10606) added (was added by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

[E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7601) Identifier Assignment. [P142](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11059) used constituent (was used in):[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Quantification:

many to many (0,n:0,n)

Scope note:

This property describes the use of
material or immaterial things in a way essential to the performance or the
outcome of an instance of E7 Activity.

This property typically applies to
tools, instruments, moulds, raw materials and items embedded in a product. It
implies that the presence of the object in question was a necessary condition
for the action. For example, the activity of writing this text required the use
of a computer. An immaterial thing can be used if at least one of its carriers
is present. For example, the software tools on a computer.

Another example is the use of a
particular name by a particular group of people over some span to identify a
thing, such as a settlement. In this case, the physical carriers of this name
are at least the people understanding its use.

Examples:

The
writing of the scope note of the CIDOC CRM property “P16 used specific object”
contained in the CIDOC CRM version 4.1 (E7) _used specific object_ Nicholas
Crofts’ computer (E22) _mode of use_ Typing Tool; Storage Medium (E55).
\[the original scope note was later extended in the CIDOC CRM version 4.3\]

The
people of Iraq calling the place identified by TGN ‘7017998’ (E7) _used_
_specific object_ “Quyunjig” (E41) _mode of use_ current; vernacular
(E55).

In first-order logic:

P16(x,y) ⇒
E7(x)

P16(x,y) ⇒ E70(y)

P16(x,y) ⇒ P12(x,y)

P16(x,y) ⇒ P15(x,y)

P16(x,y,z) ⇒ \[P16(x,y)\
∧ E55(z)\]

Properties:

P16.1 mode of use: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P17 was motivated by (motivated)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9102) was influenced by (influenced): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property describes an item or
items that are regarded as a reason for carrying out the instance of E7
Activity.

For example, the discovery of a
large hoard of treasure may call for a celebration, an order from headquarters
can start a military manoeuvre.

Examples:

The
resignation of the chief executive (E7) _was motivated by_ the collapse of
SwissAir (E68).

The
coronation of Elizabeth II (E7) _was motivated by_ the death of George VI
(E69). (Strong, 2005)

In first-order logic:

P17(x,y) ⇒ E7(x)

P17(x,y) ⇒ E1(y)

P17(x,y) ⇒
P15(x,y)

P19 was
intended use of (was made for)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431) Human-Made Thing

Quantification:

many to many (0,n:0,n)

Scope note:

This property relates an instance of
E7 Activity with instances of E71 Human-Made Thing, created specifically for
use in the activity.

This is distinct from the intended
use of an item in some general type of activity such as the book of common
prayer which was intended for use in Church of England services (see _P101_ _had as general use (was use of)_).

Examples:

Lady
Diana Spencer’s wedding dress (E71) _was made for_ Wedding of Prince
Charles and Lady Diana Spencer (E7) _mode of use_ To Be Worn (E55). (Daly,
1981)

In first-order logic:

P19(x,y) ⇒ E7(x)

P19(x,y) ⇒ E71(y)

P19(x,y,z) ⇒ \[P19(x,y)\
∧ E55(z)\]

Properties:

P19.1 mode of use: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P20 had specific purpose (was purpose of)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event

Quantification:

many to many (0,n:0,n)

Scope note:

This property describes the
relationship between a preparatory activity, an instance of E7 Activity and the
instance of E5 Event that it is intended as a preparation for.

This includes activities, orders and
other organisational actions, taken in preparation for other activities or
events.

_P20 had specific purpose (was_
_purpose of)_ implies that the activity succeeded in
achieving its aim. If it does not succeed, such as the setting of a trap that
did not catch anything, the unrealized intention should be documented using _P21_
_had general purpose (was purpose of):_ E55 Type and/or _P33 used specific_
_technique (was used by):_ E29 Design or Procedure.

Examples:

Van Eyck’s pigment grinding in 1432 (E7) _had_
_specific purpose_ the painting of the Ghent altar piece (E12). (Borchert,
2008)

In first-order logic:

P20(x,y) ⇒ E7(x)

P20(x,y) ⇒ E5(y)

P21 had
general purpose (was purpose of)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many to many (0,n:0,n)

Scope note:

This property describes an
intentional relationship between an instance of E7 Activity and some general
goal or purpose, described as an instance of E55 Type.

This
may involve activities intended as preparation for some type of activity or
event. _P21 had general purpose (was purpose of)_ differs from _P20 had_
_specific purpose (was purpose of_in that no specific event is implied as
the purpose.

Examples:

Van
Eyck’s pigment grinding (E7) _had general purpose_ painting (E55).
(Borchert, 2008)

The
setting of trap 2742 on 17th May 1874 (E7) _had general purpose_ catching
moose (E55). \[activity type\] (fictitious)

The
construction of the Berlin Wall starting 13th August 1961 (E12) had general purpose preventing emigration (E55). (History.com Editors, 2020)

The
reinforcement of the Mexico-United States barrier between the United States of
America and Mexico in Fall 2019 (E11) had general purpose preventing
immigration (E55).

The rebuilding of the city walls of Heraklion by the Venetian rulers
starting in 1462 (E12) _had general purpose_ preventing conquest by enemy
(E55). (YouIngGreece.com, 2020)

The building of the seawall in Hamamatsu, Shizuoka, Japan between
2014 and 2020 (E12) _had general purpose_ preventing inland flooding by
tsunami (E55).

In first-order logic:

P21(x,y) ⇒
E7(x)

P21(x,y) ⇒
E55(y)

P22 transferred title to (acquired title through)

Domain:

[E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7456)
Acquisition

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9076) carried out by (performed): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies the
instance of E39 Actor that acquires the legal ownership of an object as a
result of an instance of E8 Acquisition.

The property will typically describe
an Actor purchasing or otherwise acquiring an object from another Actor. However,
title may also be acquired without any corresponding loss of title by another
Actor, through legal fieldwork such as hunting, shooting, or fishing.

In reality, the title is either
transferred to or from someone, or both.

Examples:

The
acquisition of the Amoudruz collection by the Geneva Ethnography Museum (E8) _transferred_
_title to_ the Geneva Ethnography Museum (E74).

In first-order logic:

P22(x,y) ⇒
E8(x)

P22(x,y) ⇒ E39(y)

P22(x,y) ⇒ P14(x,y)

P23 transferred title from (surrendered title through)

Domain:

[E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7456)
Acquisition

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9076) carried out by (performed): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies the
instance(s) of E39 Actor who relinquish legal ownership as the result of an
instance of E8 Acquisition.

The property will typically be used
to describe a person donating or selling an object to a museum. In reality, the
title is either transferred to or from someone, or both.

Examples:

The
acquisition of the Amoudruz collection by the Geneva Ethnography Museum (E8) _transferred_
_title from_ the Heirs of Amoudruz (E74).

In first-order logic:

P23(x,y) ⇒
E8(x)

P23(x,y) ⇒ E39(y)

P23(x,y) ⇒ P14(x,y)

P24 transferred title of (changed ownership through)

Domain:

[E8](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7456) Acquisition

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650) Physical Thing

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance(s) of E18 Physical Thing involved in an instance of E8 Acquisition.

In reality, an acquisition must
refer to at least one transferred item.

Examples:

The
acquisition of the Amoudruz collection by the Geneva Ethnography Museum (E8) _transferred_
_title of_ theAmoudruz Collection (E78).

In first-order logic:

P24(x,y) ⇒
E8(x)

P24(x,y) ⇒
E18(y)

P25 moved (moved by)

Domain:

[E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7480) Move

Range:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7681) Physical Object

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9032) occurred
in the presence of (was present at): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517)
Persistent Item

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies an instance
of E19 Physical Object that was moved by an instance of E9 Move. A move must
concern at least one object.

The property implies the object’s
passive participation. For example, Monet’s painting “Impression sunrise” was
moved for the first Impressionist exhibition in 1874.

Examples:

Monet´s
“Impression sunrise” (E22) _moved by_ preparations for the First
Impressionist Exhibition (E9).

In first-order logic:

P25(x,y) ⇒
E9(x)

P25(x,y) ⇒ E19(y)

P25(x,y) ⇒ P12(x,y)

P26 moved to
(was destination of)

Domain:

[E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7480) Move

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies a
destination, an instance of E53 Place, of an instance of E9 Move.

A move will be linked to a
destination, such as the move of an artifact from storage to display. A move
may be linked to many terminal instances of E53 Place by multiple instances of
this property. In this case the move describes a distribution of a set of
objects. The area of the move includes the origin(s), route and destination(s).

Therefore, the described destination
is an instance of E53 Place which _P89 falls within (contains)_ the
instance of E53 Place the move _P7 took place at._

Examples:

The
movement of the exhibition “Tutankhamun: Treasures of the Golden Pharaoh”
between 15th September and 2nd November 2019 (E9) _moved_
_to_ the Saatchi Gallery London (E53).

In first-order logic:

P26(x,y)
⇒ E9(x)

P26(x,y)
⇒ E53(y)

P26(x,y)
⇒ (∃z) \[E53(z) ∧ P7(x,z)\
∧ P89(y,z)\]

P27 moved from
(was origin of)

Domain:

[E9](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7480) Move

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies an origin,
an instance of E53 Place, of an instance of E9 Move.

A move will be linked to an origin,
such as the move of an artifact from storage to display. A move may be linked
to many starting instances of E53 Place by multiple instances of this property.
In this case the move describes the picking up of a set of objects. The area of
the move includes the origin(s), route and destination(s).

Therefore, the described origin is
an instance of E53 Place which _P89 falls within (contains)_ the instance
of E53 Place the move _P7 took place at._

Examples:

The
movement of the exhibition “Tutankhamun: Treasures of the Golden Pharaoh”
between 15th September and 2nd November 2019 (E9) _moved_
_from_ Paris, Grande Halle de la Villette (E53).

In first-order logic:

P27(x,y)
⇒ E9(x)

P27(x,y)
⇒ E53(y)

P27(x,y)
⇒ (∃z) \[E53(z) ∧ P7(x,z)\
∧ P89(y,z)\]

P28 custody surrendered by (surrendered custody through)

Domain:

[E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7495)Transfer
of Custody

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9076) carried out by (performed): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies the
instance(s) of E39 Actor who surrender custody of an instance of E18 Physical
Thing in an instance of E10 Transfer of Custody.

The property will typically describe
an Actor surrendering custody of an object when it is handed over to someone
else’s care. On occasion, physical custody may be surrendered involuntarily,
e.g. through accident, loss, or theft.

In reality, custody is either
transferred to someone or from someone, or both.

Examples:

The
Secure Deliveries Inc. crew (E74) _surrendered custody_ _through_ the
delivery of the paintings by Secure Deliveries Inc. to the National Gallery
(E10).

In first-order logic:

P28(x,y) ⇒
E10(x)

P28(x,y) ⇒ E39(y)

P28(x,y) ⇒ P14(x,y)

P29 custody received by (received custody through)

Domain:

[E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7495)Transfer
of Custody

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9076) carried out by (performed): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies the
instance(s) of E39 Actor who receive custody of an instance of E18 Physical
Thing in an instance of E10 Transfer of Custody.

The property will typically describe
Actors receiving custody of an object when it is handed over from another
Actor’s care. On occasion, physical custody may be received involuntarily or
illegally, e.g. through accident, unsolicited donation, or theft.

In reality, custody is either
transferred to someone or from someone, or both.

Examples:

Representatives
of The National Gallery (E74) _received custody_ _through_ the
delivery of the paintings by Secure Deliveries Inc. to the National Gallery
(E10).

In first-order logic:

P29(x,y)
⇒ E10(x)

P29(x,y)
⇒ E39(y)

P29(x,y)
⇒ P14(x,y)

P30
transferred custody of (custody transferred through)

Domain:

[E10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7495)Transfer
of Custody

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance(s) of E18 Physical Thing concerned in an instance of E10 Transfer of
Custody.

The property will typically describe
the object that is handed over by an instance of E39 Actor to the custody of
another instance of E39 Actor. On occasion, physical custody may be transferred
involuntarily or illegally, e.g. through accident, unsolicited donation, or
theft.

Examples:

The
delivery of the paintings by Secure Deliveries Inc. to the National Gallery
(E10) _transferred custody of_ paintings from The Iveagh Bequest (E19).

In first-order logic:

P30(x,y)
⇒ E10(x)

P30(x,y)
⇒ E18(y)

P31 has modified (was modified by)

Domain:

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7519) Modification

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650) Physical Thing

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9032) occurred
in the presence of (was present at): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517)
Persistent Item

Superproperty of:

[E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7542) Production. [P108](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10549) has produced (was produced by): [E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7749) Physical Human-Made
Thing

[E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) Part Addition. [P110](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10588) augmented (was augmented by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7280)
Physical Thing

[E80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8567) Part Removal. [P112](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10623) diminished (was diminished by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7280) Physical Thing

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance of E18 Physical Thing modified in an instance of E11 Modification.

Examples:

The
rebuilding of the German Reichstag in Berlin (E11) _has modified_ the
Reichstag in Berlin (E24). (Foster, 2000)

In first-order logic:

P31(x,y)
⇒ E11(x)

P31(x,y)
⇒ E18(y)

P31(x,y)
⇒ P12(x,y)

P32 used general technique (was technique of)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P125](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10733) used object of type (was type of object used in): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies the technique
or method, modelled as an instance of E55 Type, that was employed in an
instance of E7 Activity.

These techniques should be drawn
from an external E55 Type hierarchy of consistent terminology of general
techniques or methods such as embroidery, oil-painting, carbon dating, etc.
Specific documented techniques should be described as instances of E29 Design
or Procedure.

Examples:

The
ornamentation of silver cup 113 (E11) _used general technique_
gold-plating (E55). \[A Design or Procedure type\] (fictitious)

In first-order logic:

P32(x,y)
⇒
E7(x)

P32(x,y)
⇒
E55(y)

P32(x,y) ⇒ P125(x,y)

P33 used specific technique (was used by)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7854) Design or Procedure

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9122) used specific object (was used for): [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies a specific
instance of E29 Design or Procedure in order to carry out an instance of E7
Activity or parts of it.

The property differs from _P32_
_used general technique (was technique of)_ in that P33 refers to an instance
of E29 Design or Procedure, which is a concrete information object in its own
right rather than simply being a term or a method known by tradition.

Typical examples would include
intervention plans for conservation or the construction plans of a building.

Examples:

The
ornamentation of silver cup 232 (E11) _used specific technique_
‘Instructions for golden chase work by A N Other’ (E29). (fictitious)

The
rebuilding of the German Reichstag in Berlin (E11) _used specific technique_
Architectural plans by Foster and Partners (E29). (Foster, 2000)

In first-order logic:

P33(x,y) ⇒ E7(x)

P33(x,y) ⇒ E29(y)

P33(x,y) ⇒
P16(x,y)

P34 concerned (was assessed by)

Domain:

[E14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7586) Condition Assessment

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650) Physical Thing

Subproperty of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) Attribute Assignment. [P140](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11015) assigned attribute to (was attributed by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance of E18 Physical Thing that was assessed during an instance of E14
Condition Assessment.

Conditions may be assessed either by
direct observation or using recorded evidence. In the latter case the instance
of E18 Physical Thing does not need to be present or extant at the time of
assessment.

Examples:

The
condition assessment of the silver collection in 1997 (E14) _concerned_
silver cup 232 (E22). (fictitious)

The
condition assessment of the cover of MS Sinai Greek 418 (E14) _concerned_
the cover of MS Sinai Greek 418 (E22). (Honey and Pickwoad, 2010)

The
condition assessment of the endband cores of MS Sinai Greek 418 (E14) _concerned_
the endband cores of MS Sinai Greek 418 (E22). (Honey and Pickwoad, 2010)

In first-order logic:

P34(x,y) ⇒ E14(x)

P34(x,y) ⇒ E18(y)

P34(x,y) ⇒
P140(x,y)

P35 has identified (was identified by)

Domain:

[E14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7586) Condition Assessment

Range:

[Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State

Subproperty of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) Attribute Assignment. [P141](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11036) assigned (was assigned by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance of E3 Condition State that was observed in an instance of E14
Condition Assessment activity.

Examples:

The
condition assessment of silver cup 232 in 1997 (E14) _has_ _identified_
oxidation traces were present in 1997 (E3).\[which _has type (P2)_\
with oxidation traces (E55)\] (fictitious)

The
condition assessment of the cover of MS Sinai Greek 418 (E13) _has identified_
the condition state in November 2003 (E3). \[which _has type_ fine (E55)\]
(Honey and Pickwoad, 2010)

The
condition assessment of the endband cores of MS Sinai Greek 418 (E14) _has_
_identified_ the condition state in November 2003 (E3). \[which _has type_\
broken (E55)\] (Honey and Pickwoad, 2010)

In first-order logic:

P35(x,y) ⇒E14(x)

P35(x,y) ⇒ E3(y)

P35(x,y) ⇒
P141(x,y)

P37 assigned (was assigned by)

Domain:

[E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7601)
Identifier Assignment

Range:

[E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier

Subproperty of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) Attribute Assignment. [P141](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11036) assigned (was assigned by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property records the identifier
that was assigned to an item in an instance of E15 Identifier Assignment.

The
same identifier may be assigned on more than one occasion.

An identifier might be created prior
to an assignment.

Examples:

The
identifier assignment on 1st June 1997 of the silver cup donated by
Martin Doerr (E15) _assigned_ “232” (E42) (fictitious)

In first-order logic:

P37(x,y) ⇒
E15(x)

P37(x,y) ⇒ E42(y)

P37(x,y) ⇒ P141(x,y)

P38 deassigned (was deassigned by)

Domain:

[E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7601)
Identifier Assignment

Range:

[E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier

Subproperty of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) Attribute Assignment. [P141](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11036) assigned (was assigned by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property records the identifier
that was deassigned from an instance of E1 CRM Entity.

De-assignment of an identifier may
be necessary when an item is taken out of an inventory, a new numbering system
is introduced or items are merged or split up.

The same identifier may be
deassigned on more than one occasion.

Examples:

The
identifier assignment on 31st July 2001 of the silver cup
OXCMS:2001.1.32 (E15) _deassigned_ “232” (E42). (fictitious)

In first-order logic:

P38(x,y) ⇒ E15(x)

P38(x,y) ⇒ E42(y)

P38(x,y) ⇒
P141(x,y)

P39 measured (was measured by)

Domain:

[E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7618) Measurement

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7666) Physical Thing

Subproperty of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) Attribute Assignment. [P140](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11015) assigned attribute to (was attributed by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property associates an instance
of E16 Measurement with the instance of E18 Physical Thing upon which it acted.
The instance of E16 Measurement is specific to the measured object. An instance
of E18 Physical Thing may be measured more than once with different results,
constituting different instances of E16 Measurement.

Examples:

The
measurement of the height of silver cup 232 on 31st August 1997
(E16) _measured_ silver cup 232 (E22). (fictitious)

The
carbon 14 dating of the “Schoeninger Speer II” in 1996 (E16) _measured_
the “Schoeninger Speer II” (E22). \[The carbon 14 dating of an approximately\
400.000 year old complete Old Palaeolithic wooden spear found in Schoeningen,\
Niedersachsen, Germany, in 1995. See also, E16 Measurement.\] (Kouwenhoven,
1997)

In first-order logic:

P39(x,y) ⇒ E16(x)

P39(x,y) ⇒ E18(y)

P39(x,y) ⇒ P140(x,y)

P40 observed dimension (was observed in)

Domain:

[E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7618)
Measurement

Range:

[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128) Dimension

Subproperty of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) Attribute Assignment. [P141](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11036) assigned (was assigned by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property records the dimension
that was observed in an E16 Measurement Event.

E54 Dimension can be any
quantifiable aspect of E70 Thing. Weight, image colour depth and monetary value
are dimensions in this sense. One measurement activity may determine more than
one dimension of one object.

Dimensions may be determined either
by direct observation or using recorded evidence. In the latter case the
measured Thing does not need to be present or extant.

Even though knowledge of the value
of a dimension requires measurement, the dimension may be an object of
discourse prior to, or even without, any measurement being made.

Examples:

The
measurement of the height of silver cup 232 on 31st August 1997
(E16) _observed dimension_ silver cup 232 height (E54). \[which _has unit_\
mm (E58), _has value_ 224 (E60)\] (fictitious)

The
carbon 14 dating of the “Schoeninger Speer II” in 1996 (E16) _observed_
_dimension_ the carbon 14 based temporal distance from 1996 to the growth of
the wood of the “Schoeninger Speer II” (E60). \[The carbon 14 dating of an\
approximately 400.000 year old complete Old Palaeolithic wooden spear found in\
Schoeningen, Niederachsen, Germany, in 1995. See also: E16 Measurement.\]
(Kouwenhoven, 1997)

In first-order logic:

P40(x,y) ⇒ E16(x)

P40(x,y)⇒ E54(y)

P40(x,y) ⇒
P141(x,y)

P41 classified (was classified by)

Domain:

[E17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7636) Type Assignment

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Subproperty of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) Attribute Assignment. [P140](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11015) assigned attribute to (was attributed by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property records the item to
which a type was assigned in an E17 Type Assignment activity.

Any instance of a CIDOC CRM entity
may be assigned a type through type assignment. Type assignment events allow a
more detailed path from E1 CRM Entitythrough _P41i was classified by,_ E17 Type Assignment _, P42 assigned,_ to E55 Type for assigning types
to objects compared to the shortcut offered by _P2_ _has type (is type_
_of)_.

Examples:

The
classification of silver cup 232 on 31st August 1997 (E17) _classified_
silver cup 232 (E22). (fictitious)

In first-order logic:

P41(x,y) ⇒ E17(x)

P41(x,y) ⇒ E1(y)

P41(x,y) ⇒
P140(x,y)

P42 assigned (was
assigned by)

Domain:

[E17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7636) Type Assignment

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Subproperty of:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561) Attribute Assignment. [P141](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11036) assigned (was assigned by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property records the type that
was assigned to an entity by an E17 Type Assignment activity.

Type assignment events allow a more
detailed path from E1 CRM Entitythrough _P41i was classified by,_ E17
Type Assignment _, P42 assigned,_ to E55 Type for assigning types to
objects compared to the shortcut offered by _P2_ _has type (is type of)_.

For example, a fragment of an
antique vessel could be assigned the type “attic red figured belly handled
amphora” by expert A. The same fragment could be assigned the type “shoulder
handled amphora” by expert B.

A Type may be intellectually
constructed independent from assigning an instance of it.

Examples:

The
classification of silver cup 232 on 31st August 1997 (E17) _assigned_
goblet (E55). (fictitious)

In first-order logic:

P42(x,y) ⇒ E17(x)

P42(x,y)⇒ E55(y)

P42(x,y) ⇒
P141(x,y)

P43 has dimension (is dimension of)

Domain:

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Range:

[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128) Dimension

Quantification:

one to many, dependent (0,n:1,1)

Scope note:

This property records an instance of
E54 Dimension of some instance of E70 Thing.

In the case that the recorded
property is a result of a measurement of an instance of E18 Physical Thing,
this property is a shortcut of the more fully developed path from E18 Physical
Thingthrough _P39i was measured by,_ E16 Measurement _, P40_
_observed dimension_ toE54 Dimension.

It offers no information about how
and when an E54 Dimension was established, nor by whom. Knowledge about an
instance of E54 Dimension need not be the result of a measurement; it may be
the result of evaluating data or other information, which should be documented
as an instance of E13 Attribute Assignment.

An instance of E54 Dimension is
specific to an instance of E70 Thing.

Examples:

Silver
cup 232 (E22) _has dimension_ height of silver cup 232 (E54). \[which _has_\
_unit (P91)_ mm (E58), _has value (P90)_ 224 (E60)\] (fictitious)

In first-order logic:

P43(x,y) ⇒
E70(x)

P43(x,y) ⇒ E54(y)

P43(x,y) ⇐ (∃z)
\[E16(z) ˄ P39i(x,z) ˄ P40(z,y)\]

P44 has
condition (is condition of)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State

Quantification:

one to many, dependent (0,n:1,1)

Scope note:

This property records an E3 Condition
State for some E18 Physical Thing.

This property is a shortcut of the
more fully developed path from E18 Physical Thingthrough _P34i was_
_assessed by,_ E14 Condition Assessment _, P35 has identified_ toE3
Condition State. It offers no information about how and when the E3 Condition
State was established, nor by whom.

An instance of E3 Condition State is
specific to an instance of E18 Physical Thing.

Examples:

Silver
cup 232 (E22) _has_ _condition_ oxidation traces were present in 1997
(E3). \[which _has type (P2)_ oxidation traces (E55)\] (fictitious)

In first-order logic:

P44(x,y) ⇒ E18(x)

P44(x,y) ⇒ E3(y)

P44(x,y) ⇐ (∃z)
\[E14(z) ˄ P34i(x,z) ˄ P35(z,y)\]

P45 consists
of (is incorporated in)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8194) Material

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This
property identifies the instances of E57 Materials of which an instance of E18 Physical
Thing is composed.

All physical things consist of
physical materials. _P45 consists of (is incorporated in)_ allows the
different materials to be recorded. _P45 consists of (is incorporated in)_
refers here to observed material as opposed to the consumed raw material.

A material, such as a theoretical
alloy, may not have any physical instances.

Examples:

Silver
cup 232 (E22) _consists of_ silver (E57). (fictitious)

In first-order logic:

P45(x,y) ⇒ E18(x)

P45(x,y) ⇒ E57(y)

P46 is composed of (forms part of)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650) Physical Thing

Superproperty of:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7681) Physical Object. [P56](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9824) bears feature (is found on): [E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7791) Physical Feature

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E18 Physical Thing with another instance of Physical Thing that forms part
of it. The spatial extent of the composing part is included in the spatial
extent of the whole.

Component elements, since they are
themselves instances of E18 Physical Thing, may be further analysed into
sub-components, thereby creating a hierarchy of part decomposition. An instance
of E18 Physical Thing may be shared between multiple wholes, for example two
buildings may share a common wall. This property does not specify when and for
how long a component element resided in the respective whole. If a component is
not part of a whole from the beginning of existence or until the end of
existence of the whole, the classes E79 Part Addition and E90 Part Removal can
be used to document when a component became part of a particular whole and/or
when it stopped being a part of it. For the time-span of being part of the
respective whole, the component is completely contained in the place the whole
occupies.

This property is intended to
describe specific components that areindividually documented, rather
than general aspects. Overall descriptions of the structure of an instance of
E18 Physical Thing are captured by the _P3_ _has note_ property.

The instances of E57 Material of
which an instance of E18 Physical Thing is composed should be documented using _P45_ _consists of (is incorporated in)_.

This property is transitive and asymmetric.

Examples:

The
Royal carriage (E22) _forms part of_ the Royal train (E22).

The
“Hog’s Back” (E24) _forms part of_ the “Fosseway” (E24).

In first-order logic:

P46(x,y) ⇒
E18(x)

P46(x,y) ⇒ E18(y)

P46(x,y) ⇒ P132(x,y)

\[P46(x,y) ∧ P46(y,z)\]
⇒ P46(x,z)

P46(x,y) ⇒ (∃uzw)\[E93(u)\
∧ P195i (x,u) ∧ E52(z) ∧ P164(u,z) ∧ E93(w) ∧ P195i (w,y) ∧ P164(w,z) ∧ P10(w,u)\]

P46(x,y) ⇒ ¬P46(y,x)

P48 has
preferred identifier (is preferred identifier of)

Domain:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Range:

[E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier

Subproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) is identified by (identifies): [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

Quantification:

many to one (0,1:0,n)

Scope note:

This property records the preferred
instance of E42 Identifier that was used to identify an instance of E1 CRM
Entity at the time this property was recorded.

More than one preferred identifier
may have been assigned to an item over time.

Use of this property requires an
external mechanism for assigning temporal validity to the respective CIDOC CRM
instance.

The fact that an identifier is a
preferred one for an organisation can be better expressed in a context
independent form by assigning a suitable instance of E55 Type to the respective
instance of E15 Identifier Assignment using the _P2 has type_ property.

Examples:

The
pair of Lederhosen donated by Dr. Martin Doerr (E22) _has preferred_
_identifier_ “OXCMS:2001.1.32” (E42). (fictitious)

In first-order logic:

P48(x,y) ⇒ E1(x)

P48(x,y) ⇒ E42(y)

P48(x,y) ⇒
P1(x,y)

P49 has former or current keeper (is former or current keeper of)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Superproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P50](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9708) has current
keeper (is current keeper of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

[E78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8537) Curated Holding. [P109](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10569) has current or former curator (is current or
former curator of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies the
instance of E39 Actor who has or has had custody of an instance of E18 Physical
Thing at some time. This property leaves open the question if parts of this
physical thing have been added or removed during the time-spans it has been
under the custody of this actor, but it is required that at least a part which
can unambiguously be identified as representing the whole has been under this
custody for its whole time. The way, in which a representative part is defined,
should ensure that it is unambiguous who keeps a part and who the whole and
should be consistent with the identity criteria of the kept instance of E18
Physical Thing.

The distinction with _P50 has_
_current keeper (is current keeper of)_ is that _P49 has former or current_
_keeper (is former or current keeper of)_ leaves open the question as to
whether the specified keepers are current.

This property is a shortcut for the
more detailed path from E18 Physical Thing through _P30i custody transferred_
_through,_ E10 Transfer of Custody, _P28 custody surrendered by_ _or_
_P29 custody received by_ to E39 Actor.

Examples:

The
paintings from The Iveagh Bequest (E78) _has former or current keeper_
Secure Deliveries Inc. (E74).

In first-order logic:

P49(x,y) ⇒
E18(x)

P49(x,y) ⇒ E39(y)

P49(x,y) ⇐ (∃z)
\[E10(z) ˄ P30i(x,z) ˄ \[P28(z,y) ˅ P29(z,y) \]\]

P50 has current keeper (is current keeper of)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P49](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9688) has former or
current keeper (is former or current keeper of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies the
instance of E39 Actor that had custody of an instance of E18 Physical Thing at
the time of validity of the record or database containing the statement that
uses this property.

This property is a shortcut for the
more detailed path from E18 Physical Thing through, _P30i custody transferred_
_through_, E10 Transfer of Custody, _P29 custody received by_ to E39
Actor, if and only if the custody has not been surrendered by the receiving actor
at any later time

Examples:

The
paintings from The Iveagh Bequest (E78) _has current keeper_ The National
Gallery (E74) (Iveagh Bequest, 1975)

In first-order logic:

P50(x,y) ⇒
E18(x)

P50(x,y) ⇒ E39(y)

P50(x,y) ⇒ P49(x,y)

P50(x,y) ⇐ (∃z)
\[\[E10(z) ˄ P30i(x,z) ˄ P29(z,y) \]\
\
˄ ¬ (∃w) \[E10(w) ˄ P30i(x,w) ˄ P28(w,y)˄ P182(z,w)\]\]

P51 has former
or current owner (is former or current owner of)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Superproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9747) has current
owner (is current owner of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies an instance
of E39 Actor that is or had been the legal owner (i.e. title holder) of an
instance of E18 Physical Thing at some time.

The distinction with _P52 has_
_current owner (is current owner of)_ is that _P51 has former or current_
_owner (is former or current owner of)_ does not indicate whether the
specified owners are current.

This property is a shortcut for the
more detailed path from E18 Physical Thing through _P24i changed ownership_
_through_, E8 Acquisition, _P23 transferred title from_, or _P22_
_transferred title to_ to E39 Actor.

Examples:

The
paintings from the Iveagh Bequest (E78) _has former or current owner_ Lord
Iveagh (E21). (Bryant, 1990)

In first-order logic:

P51(x,y) ⇒ E18(x)

P51(x,y) ⇒ E39(y)

P51(x,y) ⇐ (∃z)
\[E8(z) ˄ P24i(x,z) ˄ \[P23(z,y) ˅ P22(z,y) \]\]

P52 has current owner (is current owner
of)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P51](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9727) has former or
current owner (is former or current owner of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

[E72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8451) Legal Object. [P105](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10486) right held by (has right on): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies the
instance of E21 Person or E74 Group that was the owner of an instance of E18
Physical Thing at the time of validity of the record or database containing the
statement that uses this property.

This property is a shortcut for the
more detailed path from E18 Physical Thing through, _P24i changed ownership_
_through_, E8 Acquisition, _P22 transferred title to_ to E39 Actor, if
and only if this acquisition event is the most recent.

Examples:

The
paintings from the Iveagh Bequest (E78) _has current owner_ Historic
England (E74). \[This is still valid 2021 CE. The important collection of Old\
Master and British portraits was bequeathed to Kenwood by Edward Cecil\
Guinness, 1st Earl of Iveagh, in 1927.\] (Iveagh Bequest, 1975;
Bryant, 1990)

In first-order logic:

P52(x,y) ⇒ E18(x)

P52(x,y) ⇒ E39(y)

P52(x,y) ⇒ P51(x,y)

P52(x,y) ⇒ P105(x,y)

P52(x,y) ⇐ (∃z)
\[\[E8(z) ˄ P24i(x,z) ˄ P22(z,y) \]\
\
                             ˄ ¬\
(∃w) \[E8(w) ˄ P24i(x,w) ˄ P23(w,y)˄ P182(z,w)\]\]

P53 has former or
current location (is former or current location of)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Superproperty of:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7681) Physical Object. [P55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9804) has current location (currently holds): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P156](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11251) occupies (is
occupied by): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies an instance
of E53 Place as the former or current location of an instance of E18 Physical
Thing.

In the case of instances of E19
Physical Object, the property does not allow any indication of the Time-Span
during which the instance of E19 Physical Object was located at this instance
of E53 Place, nor if this is the current location.

In the case of immobile objects, the
Place would normally correspond to the Place of creation.

This property is a shortcut. A more
detailed representation can make use of the fully developed (i.e. indirect)
path from E19 Physical Object _,_ though _, P25i moved by_, E9 Move _,_
_P26 moved to_ or _P27 moved from_ toE53 Place.

Examples:

Silver
cup 232 (E22) _has former or current location_ Display Case 4, Room 23,
Museum of Oxford (E53). (fictitious)

In first-order logic:

P53(x,y) ⇒
E18(x)

P53(x,y) ⇒ E53(y)

P53(x,y) ⇐ (∃z)
\[E9(z) ˄ P25i(x,z) ˄ \[P26(z,y) ˅ P27(z,y)\]\]

P54 has current
permanent location (is current permanent location of)

Domain:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7681)
Physical Object

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to one (0,1:0,n)

Scope note:

This property records the foreseen
permanent location of an instance of E19 Physical Object at the time of
validity of the record or database containing the statement that uses this
property.

_P54 has current permanent_
_location (is current permanent location of)_ is
similar to _P55 has current location (currently holds)._ However, it indicates
the E53 Place currently reserved for an object, such as the permanent storage
location or a permanent exhibit location. The object may be temporarily removed
from the permanent location, for example when used in temporary exhibitions or
loaned to another institution. The object may never actually be located at its
permanent location.

Examples:

Silver
cup 232 (E22) _has current permanent location_ Shelf 3.1, Store 2, Museum
of Oxford (E53). (fictitious)

In first-order logic:

P54(x,y) ⇒ E19(x)

P54(x,y) ⇒ E53(y)

P55 has current location (currently holds)

Domain:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7681) Physical Object

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Subproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9768) has former or
current location (is former or current location of): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many (0,n:0,n)

Scope note:

This property records the location
of an instance of E19 Physical Object at the time of validity of the record or
database containing the statement that uses this property.

This property is a specialisation of
_P53_ _has former or current location (is former or current location_
_of)._ It indicates that the instance of E53 Place associated with the
instance of E19 Physical Object is the current location of the object. The
property does not allow any indication of how long the object has been at the
current location.

This property is a shortcut. A more
detailed representation can make use of the fully developed (i.e., indirect)
path from E19 Physical Object _,_ through _, P25i moved by,_ E9 Move _,_
_P26 moved to_ toE53 Place if and only if this Move is the most
recent.

Examples:

Silver
cup 232 (E22) _has current location_ Display Cabinet 23, Room 4, British
Museum (E53). (fictitious)

In first-order logic:

P55(x,y) ⇒ E19(x)

P55(x,y) ⇒ E53(y)

P55(x,y) ⇒ P53(x,y)

P55(x,y) ⇐ (∃z)
\[ \[E9(z) ˄ P25i(x,z) ˄ P26(z,y)\]\
\
                              ˄\
¬​ (∃w) \[E9(w) ˄ P25i(x,w) ˄ P27(w,y)˄ P182(z,w)\]\]​

P56 bears feature
(is found on)

Domain:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7681) Physical Object

Range:

[E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7791) Physical Feature

Subproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P46](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9643) is composed of
(forms part of): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical Thing

Quantification:

one to many, dependent (0,n:1,1)

Scope note:

This property links an instance of
E19 Physical Object to an instance of E26 Physical Feature that it bears.

An instance of E26 Physical Feature
can only exist on one object. One object may bear more than one E26 Physical
Feature. An instance of E27 Site should be considered as an instance of E26
Physical Feature on the surface of the Earth.

An instance B of E26 Physical
Feature being a detail of the structure of another instance A of E26 Physical
Feature can be linked to B by use of the property _P46 is composed of (forms_
_part of)_. This implies that the subfeature B is _P56i is found on_ the
same E19 Physical Object as A.

This property is a shortcut. A more
detailed representation can make use of the fully developed (i.e. indirect)
path _E19 Physical Object,_ through _, P59 has section,_ E53 Place _,_
_P53i is former or current location of_ toE26 Physical Feature.

Examples:

Silver
cup 232 (E22) _bears feature_ 32 mm scratch on silver cup 232 (E26).
(fictitious)

In first-order logic:

P56(x,y) ⇒E19(x)

P56(x,y) ⇒ E26(y)

P56(x,y) ⇒ P46(x,y)

P56(x,y) ⇐ (∃z)
\[E53(z) ˄ P59(x,z) ˄ P53i(z,y)\]

P57 has number
of parts

Domain:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7681) Physical Object

Range:

[E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8250) Number

Quantification:

many to one (0,1:0,n)

Scope note:

This property documents the number
of parts, an instance of E60 Number, of which an instance of E19 Physical
Object is composed.

This may be used as a method of
checking inventory counts with regard to aggregate or collective objects. What
constitutes a part or component depends on the context and requirements of the
documentation. Normally, the parts documented in this way would not be
considered as worthy of individual attention.

For a more complete description,
objects may be decomposed into their components and constituents using _P46_
_is composed of (forms parts of)_ and _P45 consists of (is incorporated in)_.
This allows each element to be described individually.

Examples:

Chess
set 233 (E22) _has number of_ _parts_ 33 (E60). (fictitious)

In first-order logic:

P57(x,y) ⇒ E19(x)

P57(x,y) ⇒ E60(y)

P59 has section (is located on or within)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many (0,n:0,n)

Subproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P157](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11276) i provides
reference space for: [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104)
Place

Scope note:

This property links an area, i.e.,
an instance of E53 Place to the instance of E18 Physical Thing upon which it is
found. This area may either be identified by a name, or by a geometry in terms
of a coordinate system adapted to the shape of the respective instance of E18
Physical Thing. Typically, names identifying sections of physical objects are
composed of the name of a kind of part and the name of the object itself, such
as “The poop deck of H.M.S. Victory”, which is composed of “poop deck” and “H.M.S.
Victory”.

Examples:

HMS
Victory (E22) _has section_ HMS Victory section B347.6 (E53). (Goodwin,
2015)

In first-order logic:

P59(x,y) ⇒ E18(x)

P59(x,y) ⇒ E53(y)

P62 depicts
(is depicted by)

Domain:

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7749) Physical Human-Made Thing

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM
Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies something
that is depicted by an instance of E24 Physical Human-Made Thing. Depicting is
meant in the sense that an instance of E24 Physical Human-Made Thing
intentionally shows, through its optical qualities or form, a representation of
the entity depicted. Photographs are by default regarded as being intentional
in this sense. Anything that is designed to change the properties of the
depiction, such as an e-book reader, is specifically excluded. The property
does not pertain to inscriptions or any other information encoding.

This property is a shortcut of the
more fully developed path from E24 Physical Human-Made Thing through _P65_
_shows visual item_, E36 Visual Item, _P138 represents_ toE1 CRM
Entity _. P62.1 mode of depiction_ allows the nature of the depiction to be
refined.

Examples:

The
painting “La Liberté guidant le peuple” by Eugène Delacroix (E22)
_depicts_ the French “July Revolution” of 1830 (E7). (Delacroix, 1982)

The
20 pence coin held by the Department of Coins and Medals of the British Museum
under registration number 2006,1101.126 (E22) _depicts_ Queen Elizabeth II
(E21) _mode of depiction_ Profile (E55).

In first-order logic:

P62(x,y) ⇒
E24(x)

P62(x,y) ⇒ E1(y)

P62(x,y,z) ⇒ \[P62(x,y)\
∧ E55(z)\]

P62(x,y) ⇐ (∃z)
\[E36(z) ˄ P65(x,z) ˄ P138(z,y)\]

Properties:

P62.1 mode of depiction: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P65 shows visual item (is shown by)

Domain:

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7749) Physical Human-Made Thing

Range:

[E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971) Visual Item

Subproperty of:

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7749)Physical Human-Made Thing. [P128](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10784) carries (is carried by): [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Quantification:

many to many
(0,n:0,n)

Scope note:

This property documents an instance
of E36 Visual Item shown by an instance of E24 Physical Human-Made Thing.

This property is similar to _P62_
_depicts (is depicted by)_ in that it associates an instance of E24 Physical
Human-Made Thing with a visual representation. However, _P65 shows visual_
_item (is shown by)_ differs from the _P62 depicts (is depicted by)_
property in that it makes no claims about what the instance of E36 Visual Item
is deemed to represent. An instance of E36 Visual Item identifies a
recognisable image or visual symbol, regardless of what this image may or may
not represent.

For example, all recent British
coins bear a portrait of Queen Elizabeth II, a fact that is correctly
documented using _P62 depicts (is depicted by)_. Different portraits have
been used at different periods, however. _P65 shows visual item (is shown by)_ can be used to refer to a particular portrait.

_P65 shows visual item (is shown_
_by)_ may also be used for Visual Items such as
signs, marks and symbols, for example the 'Maltese Cross' or the 'copyright
symbol’ that have no particular representational content.

This property is part of the fully
developed path E24 Physical Human-Made Thing, _P65 shows visual item_, E36
Visual Item, _P138 represents to_ E1 CRM Entity which is shortcut by _,_
_P62_ _depicts (is depicted by)_.

Examples:

My
T-Shirt (E22) _shows visual item_ Mona Lisa (E36). (fictitious)

In first-order logic:

P65(x,y) ⇒ E24(x)

P65(x,y) ⇒ E36(y)

P65(x,y) ⇒
P128(x,y)

P67 refers to (is referred to by)

Domain:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Superproperty of:

[E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7854) Design or Procedure. [P68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9941) foresees use of (use foreseen by): [E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8194)Material

[E31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7889)
Document. [P70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9985) documents (is documented
in): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[E32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7905) Authority
Document. [P71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10004)
lists (is listed in): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281)
CRM Entity

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object. [P129](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10803) is about (is subject of): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971)Visual Item.
[P138](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10966) represents (has
representation): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM
Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property documents that an
instance of E89 Propositional Object makes a statement about an instance of E1
CRM Entity. _P67 refers to (is referred to by)_ has the _P67.1 has type_
link to an instance of E55 Type. This is intended to allow a more detailed
description of the type of reference. This differs from _P129 is about (is_
_subject of)_, which describes the primary subject or subjects of the
instance of E89 Propositional Object.

Examples:

The
eBay auction listing of 4th July 2002 (E73) _refers to_ silver
cup 232 (E22) _has type_ item for sale (E55). (fictitious)

In
first-order logic:

P67(x,y) ⇒ E89(x)

P67(x,y) ⇒ E1(y)

P67(x,y,z) ⇒ \[P67(x,y)\
∧ E55(z)\]

Properties:

P67.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P68 foresees use of (use foreseen by)

Domain:

[E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7854) Design or Procedure

Range:

[E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8194) Material

Subproperty of:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object. [P67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9918) refers to (is referred to by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many
(0,n:0,n)

Scope note:

This property identifies an instance
of E57 Material foreseen to be used by an instance of E29 Design or Procedure.

E29
Designs and procedures commonly foresee the use of particular instances of E57
Material. The fabrication of adobe bricks, for example, requires straw,
clay and water. This property enables this to be documented.

This property is not intended for
the documentation of instances of E57 Materials that were used on a particular
occasion when an instance of E29 Design or Procedure was executed.

Examples:

The
procedure for soda glass manufacture (E29) _foresees use of_ soda (E57).
(Brooks, 1973)

In first-order logic:

P68(x,y) ⇒ E29(x)

P68(x,y) ⇒ E57(y)

P68(x,y) ⇒
P67(x,y)

P69 has
association with (is associated with)

Domain:

[E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7854) Design or Procedure

Range:

[E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7854) Design or Procedure

Quantification:

many to many
(0,n:0,n)

Scope note:

This property generalises
relationships like whole-part, sequence, prerequisite or inspired by between
instances of E29 Design or Procedure. Any instance of E29 Design or Procedure
may be associated with other designs or procedures. The property is considered
to be symmetrical unless otherwise indicated by _P69.1 has type_. The
property is not transitive.

This property is a directed
relationship. The _P69.1 has type_ property of _P69 has association_ _with_
allows the nature of the association to be specified reading from domain to
range; examples of types of association between instances of E29 Design or
Procedure include: has part, follows, requires, etc.

Instances of this property are
considered to be symmetric, in case no directed sense is provided for them by the
property _P69.1 has type_.

The property can typically be used
to model the decomposition of the description of a complete workflow into a
series of separate procedures.

Examples:

The
procedure for glass blowing (E29) _has association with_ the procedure for
glass heating (E29). (Brooks, 1973)

The
set of instructions for performing Macbeth in Max Reinhardt's production in
1916 in Berlin at Deutsches Theater (E29) _has association with_ the scene
design drawing by Ernst Stern reproduced at
http://www.glopad.org/pi/fr/record/digdoc/1003814 (E29) _has type_ has
part (E55).

The
preparation of parchment (E29) _has association with_ soaking and
unhairing of skin (E29) _has type_ has part (E55).

Stretching
of skin (E29) _has association with_ soaking and unhairing of skin (E29) _has_
_type_ follows (E55). (Poole and Reed, 1962)

The
plan for reassembling the temples at Abu Simbel (E29) _has association with_
the plan for storing and transporting the blocks (E29) _has type_ follows
(E55). (Loubiere, 1995)

In first-order logic:

P69(x,y) ⇒ E29(x)

P69(x,y) ⇒ E29(y)

P69(x,y,z) ⇒ \[P69(x,y)\
∧ E55(z)\]

Properties:

P69.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P70 documents (is
documented in)

Domain:

[E31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7889)
Document

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Subproperty of:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object. [P67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9918) refers to (is referred to by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many,
necessary (1,n:0,n)

Scope note:

This property describes the CRM
Entities documented as instances of E31 Document.

Documents may describe any
conceivable entity, hence the link to the highest-level entity in the CIDOC CRM
class hierarchy. This property is intended for cases where a reference is
regarded as making a proposition about reality. This may be of a documentary
character, in the scholarly or scientific sense, or a more general statement.

Examples:

The
‘Catalogue of the Greek coins of Arabia, Mesopotamia and Persia’ (E31) _documents_
parts of the British Museum’s Collection (E78). (British Museum & Hill,
1922)

In first-order logic:

P70(x,y) ⇒ E31(x)

P70(x,y) ⇒ E1(y)

P70(x,y) ⇒
P67(x,y)

P71 lists (is listed in)

Domain:

[E32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7905) Authority Document

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Subproperty of:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object. [P67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9918) refers to (is referred to by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many
(0,n:0,n)

Scope note:

This property associates an instance
of E32 Authority Document with an instance of E1 CRM Entity which it lists for
reference purposes.

Examples:

The
Art & Architecture Thesaurus (E32) _lists_ alcazars (E55).
(http://vocab.getty.edu/page/aat/300006897)

In first-order logic:

P71(x,y) ⇒
E32(x)

P71(x,y) ⇒ E1(y)

P71(x,y) ⇒ P67(x,y)

P72 has
language (is language of)

Domain:

[E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7918)
Linguistic Object

Range:

[E56](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8178) Language

Quantification:

many to many,
necessary (1,n:0,n)

Scope note:

This property associates an
instance(s) of E33 Linguistic Object with an instance of E56 Language in which
it is, at least partially, expressed.

Linguistic Objects are composed in
one or more human languages. This property allows these languages to be
documented.

Examples:

The
United States Declaration of Independence (E33 _) has language_ 18th
Century English (E56). (Perley, 2017)

In first-order logic:

P72(x,y) ⇒ E33(x)

P72(x,y) ⇒ E56(y)

P73 has translation (is translation of)

Domain:

[E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7918) Linguistic Object

Range:

[E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7918) Linguistic Object

Subproperty of:

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing. [P130](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10821) i features are also found on: [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Quantification:

many to many (0,n:0,n)

Scope note:

This property links an instance of
E33 Linguistic Object (A), to another instance of E33 Linguistic Object (B)
which is the translation of A.

When an instance of E33 Linguistic
Object is translated into a new language a new instance of E33 Linguistic
Object is created, despite the translation being conceptually similar to the
source.

This property is asymmetric.

Examples:

“Les
Baigneurs” (E33) _has translation_ “The Bathers” (E33). (Spiers &
Surenne, 1854)

In first-order logic:

P73(x,y) ⇒ E33(x)

P73(x,y) ⇒ E33(y)

P73(x,y) ⇒
P130i(x,y)

P73(x,y) ⇒ ¬P73(y,x)

P74 has
current or former residence (is current or former residence of)

Domain:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many
(0,n:0,n)

Scope note:

This property describes the current
or former place of residence (an instance of E53 Place) of an instance of E39
Actor.

The residence may be either the
place where the actor resides, or a legally registered address of any kind.

Examples:

Queen
Elizabeth II (E39) _has current or former residence_ Buckingham Palace
(E53). (Robinson, 2000)

In first-order logic:

P74(x,y) ⇒ E39(x)

P74(x,y) ⇒ E53(y)

P75 possesses
(is possessed by)

Domain:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Range:

[E30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7877) Right

Quantification:

many to many
(0,n:0,n)

Scope note:

This property associates an instance
of E39 Actor to an instance of E30 Right over which the actor holds or has held
a legal claim.

Examples:

Michael
Jackson (E21) _possesses_ intellectual property rights on the Beatles’
back catalogue (E30). (Raga, 2016)

In first-order logic:

P75(x,y) ⇒ E39(x)

P75(x,y) ⇒ E30(y)

P76 has
contact point (provides access to)

Domain:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Range:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039)
Appellation

Quantification:

many to many
(0,n:0,n)

Scope note:

This property associates an instance
of E39 Actor to an instance of E41 Appellation which a communication service
uses to direct communications to this actor, such as an e-mail address, fax
number, or postal address.

Examples:

The
Research Libraries Group, Inc. (RLG) (E74) _has contact point_“bl.ric@rlg.org”
(E41)

In first-order logic:

P76(x,y) ⇒
E39(x)

P76(x,y) ⇒
E41(y)

P79 beginning is qualified by

Domain:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Range:

[E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282) String

Subproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8865) has note: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282)String

Quantification:

many to one (0,1:0,n)

Scope note:

This property associates an instance
of E52 Time-Span with a note detailing the scholarly or scientific opinions and
justifications about the certainty, precision, sources etc. of its beginning.
Such notes may also be used to elaborate arguments about constraints or to give
explanations of alternatives.

Examples:

The
time-span of the Holocene (E52) _beginning is qualified by_“The formal
definition and dating of the GSSP (GlobalStratotype Section and Point) for the
base of the Holocene using the Greenland NGRIP ice core, and selected auxiliary
records” (E62). (Walker et al., 2009)

In first-order logic:

P79(x,y) ⇒ E52(x)

P79(x,y) ⇒ E62(y)

P79(x,y) ⇒
P3(x,y)

P80 end is qualified by

Domain:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Range:

[E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282) String

Subproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8865) has note: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282)String

Quantification:

many to one (0,1:0,n)

Scope note:

This property associates an instance
of E52 Time-Span with a note detailing the scholarly or scientific opinions and
justifications about the end of this time-span concerning certainty, precision,
sources etc. This property may also be used to
describe arguments constraining possible dates and to distinguish reasons for
alternative dates.

Examples:

The
time-span of the Holocene (E52) _end is qualified by_“still ongoing”
(E62). (Walker et al., 2009)

In first-order logic:

P80(x,y) ⇒ E52(x)

P80(x,y) ⇒ E62(y)

P80(x,y) ⇒
P3(x,y)

P81 ongoing
throughout

Domain:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Range:

[E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8263)Time Primitive

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property
associates an instance of E52 Time-Span with an instance of E61 Time Primitive
specifying a minimum period of time covered by it. Since Time-Spans may not
have precisely known temporal extents, the CIDOC CRM supports statements about
the minimum and maximum temporal extents of Time-Spans. This property allows a
Time-Span’s minimum temporal extent (i.e., its inner boundary) to be assigned
an E61 Time Primitive value. Time Primitives are treated by the CIDOC CRM as
application or system specific date intervals, and are not further analysed. If
different sources of evidence justify different minimum extents without
contradicting each other, the smallest interval including all these extents
will be the best estimate. This should be taken into account for information
integration.

Examples:

The
time-span of the development of the CIDOC CRM (E52) _ongoing throughout_“1996-2003”
(E61). (Doerr, 2003)

The
Time-Span of the Thirty Years War (E52) _ongoing throughout_ “23rd
May 1618 AD until 24th October 1648 AD” (E61). (Bonney, 2014)

The
time-span of the First Intermediate Period of Ancient Egypt (7th to
10th dynasty) (E52) _ongoing throughout_ “2181 BC – 2160 BC”
(E61). (Reid, 1993) \[This is the minimal common agreement of two conflicting\
dates: James Henry Breasted dates the First Intermediate Period of Ancient\
Egypt (7th to 10th dynasty) from 2475BC to 2160BC in his\
Ancient Records (first published in 1906), volume 1, sections 58–75 (Breasted,\
1906). Ian Shaw dates it from 2181BC to 2125BC in his Oxford History of Ancient\
Egypt (published in 2000), pp. 479–483 (Shaw, 2000).\]

In
first-order logic:

P81(x,y) ⇒
E52(x)

P81(x,y) ⇒
E61(y)

P82 at some
time within

Domain:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Range:

[E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8263) Time Primitive

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property
describes the maximum period of time within which an E52 Time-Span falls. Since
Time-Spans may not have precisely known temporal extents, the CIDOC CRM supports
statements about the minimum and maximum temporal extents of Time-Spans. This
property allows a Time-Span’s maximum temporal extent (i.e. its outer boundary)
to be assigned an E61 Time Primitive value. Time Primitives are treated by the
CIDOC CRM as application or system specific date intervals, and are not further
analysed. If different sources of evidence justify different maximum extents
without contradicting each other, the resulting intersection of all these
extents will be the best estimate. This should be taken into account for
information integration.

Examples:

The
time-span of the development of the CIDOC CRM (E52) _at some time within_“1992-infinity”
(E61). (Doerr, 2003)

The
Time-Span of the Battle in the Teutoburg Forest (E52) _at some time within_
“September 9 CE” (E61). (Andrews & Kesteven, 1977)

The
time-Span of the death of Tut Ankh Amun (E52) _at some time within_ **“** December
1324 BC to February 1323 BC” (E61). (Murdoch, 2003)

The
time-span of the First Intermediate Period of Ancient Egypt (7th to
10th dynasty) (E52) _at some time within_ “2475BC - 2125BC”
(E61). (Reid, 1993)

In first-order logic:

P82(x,y) ⇒ E52(x)

P82(x,y) ⇒ E61(y)

P86 falls
within (contains)

Domain:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Range:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Quantification:

many to many
(0,n:0,n)

Scope note:

This property describes the
inclusion relationship between two instances of E52 Time-Span.

This property supports the notion
that the temporal extent of an instance of E52 Time-Span falls within the
temporal extent of another instance of E52 Time-Span. It addresses temporal
containment only, and no contextual link between the two instances of E52
Time-Span is implied. This property is transitive and reflexive.

Examples:

The
time-span of the Apollo 11 moon mission (E52) _falls within_ the time-span
of the reign of Queen Elizabeth II (E52). (Riley, 2009; Robinson, 2000)

In first-order logic:

P86(x,y) ⇒ E52(x)

P86(x,y) ⇒ E52(y)

\[P86(x,y) ∧ P86(y,z)\]
⇒ P86(x,z)

P86(x,x)

P89 falls within (contains)

Domain:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many,
necessary, dependent (1,n:1,n)

Scope note:

This property identifies an instance
of E53 Place that falls wholly within the extent of another instance of E53
Place.

It addresses spatial containment
only and does not imply any relationship between things or phenomena occupying
these places.

This property is transitive and
reflexive.

Examples:

The
area covered by the World Heritage Site of Stonehenge (E53) _falls within_
the area of Salisbury Plain (E53). (Pryor, 2016)

In first-order logic:

P89(x,y) ⇒ E53(x)

P89(x,y) ⇒ E53(y)

\[P89(x,y) ∧ P89(y,z)\]
⇒ P89(x,z)

P89(x,x)

P90 has value

Domain:

[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128)Dimension

Range:

[E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8250) Number

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property allows an instance of
E54 Dimension to be approximated by an instance of E60 Number primitive.

Examples:

The height of silver cup 232 (E54) _has value_ 226
(E60). (fictitious)

Christie’s hammer price for Vincent van Gogh’s “Still Life: Vase
with Fifteen Sunflowers” in London on 30th March 1987 (E97) _has_
_value_ 24,750,000 (E60).

In first-order logic:

P90(x,y) ⇒
E54(x)

P90(x,y) ⇒
E60(y)

P91 has unit (is unit of)

Domain:

[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128)Dimension

Range:

[E58](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) Measurement Unit

[Superproperty of:](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_heading=h.1smtxgf)

[E97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8766) Monetary Amount. [P180](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11635) has currency (was currency of): [E98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8777) Currency

Quantification:

many to one,
necessary (1,1:0,n)

Scope note:

This property shows the type of unit
an instance of E54
Dimension was expressed in.

Examples:

The
height of silver cup 232 (E54) _has_ _unit_ mm (E58). (fictitious)

In first-order logic:

P91(x,y) ⇒ E54(x)

P91(x,y) ⇒ E58(y)

P92 brought into existence (was brought into existence by)

Domain:

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8293) Beginning of Existence

Range:

[E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9032) occurred
in the presence of (was present at): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517)
Persistent Item

Superproperty of:

[E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8333) Creation. [P94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10286) has created (was created by): [E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7825) Conceptual Object

[E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8349) Formation. [P95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10306) has formed (was formed by): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

[E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8367) Birth. [P98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10358) brought into life (was born): [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7719) Person

[E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7542) Production. [P108](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10549) has produced (was produced by): [E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7749) Physical Human-Made
Thing

[E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8581) Transformation. [P123](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10694) resulted in (resulted from): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Quantification:

one to many, necessary, dependent
(1,n:1,1)

Scope note:

This property links an instance of
E63 Beginning of Existence to the instance of E77 Persistent Item brought into
existence by it.

It allows a “start” to be attached
to any instance of E77 Persistent Item being documented, i.e., as instances of
E70 Thing, E72 Legal Object, E39 Actor, E41 Appellation and E55 Type.

Examples:

The
birth of Mozart (E67 _) brought into existence_ Mozart (E21). (Deutsch,
1965)

In first-order logic:

P92(x,y) ⇒ E63(x)

P92(x,y) ⇒ E77(y)

P92(x,y) ⇒
P12(x,y)

P93 took out of existence (was taken out
of existence by)

Domain:

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8314) End of Existence

Range:

[E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9032) occurred
in the presence of (was present at): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517)
Persistent Item

Superproperty of:

[E6](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7410) Destruction. [P13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9058) destroyed (was destroyed by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

[E68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8382) Dissolution. [P99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10376) dissolved (was dissolved by): [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

[E69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8395) Death. [P100](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10395) was death of (died in): [E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7719) Person

[E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8581) Transformation. [P124](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10713) transformed (was transformed by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Quantification:

one to many, necessary (1,n:0,1)

Scope note:

This property links an instance of
E64 End of Existence to the instance of E77 Persistent Item taken out of
existence by it.

In the case of immaterial things,
the instance of E64 End of Existence is considered to take place with the
destruction of the last physical carrier.

This allows an “end” to be attached
to any instance of E77 Persistent Item being documented i.e. instances of E70
Thing, E72 Legal Object, E39 Actor, E41 Appellation, and E55 Type. For many
instances of E77 Persistent Item we know the maximum life-span and can infer
that they must have ended to exist. We assume in that case an instance of E64
End of Existence, which may be as unnoticeable as forgetting the secret
knowledge by the last representative of some indigenous nation.

Examples:

The
death of Mozart (E69) _took out of existence_ Mozart (E21). (Deutsch,
1965)

In first-order logic:

P93(x,y) ⇒ E64(x)

P93(x,y) ⇒ E77(y)

P93(x,y) ⇒
P12(x,y)

P94 has created (was created by)

Domain:

[E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8333) Creation

Range:

[E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7825) Conceptual Object

Subproperty of:

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8293) Beginning of Existence. [P92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10238) brought into existence (was brought into
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Superproperty of:

[E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8600) Type Creation. [P135](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10907) created type (was created by): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

one to many, necessary, dependent
(1,n:1,1)

Scope note:

This property links an instance of
E65 Creation to the instance of E28 Conceptual Object created by it.

It represents the act of conceiving
the intellectual content of the instance of E28 Conceptual Object. It does not
represent the act of creating the first physical carrier of the instance of E28
Conceptual Object. As an example, this is the composition of a poem, not its
commitment to paper.

Examples:

The
composition of “The Four Friends” by A. A. Milne (E65) _has created_“The
Four Friends” by A. A. Milne (E33). (Milne, 2012)

In first-order logic:

P94(x,y) ⇒ E65(x)

P94(x,y) ⇒ E28(y)

P94(x,y) ⇒
P92(x,y)

P95 has formed (was formed by)

Domain:

[E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8349) Formation

Range:

[E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

Subproperty of:

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8293) Beginning of Existence. [P92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10238) brought into existence (was brought into
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Quantification:

one to many, necessary, dependent
(1,n:1,1)

Scope note:

This property associates the
instance of E66 Formation with the instance of E74 Group that it founded.

Examples:

The
formation of the CIDOC CRM SIG at the August 2000 CIDOC Board meeting (E66) _has_
_formed_ the CIDOC CRM Special Interest Group (E74).

In first-order logic:

P95(x,y) ⇒
E66(x)

P95(x,y) ⇒ E74(y)

P95(x,y) ⇒ P92(x,y)

P96 by mother (gave birth)

Domain:

[E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8367) Birth

Range:

[E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7719) Person

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9003) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property links an instance of
E67 Birth to an instance of E21 Person in the role of birth-giving mother.

Note that biological fathers are not
necessarily participants in the Birth (see _P97_ _from father (was_
_father for)_). The instance of E21 Person being born is linked to the
instance of E67 Birth with the property _P98_ _brought into life (was_
_born)_. This is not intended for use with general natural history material,
only people. There is no explicit method for modelling conception and gestation
except by using extensions.

Examples:

The
birth of Queen Elizabeth II (E67) _by mother_ Her Majesty Queen Elizabeth
The Queen Mother (E21). (Parker, 2002)

In first-order logic:

P96(x,y) ⇒ E67(x)

P96(x,y) ⇒ E21(y)

P96(x,y) ⇒
P11(x,y)

P97 from father
(was father for)

Domain:

[E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8367) Birth

Range:

[E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7719) Person

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property links an instance of
E67 Birth to an instance of E21 Person in the role of biological father.

Note that biological fathers are not
seen as necessary participants in the birth, whereas birth-giving mothers are
(see _P96_ _by mother (gave birth)_). The Person being born is linked
to the Birth with the property _P98_ _brought into life (was born)_.

This is not intended for use with
general natural history material, only people. There is no explicit method for
modelling conception and gestation except by using extensions.

An instance of E67 Birth is normally
(but not always) associated with one biological father.

Examples:

King
George VI (E21) _was father for_ the birth of Queen Elizabeth II (E67).
(Parker, 2002)

In first-order logic:

P97(x,y) ⇒ E67(x)

P97(x,y) ⇒ E21(y)

P98 brought into life (was born)

Domain:

[E67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8367) Birth

Range:

[E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7719) Person

Subproperty of:

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8293) Beginning of Existence. [P92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10238) brought into existence (was brought into
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Quantification:

one to many, dependent (0,n:1,1)

Scope note:

This property links an instance of
E67 Birth event to an instance of E21 Person in the role of offspring.

Twins, triplets etc. are brought
into life by the same instance of E67 Birth. This is not intended for use with
general Natural History material, only people. There is no explicit method for
modelling conception and gestation except by using extensions.

Examples:

The
Birth of Queen Elizabeth II (E67) _brought into life_ Queen Elizabeth II
(E21). (Parker, 2002)

In first-order logic:

P98(x,y) ⇒ E67(x)

P98(x,y) ⇒ E21(y)

P98(x,y) ⇒
P92(x,y)

P99 dissolved (was dissolved by)

Domain:

[E68](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8382) Dissolution

Range:

[E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9003) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8314) End of Existence. [P93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10262) took out of existence (was taken out of
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Quantification:

one to many, necessary (1,n:0,n)

Scope note:

This property associates the
instance of E68 Dissolution with the instance of E74 Group that it disbanded.

Examples:

The
end of The Hole in the Wall Gang (E68) _dissolved_ The Hole in the Wall
Gang (E74). (Patterson, 1998)

In first-order logic:

P99(x,y) ⇒ E68(x)

P99(x,y) ⇒ E74(y)

P99(x,y) ⇒ P11(x,y)

P99(x,y) ⇒ P93(x,y)

P100 was death of (died in)

Domain:

[E69](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8395) Death

Range:

[E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7719) Person

Subproperty of:

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8314) End of Existence. [P93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10262) took out of existence (was taken out of
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Quantification:

one to many, necessary (1,n:0,1)

Scope note:

This property links an instance of
E69 Death to the instance of E21 Person that died.

An instance of E69 Death may involve
multiple people, for example in the case of a battle or disaster.

This is not intended for use with
general natural history material, only people.

Examples:

Mozart’s
death (E69) _was death of_ Mozart (E21). (Sitwell, 2017)

In first-order logic:

P100(x,y) ⇒ E69(x)

P100(x,y) ⇒ E21(y)

P100(x,y) ⇒
P93(x,y)

P101 had as
general use (was use of)

Domain:

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E70 Thing with an instance of E55 Type that describes the type of use that
it was actually employed for.

It allows the relationship between
particular things, both physical and immaterial, and the general methods and
techniques of real use to be documented. This may well be different from the
intended functional purpose of the instance of E70 Thing (which can be
documented with _P103 was intended for (was intention of)_). For example,
it could be recorded that a particular wooden crate had a general use as a
shelf support on a market stall even though it had been originally intended for
carrying vegetables.

The use of this property is intended
to allow the documentation of usage patterns attested in historical records or
through scientific investigation (for instance ceramic residue analysis). It
should not be used to document the intended, and thus assumed, use of an
object.

Examples:

Tony
Gill’s Ford Mustang (E22) _had as general use_ transportation (E55).

The Egyptian unglazed vessel used in the
2003 study reported by Barnard et al. (E22) _had as general use_ camel
milk preparation (E55). (Barnard et al., 2007)

In first-order logic:

P101(x,y) ⇒
E70(x)

P101(x,y) ⇒ E55(y)

P101(x,y) ⇒ (∃z)\[E7(z)\
∧ P16i(,x,z) ∧ P2(z,y)\]

P102 has
title (is title of)

Domain:

[E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431) Human-Made Thing

Range:

[E35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971) Title

Subproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) is identified by (identifies): [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E35 Title that has been applied to an instance of E71 Human-Made Thing.

The _P102.1_ _has type_
property of the _P102_ _has title (is title of)_ property enables the
relationship between the title and the thing to be further clarified, for
example, if the title was a given title, a supplied title etc.

It allows any human-made material or
immaterial thing to be given a title. It is possible to imagine a title being
created without a specific object in mind.

Examples:

The
first book of the Old Testament (E33) _has title_ “Genesis” (E35) _has_
_type_ translated title (E55) (E55). (Brueggemann, 1982)

Monet’s
painting from 1868-1869 held by Musée d’Orsay, Paris, under inventory
number RF 1984 164 (E22) _has title_ “La Pie” (E35) _has type_
creator’s title (E55). (Musée
d’Orsay, 2020)

Monet’s
painting from 1868-1869 held by Musée d'Orsay, Paris, under inventory
number RF 1984 164 (E22) _has title_ “The Magpie” (E35) _has type_
translated title (E55). (Musée
d'Orsay, 2020)

In first-order logic:

P102(x,y) ⇒ E71(x)

P102(x,y) ⇒ E35(y)

P102(x,y,z) ⇒
\[P102(x,y) ∧ E55(z)\]

P102(x,y) ⇒ P1(x,y)

Properties:

P102.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P103 was intended for (was intention of)

Domain:

[E71](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8431) Human-Made Thing

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many to many (0,n:0,n)

Scope note:

This property links an instance of
E71 Human-Made Thing to an instance of E55 Type of usage or audience. It
creates a relation between specific human-made things, both physical and
immaterial, to E55 Types. This property can be used to specify intended methods
and techniques of use or to characterise the intended audience by indicating a
type of personal characteristic that everyone falling into the target audience
has.

Note: A link between specific
human-made things and a specific use activity should be expressed using _P19_ _was intended use of (was made for)._

Examples:

This
plate (E22) _was intended for_ being destroyed at wedding reception (E55).
(fictitious)

“Reading
for life, a first book for adults and their tutors” (E28) _was intended for_
adult literacy learners in the English language (E55). (Allen, 1987)

“Piglet
has a bath” (E28), published on sealed plastic pages, _was intended for_
young children having a bath (E55). (Milne & Shepard, 1998)

In first-order logic:

P103(x,y) ⇒ E71(x)

P103(x,y) ⇒ E55(y)

P104 is
subject to (applies to)

Domain:

[E72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8451) Legal Object

Range:

[E30](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7877) Right

Quantification:

many to many (0,n:0,n)

Scope note:

This property links a particular
instance of E72 Legal Object to the instances of E30 Right to which it is
subject.

The Right is held by an instance of
E39 Actor as described by _P75_ _possesses (is possessed by)_.

Examples:

The
Beatles back catalogue (E89) _is subject to_ reproduction right on the
Beatles back catalogue (E30). (Raga, 2016)

In first-order logic:

P104(x,y) ⇒ E72(x)

P104(x,y) ⇒ E30(y)

P105 right held by (has right on)

Domain:

[E72](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8451) Legal Object

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Superproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650) Physical Thing. [P52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9747) has current owner (is current owner of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property identifies the
instance of E39 Actor who holds the instances of E30 Right to an instance of
E72 Legal Object.

It is a superproperty of _P52 has_
_current owner (is current owner of)_ because ownership is a right that is
held on the owned object.

This property is a shortcut of the
fully developed path from E72 Legal Object, _P104 is subject to_, E30
Right, _P75i is possessed by_ to E39 Actor.

Examples:

The
Beatles back catalogue (E73) _right held by_ Michael Jackson (E21). (Raga,
2016)

In first-order logic:

P105(x,y) ⇒ E72(x)

P105(x,y) ⇒ E39(y)

P105(x,y) ⇐ (∃z)
\[E30(z) ˄ P104(x,z) ˄ P75i(z,y)\]

P106 is composed of (forms part of)

Domain:

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Range:

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Superproperty of:

[E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8468) Information Object. [P165](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11350) incorporates (is incorporated in): [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E90 Symbolic Object with a part of it that is by itself an instance of E90
Symbolic Object, such as fragments of texts or clippings from an image.

This property is transitive asymmetric.

Examples:

This
Scope note of property P106 (E33) _is composed of ‘_ fragments of texts’
(E33).

‘recognizable’
(E90) _is composed of_ ‘ecognizabl’ (E90).

In first-order logic:

P106(x,y) ⇒
E90(x)

P106(x,y) ⇒ E90(y)

\[P106(x,y) ∧\
P106(y,z)\] ⇒
P106(x,z)

P106(x,y) ⇒
¬P106(y,x)

P107 has
current or former member (is current or former member of)

Domain:

[E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E74 Group with an instance of E39 Actor that is or has been a member
thereof.

Instances of E74 Group and E21
Person may all be members of instances of E74 Group. An instance of E74 Group
may be founded initially without any member.

This property is a shortcut of the
more fully developed path from E74 Group _, P144i gained member by,_ E85
Joining _, P143 joined_ to E39 Actor _._

The property P107.1 _kind of_
_member_ can be used to specify the type of membership or the role the member
has in the group.

Examples:

László
Moholy-Nagy (E21) _is current or former_ _member of_ Bauhaus (E74).
(Moholy-Nagy, 2012)

National
Museum of Science and Industry (E74) _has current or former member_ The
National Railway Museum (E74). (Rolt, 1971)

The
married couple Queen Elisabeth and Prince Phillip (E74) _has current or_
_former member_ Prince Phillip (E21) _kind of member_ husband (E55).
(Brandreth, 2004)

In first-order logic:

P107(x,y) ⇒ E74(x)

P107(x,y) ⇒ E39(y)

P107(x,y,z) ⇒
\[P107(x,y) ∧ E55(z)\]

P107(x,y) ⇐ (∃z)
\[E85(z) ˄ P144i(x,z) ˄ P143(z,y)\]

Properties:

P107.1 kind of member: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P108 has produced
(was produced by)

Domain:

[E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7542) Production

Range:

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7749) Physical Human-Made Thing

Subproperty of:

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7519) Modification. [P31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9381) has modified (was modified by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8293) Beginning of Existence. [P92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10238) brought into existence (was brought into
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Quantification:

one to many, necessary, dependent
(1,n:1,1)

Scope note:

This property identifies the
instance of E24 Physical Human-Made Thing that came into existence as a result
of the instance of E12 Production.

The identity of an instance of E24
Physical Human-Made Thing is not defined by its matter, but by its existence as
a subject of documentation. An E12 Production can result in the creation of
multiple instances of E24 Physical Human-Made Thing.

Examples:

The
building of Rome (E12) _has_ _produced_ the Colosseum (E24). (Hopkins
& Beard, 2011)

In first-order logic:

P108(x,y) ⇒ E12(x)

P108(x,y) ⇒ E24(y)

P108(x,y) ⇒ P31(x,y)

P108(x,y) ⇒ P92(x,y)

P109 has current or former curator (is current or former curator of)

Domain:

[E78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8537) Curated Holding

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P49](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9688) has former or
current keeper (is former or current keeper of): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance of E39 Actor who assumed or has assumed overall curatorial
responsibility for an instance of E78 Curated Holding.

It does not allow a history of
curation to be recorded. This would require use of an event initiating a
curator being responsible for a collection.

Examples:

The
Robert Opie Collection (E78) _has current or former curator_ Robert Opie
(E21). (https://www.robertopiecollection.com/)

The
Mikael Heggelund Foslie’s coralline red algae Herbarium (E78) _has current or_
_former curator_ Mikael Heggelund Foslie (E21). (Woelkerling et al., 2005)

In first-order logic:

P109(x,y) ⇒
E78(x)

P109(x,y) ⇒ E39(y)

P109(x,y) ⇒ P49(x,y)

P110 augmented (was augmented by)

Domain:

[E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) Part Addition

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7749) Physical Thing

Subproperty of:

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7519) Modification. [P31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9381) has modified (was modified by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the instance
of E18 Physical Thing that is added to (augmented) in an instance of E79 Part
Addition.

Although an instance of E79 Part
Addition event normally concerns only one instance of E18 Physical Thing, it is
possible to imagine circumstances under which more than one item might be added
to (augmented). For example, the artist Jackson Pollock trailing paint onto
multiple canvasses.

Examples:

The
final nail-insertion Event (E79) _augmented_ Coffin of George VI (E22).
(https://www.rct.uk/collection/2000811/the-coffin-of-king-george-vi-during-the-lying-in-state)

The
attachment of the bronze hand of the Alpi Marittime sculpture (E79) _augmented_
the tree of the Alpi Marittime sculpture (E20).
\[https://giuseppepenone.com/en/words/maritime-alps\] (Mangini, 2010)

In first-order logic:

P110(x,y) ⇒ E79(x)

P110(x,y) ⇒ E18(y)

P110(x,y) ⇒ P31(x,y)

P111 added (was added by)

Domain:

[E79](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8553) Part Addition

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650) Physical Thing

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9122) used specific object (was used for): [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance of E18 Physical Thing that is added during an instance of E79 Part
Addition activity.

Examples:

The
insertion of the final nail (E79) _added_ the last nail in George VI’s
coffin (E22).
(https://www.rct.uk/collection/2000811/the-coffin-of-king-george-vi-during-the-lying-in-state)

In first-order logic:

P111(x,y) ⇒
E79(x)

P111(x,y) ⇒ E18(y)

P111(x,y) ⇒ P16(x,y)

P112 diminished (was diminished by)

Domain:

[E80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8567) Part Removal

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical Thing

Subproperty of:

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7519) Modification. [P31](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9381) has modified (was modified by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the instance of E18 Physical Thing that
was diminished by an instance of E80 Part Removal.

Although an instance of E80 Part
removal activity normally concerns only one instance of E18 Physical Thing, it is possible to imagine circumstances under which more than one
item might be diminished by a single instance of E80 Part Removal activity.

Examples:

The
coffin of Tut-Ankh-Amun (E22) _was_ _diminished by_ the opening of
the coffin of Tut-Ankh-Amun (E80). (Carter, 2014)

The
coral of the Cocos Islands (E20) _was diminished_ by the removal of the
Porite coral specimen by Charles Darwin (E80). (Natural History Museum, 2010,
b)

In first-order logic:

P112(x,y) ⇒ E80(x)

P112(x,y) ⇒ E18(y)

P112(x,y) ⇒
P31(x,y)

P113 removed (was removed by)

Domain:

[E80](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8567) Part Removal

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9032) occurred in the presence of (was present at): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance of E18 Physical Thing that is removed during an instance of E80 Part
Removal activity.

Examples:

The
opening of the coffin of Tut-Ankh-Amun (E80) _removed_ The mummy of
Tut-Ankh-Amun (E20, E22). (Carter, 2014)

In first-order logic:

P113(x,y) ⇒ E80(x)

P113(x,y) ⇒ E18(y)

P113(x,y) ⇒
P12(x,y)

P121 overlaps
with

Domain:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many (0,n:0,n)

Scope note:

This symmetric property associates
an instance of E53 Place with another instance of E53 Place geometrically
overlapping it.

It does not specify anything about
the shared area. This property is purely spatial. It does not imply that
phenomena that define, by their extent, places related by _P121 overlaps with_
have ever covered a common area at the same time or even coexisted. In
contrast, spatiotemporal overlaps described by _P132 spatiotemporally_
_overlaps_ are the total of areas simultaneously covered by the related
spacetime volumes.

This property is symmetric. This
property is reflexive.

Examples:

The
territory of the United States as in 2020 (E53) _overlaps with_ the Arctic
(E53). (Gannett et al., 1904)

The
maximal extent of the Kingdom of Greece (1832-1973) (E53) _overlaps with_
the maximal extent of the Republic of Turkey (29th October 1923 to
now) (E53).

In first-order logic:

P121(x,y) ⇒
E53(x)

P121(x,y) ⇒ E53(y)

P121(x,y) ⇒ P121(y,x)

P121(x,x)

P122 borders with

Domain:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many (0,n:0,n)

Scope note:

This symmetric property associates
an instance of E53 Place with another instance of E53 Place which shares a part
of its border.

This property is purely spatial. It
does not imply that the phenomena that define, by their extent, places related
by _P122 borders_ _with_ have ever shared a respective border at the
same time or even coexisted. In particular, this may be the case when the
respective common border is formed by a natural feature.

This property is not transitive.
This property is symmetric.

Examples:

Scotland
in its 1603 borders (E53) _borders with_ England in its 1603 borders
(E53). (Crofton, 2015)

In first-order logic:

P122(x,y) ⇒ E53(x)

P122(x,y) ⇒ E53(y)

P122(x,y) ⇒
P122(y,x)

P123 resulted in (resulted from)

Domain:

[E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8581) Transformation

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Subproperty of:

[E63](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8293) Beginning of Existence. [P92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10238) brought into existence (was brought into
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance or instances of E18 Physical Thing that are the result of an instance
of E81 Transformation. New items replace the transformed item or items, which
cease to exist as units of documentation. The physical continuity between the
old and the new is expressed by the links to the common instance of E81
Transformation.

Examples:

The
transformation of the Venetian Loggia in Heraklion into a city hall (E81, E12) _resulted_
_in_ the City Hall of Heraklion (E24). \[AND: _has produced (P108)_ the\
City Hall of Heraklion (E22)\] (Municipality of Heraklion, 2021)

The
mummification of Tut-Ankh-Amun (E81, E12) _resulted in_ the mummy of
Tut-Ankh-Amun (E22,E20). \[also: _has produced (P108)_ the mummy of Tut-Ankh-Amun\
(E22, E20).\] (Carter & Mace 1977)

The
death, carbonization and petrification of some people of Pompeii in 79AD by the
intense heat of a pyroclastic cloud and ashes from the eruption of Mount
Vesuvius (E69, E81) _resulted in_ petrified bodies (E20). \[Some of these\
bodies could later be preserved in plaster.\]

In first-order logic:

P123(x,y) ⇒
E81(x)

P123(x,y) ⇒ E18(y)

P123(x,y) ⇒ P92(x,y)

P124 transformed (was transformed by)

Domain:

[E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8581) Transformation

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Subproperty of:

[E64](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8314) End of Existence. [P93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10262) took out of existence (was taken out of
existence by): [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent Item

Quantification:

one to many, necessary (1,n:0,1)

Scope note:

This property identifies the
instance or instances E18 Physical Thing that have ceased to exist due to an
instance of E81 Transformation.

The item that has ceased to exist
and was replaced by the result of the Transformation. The continuity between
both items, the new and the old, is expressed by the links to the common
instance of E81 Transformation.

Examples:

The
transformation of the Venetian Loggia in Heraklion into a city hall (E81, E12) transformed the Venetian Loggia in Heraklion
(E24). (Municipality of Heraklion, 2021)

The
mummification of Tut-Ankh-Amun (E81, E12) transformed
the deceased Pharaoh Tut-Ankh-Amun (E21). (Carter & Mace, 1977)

The
death, carbonization and petrification of some people of Pompeii in 79AD by the
intense heat of a pyroclastic cloud and ashes from the eruption of Mount
Vesuvius (E69, E81) transformed some
people of Pompeii (E21). \[AND: _was death of (P100)_ some people of\
Pompeii (E21).\]

In first-order logic:

P124(x,y) ⇒
E81(x)

P124(x,y) ⇒ E18(y)

P124(x,y) ⇒ P93(x,y)

P125 used object
of type (was type of object used in)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Superproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P32](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9402) used general technique (was technique of): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many
to many (0,n:0,n)

Scope note:

This property associates an instance
of E7 Activity to an instance of E55 Type, which classifies an instance of E70
Thing used in an instance of E7 Activity, when the specific instance is either
unknown or not of interest, such as use of “a hammer”.

This property is a shortcut of the
more fully developed path from E7 Activity through _P16 used specific object_,
E70 Thing, _P2 has type,_ to E55 Type.

Examples:

The
English archers’ activity in the Battle of Agincourt (E7) _used object of_
_type_ long bow (E55). (Curry, 2015)

In first-order logic:

P125(x,y) ⇒ E7(x)

P125(x,y) ⇒ E55(y)

P125(x,y) ⇔ (∃z)
\[E70(z) ∧ P16(x,z) ∧ P2(z,y)\]

P126 employed
(was employed in)

Domain:

[E11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7519)
Modification

Range:

[E57](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8194) Material

Quantification:

many
to many (0,n:0,n)

Scope note:

This property identifies the
instance of E57 Material employed in an instance of E11 Modification.

The instance of E57 Material used
during the instance of E11 Modification does not necessarily become
incorporated into the instance of E24 Physical Human-Made Thing that forms the
subject of the instance of E11 Modification.

Examples:

The
repairing of the Queen Mary (E11) _employed_ Steel (E57). \[Beginning\
October 1942\] (Britton, 2012)

Distilled
water (E57) _was employed in_ the restoration of the Sistine Chapel (E11).
(Pietrangeli, 1986)

In
first-order logic:

P126(x,y) ⇒ E11(x)

P126(x,y) ⇒ E57(y)

P127 has
broader term (has narrower term)

Domain:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many
to many (0,n:0,n)

Scope note:

This property associates an instance
of E55 Type with another instance of E55 Type that has a broader meaning.

It allows instances of E55 Types to
be organised into hierarchies. This is the sense of “broader term generic (BTG)”
as defined in ISO 25964-2:2013 (International Organization for Standardization
2013).

This property is transitive. This
property is asymmetric.

Examples:

dime
(E55) _has broader term_ coin (E55). (Yerkes, 1989)

In first-order logic:

P127(x,y) ⇒ E55(x)

P127(x,y) ⇒ E55(y)

\[P127(x,y) ∧ P127(y,z)\] ⇒
P127(x,z)

P127(x,y)
⇒ ¬P127(y,x)

P128 carries (is carried by)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Subproperty of:

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing. [P130](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10821) shows features of (features are also found on): [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Superproperty of:

[E24](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7749) Physical Human-Made Thing. [P65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9897) shows visual item (is shown by): [E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971) Visual Item

Quantification:

many
to many (0,n:0,n)

Scope note:

This property identifies an instance
E90 Symbolic Object carried by an instance of E18 Physical Thing. Since an
instance of E90 Symbolic Object is defined as an immaterial idealization over
potentially multiple carriers, any individual realization on a particular
physical carrier may be defective, due to deterioration or shortcomings in the
process of creating the realization compared to the intended ideal. As long as
such defects do not substantially affect the complete recognition of the
respective symbolic object, it is still regarded as carrying an instance of
this E90 Symbolic Object. If these defects are of scholarly interest, the
particular realization can be modelled as an instance of E25 Human-Made
Feature. Note, that any instance of E90 Symbolic Object incorporated (P165) in
the carried symbolic object is also carried by the same instance of E18 Physical
Thing.

Examples:

Matthew’s
paperback copy of Reach for the Sky (E18) _carries_ the text of Reach for
the Sky (E73). \[see also: (Brickhill, 2001)\]
(fictitious)

In first-order logic:

P128(x,y) ⇒ E18(x)

P128(x,y) ⇒ E90(y)

P128(x,y) ⇒
P130(x,y)

P129 is about (is subject of)

Domain:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Subproperty of:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object. [P67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9918) refers to (is referred to by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property documents that an
instance of E89 Propositional Object has as subject an instance of E1 CRM
Entity.

This differs from _P67 refers to_
_(is referred to by)_, which refers to an instance of E1 CRM Entity, in that
it describes the primary subject or subjects of an instance of E89
Propositional Object.

Examples:

The
text entitled ‘Reach for the sky’ (E33) _is about_ Douglas Bader (E21).
(Brickhill, 2001)

In first-order logic:

P129(x,y) ⇒ E89(x)

P129(x,y) ⇒ E1(y)

P129(x,y) ⇒
P67(x,y)

P130 shows features of (features are also found on)

Domain:

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Range:

[E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Superproperty of:

[E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7918) Linguistic Object. [P73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10036)i is translation of: [E33](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7918) Linguistic Object

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650) Physical Thing. [P128](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10784) carries (is carried by): [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Quantification:

many to many (0,n:0,n)

Scope note:

This property generalises the
notions of “copy of” and “similar to” into a directed relationship, where the
domain expresses the derivative or influenced item and the range the source or
influencing item, if such a direction can be established. The property can also
be used to express similarity in cases that can be stated between two objects
only, without historical knowledge about its reasons. The property expresses a
symmetric relationship in case no direction of influence can be established
either from evidence on the item itself or from historical knowledge. This
holds in particular for siblings of a derivation process from a common source
or non-causal cultural parallels, such as some weaving patterns.

The _P130.1_ _kind of_
_similarity_ property of the _P130 shows features of (features are also_
_found on)_ property enables the relationship between the domain and the
range to be further clarified, in the sense from domain to range, if
applicable. For example, it may be expressed if both items are product “of the
same mould”, or if two texts “contain identical paragraphs”.

If the reason for similarity is a
sort of derivation process, i.e. that the creator has used or had in mind the
form of a particular thing during the creation or production, this process
should be explicitly modelled. In these cases, _P130 shows features of_ can
be regarded as a shortcut of such a process. However, the current model does
not contain any path specific enough to infer this property. Specializations of
the CIDOC CRM may however be more explicit, for instance describing the use of
moulds etc.

This property is not transitive.
This property is irreflexive.

Examples:

Mary
Lamb’s Cymbeline from Charles and Mary Lamb’s Tales from Shakespeare (E89) _shows_
_features of_ William Shakespeare’s Cymbeline (E89). (Carrington, 1954)

The
audio recording of Dante Alighieri’s La divina commedia read by Enrico de Negri
(E73) _shows features of_ the text of Dante Alighieri’s La divina commedia
(E89). (Alighieri, 1956)

In first-order logic:

P130(x,y) ⇒ E70(x)

P130(x,y) ⇒ E70(y)

P130(x,y,z) ⇒
\[P130(x,y) ∧ E55(z)\]

¬P130(x,x)

Properties:

P130.1 kind of similarity: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P132 spatiotemporally overlaps with

Domain:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Range:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Superproperty of:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume. [P10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8978) falls within (contains): [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Quantification:

many
to many (0,n:0,n)

Scope note:

This symmetric property associates
two instances of E92 Spacetime Volume that have some of their extents in
common. If only the fuzzy boundaries of the instances of E92 Spacetime Volume
overlap, this property cannot be determined from observation alone and
therefore should not be applied. However, there may be other forms of
justification that the two instances of E92 Spacetime Volume must have some of
their extents in common regardless of where and when precisely.

If this property holds for two
instances of E92 Spacetime Volume then it cannot be the case that _P133 is_
_spatiotemporally separated_ from also holds for the same two instances.
Furthermore, there are cases where neither _P132 spatiotemporally overlaps_
_with_ nor _P133 is spatiotemporally separated from_ holds between two
instances of E92 Spacetime Volume. This would occur where only an overlap of
the fuzzy boundaries of the two instances of E92 Spacetime Volume occurs and no
other evidence is available.

This property is not transitive.
This property is symmetric. This property is reflexive.

Examples:

The
“Urnfield” period (E4 _) spatiotemporally overlaps with_ the “Hallstatt”
period (E4). (Gimbutas, 1965)

In first-order logic:

P132(x,y) ⇒ E92(x)

P132(x,y) ⇒ E92(y)

P132(x,y) ⇒ P132(y,x)

P132(x,y) ⇒ P132 (x,y)

P132(x,x)

P133 is
spatiotemporally separated from

Domain:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Range:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Quantification:

many
to many (0,n:0,n)

Scope note:

This symmetric property associates
two instances of E92 Spacetime Volume that have no extents in common. If only
the fuzzy boundaries of the instances of E92 Spacetime Volume overlap, this
property cannot be determined from observation alone and therefore should not
be applied. However, there may be other forms of justification that the two
instances of E92 Spacetime Volume must not have any of their extents in common
regardless of where and when precisely.

If this property holds for two
instances of E92 Spacetime Volume then it cannot be the case that _P132_
_spatiotemporally overlaps with_ also holds for the same two instances.
Furthermore, there are cases where neither _P132 spatiotemporally overlaps_
_with_ nor _P133 is spatiotemporally separated from_ holds between two
instances of E92 Spacetime Volume. This would occur where only an overlap of
the fuzzy boundaries of the two instances of E92 Spacetime Volume occurs and no
other evidence is available.

This property is not transitive.
This property is symmetric. This property is irreflexive.

Examples:

The
“Hallstatt” period (E4) _is spatiotemporally separated from_ the “La
Tène” era (E4). (Marion, 2004)

Kingdom
of Greece (1831-1924) (E92) _is spatiotemporally separated from_ Ottoman
Empire (1299-1922) (E92).

The
path of the army of Alexander the Great (335-323 B.C.) (E7) _is_
_spatiotemporally separated from_ the Mauryan Empire (E4). (Lane Fox, 2004)

In first-order logic:

P133(x,y) ⇒ E92(x)

P133(x,y) ⇒ E92(y)

P133(x,y) ⇒ P133(y,x)

P133(x,y) ⇒ ¬P133 (x,y)

¬P133(x,x)

P134 continued (was continued by)

Domain:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Range:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9102) was influenced by (influenced): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P176i](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11531) starts before
the start of (starts after the start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Quantification:

many
to many (0,n:0,n)

Scope note:

This property associates two
instances of E7 Activity, where the domain is considered as an intentional
continuation of the range. A continuation of an activity may happen when the
continued activity is still ongoing or after the continued activity has
completely ended. The continuing activity may have started already before it
decided to continue the other one. Continuation implies a coherence of
intentions and outcomes of the involved activities.

This property is not transitive.
This property is asymmetric.

Examples:

The
construction of the Kölner Dom (Cologne Cathedral), abandoned in the 15th
century (E7), _was_ _continued by_ construction in the 19th
century (E7). \[The construction in the 19th century adapted the\
initial plans so as to preserve the intended appearance.\] (Wolff, 1999)

In first-order logic:

P134(x,y) ⇒ E7(x)

P134(x,y)⇒ E7(y)

P134(x,y) ⇒ P15(x,y)

P134(x,y) ⇒
P176i(x,y)

P134(x,y) ⇒¬P134(y,x)

P135 created type
(was created by)

Domain:

[E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8600) Type Creation

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Subproperty of:

[E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8333) Creation. [P94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10286) has created (was created by): [E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7825) Conceptual Object

Quantification:

one
to many, necessary (1,n:0,1)

Scope note:

This property identifies the
instance of E55 Type, which is created in an instance of E83 Type Creation
activity.

Examples:

The
description of a new ribbon worm species by Bürger (E83) _created type_‘ _Lineus_
_kennelii_’ (E55). (Bürger, 1892)

In first-order logic:

P135(x,y) ⇒ E83(x)

P135(x,y) ⇒ E55(y)

P135(x,y) ⇒
P94(x,y)

P136 was based on (supported type creation)

Domain:

[E83](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8600) Type Creation

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9102) was influenced by (influenced): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many
to many (0,n:0,n)

Scope note:

This property identifies one or more
instances of E1 CRM Entity that were used as evidence to declare a new instance
of E55 Type.

The examination of these items is
often the only objective way to understand the precise characteristics of a new
type. Such items should be deposited in a museum or similar institution for
that reason. The taxonomic role renders the specific relationship of each item
to the type, such as “holotype” or “original element”.

Examples:

The
taxon creation of the plant species ‘ _Serratula glauca_ Linné,
1753.’ (E83) _was based on_ Object BM000576251 of the Clayton Herbarium
(E20) _in the taxonomic role_ original element (E55). (Blake, 1918)

In first-order logic:

P136(x,y) ⇒ E83(x)

P136(x,y) ⇒ E1(y)

P136(x,y,z) ⇒
\[P136(x,y) ∧ E55(z)\]

P136(x,y) ⇒ P15(x,y)

Properties:

P136.1 in the taxonomic role: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P137 exemplifies (is exemplified by)

Domain:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Subproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8844) has type (is type of): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many
to many (0,n:0,n)

Scope note:

This property associates an instance
of E1 CRM Entity with an instance of E55 Type for which it has been declared to
be a particularly characteristic example.

The _P137.1 in the taxonomic role_ property
of _P137 exemplifies (is exemplified by)_ allows differentiation of
taxonomic roles. The taxonomic role renders the specific relationship of this
example to the type, such as “prototypical”, “archetypical”, “lectotype”, etc.
The taxonomic role “lectotype” is not associated with the instance of E83 Type
Creation itself but is selected in a later phase.

Examples:

Object
BM000098044 of the Clayton Herbarium (E20) _exemplifies ‘Spigelia_
_marilandica’_ (L.) L. (E55) _in the taxonomic role_ lectotype (E55).
(Natural History Museum, 2021)

In first-order logic:

P137(x,y) ⇒ E1(x)

P137(x,y) ⇒ E55(y)

P137(x,y,z) ⇒
\[P137(x,y) ∧ E55(z)\]

P137(x,y) ⇒ P2(x,y)

Properties:

P137.1 in the taxonomic role: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P138 represents (has representation)

Domain:

[E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971)Visual
Item

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Subproperty of:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object. [P67](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9918) refers to (is referred to by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property establishes the
relationship between an instance of E36 Visual Item and the instance of E1 CRM
Entity that it visually represents.

Any entity may be represented
visually. This property is part of the fully developed path from E24 Physical
Human-Made Thing through _P65 shows visual item (is shown by),_ E36 Visual
Item, _P138 represents (has representation)_ to E1 CRM Entity, which is
shortcut by _P62 depicts (is depicted by)_. _P138.1 mode of_
_representation_ allows the nature of the representation to be refined.

This property is also used for the
relationship between an original and a digitisation of the original by the use
of techniques such as digital photography, flatbed or infrared scanning.
Digitisation is here seen as a process with a mechanical, causal component
rendering the spatial distribution of structural and optical properties of the
original and does not necessarily include any visual similarity identifiable by
human observation.

Examples:

The
digital file found at https://www.emunch.no/N/full/No-MM\_N0001-01.jpg (E36) _represents_
page 1 of Edward Munch's manuscript MM N 1, Munch-museet (E22) _mode of_
_representation_ Digitisation (E55).

The
3D model VAM\_A.200-1946\_trace\_1M.ply (E73) _represents_ Victoria &
Albert Museum’s Madonna and child sculpture (visual work) A.200-1946 (E22) _mode_
_of representation_ 3D surface (E55).

In first-order logic:

P138(x,y) ⇒
E36(x)

P138(x,y) ⇒ E1(y)

P138(x,y,z) ⇒
\[P138(x,y) ∧ E55(z)\]

P138(x,y) ⇒ P67(x,y)

Properties:

P138.1 mode of representation: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P139 has
alternative form (is alternative form of)

Domain:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039)
Appellation

Range:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates
an instance of E41 Appellation with another instance of E41 Appellation that
constitutes a derivative or variant of the former and that may also be used for
identifying items identified by the former, in suitable contexts, independent
from the particular item to be identified. This property should not be confused
with additional variants of names used characteristically for a single,
particular item, such as individual nicknames. It is a directed relationship,
where the range expresses the derivative or variant and the domain the source
of derivation or original form of variation, if such a direction can be
established. Otherwise, the relationship is symmetric.

Multiple names assigned
to an object, which do not apply to all things identified with the specific
instance of E41 Appellation, should be modelled as repeated values of _P1 is_
_identified by (identifies)_ of this object.

_P139.1 has type_ allows the type of derivation to be refined, for instance
“transliteration from Latin 1 to ASCII”.

Examples:

“Martin Doerr” (E41) _has alternative form_ “Martin
Dörr” (E41) _has type_ alternate
spelling (E55).

“Гончарова, НатальяСергеевна” (E41) _has alternative form_ "Gončarova,
Natal´â Sergeevna" (E41) _has type_ ISO 9:1995
transliteration (E55).

“Αθήνα” (E41) _has_
_alternative form_ “Athina” (E41) _has type_ transcription (E55).

In first-order logic:

P139(x,y) ⇒ E41(x)

P139(x,y)
⇒ E41(y)

P139(x,y,z)
⇒ \[P139(x,y) ∧ E55(z)\]

¬P139(x,x)

Properties:

P139.1 has type: [E55](https://cidoc-crm.org/C:/Users/el_ts/Dropbox/52nd%20cidoc%20crm%20sig/cidoc_crm_version_7.1.2.docx#_toc8153) Type

P140 assigned attribute to (was
attributed by)

Domain:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561)Attribute Assignment

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Superproperty of:

[E14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7586) Condition Assessment. [P34](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9440) concerned (was assessed by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

[E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7618) Measurement. [P39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9518) measured (was measured by): [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

[E17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7636) Type Assignment. [P41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9555) classified (was classified by): [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E13 Attribute Assignment with the instance of E1 CRM Entity about which it
made an attribution. The instance of E1 CRM Entity plays the role of the domain
of the attribution.

The kind of attribution made should
be documented using _P177 assigned property of type (is type of property_
_assigned)_.

Examples:

The
Current Ownership Assessment of Martin Doerr’s silver cup February 1997 (E13) _assigned_
_attribute to_ Martin Doerr’s silver cup (E22). (fictitious)

The
Identifier Assignment on 1st June 1997 of the silver cup donated by
Martin Doerr (E15) _assigned attribute to_ silver cup 232 (E22).
(fictitious)

The
examination of MS Sinai Greek 418 (E13) _assigned attribute to_ MS Sinai
Greek 418 (E22). (Honey and Pickwoad, 2010)

In first-order logic:

P140(x,y) ⇒ E13(x)

P140(x,y) ⇒ E1(y)

P141 assigned (was assigned by)

Domain:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561)Attribute Assignment

Range:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Superproperty of:

[E14](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7586) Condition Assessment. [P35](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9461) has identified (identified by): [Ε3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7335) Condition State

[E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7601) Identifier Assignment. [P37](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9480) assigned (was assigned by): [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier

[E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7601) Identifier Assignment. [P38](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9499) deassigned (was deassigned by): [E42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8076) Identifier

[E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7618) Measurement. [P40](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9535) observed dimension (was observed in): [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128)Dimension

[E17](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7636) Type Assignment. [P42](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9573) assigned (was assigned by): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E13 Attribute Assignment with the instance of E1 CRM Entity used in the
attribution. The instance of E1 CRM Entity here plays the role of the range of
the attribution.

The kind of attribution made should
be documented using _P177 assigned property of type (is type of property_
_assigned)_.

Examples:

The
Current Ownership Assessment of Martin Doerr’s silver cup February 1997 (E13) _assigned_ Martin Doerr (E21). (fictitious)

The
Identifier Assignment on 1st June 1997 of the silver cup donated by
Martin Doerr (E15) _assigned_ 232 (E42). (fictitious)

The
examination of MS Sinai Greek 418 (E13) _assigned_ unsupported (E55.)
(Honey & Pickwoad, 2010)

In first-order logic:

P141(x,y) ⇒ E13(x)

P141(x,y) ⇒ E1(y)

P142 used constituent (was used in)

Domain:

[E15](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7601)
Identifier Assignment

Range:

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Subproperty of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9122) used specific object (was used for): [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8408) Thing

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E15 Identifier Assignment with the instance of E90 Symbolic Object used as
constituent of an instance of E42 Identifier in this act of assignment.

Examples:

Assigning
the personal name identifier “Guillaume, de Machaut, ca. 1300-1377” on 1st
June 2001 (E15) _used constituent_ “ca. 1300-1377” (E41). (Kelly, 2014)

Assigning
a uniform title to the anonymous textual work known as ‘The Adoration of the
Shepherds’(E15) _used constituent_ “Coventry” (E41). (Encyclopedia Britannica,
1998)

Assigning
a uniform title to Pina Bausch’s choreographic work entitled ‘Rite of spring’
(E15) _used constituent_ “(Choreographic Work: Bausch)” (E90).
(Brandstetter and Klein, 2015)

Assigning
a uniform title to the motion picture directed in 1933 by Merian C. Cooper and
Ernest B. Schoedsack and entitled ‘King Kong’ (E15) _used constituent_
“1933” (E61). (Goldner and Turner, 1976)

Assigning
the corporate name identifier ‘Univerza v Ljubljani. Oddelek za
bibliotekarstvo’ to The Department for library science of the University of
Ljubljana in 2018 (E15) _used constituent_ “Univerza v Ljubljani” (E42).
\[Done by the Department of Library and Information Science and Book Studies\
Library, University of Ljubljana in 2018\]

In first-order logic:

P142(x,y) ⇒
E15(x)

P142(x,y) ⇒ E90(y)

P142(x,y) ⇒ P16(x,y)

P143 joined (was joined by)

Domain:

[E85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8615) Joining

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9003) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance of E39 Actor that becomes member of an instance of E74 Group in an
instance of E85 Joining.

Joining events allow for describing actors
becoming members of a group with the more detailed path E74 Group, _P144i_
_gained member by_, E85 Joining, _P143 joined,_ E39 Actor, compared to
the shortcut offered by _P107 has current or former member (is current or_
_former member of)._

Examples:

The
election of Sir Isaac Newton as Member of Parliament to the Convention
Parliament of 1689 (E85) _joined_ Sir Isaac Newton (E21). (Iliffe, 2013)

The
inauguration of Mikhail Sergeyevich Gorbachev as leader of the Union of Soviet
Socialist Republics (USSR) in 1985 (E85) _joined_ Mikhail Sergeyevich
Gorbachev (E21). (Galeotti, 1997)

The
implementation of the membership treaty 1st January 1973
between EU and Denmark (E85) _joined_ Denmark (E74).

In first-order logic:

P143(x,y) ⇒
E85(x)

P143(x,y) ⇒ E39(y)

P143(x,y) ⇒ P11(x,y)

P144 joined with (gained member by)

Domain:

[E85](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8615) Joining

Range:

[E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9003) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Quantification:

many to many, necessary (1,n:0,n)

Scope
note:

This property identifies the
instance of E74 Group of which an instance of E39 Actor becomes a member
through an instance of E85 Joining.

Although a joining activity normally
concerns only one instance of E74 Group, it is possible to imagine
circumstances under which becoming member of one Group implies becoming member
of another Group as well.

Joining events allow for describing
people becoming members of a group with a more detailed path from E74 Group
through, _P144i gained member by_, E85 Joining, _P143 joined_, E39
Actor, compared to the shortcut offered by _P107 has current or former member_
_(is current or former member of)_.

The property _P144.1 kind of_
_member_ can be used to specify the type of membership or the role the member
has in the group.

Examples:

The
election of Sir Isaac Newton as Member of Parliament to the Convention
Parliament of 1689 (E85) _joined with_ the Convention Parliament (E74).
(Iliffe, 2013)

The
inauguration of Mikhail Sergeyevich Gorbachev as Leader of the Union of Soviet
Socialist Republics (USSR) in 1985 (E85) _joined with_ the office of
Leader of the Union of Soviet Socialist Republics (USSR) (E74) _kind of_
_member_ President (E55). (Galeotti, 1997)

The
implementation of the membership treaty 1st January 1973
between EU and Denmark (E85) _joined with_ EU (E74).

In first-order logic:

P144(x,y) ⇒
E85(x)

P144(x,y)⇒ E74(y)

P144(x,y,z) ⇒
\[P144(x,y) ∧ E55(z)\]

P144(x,y) ⇒ P11(x,y)

Properties:

P144.1 kind of member: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P145 separated (left by)

Domain:

[E86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8631) Leaving

Range:

[E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9003) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance of E39 Actor that leaves an instance of E74 Group through an instance
of E86 Leaving.

Examples:

The
end of Sir Isaac Newton’s duty as Member of Parliament for the University of
Cambridge to the Convention Parliament in 1702 (E86) _separated_ Sir Isaac
Newton (E21). (Iliffe, 2013)

George
Washington’s leaving office in 1797 (E86) _separated_ George Washington
(E21). (Unger, 2015)

The
implementation of the treaty regulating the termination of Greenland membership
in EU between EU, Denmark and Greenland 1st February 1985 (E86) _separated_
Greenland (E74).

In first-order logic:

P145(x,y) ⇒
E86(x)

P145(x,y) ⇒ E39(y)

P145(x,y) ⇒ P11(x,y)

P146 separated from (lost member by)

Domain:

[E86](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8631) Leaving

Range:

[E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9003) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005) Actor

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property identifies the
instance of E74 Group an instance of E39 Actor leaves through an instance of
E86 Leaving.

Although a leaving activity normally
concerns only one instance of E74 Group, it is possible to imagine
circumstances under which leaving one E74 Group implies leaving another E74
Group as well.

Examples:

The
end of Sir Isaac Newton’s duty as Member of Parliament for the University of
Cambridge to the Convention Parliament in 1702 (E86) _separated from_ the
Convention Parliament (E74). (Iliffe, 2013)

George
Washington’s leaving office in 1797 (E86) _separated from_ the office of
President of the United States (E74). (Unger, 2015)

The
implementation of the treaty regulating the termination of Greenland membership
in EU between EU, Denmark and Greenland 1st February 1985 (E86) _separated_
_from_ EU (E74).

In first-order logic:

P146(x,y) ⇒
E86(x)

P146(x,y) ⇒ E74(y)

P146(x,y) ⇒ P11(x,y)

P147 curated
(was curated by)

Domain:

[E87](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8646) Curation Activity

Range:

[E78](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8537) Curated Holding

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property associates an instance
of E87 Curation Activity with the instance of E78 Curated Holding with that is
subject of that curation activity following some implicit or explicit curation
plan.

Examples:

The
curation activity of the Benaki Museum for the Toys, Games and Childhood
Collection (E87) _curated_ The Toys, Games and Childhood Collection of the
Benaki Museum (E78). \[The curation activity included the acquisition of dolls\
and games of urban and folk manufacture dating from the 17th to the\
20th century, from England, France and Germany for the Toys, Games\
and Childhood Collection of the museum.\] (Benaki Museum, 2016)

The
curation activity for the permanent Numismatic Collection of the Historical
Museum of Crete, Heraklion, Crete from 2005 up to the present (E87) _curated_
the Numismatic Collection (E78). (Historical Museum of Crete, 2005)

The
curation activity of Mikael Heggelund Foslie (E87) _curated_ the Mikael
Heggelund Foslie’s coralline red algae Herbarium (E78). (Woelkerling et al.,
2005)

In first-order logic:

P147(x,y)
⇒ E87(x)

                P147(x,y)
⇒ E78(y)

P148 has
component (is component of)

Domain:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object

Range:

[E89](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8659) Propositional Object

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E89 Propositional Object with a structural part of it that is by itself an
instance of E89 Propositional Object.

This property is transitive. This
property is asymmetric.

Examples:

Dante’s
“Divine Comedy” (E89) _has component_ Dante’s “Hell” (E89). (Alighieri,
1956)

In first-order logic:

P148(x,y)
⇒
E89(x)

P148(x,y)
⇒
E89(y)

\[P148(x,y) ∧ P148(y,z)\] ⇒
P148(x,z)

P148(x,y)
⇒ ¬P148(y,x)

P150 defines
typical parts of (defines typical wholes for)

Domain

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E55 Type “A” with an instance of E55 Type “B”, when items of type “A”
typically form part of items of type “B”, such as “car motors” and “cars”.

It allows types to be organised into
hierarchies based on one type describing a typical part of another. This
property is equivalent to “broader term partitive (BTP)” as defined in ISO 2788
and “broaderPartitive” in SKOS.

This property is not transitive. This
property is asymmetric.

Examples:

car
motors (E55) _defines typical parts of_ cars (E55). (fictitious)

In first-order logic:

P150(x,y) ⇒ E55(x)

P150(x,y) ⇒ E55(y)

P150(x,y) ⇒¬P150(y,x)

P151 was formed from (participated in)

Domain:

[E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8349) Formation

Range:

[E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group

Subproperty of:

[E5](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7383) Event. [P11](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9003) had participant (participated in): [E39](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8005)Actor

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E66 Formation with an instance of E74 Group from which the new group was
formed preserving a sense of continuity such as in mission, membership or
tradition.

Examples:

The
formation of the House of Bourbon-Conti in 1581 (E66) _was formed from_
House of Condé (E74). (Collectif & Musée d'art et d'histoire
Louis-Senlecq, 1900)

In first-order logic:

P151(x,y) ⇒ E66(x)

P151(x,y) ⇒ E74(y)

P151(x,y) ⇒
P11(x,y)

P152 has
parent (is parent of)

Domain:

[E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7719)
Person

Range:

[E21](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7719)
Person

Quantification:

many to many, necessary (2,n:0,n)

Scope note:

This property associates an instance
of E21 Person with another instance of E21 Person who plays the role of the
first instance’s parent, regardless of whether the relationship is biological
parenthood, assumed or pretended biological parenthood or an equivalent legal
status of rights and obligations obtained by a social or legal act.

This property is, among others, a
shortcut of the fully developed paths from E21 Person through _P98i was born,_ E67 Birth _, P96 by mother_ to E21 Person _,_ andfrom E21
Person through _P98i was born,_ E67 Birth _, P97 from father_ to E21
Person.

This property is not transitive. This
property is irreflexive.

Examples:

Gaius
Octavius (E21) _has parent_ Julius Caesar (E21). (Bleicken
& Bell, 2015)

Steve
Jobs (E21) _has parent_ Joanne Simpson (E21).\[Biological mother\] (Isaacson, 2011)

Steve Jobs (E21) _has parent_
Clara Jobs (E21). \[Adoption mother\] (Isaacson, 2011)

In first-order logic:

P152(x,y) ⇒
E21(x)

P152(x,y) ⇒ E21(y)

P152(x,y) ⇐ (∃z)
\[E67(z) ˄ P98i(x,z) ˄ P96(z,y)\]

P152(x,y) ⇐ (∃z)
\[E67(z) ˄ P98i(x,z) ˄ P97(z,y)\]

¬P152(x,x)

P156 occupies (is occupied by)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Subproperty of:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9768) has former or
current location (is former or current location of): [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing. [P157](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11276) i provides
reference space for : [E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104)
Place

Quantification:

many to one (0,1:0,n)

Scope note:

This property describes the largest
volume in space, an instance of E53 Place, that an instance of E18 Physical
Thing has occupied at any time during its existence, with respect to the
reference space relative to the physical thing itself. This allows for
describing the thing itself as a place that may contain other things, such as a
box that may contain coins. In other words, it is the volume that contains all
the points which the thing has covered at some time during its existence. The
reference space for the associated place must be the one that is permanently at
rest ( _P157 is at rest relative to)_ relative to the physical thing. For
instances of E19 Physical Objects it is the one which is at rest relative to
the object itself, i.e., which moves together with the object. For instances of
E26 Physical Feature it is one which is at rest relative to the physical
feature itself and the surrounding matter immediately connected to it.
Therefore, there is a 1:1 relation between the instance E18 Physical Thing and
the instance of E53 Place it occupies. We include in the occupied space the
space filled by the matter of the physical thing and all its inner spaces.

This property implies the fully
developed path from E18 Physical Thing through _P196 defines,_ E92
Spacetime Volume, _P161 has spatial projection_ to E53 Place. However, in
contrast to _P156 occupies,_ the property _P161 has spatial projection_
does not constrain the reference space of the referred instance of E53 Place.

In contrast to _P156 occupies_,
for the property _P53 has former or current location_ the following holds:

It
does not constrain the reference space of the referred instance of E53 Place.

It
identifies a possibly wider instance of E53 Place at which a thing is or has
been for some unspecified time-span.

If
the reference space of the referred instance of E53 Place is not at rest with
respect to the physical thing found there, the physical thing may move away
after some time to another place and/or may have been at some other place
before. The same holds for the fully developed path from E18 Physical Thing
through _P196 defines_, E92 Spacetime Volume, _P161 has spatial projection_
to E53 Place.

Examples:

The
Saint Titus reliquary(E22) _occupies_ the space of the Saint Titus
reliquary (E53). \[The reliquary is currently kept in the Saint Titus Church in\
Heraklion, Crete since 1966 and contains the skull of Saint Titus.\] (Fisher
& Garvey, 2010)

Burg
Eltz near Koblenz, Germany (E24) _occupies_ the space within the 1661AD
outer walls of Burg Eltz (E53). \[The castle (English name: Eltz Castle)\
underwent a series of expansions starting in the 12th century until\
it reached its current extent in 1661AD and contains buildings from various\
periods.\]

In first-order logic:

P156(x,y) ⇒
E53(y)

P156(x,y) ⇒ E18(x)

P156(x,y)⇔ (∃z) \[E18(x)\
∧ E53(y) ∧ P196(x,z) ∧P161(z,y) ∧P157(y,x)\]

P157 is at rest relative to (provides reference space for)

Domain:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Superproperty of:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place. [P59](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9861) i is located on
or within: [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical Thing

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place. [P156](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11251) i is occupied by: [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Quantification:

many to many, necessary(1,n:0,n)

Scope note:

This property associates an instance
of E53 Place with the instance of E18 Physical Thing that determines a
reference space for this instance of E53 Place by being at rest with respect to
this reference space. The relative stability of form of an instance of E18
Physical Thing defines its default reference space. The reference space is not
spatially limited to the referred thing. For example, a ship determines a
reference space in terms of which other ships in its neighbourhood may be
described. Larger constellations of matter, such as continental plates, may
comprise many physical features that are at rest with them and define the same
reference space.

Examples:

The
spatial extent of the municipality of Athens in 2014 (E53) _is at rest_
_relative to_ The Royal Observatory in Greenwich (E25). (Maunder, 1900)

The
place where Lord Nelson died on H.M.S. Victory (E53) _is at rest relative to_ H.M.S.
Victory (E22). (Adkin, 2005)

In first-order logic:

P157(x,y) ⇒ E53(x)

P157(x,y) ⇒ E18(y)

P160 has temporal projection (is temporal projection of)

Domain:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Range:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Superproperty of:

[E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8691)Presence. [P164](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11330)
is temporally specified by (temporally specifies): [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property describes the temporal
projection of an instance of E92 Spacetime Volume. The property _P4 has_
_time-span_ is the same as _P160 has temporal projection_ if it is used
to document an instance of E4 Period or any subclass of it.

Example:

The
spatio-temporal trajectory of the H.M.S. Temeraire from its building in 1798 to
its destruction in 1838 (E92) _has temporal projection_ the time-span of
the existence of H.M.S. Temeraire (E52) \[ _at some time within (P82)_\
“1798-1838” (E61).\] (Willis, 2010)

The
Battle of Waterloo 1815 (E7) _has temporal projection_ the time-span of the
Battle of Waterloo (E52) \[ _at some time within (P82)_\
“Sunday, 18th June 1815” (E61).\] (Black, 2010)

In first-order logic:

P160(x,y) ⇒ E92(x)

P160(x,y)⇒ E52(y)

P161 has spatial projection (is spatial projection of)

Domain:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property associates an instance
of E92 Spacetime Volume with an instance of E53 Place that is the result of the
spatial projection of the instance of the E92 Spacetime Volume on a reference
space.

In general, there can be more than
one useful reference space (for reference space see _P156 occupies_ and _P157_
_is at rest relative to_) to describe the spatial projection of a spacetime
volume, for example, in describing a sea battle, the difference between the
battle ship and the seafloor as reference spaces. Thus, it can be seen that the
projection is not unique.

The spatial projection is the actual
spatial coverage of a spacetime volume, which normally has fuzzy boundaries
except for instances of E92 Spacetime Volume which are geometrically defined in
the same reference system as the range of this property and are an exception to
this and do not have fuzzy boundaries. Modelling explicitly fuzzy spatial
projections serves therefore as a common topological reference of different
spatial approximations rather than absolute geometric determination, for
instance for relating outer or inner spatial boundaries for the respective
spacetime volumes.

The spatial projection is unique
with respect to the reference system. For instance, there is exactly one
spatial projection of Lord Nelson’s dying relative to the ship HMS Victory,
i.e. the location of his body relative to the ship HMS Victory at the time of
his death.

In case the domain of an instance of
_P161 has spatial projection_ is an instance of E4 Period, the spatial
projection describes all areas that period was ever present at, for instance,
the Roman Empire.

This property is part of the fully
developed path from E18 Physical Thing through _P196 defines,_ E92
Spacetime Volume, _P161 has spatial projection_ to E53 Place, which in
turn is implied by _P156 occupies (is occupied by)._

Example:

The
Roman Empire (E4) _has spatial projection_ all areas ever claimed by Rome
(E53). (Clare & Edwards, 1992)

In first-order logic:

P161(x,y) ⇒ E92(x)

P161(x,y) ⇒ E53(y)

(∃y,z,u) \[E92(x) ˄ E53(y) ˄ E53(z)\
˄ E18(u) ˄ P157(y,u) ˄ P157(z,u) ˄ P161(x,y) ˄\
P161(x,z) \] ⇒ (x
= y)

P161(x,y)
˄ E4(x) ⇒ P7(x,y)

P164 is temporally specified by (temporally specifies)

Domain:

[E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8691) Presence

Range:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080)Time-Span

Subproperty of:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume. [P160](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11294) has temporal projection (is temporal
projection of): [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080)
Time-Span

Quantification:

many to one, necessary(1,1:0,n)

Scope note:

This property relates an instance of
E93 Presence with the instance of E52 Time-Span that defines the time-slice of
the spacetime volume that this instance of E93 Presence is related to via the
property _P166 was a presence of (had presence)._

There are two typical cases for the
determination of the related instance of E52 Time-Span. In the first, it is the
temporal extent of an instance of E2 Temporal Entity (documented with _P4 has_
_time-span (is time-span of)_): this then documents the simultaneity of the
instance of E93 Presence and the instance of E2 Temporal Entity, even if the
absolute time-span is not known, and can be regarded as a phenomenal time-span.
In the second, the instance of E52 Time-Span is a date range declared in or
derived from historical sources or provided by dating methods: this is a
declarative time-span.

Examples:

2016-02-09
(E52) _temporally specifies_ the last day of the 2016 Carnival in Cologne
(E93).

Johann
Joachim Winckelmann’s whereabouts in December 1755 (E93) _is temporally_
_specified by_ December 1755 (E52.) (Leppmann, 1970)

Johann
Joachim Winckelmann’s whereabouts from 19th November 1755 until 9th
April 1768 (E93) _is temporally specified by_ 19th November 1755
until 9th April 1768 (E52). (Leppmann, 1970)

In first-order logic:

P164(x,y) ⇒ E93(x)

P164(x,y) ⇒ E52(y)

P164(x,y) ⇒
P160(x,y)

P165 incorporates (is incorporated in)

Domain:

[E73](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8468)
Information Object

Range:

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Subproperty of:

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object. [P106](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10505) is composed of (forms part of): [E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E73 Information Object with an instance of E90 Symbolic Object (or any of
its subclasses) that was included in it.

This property makes it possible to
recognise the autonomous status of the incorporated signs, which were created
in a distinct context, and can be incorporated in many instances of E73 Information
Object, and to highlight the difference between structural and accidental
whole-part relationships between conceptual entities.

It accounts for many cultural facts
that are quite frequent and significant: the inclusion of a poem in an
anthology, the re-use of an operatic aria in a new opera, the use of a
reproduction of a painting for a book cover or a CD booklet, the integration of
textual quotations, the presence of lyrics in a song that sets those lyrics to
music, the presence of the text of a play in a movie based on that play, etc.

In particular, this property allows
for modelling relationships of different levels of symbolic specificity, such
as the natural language words making up a particular text, the characters
making up the words and punctuation, the choice of fonts and page layout for
the characters.

When restricted to information
objects, that is, seen as a property with E73 Information Object as domain and
range the property is transitive.

A digital photograph of a manuscript
page incorporates the text of a manuscript page, if the respective text is
defined as a sequence of symbols of a particular type, such as Latin
characters, and the resolution and quality of the digital image is sufficient
to resolve these symbols so they are readable on the digital image.

This property is asymmetric.

Examples:

The
content of Charles-Moïse Briquet’s ‘Les Filigranes: dictionnaire
historique des marques du papier’ (E32) _incorporates_ the visual aspect
of the watermark used around 1358-61 by some Spanish papermaker(s) and
identified as ‘Briquet 4019’ (E37). (Briquet, 1985)

The
visual content of Jacopo Amigoni’s painting known as ‘The Singer Farinelli and
friends’ (E36) _incorporates_ the musical notation of Farinelli’s musical
work entitled ‘La Partenza’ (E73). (National Gallery of Victoria)

The
visual content of Nicolas Poussin’s painting entitled ‘Les Bergers d’Arcadie’
(E36) _incorporates_ the Latin phrase ‘Et in Arcadia ego’ (E33).
(Wikipedia, 2020)

In first-order logic:

P165(x,y) ⇒ E73(x)

P165(x,y) ⇒ E90(y)

P165(x,y) ⇒
P106(x,y)

P165(x,y) ⇒¬P165(y,x)

P166 was a presence of (had presence)

Domain:

[E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8691) Presence

Range:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Subproperty of:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume. [P10](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8978) falls within (contains): [E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property associates an instance
of E93 Presence with the instance of E92 Spacetime Volume of which it
represents a temporal restriction (i.e. a time-slice). Instantiating this
property constitutes a necessary part of the identity of the respective
instance of E93 Presence.

Examples:

The
Roman Empire on 19th August AD 14 (E93) _was a presence of_ The
Roman Empire (E4). (Clare and Edwards, 1992)

In first-order logic:

P166(x,y) ⇒ E93(x)

P166(x,y) ⇒ E92(y)

P166(x,y) ⇒
P10(x,y)

P167 was
within (includes)

Domain:

[E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8691)
Presence

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many, necessary (1,n:0,n)

Scope
note:

This property associates an instance
of E93 Presence with an instance of E53 Place that geometrically includes the
spatial projection of the respective instance of E93 Presence. Besides others,
this property may be used to state in which space an object has been for some
known time, such as a room of a castle or in a drawer. It may also be used to
describe a confinement of the spatial extent of some realm during a known
time-span.

This property is a shortcut of the
more fully developed path from E93 Presence through _P161 has spatial_
_projection,_ E53 Place, _P89 falls within (contains)_ to E53 Place.

Examples:

Johann
Joachim Winckelmann’s whereabouts in December 1755 (E93) _was within_ Rome
(E53). (Leppmann, 1970)

Johann
Joachim Winckelmann’s whereabouts from 19th November 1755 until 9th
April 1768 (E93) _was within_ Italy (E53). (Leppmann, 1970)

In first-order logic:

P167(x,y) ⇒ E93(x)

P167(x,y) ⇒ E53(y)

P167(x,y) ⇔(∃z) \[E53(z) ˄ P161(x,z) ˄ P89(z,y)\]

P168 place is defined by (defines place)

Domain:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Range:

[E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8709) Space Primitive

Subproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) is identified by: [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation

Quantification:

one to many, dependent (0,n:1,1)

Scope note:

This property associates an instance
of E53 Place with an instance of E94 Space Primitive that defines it. Syntactic
variants or use of different scripts may result in multiple instances of E94
Space Primitive defining exactly the same place. Transformations between
different reference systems always result in new definitions of places
approximating each other and not in alternative definitions.

Examples:

The
centroid from https://sws.geonames.org/735927 (E53) place _is defined by_
40°31'17.9"N 21°15'48.3"E (E94). \[A single point for approximating\
the centre of the city of Kastoria, Greece\]

Martin’s
coordinates for Kastoria (E53) place _is defined by_ 40°30'23"N
21°14'53"E, 40°31'40"N 21°16'43"E (E94). \[A square covering the built settlement structure of Kastoria,\
Greece\]

Martin’s
centroid for Kastoria (E53) place _is defined by_ 40°31'01.5"N
21°15'48"E (E94). \[A point in the lake of Kastoria in the centre of the\
area covered by the city\]

The
position measured by Alexander von Humboldt for the Plaza Mayor in
Cumaná, Sucre, Venezuela 1799-1800AD (E53) _place_ _is defined by_
10°27'52"N 66°30'02"W (E94). \[West of the Observatory of Paris =\
64°09'51"W of Greenwich, actually 1.1km east of today’s Plaza\
Andrés Eloy Blanco of Cumaná\] (Humboldt, 1859)

In first-order logic:

P168(x,y) ⇒
E53(x)

P168(x,y) ⇒
E94(y)

P169 defines spacetime volume (spacetime
volume is defined by)

Domain:

[E95](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8725) Spacetime Primitive

Range:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8670) Spacetime Volume

Subproperty of:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039)
Appellation. [P1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819)i
identifies: [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to one, necessary(1,1:0,n)

Scope note:

This property associates an instance
of E95 Spacetime Primitive with the instance of E92 Spacetime Volume it
defines.

Examples:

{40°30'23"N
21°14'53"E, 40°31'40"N 21°16'43"E, 200BC-2020AD} (E95) _defines_
_spacetime volume_ Martin’s spatiotemporal enclosure 2020 for the evolution
of the settlement of today’s city of Kastoria, Greece, since its conquest by
the Romans (E92). \[A square covering the current built settlement structure of\
Kastoria, Greece, through the years 200BC to 2020AD, which includes the extents\
of earlier phases of the city\]

In first-order logic:

P169(x,y) ⇒
E95(x)

P169(x,y) ⇒ E92(y)

P169(x,y) ⇒ P1i(x,y)

P170 defines time (time is defined by)

Domain:

[E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_heading=h.meukdy) Time Primitive

Range:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Subproperty of:

[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation. [P1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) i identifies: [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity

Quantification:

many to one (0,1:0,n)

Scope note:

This property associates an instance
of E61 Time Primitive with the instance of E52 Time-Span that constitutes the
interpretation of the terms of the time primitive as an extent in absolute,
real time.

The quantification allows several
instances of E61 Time Primitive that are each expressed in different syntactic
forms, to define the same instance of E52 Time-Span.

Examples:

“1800/1/1
0:00:00 – 1899/31/12 23:59:59” (E61) _defines time_ the 19th
century (E52).

“1968/1/1
– 2018/1/1” (E61) _defines time_ 1968/1/1 – 2018/1/1 (E52). \[an arbitrary\
time-span during which the Saint Titus reliquary was present in the Saint Titus\
Church in Heraklion, Crete\]

In first-order logic:

P170(x,y) ⇒
E61(x)

P170(x,y) ⇒ E52(y)

P170(x, y) ⇒ P81i(x,
y) ∧ P82i(x, y)

P171 at some place
within

Domain:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Range:

[E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8709)Space Primitive

Quantification

many to many (0,n:0,n)

Scope note:

This property describes the maximum
spatial extent within which an instance of E53 Place falls. Since instances of
E53 Places may not have precisely known spatial extents, the CIDOC CRM supports
statements about maximum spatial extents of instances of E53 Place. This
property allows an instance of E53 Place’s maximum spatial extent (i.e., its
outer boundary) to be assigned an instance of E94 Space Primitive value.

This property is a shortcut of the
fully developed path from E53 Place _, P89 falls within,_ E53 Place _,_
_P168 place is defined by_ to E94 Space Primitive through a declarative Place
that is not explicitly documented, to a Space Primitive: declarative places are
defined in CRMgeo (Doerr and Hiebel 2013).

Examples:

The
spatial extent of the Acropolis of Athens (E53) _at some place within_ POLYGON
((37.969172 23.720787, 37.973122 23.721495 37.972741 23.728994, 37.969299
23.729735, 37.969172 23.720787)) (E94).

In first-order logic:

P171(x,y) ⇒
E53(x)

P171(x,y) ⇒ E94(y)

P171(x,y) ⇔ (∃z)
\[E53(z) ˄ P89(x,z) ˄ P168(z,y)\]

P172 contains

Domain:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Range:

[E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8709) Space Primitive

Quantification:

many to many (0,n:0,n)

Scope note:

This property describes a minimum
spatial extent which is contained within an instance of E53 Place. Since instances
of E53 Place may not have precisely known spatial extents, the CIDOC CRM
supports statements about minimum spatial extents of instances of E53 Place.
This property allows an instance of E53 Place’s minimum spatial extent (i.e.,
its inner boundary or a point being within a Place) to be assigned an instance
of E94 Space Primitive value.

This property is a shortcut of the
fully developed path from E53 Place _, P89i contains,_ E53 Place _, P168_
_place is defined by_ toE94 Space Primitive.

Examples:

The
spatial extent of the Acropolis of Athens (E53) _contains_ POINT
(37.971431 23.725947) (E94).

In
first-order logic:

P172(x,y) ⇒
E53(x)

P172(x,y) ⇒ E94(y)

P172(x,y)⇔ (∃z) \[E53(z)\
˄ P89i(x,z) ˄ P168(z,y)\]

P173 starts before or with the end of (ends after or with the start
of)

Domain:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Range:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Superproperty of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P174](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11518) starts before the end of (ends after the start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property specifies that the
temporal extent of the domain instance A of E2 Temporal Entity starts before or
simultaneously with the end of the temporal extent of the range instance B of
E2 Temporal Entity.

In other words, if A = \[Astart,\
Aend\] and B = \[Bstart, Bend\], it means Astart ≤ Bend is true.

This property is part of the set of
temporal primitives P173 – P176, P182 – P185.

This property corresponds to the
disjunction (logical OR) of the following Allen temporal relations (Allen,
1983): {before, meets, met-by, overlaps, starts, started-by, contains, finishes,
finished-by, equals, during, overlapped by}.

This property is not transitive.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image010.jpg)

Figure 8: Temporal entity A starts before or with
the end of temporal entity B. Here A is longer than B

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image011.jpg)

Figure 9: Temporal entity A starts before or with
the end of temporal entity B. Here A is shorter than B

Examples:

The
legendary run from Marathon to Athens 490BC (E7) _starts before or with the_
_end of_ The Battle of Marathon 490BC (E7).

LMIIB (E4) _ends_
_after or with the start of_ theTutankhamun period (1332-1323 B.C.E.)
(E4). \[Evidence for this is provided by the scarab seal found\
at Poros in a context of LMIIB. The scarab belongs to the type “nh.s n Jmn”.\
During the Akhenaten period he production of these scarab seals stopped (the\
name of Amun is not referred to during his reign). So the scarab could not have\
been produced before the Tutankhamun period and is probably a later\
production.\] (Karetsou, 2000)

In first-order logic:

P173(x,y) ⇒ E2(x)

P173(x,y) ⇒ E2(y)

P174 starts before the end of (ends after the start of)

Domain:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Range:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Subproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P173](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11495) starts before or with the end of (ends after or with the start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Superproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P175](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11548) starts before or with the start of (starts after or with the start of):
[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P184](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11706) ends before or with the end of (ends with or after the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Quantification:

many to many
(0,n:0,n)

Scope note:

This property specifies that the
temporal extent of the domain instance A of E2 Temporal Entity starts
definitely before the end of the temporal extent of the range instance B of E2
Temporal Entity.

In other words, if A = \[Astart,\
Aend\] and B = \[Bstart, Bend\], it means Astart
< Bend is true.

This property is part of the set of
temporal primitives P173 – P176, P182 – P185.

This property corresponds to a
disjunction (logical OR) of the following Allen temporal relations (Allen,
1983): {before, meets, overlaps, starts, started-by, contains, finishes,
finished-by, equals, during, overlapped by}

Typically, this property is a
consequence of a known influence of some event on another event or activity,
such as a novel written by someone being continued by someone else, or the
knowledge of a defeat on a distant battlefield causing people to end their
ongoing activities. This property is not transitive. This property is
irreflexive.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image012.jpg)

Figure 10: Temporal entity A starts before the end
of temporal entity B. Here A is longer than B

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image013.jpg)

Figure 11: Temporal entity A starts before the end
of temporal entity B. Here A is shorter than B

Examples:

The settling activity
of the city of Assur (Ashur) (E7) _starts before the end of_ The Tenth
Dynasty of Egypt (E4). \[There are some 200 - 300 years differences in the\
chronology of the First Intermediate Period, and Assur is dated to “about 2500\
BC”.\] (Pedersén, 1986)

The building of
the current St. Peters in Rome (E7) _starts before the end of_ the
demolition of the old 4th c. St. Peters (E6, E7) (Bosman, 2004)

In first-order logic:

P174(x,y) ⇒
E2(x)

P174(x,y) ⇒ E2(y)

P174(x,y) ⇒ P173(x,y)

¬P174(x,x)

P175 starts
before or with the start of (starts after or with the start of)

Domain:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Range:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Subproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)[Temporal\\
Entity.](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310) [P174](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11518) starts before the end of (ends after the start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Superproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P176](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11573) starts before the start of (starts after the start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Quantification:

many to many
(0,n:0,n)

Scope note:

This property specifies that the
temporal extent of the domain instance A of E2 Temporal Entity starts before or
simultaneously with the start of the temporal extent of the range instance B of
E2 Temporal Entity.

In other words, if A = \[Astart,\
Aend\] and B = \[Bstart, Bend\], it means Astart ≤ Bstart is true.

This property is part of the set of
temporal primitives P173 – P176, P182 – P185.

This property corresponds to a
disjunction (logical OR) of the following Allen temporal relations (Allen,
1983): {before, meets, overlaps, starts, started-by, contains, finished-by,
equals}

In a model with fuzzy borders, this
property will not be transitive.

This property is irreflexive.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image014.jpg)

Figure 12: Temporal entity A starts before or with
the start of temporal entity B. Here A is longer than B

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image015.jpg)

Figure 13: Temporal entity A starts before or with
the start of temporal entity B. Here A is shorter than B

Examples:

The
production of the scarab seal found in Poros in a context of LMIIIB (E12) _starts_
_after or with the start of_ Tutankhamun period (1332-1323 B.C) (E4). \[The\
scarab stamp seal found in Poros was associated with finds dated to the LMIIIB\
period. The seal is dated to the Tutankhamun period or later because it belongs\
to the scarabs of type “nh.s n Jmn”: During Akhenaten period, the\
production of this type of scarab seal stopped (the name of Amun is not\
referred to during his reign). Therefore, the scarab cannot have been produced\
before the Tutankhamun period and is probably a later production\] (Karetsou,
2000)

The production of the
cylindrical seal of the first Dynasty of Babylon found in Tholos B in Platanos
(E12) _starts after or with the start of_ the Hammurabi period of the
kingdom (E4). \[Of the cylindrical seal of the first Dynasty of Babylon found in\
tholos B in Platanos believed to connect king Hammurabi with the MM I period.\
Specifically, although the finding is believed to have been found in a MM I\
layer, it contained material from the MM III/YM I period. Therefore, the seal\
may be from the Hammurabi period or, it may be from a later period.\] (Walberg,
1992.)

In first-order logic:

P175(x,y) ⇒ E2(x)

                P175(x,y)
⇒ E2(y)

P175(x,y) ⇒ P174(x,y)

¬P175(x,x)

P176 starts before the start of (starts
after the start of)

Domain:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)[Temporal Entity](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)

Range:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Subproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P175](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11548) starts before or with the start of (starts after or with the start of):
[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Superproperty
of:

[E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412) Activity. [P134](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10887) i was continued by: [E7](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7412)
Activity

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P182](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11652) ends before or with the
start of (starts after or with the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Quantification:

many to many
(0,n:0,n)

Scope note:

This property specifies that the
temporal extent of the domain instance A of E2 Temporal Entity starts
definitely before the start of the temporal extent of the range instance B of
E2 Temporal Entity.

In other words, if A = \[Astart,\
Aend\] and B = \[Bstart, Bend\], it means Astart
< Bstart is true.

This property is part of the set of
temporal primitives P173 – P176, P182 – P185.

This property corresponds to a
disjunction (logical OR) of the following Allen temporal relations (Allen,
1983): {before, meets, overlaps, contains, finished-by}. This property is
transitive. This property is asymmetric.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image016.jpg)

Figure 14: Temporal entity A starts before the
start of temporal entity B. Here A is longer than B

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image017.jpg)

Figure 15: Temporal entity A starts before the
start of temporal entity B. Here A is shorter than B

Examples:

The reign of King
Harold II (E4) _starts before the start of_ the Battle of Hastings (E7). (Wikipedia
2022a)

The life of Attila “the
Hun” (E4) _starts before the start of_ the Battle of the Catalaunian
Plains (E7). \[June 20, 451 AD\] (Wikipedia 2022b)

In first-order logic:

P176(x,y) ⇒ E2(x)

P176(x,y) ⇒
E2(y)

                P176(x,y) ⇒
P175(x,y)

\[P176(x,y) ∧ P176(y,z)\] ⇒ P176(x,z)

P176(x,y) ⇒ ¬P176(y,x)

P177 assigned property of type (is type
of property assigned)

Domain:

[E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7561)Attribute Assignment

Range:

[E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

Subproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8844)has
type (is type of): [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153)
Type

Quantification:

many to many, necessary (1,n:0,n)

Scope note:

This property associates an instance
of E13 Attribute Assignment with the type of property or relation that this
assignment maintains to hold between the item to which it assigns an attribute
and the attribute itself. Note that the properties defined by the CIDOC CRM
also constitute instances of E55 Type themselves. The direction of the assigned
property of type is understood to be from the attributed item (the range of
property _P140 assigned attribute to_) to the attribute item (the range of
the property _P141 assigned_). More than one property type may be assigned
to hold between two items.

A comprehensive explanation about
refining CIDOC CRM concepts by E55 Type is given in the section “About Types”
in the section on “Specific Modelling Constructs” of this document.

Examples

The
Current Ownership Assessment of Martin Doerr’s silver cup February 1997 (E13) _assigned_
_property of type P52 has former or current owner (is former or current keeper_
_of)_(E55). (fictitious)

1st
June 1997 Identifier Assignment of the silver cup donated by Martin Doerr (E15)
_assigned property of type_ _P48 has preferred identifier (is preferred_
_identifier of)_ (E55). (fictitious)

The
examination of MS Sinai Greek 418 (E13) _assigned property of type_
binding structure type (E55). \[‘binding structure type’ refers to a property,\
external to the CIDOC CRM, which connects a book (E22) to the type of its\
binding structure (E55)\] (Honey & Pickwoad, 2010)

The
condition assessment of the endband cores of MS Sinai Greek 418 (E14) _assigned_
_property of type_ damage (E55). \[‘damage’ refers to a property, external to\
the CIDOC CRM, which connects an instance of a physical thing like an endband\
core (E22) to the type of damage (E55) it shows\] (Honey & Pickwoad, 2010)

The
condition assessment of the cover of MS Sinai Greek 418 (E14) _assigned_
_property of type_ quality (E55). \[‘quality’ refers to a property, external\
to the CIDOC CRM, which connects an instance of a physical thing like a book\
cover (E22) to its quality (E55)\] (Honey and Pickwoad, 2010)

In first-order logic:

P177(x,y) ⇒
E13(x)

P177(x,y) ⇒
E55(y)

P179 had
sales price (was sales price of)

Domain:

[E96](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8754) Purchase

Range:

[E97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8766) Monetary Amount

Quantification:

many to many (1,n:0,n)

Scope note:

This property establishes the
relationship between an instance of E96 Purchase and the instance of E97
Monetary Amount that forms the compensation for the transaction. The monetary
amount agreed upon may change in the course of the purchase activity.

Examples:

The
sale of Vincent van Gogh’s “Still Life: Vase with Fifteen Sunflowers” 30th
March 1987 (E96) _had sales price_ Christie’s hammer price for “Still
Life: Vase with Fifteen Sunflowers” (E97).

The
purchase of 10 okka of nails by the captain A. Syrmas on 18th
September 1895 (E96) _had sales price_ 20 piastre (grosi) (E97). (Syrmas,
1896)

In
first-order logic:

P179(x,y) ⇒ E96(x)

P179(x,y) ⇒ E97(y)

P180 has currency (was currency of)

Domain:

[E97](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8766) Monetary Amount

Range:

[E98](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8777) Currency

Subproperty of:

[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128)Dimension.
[P91](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10222) has unit (is unit
of):[E58](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8210) Measurement Unit

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property establishes the
relationship between an instance of E97 Monetary Amount and the instance of E98
Currency that it is measured in.

Examples:

Christie’s
hammer price for Vincent
van Gogh’s “Still Life: Vase with Fifteen Sunflowers” in London on 30th
March 1987 (E97) _has currency_ British Pounds
(E98).

In first-order logic:

P180(x,y) ⇒
E97(x)

P180(x,y) ⇒ E98(y)

P180(x,y) ⇒ P91(x,y)

P182 ends before or with the start of
(starts after or with the end of)

Domain:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Range:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Subproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P176](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11573) starts before the start of (starts after the start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity.[P185](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11731) ends before the end of (ends after the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Superproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P183](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11679) ends before the start of (starts after the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Quantification:

many to many
(0,n:0,n)

Scope note:

This property specifies that the
temporal extent of the domain instance A of E2 Temporal Entity ends before or
simultaneously with the start of the temporal extent of the range instance B of
E2 Temporal Entity.

In other words, if A = \[Astart,\
Aend\] and B = \[Bstart, Bend\], it means Aend ≤ Bstart is true.

This property is part of the set of
temporal primitives P173 – P176, P182 – P185.

This property corresponds to a
disjunction (logical OR) of the following Allen temporal relations (Allen,
1983): {before, meets}.

This property is transitive. This
property is asymmetric.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image018.jpg)

Figure 16: Temporal entity A ends before or with
the start of temporal entity B. Here A is longer than B

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image019.jpg)

Figure 17: Temporal entity A ends before or with
the start of temporal entity B. Here A is shorter than B

Examples:

Lerna III (E4) _ends_
_before or with the start of_ Lerna IV (E4). \[“The site at Lerna probably was\
not left uninhabited for long after the destruction of the House of the Tiles\
and the raising of the tumulus. If there was a gap corresponding to the\
earliest stage of EH III in the Argolid, as has been suggested by some (see,\
e.g., Manning 1995: 55–60), it was a brief one. In Rutter’s view, the short\
life of the Fourth Settlement began ca. 2200/2150 b.c. and ended ca. 2050/2000\
b.c.”\] (Banks & Reese, 2013)

The use of LH I
graves of Krisa in Phocis (E4) _ends before or with the start of_ LH IIIphase of reuse of the graves of Krisa in Phocis (E4). \[“…a _possible_\
hiatus in the occupation of certain sites such as the settlement of Krisa in\
Phocis, which was well occupied in the MH and LHIII periods. LHIIB pottery from\
this settlement has already been identified, but no certain example of LHIIA\
pottery.”\] (Phialon 2018)

In
first-order logic:

P182(x,y) ⇒ E2(x)

P182(x,y)
⇒ E2(y)

                P182(x,y) ⇒
P176(x,y)

P182(x,y)
⇒ P185(x,y)

\[P182(x,y)\
⋀ P182(y,z) ⇒ P182(x,z)\]

P182(x,y) ⇒¬P182(y,x)

P183 ends before the start of (starts after the end of)

Domain:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Range:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Subproperty of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P182](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11652) ends before or with the start of (starts after or with the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Quantification:

many to many (0,n:0,n)

Scope note:

This property specifies that the
temporal extent of the domain instance A of E2 Temporal Entity ends definitely
before the start of the temporal extent of the range instance B of E2 Temporal
Entity.

In other words, if A = \[Astart,\
Aend\] and B = \[Bstart, Bend\], it means Aend
< Bstart is true.

This property is part of the set of
temporal primitives P173 – P176, P182 – P185.

This property corresponds to the
following Allen temporal relation (Allen, 1983) : {before}.

This property is transitive. This
property is asymmetric.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image020.jpg)

Figure 18: Temporal entity A ends before the start
of temporal entity B. Here A is longer than B

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image021.jpg)

Figure 19: Temporal entity A ends before the start
of temporal entity B. Here A is shorter than B

Examples:

Gisle
taking office as Bishop of Linköping 1139 AD (E7) _ends before the start_
_of_ The Guta saga composition (E65). (Peel, 1999)

Troy
VII(E4) _ends before the start of_ Troy VIII (E4). \[uninhabited\
for some 200 years\]

The use of the Tomb
Four from Nikitopoulou group in Nihoria in the MHIII-LHI period (E4) _ends_
_before the start of_ the period of reuse of the Tomb Four from Nikitopoulou
group in LHIIIA (E4). \[“Of the six tombs excavated in the Nikitopoulou group\
\[…\] the finds in Tomb Four are of MH II or MH III-LH I date, with the exception\
of the finds with the Northern group of material, which is uniformly dated to\
LHIIA2, end the ewer in the middle of the floor, dated LHIIIA1. \[…\] The\
preserved evidence seems clearly to indicate use in the MHIII-LHI use in the\
MHIII-LHI period followed by a period of reuse in LHIIIA, a pattern matched at\
architecturally similar sites such as _13:Kaminia_ and _10:Gouvalári_.”\]
(Boyd, 2002)

In first-order logic:

P183(x,y) ⇒
E2(x)

P183(x,y) ⇒ E2(y)

P183(x,y) ⇒ P182(x,y)

\[P183(x,y) ∧\
P183(y,z)\] ⇒
P183(x,z)

P183(x,y) ⇒¬P183(y,x)

P184 ends before or with the end of (ends with or after the end of)

Domain:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Range:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Subproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P174](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11518) starts before the end of (ends after the start of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Superproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P185](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11731) ends before the end of (ends after the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Quantification:

many to many
(0,n:0,n)

Scope note:

This property specifies that the
temporal extent of the domain instance A of E2 Temporal Entity ends before or
simultaneously with the end of the temporal extent of the range instance B of
E2 Temporal Entity.

In other words, if A = \[Astart,\
Aend\] and B = \[Bstart, Bend\], it means Aend ≤ Bend  is true.

This property is part of the set of
temporal primitives P173 – P176, P182 – P185.

This property corresponds to a
disjunction (logical OR) of the following Allen temporal relations (Allen,
1983): {before, meets, overlaps, finished by, start, equals, during, finishes}.

This property is irreflexive

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image022.jpg)

Figure 20: Temporal entity A ends before or with
the end of temporal entity B. Here A is longer than B

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image023.jpg)

Figure 21: Temporal entity A ends before or with
the end of temporal entity B. Here A is shorter than B

Examples:

§The reign/life of Harold II (E4) _ends before or with the end_
_of_ the Battle of Hastings (E7)

In first-order logic:

P184(x,y) ⇒
E2(x)

P184(x,y) ⇒ E2(y)

P184(x,y) ⇒ P174(x,y)

¬P184(x,x)

P185 ends before the end of (ends after
the end of)

Domain:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Range:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Subproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P184](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11706) ends before or with the end of (ends with or after the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Superproperty
of:

[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity. [P182](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11652) ends before or with the start of (starts after or with the end of): [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7310)Temporal Entity

Quantification:

many to many
(0,n:0,n)

Scope note:

This property specifies that the temporal
extent of the domain instance A of E2 Temporal Entity ends definitely before
the end of the temporal extent of the range instance B of E2 Temporal Entity.

In other words, if A = \[Astart,\
Aend\] and B = \[Bstart, Bend\], it means Aend
< Bend  is true.

This property is part of the set of
temporal primitives P173 – P176, P182 – P185.

This property corresponds to a
disjunction (logical OR) of the following Allen temporal relations (Allen,
1983): {before, meets, overlaps, starts, during}.

This property is transitive. This
property is asymmetric.

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image024.jpg)

Figure 22: Temporal entity A ends before the end of
temporal entity B. Here A is longer than B

![](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3_files/image025.jpg)

Figure 23: Temporal entity A ends before the end of
temporal entity B. Here A is shorter than B

Examples:

§Godstow
Abbey, Oxfordshire as a working abbey (E4 Period) _ends before the end_
_of_ the reign of Henry VIII (E4 Period).

In first-order logic:

P185(x,y) ⇒ E2(x)

P185(x,y) ⇒
E2(y)

                P185(x,y) ⇒
P184(x,y)

\[P185(x,y)\
∧ P185(y,z)\] ⇒
P185(x,z)P185(x,y) ⇒¬P185(y,x)

P186 produced thing of product type (is
produced by)

Domain:

[E12](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7542)
Production

Range:

[E99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8788)
Product Type

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E12 Production with the instance of E99 Production Type, that is, the type
of the things it produces.

Examples:

The
production activity of the Volkswagen factory related to the “Standard
limousine Type II” during 1949-1953 (E12) _produced thing of product type_
Volkswagen Type 11 (Beetle) (E99). (Rieger, 2013)

In
first-order logic:

P186(x,y) ⇒ E12(x)

P186(x,y) ⇒ E99(y)

P186(x,y) ⇒ (∃z)
\[E24(z) ∧ P108(x,z) ∧ P2(z,y)\]

P187 has
production plan (is production plan for)

Domain:

[E99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8788) Product Type

Range:

[E29](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7854) Design or Procedure

Quantification:

one to many, necessary (1,n:0,1)

Scope note:

This property associates an instance
of E99 Product Type with an instance of E29 Design or Procedure that completely
determines the production of instances of E18 Physical Thing. The resulting
instances of E18 Physical Thing are considered exemplars of this instance of
E99 Product Type when the process specified is correctly executed. Note that
the respective instance of E29 Design or Procedure may not necessarily be fixed
in a written/graphical form, and may require the use of tools or models unique
to the product type. The same instance of E99 Product Type may be associated
with several variant plans.

Examples:

Volkswagen Type 11
(Beetle) (E99) _has production plan_ the production plans for Volkswagen
Type 11 (Beetle) (E29). (Rieger, 2013)

In first-order logic:

P187(x,y) ⇒ E99(x)

P187(x,y) ⇒ E29(y)

P188 requires production tool (is
production tool for)

Domain:

[E99](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8788) Product Type

Range:

[E19](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7681) Physical Object

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E99 Product Type with an instance of E19 Physical Object that is needed for
the production of an instance of E18 Physical Thing. When the process of
production is correctly executed in accordance with the plan and using the
specified instance of E19 Physical Object, the resulting instance of E18
Physical Thing is considered an exemplar of this instance of E99 Product Type.
The instance of E19 Physical Object may bear distinct features that are
transformed into characteristic features of the resulting instance of E18
Physical Thing. Examples include models and moulds.

Examples:

Volkswagen
Type 11 (Beetle) (E99) _requires production tool_ the luggage compartment
lid mould for the Volkswagen Type 11 (Beetle) (E22). \[See thumbnail image\
of the luggage compartment lid: [https://upload.wikimedia.org/wikipedia/commons/thumb/b/b5/Volkswagen\_Type\_1\_(Auto\_classique\_St.\_Lazare\_%2710).jpg/220px-Volkswagen\_Type\_1\_(Auto\_classique\_St.\_Lazare\_%2710).jpg](https://upload.wikimedia.org/wikipedia/commons/thumb/b/b5/Volkswagen_Type_1_(Auto_classique_St._Lazare_'10).jpg/220px-Volkswagen_Type_1_(Auto_classique_St._Lazare_'10).jpg))\]
(Rieger, 2013)

In first-order logic:

P188(x,y) ⇒
E99(x)

P188(x,y) ⇒
E19(y)

P189
approximates (is approximated by)

Domain:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many
to many (0,n:0,n)

Scope note:

This property associates an instance
of E53 Place with another instance of E53 Place, which is defined in the same
reference space, and which is used to approximate the former. The property does
not necessarily state the quality or accuracy of this approximation, but rather
indicates the use of the first instance of place to approximate the second.

In common documentation practice,
find or encounter spots e.g. in archaeology, botany or zoology are often
related to the closest village, river or other named place without detailing
the relation, e.g. if it is located within the village or in a certain distance
of the specified place. In this case the stated “phenomenal” place found in the
documentation can be seen as an approximation of the actual encounter spot
without more specific knowledge.

In more recent documentation often
point coordinate information is provided that originates from GPS measurements
or georeferencing from a map. This point coordinate information does not state
the actual place of the encounter spot but tries to approximate it with a
“declarative” place. The accuracy depends on the methodology used when creating
the coordinates. It may be dependent on technical limitations like GPS accuracy
but also on the method where the GPS location is taken in relation to the
measured feature. If the methodology is known a maximum deviation from the
measured point can be calculated and the encounter spot or feature may be
related to the resulting circle using an instance of _P171 at some place_
_within_.

This property is not transitive.
This property is reflexive.

Examples:

\[40°31'17.9"N 21°15'48.3"E\] (E53) _approximates_ Kastoria, Greece, TGN ID: 7010880 (E53). \[The approximating declarative place with point shape is defined in terms\
of coordinates taken from [https://sws.geonames.org/735927](https://sws.geonames.org/735927)\]

\[40°31'00.1"N 21°16'00.1"E\] (E53) _approximates_ Kastoria, Greece, TGN ID: 7010880 (E53). \[The approximating declarative place with point shape is defined in terms\
of coordinates taken from [http://vocab.getty.edu/page/tgn/7010880](http://vocab.getty.edu/page/tgn/7010880)\]

\[40°04'60.0"N 22°21'00.0"E\] (E53) _approximates_ Mount Olympus National Park, Greece (E53). \[The approximating declarative place with point shape is defined in terms\
of coordinates taken from [https://www.geonames.org/6941814](https://www.geonames.org/6941814)\]

In first-order logic:

P189(x,y) ⇒
E53(x)

P189(x,y) ⇒ E53 (y)

P189(x,y,z) ⇒
\[P189(x,y) ∧ E55(z)\]

P189(x,x)

Properties:

P189.1 has type: [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8153) Type

P190 has symbolic content

Domain:

[E90](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8683) Symbolic Object

Range:

[E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282)String

Subproperty of:

[E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7281) CRM Entity. [P3](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8865) has note: [E62](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8282)String

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E90 Symbolic Object with a complete, identifying representation of its
content in the form of an instance of E62 String.

This property only applies to
instances of E90 Symbolic Object that can be represented completely in this
form. The representation may be more specific than the symbolic level defining
the identity condition of the represented. This depends on the type of the
symbolic object represented. For instance, if a name has type “Modern Greek
character sequence”, it may be represented in a loss-free Latin transcription,
meaning however the sequence of Greek letters.

As another example, if the
represented object has type “English words sequence”, American English or
British English spelling variants may be chosen to represent the English word “colour”
without defining a different symbolic object. If a name has type “European
traditional name”, no particular string may define its content.

Examples:

The
materials description of the painting (E33) _has symbolic content_ “Oil,
French Watercolors on Paper, Graphite and Ink on Canvas, with an Oak frame.”
(E62).

The
title of Einstein’s 1915 text (E35) _has symbolic content_ “Relativity,
the Special and the General Theory” (E62). (Einstein, 2001)

The
story of Little Red Riding Hood (E33) _has symbolic content_ “Once upon a
time there lived in a certain village.” (E62). (Lang, 1965)

The
inscription on Rijksmuseum object SK-A-1601 (E34) has symbolic content “B”
(E62). \[reference: [https://www.rijksmuseum.nl/en/collection/SK-A-1601/catalogue-entry](https://www.rijksmuseum.nl/en/collection/SK-A-1601/catalogue-entry)\
(accessed 10th April 2021)\]

In first-order logic:

P190(x,y) ⇒
E90(x)

P190(x,y) ⇒
E62(y)

P191 had duration (was duration of)

Domain:

[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span

Range:

[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128)Dimension

Quantification:

one to one (1,1:1,1)

Scope note:

This property describes the length
of time covered by an instance of E52 Time-Span. It allows an instance of E52
Time-Span to be associated with an instance of E54 Dimension representing
duration independent from the actual beginning and end. Indeterminacy of the
duration value can be expressed by assigning a numerical interval to the
property _P90 has value_ of E54 Dimension.

Examples:

The
time-span of the Battle of Issos 333 B.C.E. (E52) _had duration_ Battle of
Issos duration (E54). (Howard, 2012)

In first-order logic:

P191(x,y)
⇒
E52(x)

P191(x,y)
⇒
E54(y)

P195 was a presence of (had presence)

Domain:

[E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8691) Presence

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Quantification:

many to one, necessary (1,1:0,n)

Scope note:

This property associates an instance
of E93 Presence with the instance of E18 Physical Thing of which it represents
a temporal restriction (i.e. a time-slice) of the thing’s trajectory through
spacetime. In other words, it describes where the instance of E18 Physical
Thing was or moved around within a given time-span. Instantiating this property
constitutes a necessary part of the identity of the respective instance of E93
Presence.

This property is a shortcut of the
fully developed path from E18 Physical Thing through _P196 defines_, E92
Spacetime Volume, _P166 was a presence of (had presence)_ to E93
Presence.

Examples:

Johann
Joachim Winckelmann’s whereabouts in December 1755 (E93) _was a presence of_
Johann Joachim Winckelmann (E21). (Wiencke, 1998)

Johann
Joachim Winckelmann’s whereabouts from 19th November 1755 until 9th
April 1768 (E93) _was a presence of_ Johann Joachim Winckelmann (E21).
(Wiencke, 1998)

In first-order logic:

P195(x,y) ⇒ E93(x)

P195(x,y) ⇒ E18(y)

P195(x,y) ⇔(∃z)\[E92(z) ∧ P166(z,x) ∧ P196i(z,y)\]

P196 defines
(is defined by)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_E18_Physical_Thing) Physical
Thing

Range:

[E92](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_E92_Spacetime_Volume) Spacetime
Volume

Quantification:

one to one, necessary (1,1:0,1)

Scope note:

This property associates an instance
of E18 Physical Thing with the instance of E92 Spacetime Volume that
constitutes the complete trajectory of its geometric extent through spacetime
for the whole time of the existence of the instance of E18 Physical Thing.

An instance of E18 Physical Thing
not only occupies a particular geometric space at each instant of its
existence, but in the course of its existence it also forms a trajectory
through spacetime, which occupies a real, that is phenomenal, volume in spacetime,
i.e. the instance of E92 Spacetime Volume this property associates it with.
This real spatiotemporal extent of the instance of E18 Physical Thing is
regarded as being unique, in all its details and fuzziness; the identity and
existence of the instance of E92 Spacetime Volume depend uniquely on the
identity of the instance of E18 Physical Thing, whose existence defines it. It
constitutes a phenomenal spacetime volume as defined in CRMgeo (Doerr &
Hiebel, 2013).

Included in this spacetime volume
are both the spaces filled by the matter of the physical thing and any inner
space that may exist, for instance the interior of a box. Physical things
consisting of aggregations of physically unconnected objects, such as a set of
chessmen, occupy a finite number of individually contiguous subsets of this
spacetime volume equal to the number of objects that constitute the set and
that are never connected during its existence.

Examples:

H.M.S.
Temeraire (E22) defines the
spacetime volume of H.M.S. Temeraire (E92). \[it was built, during 1798, in\
Chatham and destroyed, during 1838, in Rotherhithe\] (Willis, 2010)

The
Saint Titus reliquary (E22) _defines_ the spacetime volume of the Saint
Titus reliquary (E92). \[the reliquary has been produced by the workshop of the Vogiatzis\
brothers located at Monastiraki, Athens, in 1966 as container for the skull of\
Saint Titus, which was placed into it at that time and has since then continued\
to fall within the container’s spacetime volume. The reliquary with the skull\
has been kept in the Saint Titus Church in Heraklion, Crete since 1966\] (Fisher
& Garvey, 2010; Panotis, 2016)

In first-order logic:

P196(x,y) ⇒
E18(x)

P196(x,y) ⇒
E92(y)

P197 covered parts of (was
partially covered by)

Domain:

[E93](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8691)Presence

Range:

[E53](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8104) Place

Quantification:

many to many (0,n:0,n)

Scope note:

This property associates an instance
of E93 Presence with an instance of E53 Place that geometrically overlaps with
the spatial projection of the respective instance of E93 Presence. A use case
of this property is to state through which places an object or an instance of
E21 Person has or was moved within a given time-span. It may also be used to
describe a partial or complete, temporary or permanent extension of the spatial
extent of some realm into a neighbouring region during a known time-span. It
may also be used to describe a partial or complete, temporary or permanent
extension of the spatial extent of some realm into a neighbouring region during
a known time-span.

This property is a shortcut of the
more fully developed path from E93 Presence through _P161 has spatial_
_projection_, E53 Place _, P121 overlaps with,_ to E53 Place.

Examples:

Johann
Joachim Winckelmann’s whereabouts from 19th November 1755 until 9th
April 1768 (E93) _covered parts of_ Paestum, Italy (E53). (Wiencke, 1998)

The
Byzantine Empire 1013 AD (E93) _covered parts_ of The Italian Peninsula
(E53). (Browning, 1980)

In first-order logic:

P197(x,y) ⇒ E93(x)

P197(x,y) ⇒ E53(y)

P198 holds or
supports (is held or supported by)

Domain:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Range:

[E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical
Thing

Quantification:

one to many (0,n:0,n)

Scope note:

This property relates one instance
of E18 Physical Thing which acts as a container or support to a supported or
contained instance of E18 Physical Thing. Typical examples of E18 Physical
Things which are intended to function as a container or support include
shelves, folders or boxes. These containers or supports provide a stable
surface which is intended for other physical objects to be placed upon for
storage, display, transport or other similar functions.

This property is a shortcut of the
more fully developed path from E18 Physical Thing through _P59 has section_,
E53 Place, _P53i is former or current location_ _of,_ to E18 Physical
Thing. It is not a sub-property of _P46 is composed of_, as the held or
supported object is not a component of the container or support.

This property can be used to avoid
explicitly instantiating the E53 Place which is defined by an instance of E18
Physical Thing, especially when the only intended use of that instance of E18
Physical Thing is to act as a container or surface for the storage of other
instances of E18 Physical Thing. The place’s existence is defined by the
existence of the container or surface, and will go out of existence at the same
time as the destruction of the container or surface.

This property is transitive. This
property is asymmetric.

Examples:

Archival
folder “6” (E22) _holds or supports_ the piece of paper carrying the text
of a letter from Lawrence Alloway to Sylvia Sleigh (E22).

\[ [http://archives2.getty.edu:8082/xtf/view?docId=ead/2003.M.46/2003.M.46.xml;chunk.id=aspace\_ref12\_kf7;brand=default](http://archives2.getty.edu:8082/xtf/view?docId=ead/2003.M.46/2003.M.46.xml;chunk.id=aspace_ref12_kf7;brand=default)\]

Archival
folder "17" (E22) _holds or supports the_ daguerreotype that
shows the image of Henry Ward Beecher as a young man (E22).

\[ [https://archives.yale.edu/repositories/12/archival\_objects/1402266](https://archives.yale.edu/repositories/12/archival_objects/1402266)\]

Box
"88" (E22) _holds or supports_ folder "17" (E22). \[ [https://archives.yale.edu/repositories/12/archival\_objects/1402266](https://archives.yale.edu/repositories/12/archival_objects/1402266)\]

Bookshelf
“GRI-708.1” (E22) _holds or supports_ the book entitled “Catalog of
Paintings in the J. Paul Getty Museum” (E22). (Potts, 2015)

In first-order logic:

P198(x,y) ⇒ E18(x)

P198(x,y) ⇒ E18(y)

\[P198(x,y) ∧\
P198(y,z)\] ⇒
P198(x,z)

\[P198(x,y)\
∧ P198(z,y)\] ⇒ \[P198(x,z) ˅ P198(z,x)\]

P198(x,y) ⇐ (∃z) \[E53(z)\
˄ P59(x,z) ˄ P53i(z,y)\]

P198(x,y) ⇒¬P198(y,x)

# Works Cited

Aczel, A. D.
(2007) _The artist and the mathematician: the story of Nicolas Bourbaki, the_
_genius mathematician who never existed_. London: High Stakes.

Adkin, M.
(2005) _The Trafalgar companion: a guide to history’s most famous sea battle_
_and the life of Admiral Lord Nelson_. London: Aurum Press Ltd.

Aldridge, R.
(2008) _The Sinking of the Titanic._ New York: Infobase Pub.

Alighieri, D.
(1956) _La Divina Commedia: Inferno_. New York: Folways Records.

Allen, J. F.
(1983) ‘Maintaining knowledge about temporal intervals’, _Communications of_
_the ACM_, 26(11), pp. 832–843. doi: [10.1145/182.358434](https://doi.org/10.1145/182.358434).

Allen, V. F.
(1987) _Reading for life, a first book for adults and their tutors_. Palm
Springs: ALTA English Publishers.

Andrews, I. and
Kesteven, P. (1977) _Defeat in the forest_. London: Cambridge Press.

Atlas, R. D.
(2001) ‘ENRON’S COLLAPSE: THE OPTIONS; A Trend Toward Liquidation, Not Company
Reorganization’, _The New York Times_, 30 November. Available at:  [https://www.nytimes.com/2001/11/30/business/enron-s-collapse-options-trend-toward-liquidation-not-company-reorganization.html](https://www.nytimes.com/2001/11/30/business/enron-s-collapse-options-trend-toward-liquidation-not-company-reorganization.html) (Accessed: 4 February 2021).

Ball, D. W.
(1962) _Maxwell’s equations of electrodynamics: an explanation_.
Washington: Spie Press.

Barber, N.
(1994) _World War II._ Great Britain: Evans.

Barnard, H. et
al. (2007) ‘Mixed results of seven methods for organic residue analysis applied
to one vessel with the residue of a known foodstuff’, _Journal of_
_Archaeological Science_, 34(1), pp. 28–37. doi: [10.1016/j.jas.2006.03.010](https://doi.org/10.1016/j.jas.2006.03.010).

Barton, S. J.
(1992) _The study of an electrically insulating resin for humid environments._
Kingston University Press.

Beckman,
O. (1998) ‘Celsius, Linne and the Celsius Temperature Scale’, _Bulletin of_
_the Scientific Instrument Society_, 56, pp. 17–23.

Bekiari, C. et
al. (eds) (2015) _FRBR, object-oriented definition and mapping from FRBRER,_
_FRAD and FRSAD_. Available at: [http://www.cidoc-crm.org/frbroo/sites/default/files/FRBRoo\_V2.4.pdf](http://www.cidoc-crm.org/frbroo/sites/default/files/FRBRoo_V2.4.pdf) (Accessed: 6 February 2021).

Bekiari, C. et al. (eds) (2022) CIDOC Conceptual
Reference Model version 7.1.2. Available at: [https://cidoc-crm.org/sites/default/files/cidoc\_crm\_version\_7.1.2.pdf](https://cidoc-crm.org/sites/default/files/cidoc_crm_version_7.1.2.pdf) (Accessed: 19 April 2023).

Benaki Museum
(2016) _Childhood, Toys and Games–- Benaki Museum_. Available at: [https://www.benaki.org//index.php?option=com\_collections&view=collection&id=45&Itemid=540&lang=en](https://www.benaki.org/index.php?option=com_collections&view=collection&id=45&Itemid=540&lang=en)(Accessed:
5 February 2021).

Berkoff, S. (2013)
_Sturm und Drang_. London: Bloomsbury. Available
at: [http://dx.doi.org/10.5040/9780571291168.00000104](http://dx.doi.org/10.5040/9780571291168.00000104) (Accessed: 5 February 2021).

_Berlin Wall_
_built_ (no date) _HISTORY_. Available at: [https://www.history.com/this-day-in-history/berlin-wall-built](https://www.history.com/this-day-in-history/berlin-wall-built) (Accessed: 6 February 2021).

Bertaud, J.-P.
(2004) _La révolution française_. Paris:
Perrin.

Bieber, M.
(1961) _The Sculpture of the Hellenistic Age–- Revised Edition_. New York:
Columbia University Press.

Black, J.
(2010) _The Battle of Waterloo_. New York: Random House.

Blake, S. F.
(1918) ‘Notes on the Clayton Herbarium’, _Rhodora_, 20(230), pp. 21–28,
48–54, 65–73.

Bleicken, J.
and Bell, A. (2015) _Augustus: the biography_. London: Allen Lane.

Bonney, R.
(2014) _The Thirty years’ war: 1618-1648_. Oxford: Osprey.

Borchert, T.-H.
(2008) _Jan van Eyck_. Londo n: Taschen.

Bortolatto, L. R.
(1981) _Tout l’œuvre peint de Mone t: 1870-1889_. Paris:
Flammarion Groupe.

Bosman, L. (2004) _The power_
_of tradition: spolia in the architecture of St. Peter’s in the Vatican / Lex_
_Bosman._ Hilversum : Uitgeverij Verloren.

Boyd, M. J. (2002). _Middle_
_Helladic and early Mycenaean mortuary practices in the southern and western_
_Peloponnese_. Oxford, Archaeopress.

Brandreth, G.
(2004) _Philip & Elizabeth: Portrait of a marriage_. London: Arrow.

Brandstetter, G.
and Klein, G. (2015) _Methoden der Tanzwissenschaft: Modellanalysen zu Pina_
_Bauschs ‘Le Sacre du Printemps/Das Frühlingsopfer’_. Bielefeld: Transcript.

Breasted, J. H.
(1906) _Ancient records_. Chicago: University of Chicago Press.

Brickhill, P.
(2001) _Reach for the sky: the story of Douglas Bader, legless ace of the_
_Battle of Britain_. Annapolis, Md.: Naval Institute Press.

Brilliant, R.
(2000) _My Laocoön: alternative claims in the interpretation of artworks_.
Berkele y: Univ. of California Press.

Briquet, C.-M.
(1985) _Les filigrane s: dictionnaire historique des marques du_
_papier  : dès leur apparition vers 1282 jusqu’en 1600_. New York: Hacker art Books.

British Museum
and Hill, G. F. (1922) _Catalogue of the Greek coins of Arabia, Mesopotamia_
_and Persia (Nabataea, Arabia Provincia, S. Arabia, Mesopotamia, Babylonia,_
_Assyria, Persia, Alexandrine empire of the East, Persis, Elymais, Characene_.
London: British Museum.

Britton, A.
(2012) _RMS Queen Mary_. Stroud, Gloucestershire: The History Press Ltd.

Brooks, J. A.
(1973) _Glass_. New York: Golden Press.

Brown, L. and
Hort, L. (2006) _Nelson Mandela_. New York: Dorling Kindersley.

Browning, R.
(1980) _The Byzantine Empire_. London: Weidenfeld and Nicolson.

Brueggemann, W.
(1982) _Genesis: a Bible commentary for teaching and preaching_. Atlanta:
John Knox Press.

Bryant, J.
(1990) _The Iveagh Bequest, Kenwood_. London: English
Heritage Guidebooks.

Bürger, O.
(1892) ‘Zur Systematik der Nemertinenfauna des Golfs von Neapel’, _Nachrichten_
_von der königlichen Gesellschaft der Wissenschaften und der_
_Georg-Augusts-Universität zu Göttingen_, 5, pp. 137–178.

Butson, T. G.
(1986) _Mikhail Gorbachev_. New York: Chelsea House.

Cali, J.,
Dougill, J. and Ciotti, G. (2012) _Shinto shrines: a guide to the sacred_
_sites of Japan’s ancient religion_. Honolulu: University of Hawaiʻi
Press.

Camardo, D.
(2013) ‘Herculaneum from the ad 79 eruption to the medieval period: analysis of
the documentary, iconographic and archaeological sources, with new data on the
beginning of exploration at the ancient town1’, _Papers of the British School_
_at Rome_, 81, pp. 303–340. doi: [10.1017/S0068246213000123](https://doi.org/10.1017/S0068246213000123).

Carrington, N.
T. (1954) _Shakespeare: Cymbeline._ London: J. Brodie.

Carroll, L.
(1981) _Jabberwocky: and other poems_. London: Macmillan Children’s Books.

Carter, H.
(2014) _The tomb of Tutankhamun_. London: Bloomsbury Academic.

Carter, H. and
Mace, A. C. (1977) _The discovery of the tomb of Tutankhamen_. New York:
Dover Publications.

Chan, H. (2011)
_Ming Taizu (r.1368-98) and the foundation of the Ming Dynasty in China_.
Farnham: Ashgate.

Chester, D.
(2001) ‘The 1755 Lisbon earthquake’, _Progress in Physical Geography: an_
_international review of geographical work in the natural and environmental_
_sciences_, 25(3), pp. 363–383.

Childe, V. G.
(1963) _The bronze age_. New York: Biblo and Tannen.

Chipp, H. B.
(1988) _Picasso’s Guernica: history, transformations, meanings._ Berkeley:
University of California Press.

Clare, J. D.
and Edwards, M. (1992) _I was there: Roman Empire._Londo n:
The Bodley Head.

Collectif &
Musée d’art et d’histoire Louis-Senlecq (1900) _Les trésors des_
_princes de Bourbon Conti_. Paris: Somogy
éditions d’art.

_Construction_
_of massive seawall completed in Shizuoka_ (no date) _The_
_Asahi Shimbun_. Available at: [http://www.asahi.com/ajw/articles/13257178](http://www.asahi.com/ajw/articles/13257178) (Accessed: 6 February 2021).

Cooper, B. L.
(2008) ‘Audio Reviews, Blue Suede Shoes: A Rockabilly Session by Carl Perkins
and friends.’, _Popular Music and Society_, 31(3), pp. 395–401. doi: [10.1080/03007760802021093](https://doi.org/10.1080/03007760802021093).

Correll, J. L.
(1972) _Welcome to the land of the Navajo: a book of information about the_
_Navajo Indians_. 3rd edn. Arizona: Window Rock.

Courtney Banks,
E. (2013). _The Settlement and Architecture of Lerna IV; Results of_
_excavations conducted by the American School of Classical Studies at Athens_,
6\. Princeton: American School of Classical Studies at Athens.

Cox, N. (2000) _Cubism_.
London: Phaidon.

Craig, N. C.
and Gislason, E. A. (2002) ‘First Law of Thermodynamics; Irreversible and
Reversible Processes’, _Journal of Chemical Education_, 79(2), p. 193.
doi: [10.1021/ed079p193](https://doi.org/10.1021/ed079p193).

Crocker, B.
(2012) _Betty Crocker vegetarian cooking._ Hoboken, N.J.: Wiley.

Crofton, I.
(2015) _Walking the border: a journey between Scotland and England_.
Edinburgh: Birlinn.

Curry, A. (2015)
_The battle of Agincourt: sources and interpretations_. Woodbridge,
Suffolk: The Boydell Press.

Dalrymple, W.
and Anand, A. (2017) _Koh-I-Noor: the history of the world’s most infamous_
_diamond_. London: Bloomsbury.

Daly, A. (1981)
_Royal wedding_. Loughborough: Ladybird Books.

Daniel, B. C.
(2014) ‘A graceful return of the drachma’, _European Economic Review_, 71,
pp. 228–243. doi: [10.1016/j.euroecorev.2014.08.004](https://doi.org/10.1016/j.euroecorev.2014.08.004).

Dawson, P. L.
(2018) _Waterloo: the truth at last: why Napoleon lost the great battle_. Barmsley: Frontline Books.

Delacroix, E. and
Toussaint, H. (1982) _La Liberte guidant le peuple de  Delacroix:_
_\[catalogue d’une exposition presentee au Musee du Louvre, 5 nov. 1982 au 7 fev._\
_1983_.  Paris: Reunion des Musees Nationaux.\
\
Deutsch, O. E.\
(1965) _Mozart, a documentary biography_. Stanford: Stanford University\
Press.\
\
Dewey, D.\
(2003) ‘The Little Mermaid’, _Scandinavian Review_, 91(1), p. 34.\
\
Dodge, B. O.\
(1933) _Penicillium brefeldianum B.O.Dodge_. In: Mycologia 25(2): 92.\
\
Doerr, M.\
(2003) _The CIDOC conceptual reference module: an ontological approach to_\
_semantic interoperability of metadata_. AI Magazine. 24, 3 (September 2003),\
pp. 75–92.\
\
Doerr, M. and\
Hiebel, G. (2013) ‘CRMgeo: Linking the CIDOC CRM to GeoSPARQL through a\
Spatiotemporal Refinement’, _TECHNICAL REPORT: ICS-FORTH/TR-435_.\
Institute of Computer Science, Foundation for Research and Technology Hellas,\
Heraklion, Crete, Greece.\
\
Dolan, J. W.\
(2005) ‘The Bermuda Triangle’, _LC GC North America_, 23(4), pp. 370–375.\
\
Dorman Long\
(Firm) (1932) _Sydney Harbour Bridge._ Middlesbrough, England: Dorman Long\
and Company Limited.\
\
Droste, M. and\
Gössel, P. (2006) _Bauhaus 1919-1933: reform and Avant-Garde_.\
Köln: Taschen.\
\
Edwards, I. E.\
S. and Boltin, L. (1979) _Tutankhamun: his tomb and its treasures_.\
London: Gollancz.\
\
Einstein, A.\
(2001) _Relativity: the special and the general theory_. London:\
Routledge.\
\
Encyclopedia\
Britannica, the Editors (1998) _‘Adoration of the shepherds’_.\
Encyclopedia Britannica. Available at: [https://www.britannica.com/topic/adoration-of-the-shepherds-religious-motif](https://www.britannica.com/topic/adoration-of-the-shepherds-religious-motif) (Last edit: 1 March 2018. Accessed: 6 February 2021).\
\
Evans, A.\
(1921) _The palace of Minos: a comparative account of the successive stages_\
_of the early Cretan civilization as illustrated by the discoveries at Knossos._\
London: Macmillan & Co.\
\
Farnie, D. A.\
(1980) _The Manchester Ship Canal and the rise of the Port of Manchester,_\
_1894-1975._ Manchester: Manchester University Press.\
\
Farrand, M.\
(1913) _Framing of Constitution of United States._ United States: Yale\
University Press.\
\
Fisher, J. and\
Garvey, G. (2010) _The rough guide to Crete_. UK: Rough Guides Limited.\
\
Foster, N.\
(2000) _Rebuilding the Reichstag_. Woodstock, N.Y.: Overlook Press.\
\
Galeotti, M.\
(1997) _Gorbachev and His Revolution_. London: Macmillan Education,\
Limited.\
\
Gangemi, A. et\
al. (2002) ‘Sweetening Ontologies with DOLCE’, in Gómez-Pérez, A.\
and Benjamins, V. R. (eds) _Knowledge Engineering and Knowledge Management:_\
_Ontologies and the Semantic Web_. Berlin, Heidelberg: Springer (Lecture\
Notes in Computer Science), pp. 166–181. doi: [10.1007/3-540-45810-7\_18](https://doi.org/10.1007/3-540-45810-7_18).\
\
Gannett, H.\
(1904) _Boundaries of the United States and of the several states and_\
_territories: with an outline of the history of all important changes of_\
_territory_. Washington, D.C.: Department of the Interior, United States Geological\
Survey.\
\
Getty Trust.\
(1990). _Art & architecture thesaurus_. Oxford University Press.\
\
Georgoula, E.\
(2005) _Greek treasures from the Benaki Museum in Athens_. Sydney:\
Powerhouse Publishing in association with Benaki Museum.\
\
Gergatsoulis,\
M. et al. (2010) ‘Mapping Cultural Metadata Schemas to CIDOC Conceptual\
Reference Model’, in _Artificial Intelligence: Theories, Models and_\
_Applications_. _Hellenic Conference on Artificial Intelligence_,\
Springer, Berlin, Heidelberg, pp. 321–326. doi: [10.1007/978-3-642-12842-4\_37](https://doi.org/10.1007/978-3-642-12842-4_37).\
\
Gibbon, E.\
(2013) _The History of the Decline and Fall of the Roman Empire: Edited in_\
_Seven Volumes with Introduction, Notes, Appendices, and Index_. Edited by J.\
B. Bury. Cambridge: Cambridge University Press (Cambridge Library Collection–-\
Classics). doi: [10.1017/CBO9781139333580](https://doi.org/10.1017/CBO9781139333580).\
\
Gibson, J. L.\
(1986) _Ian McKellen_. London: Weidenfeld and\
Nicolson.\
\
Gimbutas, M. A.\
(1965) _Bronze age cultures in central and eastern Europe_. Paris: Mouton\
& Co.\
\
Gleick, J.\
(2003) _Isaac Newton_. London; New York: Fourth Estate.\
\
Goldner, O. and\
Turner, G. E. (1976) _The making of King Kong: the story behind a film_\
_classic_. New York: Ballantine Books.\
\
Goldscheider,\
L. (1953) _Michelangelo: paintings, sculpture, architecture_. London:\
Phaidon Press.\
\
Goodwin, P.\
(2015) _HMS Victory: 1765-1812 (first rate ship of the line)_.\
\
Gregor, H.\
(1971) _The S.S. Great Britain_. London: Published for the S.S. Great\
Britain Project by Macmillan.\
\
Guarino, N.\
(1998) _Formal Ontology in Information Systems: Proceedings of the 1st_\
_International Conference June 6-8, 1998, Trento, Italy_. 1st edn.\
NLD: IOS Press.\
\
Gurcke, K.\
(1987) _Bricks and brickmaking: a handbook for historical archaeology_.\
Moscow, Idaho: University of Idaho Press.\
\
Håfors,\
B. (2010) _Conservation of the wood of the Swedish warship Vasa of a.d. 1628:_\
_evaluation of polyethylene glycol conversation programmes_. Acta\
Universitatis Gothoburgensis.\
\
Hallam, A.\
(1975) _Jurassic environment._ Cambridge: Cambridge University Press.\
\
Hallam, E. M.\
(1986) _Domesday Book through Nine Centuries_. London: Thames &\
Hudson. ISBN 0500250979.\
\
Harbutt, F. J.\
(2010) _Yalta 1945: Europe and America at the crossroads_. Cambridge:\
Cambridge University Press.\
\
Harrison, R. J.\
(2004) _Symbols and warriors: images of the European Bronze Age_. Bristol:\
Western Academic & Specialist Press.\
\
Hartle, J. B.\
(2003) _Gravity an introduction to Einstein’s general relativity_. San\
Francisco: Addison-Wesley.\
\
Hau, L. V. et\
al. (1999) ‘Light speed reduction to 17 metres per second in an ultracold\
atomic gas’, _Nature_, (6720), pp. 594–597.\
\
Hawass, Z.\
(2000) _The Mysteries of Abu Simbel: Ramesses II and the Temples of the_\
_Rising Sun_. Cairo: American University in Cairo.\
\
Hegen, E. E.\
(1966) _Highways into the Upper Amazon Basin: pioneer lands in southern_\
_Colombia, Ecuador, and northern Peru_. Gainesville: University of Florida\
Press.\
\
Hershberger\
A.J, Robacker C, and Jenkins T.M (2015) ‘Molecular genetic variability of\
spigelia marilandica and S. Gentianoides’, _J. Am. Soc. Hortic. Sci. Journal_\
_of the American Society for Horticultural Science_, 140(2), pp. 120–128.\
\
Hilmo, M.\
(2019) _Medieval Images, Icons, and Illustrated English Literary Texts :_\
_From the Ruthwell Cross to the Ellesmere Chaucer_. Aldershot: Ashgate\
Publishing, Ltd. doi: [10.4324/9781315249278](https://doi.org/10.4324/9781315249278).\
\
Hind, A. M.\
(1923) _A catalogue of Rembrandt’s etchings: chronologically arranged and_\
_completely illustrated_. London: Methuen.\
\
Historical\
Museum of Crete (2005) _Numismatics_. Available at: [https://www.historical-museum.gr/eng/collections/view/nomismatikh-sullogh](https://www.historical-museum.gr/eng/collections/view/nomismatikh-sullogh) (Accessed: 4 March 2021).\
\
Holliday, I.,\
Marcou, G. and Vickerman, R. W. (1991) _The Channel tunnel: public policy,_\
_regional development and European integration_. London; New York: Belhaven\
Press.\
\
Honey, A. and\
Pickwoad, N. (2010) ‘Learning from the Past: Using Original Techniques to\
Conserve a Twelfth-Century Illuminated Manuscript and Its Sixteenthcentury\
Greek-Style Binding at the Monastery of St Catherine, Sinai’, _Studies in_\
_Conservation_, 55(sup2), pp. 56–61. doi: [10.1179/sic.2010.55.Supplement-2.56](https://doi.org/10.1179/sic.2010.55.Supplement-2.56).\
\
Hood, S. (1971)\
_The Minoans: Crete in the Bronze Age_. London: Thames and Hudson (Ancient\
Peoples and Places, 75).\
\
Hopkins, K. and\
Beard, M. (2011) _The Colosseum_. Cambridge, MA: Harvard University Press.\
\
Howard, M.\
(2012) _Alexander the Great: the Story of the Invincible Macedonian King._\
London: Bloomsbury Publishing Plc.\
\
Hoyt, E. P.\
(1993) _199 days: the battle of Stalingrad_. New York: Tor.\
\
Hufford, D. J.\
and Horwitz, P. (2005) ‘Fixing the Hole in the Ozone Layer: A Success in the\
Making’, _Natural Resources and the Environment–- Chicago_, 19(4), pp.\
8–14.\
\
Humboldt, A. von\
(1859) _Reise in die Aequinoctial Gegenden des neuen Continents_. Translated by H. Hauff. Stuttgart: J. G. Cotta.\
\
Huray, P. G.\
(2010) _Maxwell’s Equations_. Hoboken, NJ, USA: John Wiley & Sons,\
Inc.\
\
Iliffe, R.\
(2013) _Newton: The Making of a Politician_, _The Newton Project_.\
Available at: [http://www.newtonproject.ox.ac.uk/view/contexts/CNTX00002](http://www.newtonproject.ox.ac.uk/view/contexts/CNTX00002) (Accessed: 6 February 2021).\
\
Ingamells, J.\
(1990) _The Wallace collection_. London: Scala Books.\
\
International\
Organization for Standardization (1998) _ISO 639-2. Codes for the_\
_representation of names of languages –Part 2: Alpha-3 code_. Geneva,\
Switzerland: International Organization for Standardization.\
\
International\
Organization for Standardization (2013a) _ISO 21127:2014 Information and_\
_documentation — A reference ontology for the interchange of cultural heritage_\
_information_. 1st edn. Geneva, Switzerland: International\
Organization for Standardization.\
\
International\
Organization for Standardization (2013b) _ISO 25964-2:2013. Information and_\
_documentation — Thesauri and interoperability with other vocabularies — Part 2:_\
_Interoperability with other vocabularies_. 1st edn. Geneva,\
Switzerland: International Organization for Standardization.\
\
Irwin, W. A.\
(1935) _The Julius Caesar Murder Case._ New York, London: D.\
Appleton-Century Co.\
\
Iveagh Bequest\
(1975) Catalogue of paintings. London: Greater London Council.\
\
Isaacson, W.\
(2011) _Steve Jobs._ USA: Little, Brown.\
\
Jones, R. F.\
(1979) _George Washington._ Boston Mass.: Twayne.\
\
Karetsou A. (ed.).\
(2000). Kriti – Aigyptos. Politismikoi desmoi trion\
chilietion. _Athens: Archaeological Museum of_\
_Herakleion._\
\
Karyanos, P.,\
Lagos, C. and Carr, J. (2020) _Who really won the Battle of Marathon?_ UK:\
Barnsley Pen et Sword Military.\
\
Kelly, D.\
(2014) _Machaut and the medieval apprenticeship tradition: truth, fiction and_\
_poetic craft_. New York: Brewer.\
\
Kogan, H.\
(1958) _The great EB: the story of the Encyclopædia Britannica_.\
Chicago: University of Chicago Press.\
\
Kousser, R.\
(2005) ‘Creating the Past: The Venus de Milo and the Hellenistic Reception of\
Classical Greece’, _American Journal of Archeaology_, 109(2), pp. 227–250.\
\
Kouwenhoven, A.\
P. (1997) ‘Newsbriefs: World’s Oldest Spears’, _Archaeology_, 50(3).\
Available at: [https://archive.archaeology.org/9705/newsbriefs/spears.html](https://archive.archaeology.org/9705/newsbriefs/spears.html) (Accessed: 6 February 2021).\
\
Kutschera, W.\
(2002) _Radiocarbon dating of the Iceman Ötzi with accelerator mass_\
_spectrometry_. Available at: [https://www.semanticscholar.org/paper/Radiocarbon-dating-of-the-Iceman-%C3%96tzi-with-mass-Kutschera/20d9b3be6466e3a6d51ddb213f9c982fdf949024](https://www.semanticscholar.org/paper/Radiocarbon-dating-of-the-Iceman-%C3%96tzi-with-mass-Kutschera/20d9b3be6466e3a6d51ddb213f9c982fdf949024) (Accessed: 6 February 2021).\
\
Lamb, R. (2005)\
‘Alexander the Great and Bucephalus’, _Horse & Rider_, 44(6), p. 19.\
\
Lane Fox, R.\
(2004) _Alexander the Great_. New York: Penguin.\
\
Lang, A. (ed.)\
(1965) _The blue fairy book._ Dover Pubs.\
\
Leach, A.\
(2017) _Rome_. Cambridge: Polity Press.\
\
Lee, S. J.\
(1991) _The Thirty years war_. London; New York: Routledge.\
\
Lehner, M. and\
Hawass, Z. A. (2017) _Giza and the pyramids: the definitive history_.\
Chicago: University of Chicago Press.\
\
Lennon, J.\
(1967) _Lucy in the Sky with Diamonds_. London: Northern Songs.\
\
Leppmann, W.\
(1970) _Winckelmann_. New York: Knopf.\
\
Li, X. J.\
(2012) _Standardisation, labour organisation and the bronze weapons of the_\
_Qin terracotta warriors / Xiuzhen Janice Li._ Ph.D. University College\
London. Available at: [http://discovery.ucl.ac.uk/1350109/](http://discovery.ucl.ac.uk/1350109/) (Accessed: 22 April 2021).\
\
Liess, R. (1985)\
‘Der Riss A1 der Straßburger Münsterfassade im Kontinuum der\
Entwürfe Magister Erwins.’, _Kunsthistorisches Jahrbuch Graz_, 21,\
pp. 47–121.\
\
Lockwood, L.\
(2015) _Beethoven’s symphonies: an artistic vision_. New York: W. W.\
Norton & Company.\
\
Loubiere, C. P.\
(1995) _L’aventure d’Abou Simbel Texte imprimé le regard d’un Roi-Dieu_.\
Paris: Publisud.\
\
Lovell, J. and\
Kluger, J. (1994) _Lost moon: the perilous voyage of Apollo 13_. Boston:\
Houghton Mifflin.\
\
Lowe Fri, M.\
(2011) _The double axe in Minoan Crete: an experimental study of production_\
_and use_. Oxford: Archaeopress.\
\
Macdonald, F. (1992)\
_The Italian Renaissance: Teacher’s Notes (Collins living history)_.\
London: Collins Educational.\
\
Maddox, S.\
(2015) _Saving Stalin’s imperial city historic preservation in Leningrad,_\
_1930-1950_. Bloomington, Indian a: Indiana University Press.\
\
Mangini, E. (2010). 1000 Words:\
Giuseppe Penone. _ARTFORUM INTERNATIONAL_, 49(2), 226–228.\
\
Marion, S. (2004) _Recherches_\
_sur l’âge du Fer en Ile-de-Franc e: entre Hallstatt final et La_\
_Teǹe finale  ; analyse des sites fouillés  ;_\
_chronologie et société._Oxford: John and Erica Hedges\
Ltd.\
\
Maunder, E. W.\
(1900) _The Royal observatory, Greenwich. A glance at its history and work_.\
London, The Religious tract society.\
\
McCullough, C.\
(2005) _The Merchant of Venice_. Basingstoke: Palgrave Macmillan.\
\
Meghini, C. and\
Doerr, M. (2018) ‘A first-order logic expression of the CIDOC conceptual\
reference model’, _International Journal of Metadata, Semantics and_\
_Ontologies_, 13(2), pp. 131–149. doi: [10.1504/IJMSO.2018.098393](https://doi.org/10.1504/IJMSO.2018.098393).\
\
Mellen, J. (2002) _Seven_\
_samurai_. London: BFI Pub.\
\
Mhaske, S. T.\
(2011) ‘Polycarbonate: Medical applications’, _Chemical Weekly_, 56(30),\
pp. 201–204.\
\
Milne, A. A.\
(2012) _The Sunny Side_. The Floating Press.\
\
Milne, A. A.\
& Shepard, E. H. (1998) _Piglet has a bath_. Boston: Dutton Children’s\
Books.\
\
Mohen, J.-P.,\
Menu, M. and Mottin, B. (2006) _Mona Lisa: Inside the Painting_. Harry N.\
Abrams.\
\
Moholy-Nagy, L.\
(2012) _The New Vision: Fundamentals of Bauhaus Design, Painting, Sculpture,_\
_and Architecture_. Courier Corporation.\
\
Mommsen, T.\
(1872) _Corpus inscriptionum Latinarum Vol. 5, Pars 1._ Berolini: Apud\
Georgium Reimerum.\
\
Mommsen, T. E.\
(1941) ‘The Venetians in Athens and the Destruction of the Parthenon in 1687’, _American_\
_Journal of Archaeology_, 45(4), pp. 544–556. doi: [10.2307/499533](https://doi.org/10.2307/499533).\
\
Monast, J. and\
Tao, B. (2002) ‘In Memoriam: Paul Wellstone (1944-2002)’, _Georgetown_\
_International Environmental Law Review_, 15, p. 133.\
\
Morton, H. C.\
(1994) _The story of Webster’s third: Philip Gove’s controversial dictionary_\
_and its critics_. Cambridge: Cambridge University Press.\
\
Municipality of\
Heraklion (2021) _City Hall_. Available at: [https://www.heraklion.gr/en/municipality/city-hall//city-hall.html](https://www.heraklion.gr/en/municipality/city-hall/city-hall.html) (Accessed: 6 February 2021).\
\
Murdoch, D. H.\
et al. (2003) _Tutankhamun: the life and death of a_\
_pharaoh_. London: Dorling Kindersley.\
\
Musée d’Orsay (2020) _Claude_\
_Monet “La Pie”_. Available at: [https://www.musee-orsay.fr/fr/collections/catalogue-des-oeuvres/notice.html?no\_cache=1&nnumid=715](https://www.musee-orsay.fr/fr/collections/catalogue-des-oeuvres/notice.html?no_cache=1&nnumid=715) (Accessed: 1 April 2021).\
\
National\
Gallery of Victoria (no date) _Portrait group: The singer Farinelli and_\
_friends (c. 1750-1752) Jacopo Amigoni_. Available at: [http://www.ngv.vic.gov.au/explore/collection/work/3701/](http://www.ngv.vic.gov.au/explore/collection/work/3701/) (Accessed: 6 February 2021).\
\
Natural History Museum (2021). Data Portal Query on\
“Clayton Herbarium” created at 2021-02-03 21:48:21.969228 PID [https://doi.org/10.5519/qd.thnwfxy8](https://doi.org/10.5519/qd.thnwfxy8). Subset of “Clayton Herbarium” (dataset)\
PID [https://doi.org/10.5519/0063794](https://doi.org/10.5519/0063794)\
\
Natural History Museum (2021) b. Collection\
Specimens–- Specimens–- 1842.12.14.24-27–- Data Portal created at 2010-04-07. [https://data.nhm.ac.uk/object/e1bfb1ab-e94e-4e0a-a13c-bc54e03f22e5](https://data.nhm.ac.uk/object/e1bfb1ab-e94e-4e0a-a13c-bc54e03f22e5).\
\
Norman, C. F.\
W. (1986) _Corrosion of aluminium._ University of Manchester Press.\
\
Kershaw, R.\
(1999) _Ode to joy: theme and 6 variations on Beethoven’s Ode to joy, in the_\
_style of Bach, Mozart, Mendelssohn, Dvořák, Wagner and Scott_\
_Joplin : string orchestra_. Monmouth: Spartan Press.\
\
Owen, J. C.\
(2009) _Forever Amber : the impact of the Amber Room on Russia’s cultural_\
_stature then, now and in the future_, _Dept. of Art and Art History,_\
_Masters dissertations, 2009._ thesis. Georgetown University. Available at: [https://repository.library.georgetown.edu/handle/10822/552838](https://repository.library.georgetown.edu/handle/10822/552838) (Accessed: 6 February 2021).\
\
Panotis, A. (2016) ‘« Η Θείω\
Πνεύματι κραταιωθείσα Σύνοδος της Κρήτης »’, _Πανώτης_. Available at: [https://www.panotis.gr/index.php/2016/06/29/the-holy-spirit-stressed-summit-of-crete/](https://www.panotis.gr/index.php/2016/06/29/the-holy-spirit-stressed-summit-of-crete/) (Accessed: 6 February 2021).\
\
Paoletti, J. T.\
and Bagemihl, R. (2015) _Michelangelo’s David: Florentine history and civic_\
_identity_. New York: Cambridge University Press. Available at: [https://doi.org/10.1017/CBO9781107338784](https://doi.org/10.1017/CBO9781107338784) (Accessed: 6 February 2021).\
\
Parker, V.\
(2002) _Queen Elizabeth II_. Oxford: Heinemann Library.\
\
Patterson, R.\
(1998) _Butch Cassidy: A Biography._ Lincoln: University of Nebraska\
Press.\
\
Pedersén,\
O. (1986) _Archives and libraries in the City of Assur: a survey of the_\
_material from the German excavations_. Uppsala; Stockholm, Sweden: Uppsala\
University.\
\
Peel, C.\
(tran.) (1999) _Guta Saga: The History of the Gotlanders_. London: Viking\
Society for Northern Research.\
\
Perley, B.\
(2017) ‘Declaration of Independence: The First Public Reading’, _Anthropology_\
_News_, 58(3), pp. e197–e199. doi: [https://doi.org/10.1111/AN.445](https://doi.org/10.1111/AN.445).\
\
Petrocchi, G. and\
Società dantesca italiana (1967) _Le opere di Dante Alighieri:_\
_edizione nazionale_. Milano: Mondadori.\
\
Phialon, L. (2018). _Funerary_\
_Landscapes in Middle Helladic and Early Mycenaean Central Greece: an Update,_\
_Aegeus_ – Society for Aegean Prehistory\
\
Pietrangeli, C.\
(1986) _The Sistine Chapel: the art, the history, and the restoration_.\
New York: Harmony Books.\
\
Pipes, R.\
(1964) _The Formation of the Soviet Union._ Cambridge: Harvard University\
Press.\
\
Poe, E. A.\
(1869) _The Raven_. Glasgow.\
\
Pomeroy, S. B.\
(1984) _Women in Hellenistic Egypt: from Alexander to Cleopatra_. Ann\
Arbor, Michigan: University of Michigan Library.\
\
Poole, J. B.\
and Reed, R. (1962) ‘The Preparation of Leather and Parchment by the Dead Sea\
Scrolls Community’, _Technology and Culture_, 3(1), pp. 1–26. doi: [10.2307/3100798](https://doi.org/10.2307/3100798).\
\
Porter, S.\
(2009) _The Great Plague of London_. Stroud: Amberley Publishing.\
\
Potts, T.\
(2015) _The J. Paul Getty Museum Handbook of the Collection: Eighth Edition_.\
Revised edition. Los Angeles: J. Paul Getty Museum.\
\
Pryor, F.\
(2016) _Stonehenge:The story of a sacred landscape_. London: Head of Zeus.\
\
Psimenos, S.\
(2005) _Unexplored Peloponnese_. Greece: Road Editions.\
\
Raga, S. (2016)\
‘How Michael Jackson Bought the Publishing Rights to The Beatles Catalogue’, _Mental_\
_Floss_, 29 August. Available at: [https://www.mentalfloss.com/article/85007/how-michael-jackson-bought-publishing-rights-beatles-catalogue](https://www.mentalfloss.com/article/85007/how-michael-jackson-bought-publishing-rights-beatles-catalogue) (Accessed: 6 February 2021).\
\
Raymond, L. (2006)\
‘Exxon Mobil Corp.’, _Mergent’s Dividend Achievers_, 3(1), pp. 97–97. doi:\
[https://doi.org/10.1002/div.4323](https://doi.org/10.1002/div.4323).\
\
Reaney, G. (1974) _Guillaume_\
_de Machaut._London: Oxford University Press.\
\
Reid, S. (1993)\
_Ancient Egypt_. London: Belitha.\
\
Reiter, R.\
(1984) ‘Towards a logical reconstruction of relational database theory’, in\
Brodie, M.L., Mylopoulos, J. and Schmidt, J.W. (eds), _On Conceptual_\
_Modelling_, New York: Springer-Verlag, pp. 191–233.\
\
Rieger, B. (2013) _The People’s Car: A Global_\
_History of the Volkswagen Beetle._ Princeton University Press,\
Princeton 2013, [ISBN 978-0-674-05091-4](https://de.wikipedia.org/wiki/Spezial:ISBN-Suche/9780674050914)\
\
Riley, C. and\
Dolling, P. (2009) _Apollo 11 Manual: An Insight into the Hardware from the_\
_First Manned Mission to Land on the Moon_. Reprint edition. Sparkford: J H\
Haynes & Co Ltd.\
\
River, C.\
(2016) _Nineveh: The History and Legacy of the Ancient Assyrian Capital_.\
CreateSpace Independent Publishing Platform.\
\
Robinson, J. M.\
(2000) _Buckingham Palace: The Official Illustrated History_. First\
Edition. London: Royal Collection Trust.\
\
Rolt, L. T. C.\
(1971) _The railway museum, York._ British Railways Board.\
\
Rose, H. et al.\
(1978) _The US dollar and its role as a reserve currency_. British-North\
American Research Association.\
\
Scarratt, K.\
and Shor, R. (2006) ‘The Cullinian Diamond Centennial: A history and\
Gemological Analysis of Cullinians’, _Gems & Gemology_, 42(2), pp.\
120–132.\
\
Shaw, I. (2000)\
_The Oxford history of ancient Egypt_. Oxford; New York: Oxford University\
Press.\
\
Shipway, J. S.,\
Bouch, T., Baker, B. and Fowler, J. (1990) ‘The Forth Railway Bridge Centenary\
1880-1990: Some Notes on its Design’, _Proceedings of the Institution of_\
_Civil Engineers_, 88(6), pp. 1079–1107.\
\
Siegler, M. A.\
and Smrekar, S. E. (2014) ‘Lunar heat flow: Regional prospective of the Apollo\
landing sites’, _Journal of Geophysical Research: Planets_, 119(1), pp.\
47–63.\
\
Sinkevičius,\
S. and Naruševičius, V. (2002) ‘Investigation of anaphase aberrations\
in Chaffinch (Fringilla coelebs Linnaeus, 1758) populations from different\
regions of Lithuania’, _Acta zoologica Lituanica_, 12(1), pp. 3–9.\
\
Sitwell, S.\
(2017) _Mozart_. London: Bello.\
\
Smith, B. and\
Varzi, A. C. (2000) ‘Fiat and bona fide boundaries’, _Philosophical and phenomenological_\
_research_, pp. 401–420.\
\
Smith, W.\
(1844) _Dictionary of Greek and Roman biography and mythology._ London:\
Taylor and Walton.\
\
Solomon, B.\
(2003) _Railway Masterpieces_. David & Charles.\
\
Spiers, A. and\
Surenne, G. (1854) _The standard pronouncing dictionary of the French and_\
_English languages_. New York: Appleton.\
\
Steinbeck, J.\
(2000) _The Log from the Sea of Cortez_. New York.\
\
Stevenson, R.\
L., Morrison, W. and Mann, W. W. (1909) _Doktoro Jekyll kaj Sinjoro Hyde_.\
London: The British Esperanto Association.\
\
Stoneman, R.\
(2004) _Alexander the Great_. London; New York: Routledge.\
\
Strano, T. (1953) _Leonard da_\
_Vinci_. Milano.\
\
Strauss, W. L.\
(1974) _The Complete Drawings of Albrecht Dürer: 1520-1528_. Abaris\
Books.\
\
Strong, R.\
(2005) _Coronation: a history of kingship and the British monarchy_.\
Harpercollins Pub Limited.\
\
Syrmas, A.\
(1896) _Account Book of ship D.S.Skyliytsis 28/9/1895-19/10/1896 Captain_\
_A.Syrmas_, Book no5; Inventory Number A.E 53/01, Hellenic Literary and\
Historical Archive (E.L.I.A), Athens. See also: “Archival Corpus” of the\
European SEALIT project ([http://www.sealitproject.eu/archival-corpus](http://www.sealitproject.eu/archival-corpus)).\
\
Temperton, P.\
(1997) _The euro_. Chichester: Wiley.\
\
Temple, R. and\
Temple, O. (2009) _The Sphinx Mystery: The Forgotten Origins of the Sanctuary_\
_of Anubis_. Rochester, Vt: Inner Traditions.\
\
_The Oxford_\
_English Dictionary: 20 Volume Set_. Second Edition\
(1989). Oxford, New York: Oxford University Press.\
\
Thieberger, F.\
(1947) _King Solomon_. Oxford.\
\
Thomas, J.\
(1972) _The Tay Bridge disaster: new light on the 1879 tragedy_. Douglas David & Charles.\
\
Tissandier, G.\
(1889) _La tour Eiffel de 300 mètres: description du monument, sa_\
_construction, ses organes mécaniques, son but et son utilité_.\
Paris: G. Masson.\
\
Trell, B. L.\
(1945) ‘The temple of Artemis at Ephesos’, _Numismatic Notes and Monographs_,\
(107), pp. ii–71.\
\
Unger, H. G.\
(2015) _Mr. President George Washington and the Making of the Nation’s_\
_Highest Office._ Cambridge; New York: Da Capo Press, Incorporated Perseus\
Books Group.\
\
United Nations\
Security Council (2002) _Resolution 1441_. Resolution. United Nations\
Security Council. Available at: [http://digitallibrary.un.org/record/478123](http://digitallibrary.un.org/record/478123) (Accessed: 6 February 2021).\
\
Walberg G.\
(1992). The Finds at Tell el-Dabʿa and Middle Minoan Chronology. _Ägypten_\
_und Levante_ / Egypt and the Levant, 157-159.\
\
Walker, M. et\
al. (2009) ‘Formal definition and dating of the GSSP (Global Stratotype Section\
and Point) for the base of the Holocene using the Greenland NGRIP ice core, and\
selected auxiliary records’, _Journal of Quaternary Science: Published for_\
_the Quaternary Research Association_, 24(1), pp. 3–17.\
\
Walker, S.\
(2004) _The Portland vase_. London: British Museum Press.\
\
Watrous, L. V. et al. (2012) _Archaeological Survey of the Gournia Landscape: A Regional_\
_History of the Mirabello Bay, Crete, in Antiquity_. INSTAP Academic Press\
(Institute for Aegean Prehistory).\
\
Watson, M. J.\
(1990) _Cluster compounds of gold and the platinum metals._ Ph.D.\
University of Oxford. Available at: [https://ethos.bl.uk/OrderDetails.do?uin=uk.bl.ethos.279996](https://ethos.bl.uk/OrderDetails.do?uin=uk.bl.ethos.279996) (Accessed: 6 February 2021).\
\
Wheat, C.\
(2005) ‘The Real Queen(s) of Crime’, _CLUES: A Journal of Detection_, 23,\
pp. 86–90. doi: [doi:10.3200/CLUS.23.4.87-90](https://doi.org/doi:10.3200/CLUS.23.4.87-90).\
\
Whittington, H.\
(1964) _The fall of the Roman Empire_. Greenwich, Conn.: Fawcett.\
\
Wicks, R.\
(2014) _Heathrow Airport Manual: Designing, building and operating the_\
_world’s busiest international airport (Haynes Manual) (Airfield Operations_\
_Manual) by Robert Wicks (2014) Hardcover_. UK: Haynes Publishing.\
\
Wiencke, M.\
(1998) ‘Johann Winckelmann \| German art historian’, _Encyclopedia Britannica_.\
Available at: [https://www.britannica.com/biography/Johann-Joachim-Winckelmann](https://www.britannica.com/biography/Johann-Joachim-Winckelmann) (Last edit: 5 December 2020. Accessed: 5 February 2021).\
\
Wikipedia\
(2021) _‘Et in Arcadia ego’_. Available at: [https://en.wikipedia.org/w/index.php?title=Et\_in\_Arcadia\_ego&oldid=1003943423](https://en.wikipedia.org/w/index.php?title=Et_in_Arcadia_ego&oldid=1003943423) (Accessed: 5 February 2021).\
\
Wikipedia (2022a) ‘Battle of\
Hastings’, _Wikipedia; The Free Encyclopedia_. Available at: [https://en.wikipedia.org/wiki/Battle\_of\_Hastings](https://en.wikipedia.org/wiki/Battle_of_Hastings)\
(Accessed: 19 May 2022).\
\
Wikipedia (2022b) ‘Battle of the\
Catalaunian Plains’, _Wikipedia; The Free Encyclopedia_. Available at: [https://en.wikipedia.org/wiki/Battle\_of\_the\_Catalaunian\_Plains](https://en.wikipedia.org/wiki/Battle_of_the_Catalaunian_Plains)\
(Accessed: 19 May 2022).\
\
Wildfang, F. B.\
(2005) _Lake Havasu City_. Charleston SC: Arcadia.\
\
Willis, S.\
(2010) _The ‘Fighting Temeraire’: Legend of Trafalgar_. edition. London:\
Quercus.\
\
Williams, A. S.\
(1993) _The Greeks._ Wayland.\
\
Williams, J.\
(2020) _Goethe’s Faust_. London: Routledge. doi: [10.4324/9781003006121](https://doi.org/10.4324/9781003006121).\
\
Wilson, M.\
(1994) _The Impressionists_. Reprint edition. Oxford England; New York:\
\[New York\]: Phaidon Press.\
\
Woelkerling, W.\
J., Gustavsen, G. and Myklebost, H. E. (2005) _The coralline red algal_\
_herbarium of Mikael Foslie: revised catalogue with analyses_. Trondheim:\
Kgl. Norske videnskabers selskab, Museet.\
\
Wolff, A.,\
Gaertner, R. and Maranuk-Rohmeder, M. (1999) _The Cologne Cathedral_.\
Verlag Kolner Dom.\
\
Yakel, E.\
(2000) ‘Museums, Management, Media, and Memory: Lessons from the Enola Gay\
Exhibition’, _Libraries and Culture_, 35, pp. 278–310.\
\
Yerkes, D.\
(1989) _Webster’s Encyclopedic Unabridged Dictionary of the English Languagea_.\
Abridged edition. New York: Random House.\
\
YouInGreece.com.\
(2020) ‘Venetian Walls of Heraklion’, _YouInGreece.com_. Available at: [https://youingreece.com/heraklion/venetian-walls](https://youingreece.com/heraklion/venetian-walls) (Accessed: 5 February 2021).\
\
# Appendix\
\
## Deprecated classes and properties\
\
The following is a list of classes and/or properties that have been\
deprecated between the version 5.0.4 of the CIDOC CRM, which served as\
community draft for ISO21127:2014, and this release (7.1.3). While the CIDOC\
CRM is developed with the principle of monotonic change, attempting to minimize\
backwards incompatibility through conservative initial modelling as well as\
modelling evolution, certain revisions inevitably entail changes to the model\
which will require an update to knowledge bases based on old versions of the\
ontology, in order to reconcile instances with the current version. The\
following tables provide information on which classes or properties have been\
deprecated and will thus require an update to previous official CRM compliant\
KBs in order to be in accord with the latest version of the standard. The\
reader will find in the first table, "Deprecated Class Migration\
Instructions", classes that have been deprecated and the suggested class\
or primitive replacement for that class. The reader should further refer to the\
'deprecated property migration instructions table' in order to see not only the\
replacements for deprecated properties but also to understand how to build\
correct new semantic paths between the instances of deprecated classes and the\
newly suggested replacement classes or primitives. Finally, there are migration\
instructions where the range of a property has been reduced to a subclass of\
the previous range.\
\
### Deprecated Class Migration Instructions\
\
Table 6:\
Deprecated Class Migration Instructions\
\
|     |     |\
| --- | --- |\
| **Deprecated Class** | **Migration Instruction** |\
| E38 Image | use [E36](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7971)Visual Item |\
| E40 Legal Body | use [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group |\
| E44 Place Appellation | use [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation |\
| E45 Address | use [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation, [_P2_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8844) _has type_: “Address” |\
| E46 Section Definition | use [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation |\
| E47 Spatial Coordinates | use [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8709) Space Primitive |\
| E48 Place Name | use [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation |\
| E49 Time Appellation | use [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation |\
| E50 Date | use [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8263) Time Primitive |\
| E51 Contact Point | use [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation, [_P2_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8844) _has type_: “Contact Point” |\
| E75 Conceptual Object Appellation | use [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation |\
| E82 Actor Appellation | use [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039) Appellation |\
| E84 Information Carrier | use [E22](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7751) Human-Made Object, [_P2_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8844) _has type_:<br>“Information Carrier” |\
\
### Deprecated Property Migration Instructions\
\
Table 7:\
Deprecated Property Migration Instructions\
\
|     |     |\
| --- | --- |\
| **Deprecated property** | **Migration Instruction** |\
| _P58 has section definition (defines_<br>_section)_ | use[_P1_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) _is identified by (identifies)_ |\
| _P78 is identified by (identifies):_ E49 Time Appellation<br>\[except for instances of E50 Date\] | use [_P1_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819)_identified by (identifies):_[E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039)<br>Appellation \[for instance, Japanese imperial rule names\] |\
| _P78 is identified by (identifies):_ E50 Date | use [_P170i_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11400) _time is defined by_: [E61](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8226)Time Primitive |\
| _P88 consists of (forms part of)_ | If used as a geometric<br>decomposition, use [_P89i_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10142) _contains_.<br>If the respective place is<br>defined in the source by an instance of [E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7791) Physical Feature, and the use of _P88 consists of_<br>aims at describing its decomposition into its natural components, describe<br>explicitly in the migration target the instance of [E26](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7791) Physical Feature and its parts using [_P46_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9643) _is composed of_ |\
| _P83 had at least duration (was minimum_<br>_duration of)_<br>and<br>_P84 had at most duration (was maximum_<br>_duration of)_ | use [_P191_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11843) _had duration (was duration of)_:<br>The instances of [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8250) Number in the full source paths: [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span _. P83 had at least_<br>_duration._[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128) Dimension _._[_P90_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10161) _has value._ [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8250) Number and in [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span _. P84 had at most duration._[E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128) Dimension _._[_P90_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10161) _has value._ [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8250) Number <br>should both be merged in the<br>migration target path into one numerical interval, instance of [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8250) Number:<br>[E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span _._[_P191_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11802) _had duration._ [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128) Dimension _._[_P90_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10161) _has value._ [E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8250) Number<br>For representing intervals in<br>RDF/OWL encoding see the respective implementation guidelines. |\
| _P87 is identified by (identifies)_: E44 Place Appellation(except for<br>instances of E47 Spatial Coordinates) | use [_P1_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) _identified_<br>_by (identifies)_: [E41](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8039)<br>Appellation |\
| _P87 is identified by (identifies)_: E47 Spatial Coordinates | use [_P168i_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11363) _defines place_: [E94](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8709) Space Primitive |\
| _P114 is equal in time to\*_ | use the fully developed path<br>from [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7256) Temporal Entity through [_P4_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8889) _has time-span_, [E52](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8080) Time-Span, [_P4_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8889) _i is time-span of,_ to [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7256) Temporal Entity.<br>Theoretically, _P114 is_<br>_equal in time to_ is equal to the conjunction of: _(_[_P175_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11548) _starts before or with the_<br>_start of_ and[_P175_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11548) _i starts after or with the start of_ and[_P184_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11706) _ends before or with the end of_ and[_P184_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11706) _i ends with or after the end of),_ without fuzzy temporal<br>boundaries. However, note that only a common cause or a socially declared<br>time-span can lead to temporal equality of different instances of [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7256) Temporal Entity. Consequently, creating<br>the full path is always the preferred migration strategy. |\
| _P115 finishes (is finished by) \*_ | [_P176_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11573) _i starts after the start of_ and[_P184_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11706) _ends before or with the end of_ and[_P184_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11706) _i ends with or after the end of_\[[_P176_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11573) _i starts after the start of_ is required because the Range<br>[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7256) Temporal Entity must be<br>longer than the Domain [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7256) Temporal Entity\] |\
| _P116 starts (is started by) \*_ | [_P175_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11548) _starts before or with the_<br>_start of_ and _P175i starts after or with_<br>_the start of_ and[_P185_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11731) _ends before the end of_ \[[_P185_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11731) _ends before the end of_ is required because the Range<br>[E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7256) Temporal Entity must be<br>longer than the Domain [E2](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7256) Temporal Entity\] |\
| _P117 occurs during (includes) \*_ | [_P176_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11573) _i starts after the start of_ and[_P185_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11731) _ends before the end of_ |\
| _P118 overlaps in time with (is overlapped_<br>_in time by) \*_ | [_P176_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11573) _starts before the start of_ and[_P185_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11731) _ends before the end of_ |\
| _P119 meets in time with (is met in time_<br>_by) \*_ | use [_P182_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11652) _ends before or with the start of_ and[_P173_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11495) _i ends after or with the_<br>_start of_ |\
| _P120 occurs before (occurs after) \*_ | use [_P183_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11679) _ends before the start of_ |\
| _P131 is identified by (identifies)_ | use [_P1_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) _identified by (identifies)_ |\
| _P149 is identified by (identifies)_ | use [_P1_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8819) _identified by (identifies)_ |\
| _P178 ends after or with (ends before or_<br>_at the end of)_ | use [_P184_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11706) _i ends with or after the end of_ instead |\
| _P181 has amount_ | [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8128) Dimension. [_P90_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10207) _has value_:[E60](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8250) Number instead |\
\
\*The\
properties P114 to P120 have been introduced in the CIDOC CRM extension\
“Definition of the CRMarchaeo. An Extension of CIDOC CRM to support the\
archaeological excavation process”, Version 1.5.1, March 2021.\
\
#### Migration Instructions for the reduced scope of  [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html\#_toc8541) Transformation\
\
From version 7.1.1 on, the class [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8581) Transformation\
pertains only to instances of [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical Thing, rather than to instances of [E77](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8517) Persistent\
Item. The reason is the insight that only for physical things the form previous\
to a transformation must cease to exist. For instances of [E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7737) Conceptual Object, any number of copies can be around that\
are not affected by the transformation. Similarly, transformations of instances\
of [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8492) Group do not necessarily cause the dissolution of the\
previous grouping.\
\
Therefore, the properties [_P123_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10694) _resulted in (resulted from)_ and [_P124_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10713) _transformed (was transformed by) now_ have the range: [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7650)Physical Thing.\
\
If these properties were applied in the source\
to instances of [E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7825) Conceptual Object or its subclasses, use in the migration\
target [E65](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8333) Creation\
instead of [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8581)\
Transformation, [_P94_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10286) _has created (was created by)_ instead of [_P123_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10694) _resulted in_\
_(resulted from),_ and [_P16_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9122) _used specific_\
_object (was used for)_ instead of [_P124_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10713) _transformed (was_\
_transformed by)._\
\
If these properties were applied in the source\
to instances of [E74](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8403) Group, use in the migration target [E66](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8349) Formation instead of [E81](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8581) Transformation, [_P95_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10306) _has formed (was_\
_formed by)_ instead of [_P123_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10694) _resulted in_\
_(resulted from),_ and [_P151_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11213) _was formed from_\
_(participated in)_ instead of [_P124_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc10713) _transformed (was_\
_transformed by)._\
\
#### Migration Instructions for the reduced scope of  [E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html\#_toc7578) Measurement\
\
From version 7.1.1 on, the class [E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7578) Measurement pertains only to instances of [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7610) Physical Thing,\
rather than to instances of [E1](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7226)\
CRM Entity. The reason is twofold. Firstly, the property [_P43_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9592) _has dimension (is dimension of)_\
associates a dimension only with [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8368) Thing, and thereby only allows for\
documenting the results of the measuring of instances of [E70](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8368) Thing. Secondly, in the narrower sense,\
only physical things can be observed for quantitative measurements, but\
instances of [E54](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8088)\
Dimension, in particular for instances of [E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7785) Conceptual Object, may be inferred by\
other forms of [E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7522)\
Attribute Assignment, such as data evaluation. Therefore, the property [_P39_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9517) _measured_\
_(was measured by)_ now has the range: [E18](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7610) Physical Thing.\
\
If this property was applied in the source to instances of [E28](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7785) Conceptual Object\
or its subclasses, use in the migration target [E13](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7522) Attribute Assignment instead of [E16](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc7578) Measurement, [_P140_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11014) _assigned attribute to (was attributed by)_ instead of [_P39_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9517) _measured (was measured by)_, [_P141_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11035) _assigned (was assigned by)_ instead of [_P40_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc9534) _observed dimension (was observed_\
_in),_ and [_P177_](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc11558) _assigned property of type (is type of property assigned)_:“P43 has\
dimension (is dimension of)” ( [E55](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_toc8064)).\
\
## Amendments\
\
The amendments can be found in “Amendments of the CIDOC: Conceptual\
reference Model ver. 7.1.1: volume B”.\
\
* * *\
\
[\[1\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftnref1 "") The\
ICOM Statutes provide a definition of the term “museum” at\
http://icom.museum/statutes.html#2\
\
[\[2\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftnref2 "") The practical\
scope of the CIDOC CRM, including a list of the relevant museum documentation\
standards, is discussed in more detail on the CIDOC CRM website at < [https://cidoc-crm.org/scope.html](https://cidoc-crm.org/scope.html)\
>.\
\
[\[3\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftnref3 "")\
Information about the Resource Description Framework (RDF) can be found at\
http://www.w3.org/RDF/\
\
[\[4\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftnref4 "") Nicola\
Guarino defines a formal ontology as a specification of a set of named concepts\
used to describe and approximate a part of reality, plus a first-order logical\
theory narrowing down the intended meaning of the named concepts.\
\
[\[5\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftnref5 "") For\
the readers interested in computer science and logic, the syntax and formal\
semantics employed by the CIDOC CRM are given in (Meghini & Doerr 2018),\
where the computational aspects are also discussed.\
\
[\[6\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftnref6 "") The URI\
(instance of E41 Appellation) of the Library of Congress for Tut-Ankh-Amun, the\
pharaoh.\
\
[\[7\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftnref7 "")\
Statements in a KB may be in contradiction to the ontologically defined\
quantification of properties without the KB being broken or invalid in any\
sense, either because necessary properties are unknown or there exist good\
reasons to assume alternative values for properties with limited cardinality,\
be it by the same or by different maintainers.\
\
[\[8\]](https://cidoc-crm.org/sites/default/files/Documents/cidoc_crm_version_7.1.3.html#_ftnref8 "") This holds for applications in the scope of the\
CIDOC CRM, which are in the non-relativistic area, but not strictly, for\
instance, for satellites.